/// <reference path="pages/saleorder/saleorder.component.ts" />
import { NgModule } from "@angular/core";
import { Routes, RouterModule } from "@angular/router";
import { LoginComponent } from "./pages/login/login.component";
import {
  AuthLoggedIn,
  AuthGuard,
  AuthLoad,
  AuthGuardWithRefresh,
} from "./core/auth-guard.service";
import { PortalComponent } from "./pages/portal/portal.component";
import { MainComponent } from "./pages/main/main.component";
import { ChangePasswordComponent } from "./pages/changepwd/changepwd.component";
import { NotFoundComponent } from "./pages/404/notfound.component";
import { MaintenanceComponent } from "./pages/maintenance/maintenance.component";
//import { AutoCompleteComponent } from './components/shared/autoComplete/auto-complete.component';

const routes: Routes = [
  {
    path: "",
    redirectTo: "login",
    pathMatch: "full",
  },
  {
    path: "login",
    component: LoginComponent,
    canActivate: [AuthLoggedIn],
  },
  {
    path: "changepwd",
    component: ChangePasswordComponent,
  },
  { path: "404", component: NotFoundComponent },
  {
    path: "main",
    component: MainComponent,
    canActivate: [AuthGuardWithRefresh],
  },
  {
    path: "maintenance",
    component: MaintenanceComponent,
  },
  {
    path: "SaleOrder",
    loadChildren: () =>
      import("./modules/saleorder/saleorder.module").then(
        (m) => m.SaleOrderModule
      ),
    canLoad: [AuthLoad],
  },
  {
    path: "WareHouse",
    loadChildren: () =>
      import("./modules/warehouse/warehouse.module").then(
        (m) => m.WareHouseModule
      ),
    canLoad: [AuthLoad],
  },
  {
    path: "Purchase",
    loadChildren: () =>
      import("./modules/purchase/purchase.module").then(
        (m) => m.PurChaseModule
      ),
    canLoad: [AuthLoad],
  },
  {
    path: "Receipt",
    loadChildren: () =>
      import("./modules/receipt/receipt.module").then((m) => m.ReceiptModule),
    canLoad: [AuthLoad],
  },
  {
    path: "PriceRevision",
    loadChildren: () =>
      import("./modules/pricerevision/pricerevision.module").then(
        (m) => m.PriceRevisionModule
      ),
    canLoad: [AuthLoad],
  },
  {
    path: "PS_DeadStock",
    loadChildren: () =>
      import("./modules/ps_deadstock/ps_deadstock.module").then(
        (m) => m.PS_DeadStockModule
      ),
    canLoad: [AuthLoad],
  },
  {
    path: "Inventory",
    loadChildren: () =>
      import("./modules/inventory/inventory.module").then(
        (m) => m.InventoryModule
      ),
    canLoad: [AuthLoad],
  },
  {
    path: "PS_SCG_GestOrder",
    loadChildren: () =>
      import("./modules/ps_scg_gest_order/ps_scg_gest_order.module").then(
        (m) => m.PS_SCG_GestOrderModule
      ),
    canLoad: [AuthLoad],
  },
  {
    path: "Inventory_Control_Common",
    loadChildren: () =>
      import(
        "./modules/inventory_control_common/inventory_control_common.module"
      ).then((m) => m.Inventory_Control_CommonModule),
    canLoad: [AuthLoad],
  },
  {
    path: "Master",
    loadChildren: () =>
      import("./modules/master/master.module").then((m) => m.MasterModule),
    canLoad: [AuthLoad],
  },
  {
    path: "MKT",
    loadChildren: () =>
      import("./modules/mkt/mkt.module").then((m) => m.MKTModule),
    canLoad: [AuthLoad],
  },
  {
    path: "Accounting",
    loadChildren: () =>
      import("./modules/accounting/accounting.module").then(
        (m) => m.AccountingModule
      ),
    canLoad: [AuthLoad],
  },
  {
    path: "ExportBiz",
    loadChildren: () =>
      import("./modules/exportbiz/exportbiz.module").then(
        (m) => m.ExportBizModule
      ),
    canLoad: [AuthLoad],
  },
  {
    path: "DomSales",
    loadChildren: () =>
      import("./modules/domsales/domsales.module").then(
        (m) => m.DomSalesModule
      ),
    canLoad: [AuthLoad],
  },
  {
    path: "K9",
    loadChildren: () =>
      import("./modules/k9/k9.module").then((m) => m.K9Module),
    canLoad: [AuthLoad],
  },
  {
    path: "report",
    loadChildren: () =>
      import("./modules/report/report.module").then((m) => m.ReportModule),
    canActivate: [AuthGuard],
  },
  {
    path: "Technical",
    loadChildren: () =>
      import("./modules/technical/technical.module").then(
        (m) => m.TechnicalModule
      ),
    canActivate: [AuthGuard],
  },
  {
    path: "MA",
    loadChildren: () =>
      import("./modules/ma/ma.module").then((m) => m.MAModule),
    canActivate: [AuthGuard],
  },
  {
    path: "reportviewer",
    loadChildren: () =>
      import("./modules/report-viewer/report-viewer.module").then((m) => m.ReportViewerModule),
    canActivate: [AuthGuard],
  },
  {
    path: "Monitoring",
    loadChildren: () =>
      import("./modules/monitoring/monitoring.module").then(
        (m) => m.MonitoringModule
      ),
    //canLoad: [AuthLoad],
  },
  {
    path: "document",
    loadChildren: () =>
      import("./modules/document/document.module").then(
        (m) => m.DocumentModule
      ),
    canLoad: [AuthLoad],
  },
  {
    path: "icms",
    loadChildren: () =>
      import("./modules/icms/icms.module").then(
        (m) => m.ICMSModule
      ),
    canLoad: [AuthLoad],
  },
  {
    path: "demo",
    loadChildren: () =>
      import("./demo/demo.module").then(
        (m) => m.DemoModule
      ),
    canLoad: [AuthLoad],
  },
  {
    path: "**",
    redirectTo: "/404",
    pathMatch: "full",
  },
];

@NgModule({
  imports: [RouterModule.forRoot(routes, {useHash: true})],
  exports: [RouterModule],
})
export class AppRoutingModule {}
