import { Component, OnInit, Input, OnChanges, ContentChild, TemplateRef, Output, EventEmitter, ViewChild, SimpleChanges, ContentChildren, NgZone } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { MatTable, MatTableDataSource } from '@angular/material/table';
import { MatPaginator } from '@angular/material/paginator';
import { MatSort, Sort } from '@angular/material/sort';
import { CdkDragDrop, moveItemInArray } from '@angular/cdk/drag-drop';
import { Globals } from 'src/app/core/global';
import { filter, take } from 'rxjs/operators';
import { Subject } from 'rxjs';

/**
 * How to use the table?
 * you can just add element into yout html
 * @param {string} tableName Field TABLE_NAME.
 * @param {Array<any>} tableData Detail row list in table.
 * @param {Array<any>} tableHeader
 * @param {Array<any>} tableFooter show footer
 * @param {boolean} showPagination
 * @param {boolean} sortTable
 * @param {string} stickyCol
 * @param {string} stickyEndCol
 * @event editClick($event) Send function name to this for Edit button action.
 * 
 * @tableFooter param list
 *  1. fieldName: show under the header fieldName
 *  2. show: true | false (show column in footer)
 *  3. value: fix value of the field (If not defined, table will sum field value)
 * 
 * you can custom condition to show another value inside the column
 * @var {object} header Current header row
 * @var {object} data Current data row
 * @description<ng-template let-header="header" let-data="data">
 * @description--> insert your condition
 * @description</ng-template>
 */

@Component({
  selector: 'auto-table-reorder',
  templateUrl: './auto-table-reorder.component.html',
  styleUrls: ['./auto-table-reorder.component.scss']
})
export class AutoTableeorderComponent implements OnChanges {
  public headerList: Array<any> = [];
  public dataList: any;
  public displayedColumns: string[] = [];
  public displayFooter: Array<any> = [];
  public isCustomContent: boolean = false;
  public isCustomHeader: boolean = false;
  public templateBody: TemplateRef<any>;
  public templateHeader: TemplateRef<any>;

  public progressBar: any;
  public showProgressBar: boolean = false;
  public showNoRecord: boolean = false;
  private dataTypes: Array<string> = [];
  public _filter: any = {};

  public i: number;
  private tableFooterChanged: Subject<Array<any>> = new Subject<Array<any>>();

  @Input("tableName") tableName: string;
  @Input("tableData") tableData: Array<any> = [];
  @Input("tableHeader") tableHeader: Array<any> = [];
  @Input("tableFooter") tableFooter: Array<any> = [];
  @Input("maxHeight") maxHeight: string = "45vh";
  //@Input("editIcon") editIcon: string = "edit";
  //@Output("editClick") editClick = new EventEmitter<any>();

  @ContentChildren(TemplateRef) templateRef;
  //@ViewChild("table") table: any;
  @ViewChild(MatPaginator, { static: true }) paginator: MatPaginator;
  @ViewChild(MatSort, { static: true }) sort: MatSort;
  @ViewChild('table') table: MatTable<any>;
  constructor(
    private http: HttpService,
    public global: Globals,
    private ngZone: NgZone
  ) { }

  ngOnInit(): void {
    if (this.tableName) {
      this.getTableHeader();
    } else if (this.tableHeader.length > 0) {
      this.headerList = this.tableHeader;
      this.ArrangeShowColumn(this.headerList);
    }
  }

  ngOnChanges(changes: SimpleChanges): void {
    if (!changes["tableData"].isFirstChange() && this.tableData) {
      if (this.tableData.length === 0) {
        if (!this.showProgressBar) {
          this.loading();
        } else {
          this.unloading();
          this.showNoRecord = true;
        }
      } else {
        this.unloading();
      }
    }

    this.dataList = this.tableData//new MatTableDataSource<any>(this.tableData || []);

    // this.tableFooterChanged.next(this.tableFooter);

    // this.dataList.filterPredicate = (data, filterObject: string): boolean => {
    //   const filters: any = JSON.parse(filterObject);

    //   return Object.keys(filters)
    //     .map(column => (data[column] || "").toString().includes(filters[column].toString()))
    //     .reduce((acc: boolean, curr: boolean) => (acc == curr) && acc, true);
    // };
    // this.dataList.filter = JSON.stringify(this._filter);

    this.ArrangeShowColumn(this.headerList);

  }

  ngAfterContentInit(): void {
    this.isCustomContent = false;
    this.isCustomHeader = false;
    if (this.templateRef) {
      if (this.templateRef.length == 1) {
        this.isCustomContent = true;
        this.templateBody = this.templateRef._results[0];
      } else if (this.templateRef.length == 2
        && this.templateRef._results.find(t => t._declarationTContainer?.localNames?.includes("tblHeader"))
        && this.templateRef._results.find(t => t._declarationTContainer?.localNames?.includes("tblBody"))) {
        let headerIndex = this.templateRef._results.findIndex(t => t._declarationTContainer?.localNames?.includes("tblHeader"));
        let bodyIndex = this.templateRef._results.findIndex(t => t._declarationTContainer?.localNames?.includes("tblBody"));
        this.isCustomContent = true;
        this.isCustomHeader = true;
        this.templateHeader = this.templateRef._results[headerIndex];
        this.templateBody = this.templateRef._results[bodyIndex];
      }
    }
  }

  ngAfterViewChecked() {
    this.ngZone.onMicrotaskEmpty.pipe(take(3)).subscribe(() => this.table.updateStickyColumnStyles());
    
  }

  public AutodropTable() {
    moveItemInArray(this.dataList, 0, this.dataList.length);
    this.table.renderRows();
  }
  
  dropTable(event: CdkDragDrop<any[]>) {
    const prevIndex = this.dataList.findIndex((d) => d === event.item.data);
    moveItemInArray(this.dataList, prevIndex, event.currentIndex);
    this.table.renderRows();
    }

  getTableHeader() {
      this.http.get("System", "GetHeaderGridView", this.tableName)
      .subscribe(result => {
        this.headerList = result.filter(v => v.VISIBILITY === true);
        
        //Change footer for header column map
        this.tableFooterChanged.next(this.tableFooter);

        this.ArrangeShowColumn(this.headerList);
      })
  }


  // editBtnClick(item: any) {
  //   this.editClick.emit(item);
  // }

  loading(isFirstCall: boolean = false) {
    this.showProgressBar = true;
    this.showNoRecord = false;

    clearTimeout(this.progressBar);

    this.progressBar = setTimeout(() => {
      this.showProgressBar = false;

      if (!isFirstCall && this.tableData.length === 0) {
        this.showNoRecord = true;
      }
    }, 5000);
  }

  unloading() {
    clearTimeout(this.progressBar);
    this.showProgressBar = false;
    this.showNoRecord = false;
  }


  ArrangeShowColumn(data) {
    this.displayedColumns = data.map(v => v.FIELD_NAME);
  }

  public CheckIsFinite(value: number) {
    return Number.isFinite(value);
  }
}
