import { Component, OnInit, Input, Output, EventEmitter } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { FormGroup, FormControl } from '@angular/forms'
import { Router } from '@angular/router';
import { Observable, config } from 'rxjs';
import { MomentDateAdapter } from '@angular/material-moment-adapter';
import { DateAdapter, MAT_DATE_FORMATS, MAT_DATE_LOCALE } from '@angular/material/core';
import { MatDatepicker } from '@angular/material/datepicker';


import * as moment from 'moment';

export const MY_FORMATS = {
  parse: {
    dateInput: 'MM/YYYY',
  },
  display: {
    dateInput: 'MM/YYYY',
    monthYearLabel: 'MM/YYYY',
    dateA11yLabel: 'LL',
    monthYearA11yLabel: 'MMMM YYYY',
  },
};

@Component({
  selector: 'data-month',
  templateUrl: './data-month.component.html',
  styleUrls: ['./data-month.component.css'],
   providers: [
    { provide: DateAdapter, useClass: MomentDateAdapter, deps: [MAT_DATE_LOCALE] },
    { provide: MAT_DATE_FORMATS, useValue: MY_FORMATS },
  ],
})

export class DataMonthComponent implements OnInit {

  constructor(
    private http: HttpService,
    private router: Router
  ) { }

  @Input() config: any;
  @Input() data: any;
  @Output() datefromchange = new EventEmitter<any>();
  @Output() datetochange = new EventEmitter<any>();
  @Input() datefrom: any;
  @Input() dateto: any;

  public datasent: any;
  public states: any;
  public setting: any;
  myControl = new FormControl();
  filteredOptions: Observable<string[]>;

  dateFrom = new FormControl(moment());
  dateTo = new FormControl(moment());

  //public dateFrom: any = moment();

  public isReadOnly: any = true;

  ngOnInit() {

    //let my = new Date(this.datefrom);
    //let newdate = _moment(my);
    //console.log('datefrom', newdate);
    //this.dateFrom.setValue(newdate);
    let date: any = new Date();

    this.setting = {
      minDate: date,
      maxDate: date
    }

    if (this.config) {
      for (const key in this.config) {
        if (this.setting.hasOwnProperty(key) && this.config[key] !== undefined) {
          this.setting[key] = this.config[key]
        }
      }
    }

         
  }
 
  chosenYearFrom(normalizedYear: moment.Moment) {
    const ctrlValue = this.dateFrom.value;
    ctrlValue.year(normalizedYear.year());
    this.dateFrom.setValue(ctrlValue);
  }

  chosenMonthFrom(normalizedMonth: moment.Moment, datepicker: MatDatepicker<moment.Moment>) {
    const ctrlValue = this.dateFrom.value;
    ctrlValue.year(normalizedMonth.year());
    ctrlValue.month(normalizedMonth.month());
    this.dateFrom.setValue(ctrlValue);

    this.setting.minDate = new Date(this.dateFrom.value);
    let dt = new Date(this.dateFrom.value);
    this.datefrom = this.getFormateDate(dt);
    this.datefromchange.emit(this.datefrom)

    datepicker.close();
  }

  chosenYearTo(normalizedYear: moment.Moment) {
    const ctrlValue = this.dateTo.value;
    ctrlValue.year(normalizedYear.year());
    this.dateTo.setValue(ctrlValue);
  }

  chosenMonthTo(normalizedMonth: moment.Moment, datepicker: MatDatepicker<moment.Moment>) {
    const ctrlValue = this.dateTo.value;
    ctrlValue.year(normalizedMonth.year());
    ctrlValue.month(normalizedMonth.month());
    this.dateTo.setValue(ctrlValue);

    this.setting.maxDate = new Date(this.dateTo.value);
    let dt = new Date(this.dateTo.value);
    this.dateto = this.getFormateDate(dt);
    this.datetochange.emit(this.dateto)
    datepicker.close();
  }

  OpendateFromPopup(datepicker: MatDatepicker<moment.Moment>) {

    datepicker.open();
  }

  OpendateToPopup(datepicker: MatDatepicker<moment.Moment>) {

    datepicker.open();
  }

  getFormateDate(date) {

    let _date = new Date(date);
    let year = _date.getFullYear()
    let month = _date.getMonth() + 1;
    let _month: any = null;
    if (month < 10) { _month = '0' + month; } else { _month = month }
    return _month + '/' + year

  }
}
