import { PickToken } from "./PickTokenExtractor";
import { PackExportToken } from "./PackTokenExtractor";

type propName = "QR" | "partNo" | "caseNo" | "baBy" | "caseNoExport" | "caseType";

export class InvoiceControl {
	public reset(): void {
		this.QR = null;
		this.caseNo = null;
		this.partNo = null;
		this.latestScanned = null;
	}
	public set(args: InvoiceControlSetValue) {
		if (args.propName == "QR" && args.value instanceof PickToken)
			this.QR = args.value;

		if (args.propName == "caseNo" && args.value instanceof CaseNo)
			this.caseNo = args.value;

		if (args.propName == "partNo" && typeof args.value == "string")
			this.partNo = args.value;

		this.latestScanned = args.propName
	}
	public QR: PickToken;
	public caseNo: CaseNo;
	public partNo: string;
	public latestScanned: propName;
}
export class InvoiceControlSetValue {
	public propName: propName;
	public value: PickToken | CaseNo | string;
}

export class InvoiceExportControl {
	public reset(): void {
		this.QR = null;
		this.caseNoExport = null;
		this.partNo = null;
		this.baBy = null;
		this.caseType = null;
		this.latestScanned = null;
		this.baBy = null;
	}
	public set(args: InvoiceExportControlSetValue) {
		if (args.propName == "QR" && args.value instanceof PackExportToken)
			this.QR = args.value;

		if (args.propName == "caseNoExport" && args.value instanceof CaseNoExport)
			this.caseNoExport = args.value;

		if (args.propName == "partNo" && typeof args.value == "string")
			this.partNo = args.value;

		if (args.propName == "baBy" && typeof args.value == "string")
			this.baBy = args.value;

		if (args.propName == "caseType" && typeof args.value == "string")
			this.caseType = args.value;

		this.latestScanned = args.propName;
	}
	public QR: PackExportToken;
	public caseNoExport: CaseNoExport;
	public partNo: string;
	public baBy: string;
	public caseType: string;
	public latestScanned: propName;
}
export class InvoiceExportControlSetValue {
	public propName: propName;
	public value: PackExportToken | CaseNoExport | string;
}

export class CaseNo {
	public constructor(caseno: string, casedate: string, casetype?:'BOX' | 'BAG') {
		this.caseNo = caseno;
		this.caseDate = casedate;
		
		if(casetype)
			this.caseType = casetype;
	}
	
	public caseNo: string;
	public caseDate: string;
	public caseType?: 'BOX' | 'BAG';
}
export class CaseNoExport {
	public constructor(
		customercode?: string,
		customername?: string,
		branchcode?: string,
		branchname?: string,
		ordertype?: string,
		caseno?: string,
		casedate?: string,
		casetype?: string,
		casename?: string,
		casegroup?: string
	) {
		this.customerCode = customercode;
		this.customerName = customername;
		this.branchCode = branchcode;
		this.branchName = branchname;
		this.orderType = ordertype;
		this.caseNo = caseno;
		this.caseDate = casedate;
		this.caseName = casename;
		this.caseGroup = casegroup;
		if (casetype) this.caseType = casetype;
	}

	public customerCode: string;
	public customerName: string;
	public branchCode: string;
	public branchName: string;
	public orderType: string;
	public caseNo: string;
	public caseDate: string;
	public caseType?: string;
	public caseName?: string;
	public caseGroup?: string;
}