import { Component, OnInit, ViewChild } from "@angular/core";

@Component({
  selector: "tinymce",
  template: `
    <div>
      <editor
        [init]="tinymceOptions"
        #tinymceEditorRef
        [(ngModel)]="emailTemplate"
      >
      </editor>
    </div>
  `,
})
export class TinyMCEComponent implements OnInit {
  constructor() {}

  @ViewChild("tinymceEditorRef") tinymceEditorRef;
  public emailTemplate: string;
  public tinymceOptions: any = {};

  ngOnInit() {
    this.InitTinyMCE();
  }

  private InitTinyMCE(isDisabled: boolean = false) {
    this.tinymceOptions = null;
    const _component = this;
    this.tinymceOptions = {
      base_url: '/tinymce',
      suffix: '.min',
      height: 500,
      plugins:
        'importcss image fullscreen table lists link code help wordcount save pagebreak preview',
      body_id: 'pdftemplate',
      body_class: 'editor',
      importcss_append: true,
      contextmenu_avoid_overlap: '.editor-container',
      contextmenu_never_use_native: true,
      convert_fonts_to_spans: false,
      toolbar_mode: 'sliding',
      formats: {
        bold: {
          inline: 'span',
          styles: { 'font-weight': 'bold' },
          exact: true,
        },
      },
      font_family_formats: 'Nissan Brand=NissanBrand; Tahoma=Tahoma',
      font_size_formats: [
        '8pt',
        '9pt',
        '10pt',
        '11pt',
        '12pt',
        '14pt',
        '16pt',
        '18pt',
        '20pt',
        '22pt',
        '24pt',
        '30pt',
        '36pt',
        '48pt',
        '60pt',
        '72pt',
        '96pt',
      ],
      toolbar: !isDisabled && [
        // `template`, //Custom button ref
        `save | fontsize forecolor |
      undo redo |
      bold italic underline strikethrough subscript superscript |
      formatselect align numlist bullist outdent indent blockquote | 
      link image table | pagebreak |
      preview print code fullscreen`,
      ],
      menubar: !isDisabled,
      statusbar: !isDisabled,
      pagebreak_separator:
        '<p style="page-break-before: always; clear:both"/></p>',
      pagebreak_split_block: true,
      save_enablewhendirty: false,
      save_onsavecallback: (editor) => {
        console.log("Here is my content.", editor.getContent())
        //On Save callback
      },
      setup: function (editor) {
        //Set readonly mode
        if (isDisabled) editor.mode.set('readonly');

        //Custom button
        // editor.ui.registry.addMenuButton('template', {
        //   text: 'Template',
        //   fetch: function (callback) {
        //     const items = [
        //       {
        //         type: 'menuitem',
        //         text: 'Load NMT Brand',
        //         onAction: function () {
        //           editor.insertContent(_component.templateInit.NMT_BRAND);
        //         },
        //       }
        //     ];

        //     callback(items);
        //   },
        // });
      },
    };
  }
}
