import { NgModule } from "@angular/core";
import { CommonModule } from "@angular/common";
import { FormsModule, ReactiveFormsModule } from "@angular/forms";
import { RouterModule } from "@angular/router";

import { SharedComponentModule } from "src/app/modules/shared/shared-component.module";
import { MaterialImportModule } from "src/app/modules//shared/material.module";

import { AuthGuard } from "src/app/core/auth-guard.service";
import { RoleResolver } from "src/app/core/role-resolver.service";

import { ICMSComponent } from "src/app/pages/icms/icms.component";

import { SNIC001Component } from "src/app/pages/icms/SNIC001/SNIC001.component";
import { VendorSelectComponent } from "src/app/pages/icms/SNIC001/vendorSelect.component";
import { SNIC002Component } from "src/app/pages/icms/SNIC002/SNIC002.component";
import { SNIC003Component } from "src/app/pages/icms/SNIC003/SNIC003.component";
import { SNIC004Component } from "src/app/pages/icms/SNIC004/SNIC004.component";

@NgModule({
  declarations: [
    ICMSComponent, 
    SNIC001Component, 
    VendorSelectComponent,
    SNIC002Component,
    SNIC003Component,
    SNIC004Component
  ],
  imports: [
    CommonModule,
    FormsModule,
    ReactiveFormsModule,

    SharedComponentModule,
    MaterialImportModule,
    
    RouterModule.forChild([
      {
        path: "",
        component: ICMSComponent,
        children: [
          {
            path: 'SNIC002',
            component: SNIC002Component,
             resolve: {
               role: RoleResolver
             },
          },

          {
            path: 'SNIC001',
            component: SNIC001Component,
             resolve: {
               role: RoleResolver
             },
            },
          {
            path: 'SNIC003',
            component: SNIC003Component,
             resolve: {
               role: RoleResolver
             },
          },
          {
            path: 'SNIC004',
            component: SNIC004Component,
             resolve: {
               role: RoleResolver
             },
          },
        ],
      },
    ]),
  ],
  exports: [],
  providers: [AuthGuard, RoleResolver],
})
export class ICMSModule {}
