import { NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { HttpClientModule } from '@angular/common/http';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';
import { RouterModule } from '@angular/router';
import { AuthGuard } from 'src/app/core/auth-guard.service';
import { MaterialImportModule } from '../shared/material.module';
import { SharedComponentModule } from '../shared/shared-component.module';
import { ReportViewerComponent } from 'src/app/pages/report-viewer/report-viewer.component';
import { ListComponent } from '../../pages/report-viewer/list/list.component';
import { RunComponent } from '../../pages/report-viewer/run/run.component';
import { RoleReportResolver } from 'src/app/core/role-resolver.service';


@NgModule({
  declarations: [ListComponent, RunComponent, ReportViewerComponent],
  imports: [
    CommonModule,
    HttpClientModule,
    FormsModule,
    ReactiveFormsModule,
    SharedComponentModule,
    FormsModule,

    //Material imports
    MaterialImportModule,

    RouterModule.forChild([
      {
        path: '',
        component: ReportViewerComponent,
        children: [
          {
            path: '',
            redirectTo: 'list',
          },
          {
            path: 'list',
            component: ListComponent,
            resolve: {
              role: RoleReportResolver
            }
          },
          {
            path: 'run',
            component: RunComponent,
            resolve: {
              role: RoleReportResolver
            }
          }
        ],
        canActivate: [AuthGuard],
      }
    ])
  ],
  providers: [RoleReportResolver]
})
export class ReportViewerModule { }
