import { NgModule } from '@angular/core';
import { CommonModule, DatePipe, DecimalPipe } from '@angular/common';
import { HeaderComponent } from 'src/app/components/shared/header/header.component';
import { HttpClientModule, HTTP_INTERCEPTORS } from '@angular/common/http';

import { ReactiveFormsModule, FormsModule } from '@angular/forms';
import { RouterModule } from '@angular/router';

import { HttpService } from 'src/app/core/http.service';
import { Globals } from 'src/app/core/global';
import { AutoTableComponent } from 'src/app/components/shared/auto-table/auto-table.component';
import { AutoTableHighlightComponent } from 'src/app/components/shared/auto-table-hl/auto-table-hl.component';
import { MenuListComponent } from 'src/app/components/shared/menu-list/menu-list.component';
import { AutoCompleteComponent, AutoCompleteDialog } from 'src/app/components/shared/autoComplete/auto-complete.component';
import { AutoCompleteQueryComponent, AutoCompleteQueryDialog } from 'src/app/components/shared/auto-complete-query/auto-complete-query.component';
import { DataMonthComponent } from 'src/app/components/shared/dataMonth/data-month.component';

import { FileUploadComponent } from 'src/app/components/shared/file-upload/file-upload.component';
import { DialogComponent } from 'src/app/components/shared/dialog/dialog.component';
import { MegaMenuComponent } from '../../components/shared/mega-menu/mega-menu.component';
import { DialogPoComponent } from '../../components/shared/dialog-po/dialog-po.component';
import { AuthDecode } from '../../core/auth-decode.service';

import { AutoCompleteQuerySearchComponent, AutoCompleteQuerySearchDialog } from 'src/app/components/shared/auto-complete-query-search/auto-complete-query-search.component';
import { MaterialImportModule } from './material.module';
import { DialogTemplateComponent, DialogTemplateDialog } from 'src/app/components/shared/dialog-template/dialog-template.component';
import { DialogTemplateCallerComponent, DialogTemplateCallerDialog } from 'src/app/components/shared/dialog-template-caller/dialog-template-caller.component';
import { FormHeaderComponent } from 'src/app/components/shared/form-header/form-header.component';
import { FormHeaderEnissanComponent } from 'src/app/components/shared/form-header-enissan/form-header-enissan.component';
import { dateFormatPipe, dateTimeFormatPipe, FilterBytextPipe, OrderByPipe, SafePipe, UniquePipe, DataTypePipe, dateTimeFormat24HPipe, MonthPipe } from 'src/app/core/app.pipe';
import { AlertModalComponent } from 'src/app/components/shared/modal/alert-modal.component';
import { InfoModalComponent } from 'src/app/components/shared/modal/info-modal.component';
import { WarnModalComponent } from 'src/app/components/shared/modal/warn-modal.component';
import { ConfirmModalComponent } from 'src/app/components/shared/modal/confirm-modal.component';
import { AutoCompletePartComponent, AutoCompletePartDialog } from 'src/app/components/shared/auto-complete-part/auto-complete-part.component';
import { TokenInterceptor } from 'src/app/core/token.interceptor';
import { LoaderComponent } from 'src/app/components/shared/loader/loader.component';
import { LoaderService } from 'src/app/core/loader.service';
import { RoleDirective } from 'src/app/core/role.directive';
import { MatInputNumberDirective } from 'src/app/core/mat-input-commified.directive';
import { AutocompleteOffDirective } from 'src/app/core/autocomplete-off.directive';
import { MonthPickerComponent } from 'src/app/components/shared/month-picker/month-picker.component';
import { AutoTableeorderComponent } from 'src/app/components/shared/auto-table-reoder/auto-table-reorder.component';
import { StackBarChartComponent } from 'src/app/components/shared/chart/stack-bar/stack-bar.component';
import { EditorModule, TINYMCE_SCRIPT_SRC } from '@tinymce/tinymce-angular';
import { NumberCommaDirective } from 'src/app/core/number-comma.directive';


@NgModule({
    declarations: [
        HeaderComponent,
        LoaderComponent,
        AutoTableComponent,
        AutoTableHighlightComponent,
        MenuListComponent,
        AutoCompleteComponent,
        AutoCompleteDialog,
        DataMonthComponent,
        FileUploadComponent,
        DialogComponent,
        DialogPoComponent,
        MegaMenuComponent,
        AutoCompleteQueryComponent,
        AutoCompleteQueryDialog,
        AutoCompleteQuerySearchComponent,
        AutoCompleteQuerySearchDialog,
        AutoCompletePartComponent,
        AutoCompletePartDialog,
        AutoTableeorderComponent,

        DialogTemplateComponent,
        DialogTemplateDialog,
        DialogTemplateCallerComponent,
        DialogTemplateCallerDialog,
        FormHeaderComponent,
    FormHeaderEnissanComponent,
        MonthPickerComponent,
        StackBarChartComponent,

        //Pipes
        dateFormatPipe,
        dateTimeFormatPipe,
        FilterBytextPipe,
        UniquePipe,
        SafePipe,
        OrderByPipe,
        DataTypePipe,
        dateTimeFormat24HPipe,
        MonthPipe,

        //Modals
        AlertModalComponent,
        InfoModalComponent,
        WarnModalComponent,
        ConfirmModalComponent,

        //Directive
        RoleDirective,
        MatInputNumberDirective,
        AutocompleteOffDirective,
        NumberCommaDirective
    ],
    imports: [
        CommonModule,
        HttpClientModule,
        ReactiveFormsModule,
        FormsModule,
        RouterModule,

        //Material imports
        MaterialImportModule,

        EditorModule
    ],
    exports: [
        HeaderComponent,
        LoaderComponent,
        AutoTableComponent,
        AutoTableHighlightComponent,
        MenuListComponent,
        AutoCompleteComponent,
        DataMonthComponent,
        FileUploadComponent,
        AutoCompleteQueryComponent,
        AutoCompleteQuerySearchComponent,
        AutoCompletePartComponent,
        AutoTableeorderComponent,

        DialogTemplateComponent,
        DialogTemplateCallerComponent,
        FormHeaderComponent,
    FormHeaderEnissanComponent,
        MonthPickerComponent,
        StackBarChartComponent,

        EditorModule,

        dateFormatPipe,
        dateTimeFormatPipe,
        FilterBytextPipe,
        UniquePipe,
        SafePipe,
        OrderByPipe,
        DataTypePipe,
        dateTimeFormat24HPipe,
        MonthPipe,
        
        RoleDirective,
        MatInputNumberDirective,
        AutocompleteOffDirective,
        NumberCommaDirective
    ],
    entryComponents: [
        DialogComponent,
        AutoCompleteDialog,
        DialogPoComponent,
        AutoCompleteQueryDialog,
        AutoCompleteQuerySearchDialog,
        AutoCompletePartDialog,
        DialogTemplateDialog,
        DialogTemplateCallerDialog,
        AlertModalComponent,
        InfoModalComponent,
        WarnModalComponent,
        ConfirmModalComponent,
    ],
    providers: [
        HttpService,
        Globals,
        AuthDecode,
        LoaderService,
        DecimalPipe,
        dateFormatPipe,
        dateTimeFormatPipe,
        dateTimeFormat24HPipe,
        DatePipe,
        TokenInterceptor,
        {
            provide: HTTP_INTERCEPTORS,
            useClass: TokenInterceptor,
            multi: true
        },
        { provide: TINYMCE_SCRIPT_SRC, useValue: 'tinymce/tinymce.min.js' },
    ],
})
export class SharedComponentModule { }
