import { Component, OnInit, ViewChild, ViewContainerRef } from "@angular/core";
import { MatSelectionList, MatSelectionListChange } from "@angular/material/list";
import * as moment from "moment";
import { Globals } from "src/app/core/global";
import { HttpService } from "src/app/core/http.service";
import { ModalService } from "src/app/core/modal.service";
import { SNSD118ADJComponent } from "./SNSD118_ADJ/SNSD118_ADJ.component";

@Component({
  selector: "account-report",
  templateUrl: "AccountReport.component.html",
  styleUrls: ["AccountReport.component.css"],
})
export class AccountReportComponent implements OnInit {
  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewRef: ViewContainerRef,
    private global: Globals
  ) {}

  public currentDate: moment.Moment;
  public countRow: number;
  public reportList: Array<any> = [];
  public param  : any = {}
  public reportName : string;
  
  @ViewChild("reportSelectList") reportSelectList: MatSelectionList;
  @ViewChild("dialogNRV",{static: false}) dialogNRV : any;
  @ViewChild("dialogSNSD118ADJ",{static: false}) dialogSNSD118ADJ : any;
  @ViewChild("snsd118Adj", {static: false}) snsd118AdjRef: SNSD118ADJComponent;

  ngOnInit() {
    this.param.P_COMPANY_CODE = this.global.GetTokenDetail("ssComCode");
    this.currentDate = moment();
    this.GetReportList();
    // this.GetCurrentDate();
  }

  GetReportList() {
    this.http.get("wPMS", "GetReportList", "Account").subscribe(
      (res) => {
        if (res.Table) {
          this.reportList = res.Table;
        }
      },
      (err) => {
        console.log(err, "err");
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewRef
        );
      }
    );
  }

  GetCurrentDate() {
    this.http.GetSystemDate().subscribe((d) => {
      this.currentDate = moment(d);
    });
  }

  RunReport(selectVal: MatSelectionListChange) {
    const reportName = selectVal.options[0].value;
    console.log(reportName)
    this.reportName = reportName;
    this.param = {}

    if(reportName == 'PMS_RPT_ACC_NRV_ADDI_BOOKING_CURRENT_PRICE'){
     
      this.dialogNRV.OpenDialog();
 
    } else if (reportName == 'PMS_RPT_ACC_SNSD118_ADJ') {
      this.dialogSNSD118ADJ.OpenDialog();
    }else{
      this.global.GoToReport(
        reportName,
        {
          P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        },
        true,
        true
      );
    }

    this.reportSelectList.deselectAll();
  }

  public Export(){
   this.http.Download("AC","Acc_NRV_Report_Download",this.param)
   .subscribe(res =>{
     this.writeContents(res)
   })
  }

  private writeContents(content) {
    var currentDate = moment().format('DD-MM-YYYY');
    const a = document.createElement('a');
    const file = new Blob([content], { type: content.type });
    a.href = URL.createObjectURL(file);
    a.download = this.reportName + ".xlsx" ;
    a.click();
  }
}
