import { Component, ElementRef, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { AuthDecode } from 'src/app/core/auth-decode.service';
import { ModalService } from '../../../core/modal.service';
import { NgForm } from '@angular/forms';
import { Globals } from 'src/app/core/global';
import * as moment from 'moment';
import { I } from '@angular/cdk/keycodes';

@Component({
  selector: 'SNIE001_M',
  templateUrl: './SNIE001_M.component.html',
  styleUrls: ['./SNIE001_M.component.css']
})

export class SNIE001MComponent implements OnInit {

  constructor(
    private http: HttpService,
    private auth: AuthDecode,
    private viewref: ViewContainerRef,
    private modal: ModalService,
    private router: Router,
    private global: Globals
  ) { }

  public ConfigDocS: any = {
    ColName: "DOCUMENT_NO",
    PlaceholderText: "Select Document No",
    SourceController: "AC",
    SourceMethodName: "SNIE001_M_GetDoc",
    NoOfShowRecords: 30,
    MinLengthSearch: 5,
    UpperCase: false
  }
  public ConfigDocType: any = {
    ColName: "LOOKUP_TYPE",
    PlaceholderText: "Select Document Type",
    SourceController: "AC",
    SourceMethodName: "SNIE001_M_GetDocType",
    NoOfShowRecords: 30,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public ConfigReason: any = {
    ColName: "LOOKUP_REASON",
    PlaceholderText: "Select Reason Code",
    SourceController: "AC",
    SourceMethodName: "SNIE001_M_GetReason",
    NoOfShowRecords: 30,
    MinLengthSearch: 0,
    UpperCase: false
  }

  public ConfigReasonAdd: any = {
    ColName: "LOOKUP_REASON",
    PlaceholderText: "Select Reason Code",
    SourceController: "AC",
    SourceMethodName: "SNIE001_M_GetReason",
    NoOfShowRecords: 30,
    MinLengthSearch: 0,
    UpperCase: false,
    SourceParams: {}
  }

  public ConfigPart: any = {
    ColName: "LOOKUP_PART",
    PlaceholderText: "Select Part",
    SourceController: "AC",
    SourceMethodName: "SNIE001_M_GetPart",
    NoOfShowRecords: 30,
    MinLengthSearch: 3
  }

  public params: any = {
    DOCUMENT_DATE: moment()
  }
  public data: any = {};


  public tblFooterDetail: any = [
    {
      fieldName: "PART_NAME",
      value: "Total",
      show: true
    },
    {
      fieldName: "QUANTITY",
      // value: false,
      show: true
    },
    {
      fieldName: "UNIT_PRICE",
      // value: false,
      show: true
    },
    {
      fieldName: "AMOUNT",
      // value: false,
      show: true
    }]


  public tableData: any = [];
  public MainDatatable: any;
  public sDocData: any;
  public sReasonData: any;
  public sBranchData: any;
  public sPartData: any;
  public IsSearch: any = true;
  public IsAdd = false;
  public IsSaved = true;
  public editRefDoc: boolean = false;
  public confirmHeader: boolean = false;
  @ViewChild("headerForm") headerForm: NgForm;

  @ViewChild("autoCompleteReasonAdd") autoCompleteReasonAdd: any;
  @ViewChild("inputDocType") inputDocType: ElementRef;

  ngOnInit() {

  }

  ngAfterViewInit(): void {
    // setTimeout(() => {
    //   this.inputDocType.nativeElement.select();
    //   this.inputDocType.nativeElement.focus();
    // }, 100);
  }


  

  GetDocType(Doc) {
    this.params.DOCUMENT_TYPE = Doc.DOCUMENT_TYPE;
  }

  GetDocTypeAdd(Doc) {
    if (Doc) {
      this.data.DOCUMENT_TYPE = Doc.DOCUMENT_TYPE;
      this.data.DOC_TYPE_DESC = Doc.DOC_NAME;
      this.data.JOB_TYPE = Doc.JOB_TYPE;
      this.data.VAT_FLAG = Doc.VAT_FLAG;
      this.data.VAT_RATE = Doc.VAT_RATE;

      //Set ref doc type
      if (this.data.DOCUMENT_TYPE === "RS") {
        this.data.REF_DOC_TYPE = "SP";
        this.editRefDoc = false;
      } else if (this.data.DOCUMENT_TYPE === "RT") {
        this.data.REF_DOC_TYPE = "TF";
        this.editRefDoc = false;
      } else {
        this.data.REF_DOC_TYPE = null;
        this.editRefDoc = true;
      }

      console.log('jobtype', this.data.JOB_TYPE)

      this.ConfigReasonAdd.SourceParams.JOB_TYPE = this.data.JOB_TYPE;
      this.ConfigReasonAdd.SourceParams.DOC_TYPE = this.data.DOCUMENT_TYPE;

      this.ConfigPart.SourceParams = { REF_DOC_TYPE: "", REF_DOC_NO: "" };
    }
  }

  GetReason(Rea) {
    this.params.REASON_CODE = Rea.REASON_CODE;
  }

  GetReasonAdd(Rea) {

    if (this.data.DOCUMENT_TYPE == "RS" || this.data.DOCUMENT_TYPE == "RT") {
      if (this.data.OLD_REASON_CODE != Rea.REASON_CODE) {
        this.modal.warning('Reason Code must be the same as reference document', this.viewref)
        return;
      }
    }
    this.data.REASON_CODE = Rea.REASON_CODE;
    this.data.DSP_REASON = Rea.REASON_DESC;
  }

  checkRefdoctype() {
    if (this.data.DOCUMENT_TYPE == "RS" && this.data.REF_DOC_TYPE !== "SP") {
      this.modal.warning('Invalid Reference document Type', this.viewref)
      return;
    }
    if (this.data.DOCUMENT_TYPE == "RT" && this.data.REF_DOC_TYPE !== "TF") {
      this.modal.warning('Invalid Reference document Type', this.viewref)
      return;
    }
  }

  GetPart(evt, data, index) {
    if (evt) {
      if (this.tableData.find((v, i) => i !== index && v.EDIT === 'EDIT' && v.PART_NO === evt.PART_NO)) {
        this.modal.warning("Duplicate Part number!", this.viewref)
        data.PART_NO = null;
      }
      else {
        data.PART_NO = evt.PART_NO;
        data.PART_NAME = evt.PART_NAME_EN;
        data.UNIT_PRICE = evt.UNIT_PRICE_B;
        data.AVERAGE_COST = evt.UNIT_PRICE_B;
        data.TOTAL_VAT = evt.TOTAL_VAT;
        data.OH_QTY = evt.OH_QTY;
        data.TRANSFER_QTY = evt.TRANSFER_QTY;
        data.SUSPEND_QTY = evt.SUSPEND_QTY;
        data.MAX_REVERSE_QTY = evt.MAX_REVERSE_QTY;
        data.MAX_REV_TRANSFER_QTY = (evt.TRANSFER_QTY > evt.MAX_REVERSE_QTY) ? evt.MAX_REVERSE_QTY : evt.TRANSFER_QTY;
        data.MAX_REV_SUSPEND_QTY = (evt.SUSPEND_QTY > evt.MAX_REVERSE_QTY) ? evt.MAX_REVERSE_QTY : evt.SUSPEND_QTY;
        if (this.data.DOCUMENT_TYPE === "RS") {
          data.QUANTITY = data.MAX_REV_SUSPEND_QTY;
        } else if (this.data.DOCUMENT_TYPE === "RT") {
          data.QUANTITY = data.MAX_REV_TRANSFER_QTY;
        } else {
          data.QUANTITY = 0;
        }
      }
    }
  }

  checkavail(evt, data) {
    if (this.data.DOCUMENT_TYPE === "PA") {
      return;
    }
    if (this.data.DOCUMENT_TYPE === "RS") {
      if (data.QUANTITY > data.MAX_REV_SUSPEND_QTY) {
        data.QUANTITY = data.MAX_REV_SUSPEND_QTY;
        this.tableData = [...this.tableData];
        this.modal.warning('QTY Balance less than input QTY.', this.viewref)
        return false;
      }
    } else if (this.data.DOCUMENT_TYPE === "RT") {
      if (data.QUANTITY > data.MAX_REV_TRANSFER_QTY) {
        data.QUANTITY = data.MAX_REV_TRANSFER_QTY;
        this.tableData = [...this.tableData];
        this.modal.warning('QTY Balance less than input QTY.', this.viewref)
        return false;
      }
    } else if (data.QUANTITY > data.OH_QTY) {
      data.QUANTITY = data.OH_QTY;
      this.tableData = [...this.tableData];
      this.modal.warning('QTY Balance less than input QTY.', this.viewref)
      return false;
    }
  }

  AddNew() {
    this.data = {};
    this.data.DOCUMENT_DATE = moment();
    this.data.DOCUMENT_NO = "AUTO";
    this.data.VAT_RATE = "0.00";
    this.tableData = [];
    this.IsSearch = false;
    this.IsAdd = true;
    this.IsSaved = false;
    this.confirmHeader = false;
    this.editRefDoc = false;
    this.CreateDetailRow(0);

    setTimeout(() => {
      this.inputDocType.nativeElement.select();
      this.inputDocType.nativeElement.focus();
    }, 100);
  }

  Search() {
    this.params._DOCUMENT_DATE = this.global.ConvertDateToFormatSTD(this.params.DOCUMENT_DATE);

    this.http.post("AC", "SNIE001_M_GetList", this.params)
      .subscribe(result => {
        this.MainDatatable = result.Table;
      });
  }


  Edit(P_data) {
    this.data = {}
    this.tableData = [];
    this.IsSearch = false;
    this.IsAdd = false;
    this.IsSaved = true;
    this.confirmHeader = true;
    this.editRefDoc = false;
    this.http.get("AC", "SNIE001_M_GetHead", P_data.DOCUMENT_NO)
      .subscribe(result => {
        if (result.Table.length > 0) {
          this.data = result.Table[0];
          this.http.get("AC", "SNIE001_M_GetPartList", P_data.DOCUMENT_NO)
            .subscribe(result => {
              if (result.Table.length > 0) {
                this.tableData = result.Table;
              }
            });
        }
      });
  }

  CheckHeaderValid(tblIndex) {
    if (this.headerForm.valid && this.tableData[tblIndex].PART_NO) {
      this.CreateDetailRow(tblIndex);

      return true;
    }

    return false;
  }

  CreateDetailRow(tblIndex) {
    let currentMaxRow: number = this.tableData.length || 0;
    let nextMaxRow: number = (Math.floor(currentMaxRow / 10) + 1) * 10;

    if (currentMaxRow - tblIndex <= 2) {
      for (let i = currentMaxRow; i < nextMaxRow; i++) {
        this.tableData.push({
          EDIT: 'EDIT',
        });
      }

      this.tableData = [...this.tableData];
    }

  }

  DeleteRow(index) {
    if (this.IsAdd) {

      this.modal.confirm("Are you sure to remove this row?", this.viewref,
        () => {
          this.tableData.splice(index, 1);
          this.tableData = [...this.tableData];
        }, () => { })

    }
  }

  Save() {
    if (this.headerForm.valid) {
      let detailRows = this.tableData.filter(v => v.PART_NO)

      if (detailRows.length <= 0) {
        this.modal.warning("Please select at least 1 Parts.", this.viewref)
        return;
      }
      if (detailRows.find(v => v.EDIT === "EDIT" && ((!v.QUANTITY || v.QUANTITY === 0) || (!v.UNIT_PRICE || v.UNIT_PRICE === 0)))) {
        if(this.data.DOCUMENT_TYPE == "MA"){
          let filterUnitPrice = detailRows.filter(x => x.AVERAGE_COST > 0)
          if(filterUnitPrice.length > 0){
        this.modal.warning("Some record in transaction detail have unfinished detail.", this.viewref);
        return;
          }
        }else{
          this.modal.warning("Some record in transaction detail have unfinished detail.", this.viewref);
          return;
        }
      }
      this.modal.confirm('Do you want to save changed you have made?', this.viewref, this.ConfirmSave);
    } else {
      this.modal.warning("Please fill all required(*) fields.", this.viewref);
    }
  }

  FindDocForRef() {
    if (this.data.DOCUMENT_TYPE === "RS" || this.data.DOCUMENT_TYPE === "RT") {
      if (this.data.REF_DOC_NO.substring(0, 2) !== this.data.REF_DOC_TYPE) {
        this.modal.warning('Invalid  Document No', this.viewref)
        this.data.REF_DOC_NO = null;
        return;
      }

      this.ConfigPart.SourceParams = { REF_DOC_TYPE: this.data.REF_DOC_TYPE, REF_DOC_NO: this.data.REF_DOC_NO };

      this.http.get("AC", "SNIE001_M_GetDoc", this.data.REF_DOC_NO)
        .subscribe(result => {
          if (result.Table.length > 0) {
            if(result.Table[0].CHECK_WH_PROCESS == "Y"){
              this.IsSaved = true;
              this.modal.warning('ไม่สามารถดำเนินการได้<br>เนื่องจากเอกสารนี้อยู่ใน process ของทาง Warehouse', this.viewref)
            }else {
              this.IsSaved = false;
            }
            let rscode = result.Table[0].REASON_CODE.toString();
            this.data.REASON_CODE = rscode;
            this.data.OLD_REASON_CODE = rscode;
            this.autoCompleteReasonAdd.textInput = rscode;
            this.autoCompleteReasonAdd.query();
          }
        });
    }
  }

  ConfirmSave = () => {
    let detailRows = this.tableData.filter(v => v.PART_NO)

    this.data._DOCUMENT_DATE = this.global.ConvertDateToFormatSTD(this.data.DOCUMENT_DATE);
    this.data.PART_LIST = [];
    this.data.PART_LIST = detailRows;
    this.data.TOTAL_ITEM = detailRows.length;
    this.data.TOTAL_QTY = this.CalTotalQTY();
    this.data.REF_DOC_TYPE = this.data.REF_DOC_TYPE ? this.data.REF_DOC_TYPE.toUpperCase() : null
    this.http.post("AC", "SNIE001_M_Save", this.data)
      .subscribe(res => {
        this.IsSaved = true;
        this.data.DOCUMENT_NO = res.DOCUMENT_NO;
        this.Edit(this.data);
        this.modal.info('Transaction complete: applied and saved.', this.viewref);
      }, err => {
        this.modal.error('Found an error, please contact support team', this.viewref);
      });
  }
  getDateParam(dt) {
    if (dt !== undefined) {
      dt = new Date(dt)
      let year = dt.getFullYear();
      let month = (1 + dt.getMonth()).toString().padStart(2, '0');
      let day = dt.getDate().toString().padStart(2, '0');
      var p_Date = year + '-' + month + '-' + day;
      return p_Date;
    }
  }

  Cancel() {
    this.IsSearch = true;
  }
  BackToGrid() {
    this.IsSearch = true;
  }

  CalTotalQTY() {
    return this.tableData.reduce((prev, currObj) => prev + parseFloat((currObj.QUANTITY || 0)), 0);
  }

  CalTotalAmount() {
    return this.tableData.reduce((prev, currObj) => prev + (parseFloat((currObj.QUANTITY || 0)) * parseFloat((currObj.UNIT_PRICE || 0))), 0);
  }

  CalTotalVat() {
    return this.tableData.reduce((prev, currObj) => prev + (parseFloat((currObj.QUANTITY || 0)) * (parseFloat((currObj.UNIT_PRICE || 0)) * this.data.VAT_RATE / 100)), 0);
  }

}

