import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { FormControl, Validators } from '@angular/forms';
import { ModalService } from 'src/app/core/modal.service';

@Component({
    selector: 'snm019p',
    templateUrl: './SNM019P.component.html',
    styleUrls: ['./SNM019P.component.css']
})

export class SNM019PComponent implements OnInit {


    constructor(
        private http: HttpService,
        private router: Router,
        private global : Globals,
        private modal : ModalService,
        private viewref : ViewContainerRef
    ) { }
    
    @ViewChild("dialogAdd", { static: false }) dialogAdd: any;
    @ViewChild("dialogEdit", { static: false }) dialogEdit: any;

    public currentDate: string;
    public CustomerList: any;
    public tableData: any = [];
    public JobTypeList : any = [];
    public opened : boolean = false;

    public Param = {
        JOB_TYPE: null,
        REASON_CODE: null
    }

    public ParamAdd = {
        REASON_CODE: null,
        REASON_NAME_EN: null,
        REASON_NAME_TH: null,
        JOB_TYPE: null,
        JOB_DESCRIPTION : null
    }

    public ParamEdit = {
        REASON_CODE: null,
        REASON_NAME_EN: null,
        REASON_NAME_TH: null,
        JOB_TYPE: null,
        JOB_DESCRIPTION : null,
        LAST_UPD_BY_NAME : null,
        LAST_UPD_DATE : null
    }

    public ConfigReasonCode: any = {
        ColName: "LOOKUP_REASON",
        ColValue: "",
        PlaceholderText: "Select Reason Code",
        SourceController: "wPMS",
        SourceMethodName: "GetReasonCodeByJobType",
        NoOfShowRecords: 100,
        MinLengthSearch: 0,
        SourceParams: {},
        UpperCase: true
      }

    public hideCols: Array<string> = []
    JobTypeControl = new FormControl('', [Validators.required]);
    ReasonCodeControl = new FormControl('', [Validators.required]);


    ngOnInit() {


        this.GetJobType();
        this.global.GetRoleDetail().CHG === "N" ? this.hideCols.push("EDIT") : null;
        this.global.GetRoleDetail().DEL === "N" ? this.hideCols.push("DELETE") : null;
    }

    GetJobType(){
        
        this.http.get("wPMS","GetJobTypeMaster")
        .subscribe(res => {       
            this.JobTypeList = res.Table
        })
    }

    SelectionJobType(){
       
        this.ConfigReasonCode.SourceParams.JOB_TYPE = this.Param.JOB_TYPE
    }

    SelectionJobTypeAdd(event){
        
        let job_desc = this.JobTypeList.find(x => x.JOB_TYPE == event.value)
        this.ParamAdd.JOB_DESCRIPTION = job_desc.JOB_DESCRIPTION
    }

    Search(){
        this.tableData = []
        this.http.post("AC","SNM019PP_GetData",this.Param)
        .subscribe(res => {       
            this.tableData = res.Table
        })
    }

    openDialog(){
        this.JobTypeControl.reset()
        this.ReasonCodeControl.reset()
        this.ParamAdd = this.global.ClearObject(this.ParamAdd)
        this.dialogAdd.OpenDialog();
        this.JobTypeControl.reset();
        this.ReasonCodeControl.reset();
    }

    SaveAdd(){
        this.modal.confirm("Do you want to save changed you have made?",this.viewref,this.ConfirmSave)
    }

    CancelAdd(){
        this.dialogAdd.Close()
    }

    ConfirmSave = () => {
        this.http.post('AC','SNM019P_Insert',this.ParamAdd)
        .subscribe(res =>{
           
            if (res.Table[0].STATUS == 'Done') {
                this.modal.info('Transaction complete: applied and saved.', this.viewref);
                this.Search();
                this.ParamAdd = this.global.ClearObject(this.ParamAdd)
                this.dialogAdd.Close();

            } else if (res.Table[0].STATUS == 'Duplicate') {
                this.modal.warning('No change to save. Found duplicate record.', this.viewref);
            }
            else {
                this.modal.error('No change to save. Something went wrong.', this.viewref);
            }
        })
    }


    Edit(data){
       
        this.ParamEdit.JOB_TYPE = data.JOB_TYPE
        this.ParamEdit.JOB_DESCRIPTION = data.JOB_DESCRIPTION
        this.ParamEdit.REASON_CODE = data.REASON_CODE
        this.ParamEdit.REASON_NAME_EN = data.REASON_NAME_EN
        this.ParamEdit.REASON_NAME_TH = data.REASON_NAME_TH
        this.ParamEdit.LAST_UPD_BY_NAME = data.LAST_UPD_BY
        this.ParamEdit.LAST_UPD_DATE = data.LAST_UPD_DATE
        this.dialogEdit.OpenDialog()
        this.JobTypeControl.reset();
        this.ReasonCodeControl.reset();
    }

    SaveEdit(){
        this.modal.confirm("Do you want to save changed you have made?",this.viewref,this.ConfirmEdit)
    
    }

    ConfirmEdit = () => {

        this.http.post('AC','SNM019P_Update',this.ParamEdit)
        .subscribe(res =>{
           //console.log(res)
            if (res.Table[0].STATUS == 'Done') {
                this.modal.info('Transaction complete: applied and saved.', this.viewref);
                this.Search();
                this.dialogEdit.Close();
            } 
            else {
                //console.log(res)
                this.modal.error('No change to save. Something went wrong.', this.viewref);
            }
        })
    }

    CancleEdit(){
        this.dialogEdit.Close();
    }


    Delete(data){
        this.modal.confirm("Do you want to delete record?",this.viewref, () => this.ConfirmDelete(data) )
    }

    ConfirmDelete = data => {

        this.http.post('AC','SNM019P_Delete',data)
        .subscribe(res =>{
           
            if (res.Table[0].STATUS == 'Done') {
                this.modal.info('Transaction complete: applied and saved.', this.viewref);
                this.Search();
            } 
            else {
                this.modal.error('No change to save. Something went wrong.', this.viewref);
            }
        })     
    }

    SetReasonCode(event) {
        this.Param.REASON_CODE = event.REASON_CODE;
    }

}

