import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { FormControl, Validators } from '@angular/forms';
import { ModalService } from 'src/app/core/modal.service';

@Component({
    selector: 'snm027p',
    templateUrl: './SNM027P.component.html',
    styleUrls: ['./SNM027P.component.css']
})

export class SNM027PComponent implements OnInit {


    constructor(
        private http: HttpService,
        private router: Router,
        private global : Globals,
        private modal : ModalService,
        private viewref : ViewContainerRef
    ) { }
    
    @ViewChild("dialogAdd", { static: false }) dialogAdd: any;
    @ViewChild("dialogEdit", { static: false }) dialogEdit: any;

    public currentDate: string;
    public CustomerList: any;
    public tableData: any = [];
    public JobTypeList : any = [];
    public opened : boolean = false;

    public Param = {
        CURRENCY_CODE: null,
        CURRENCY_NAME: null
    }

    public ParamAdd = {
        CURRENCY_CODE: null,
        CURRENCY_NAME: null,
        CURRENCY_SYMBOL: null, 
    }

    public ParamEdit = {
        CURRENCY_CODE: null,
        CURRENCY_NAME: null,
        CURRENCY_SYMBOL: null, 
        LAST_UPD_BY : null,
        LAST_UPD_DATE : null
    }

    public ConfigCurrency: any = {
        ColName: "LOOKUP",
        ColValue: "",
        PlaceholderText: "Select Currency Code",
        SourceController: "AC",
        SourceMethodName: "SNM027P_GetCurrencyList",
        NoOfShowRecords: 100,
        MinLengthSearch: 0,
        UpperCase: true
      }

    public hideCols: Array<string> = []
    CurrencyCodeControl = new FormControl('', [Validators.required]);


    ngOnInit() {
        // this.global.GetRoleDetail().CHG === "N" ? this.hideCols.push("EDIT") : null;
        // this.global.GetRoleDetail().DEL === "N" ? this.hideCols.push("DELETE") : null;
    }





    Search(){
        this.tableData = []
        this.http.get("AC","SNM027P_GetCurrencyData",this.Param.CURRENCY_CODE)
        .subscribe(res => {       
            this.tableData = res.Table
        })
    }

    openDialog(){
        this.CurrencyCodeControl.reset();
        this.ParamAdd = this.global.ClearObject(this.ParamAdd);
        this.dialogAdd.OpenDialog();
    }

    SaveAdd(){
        this.modal.confirm("Do you want to save changed you have made?",this.viewref,this.ConfirmSave)
    }

    CancelAdd(){
        this.dialogAdd.Close()
    }

    ConfirmSave = () => {
        this.http.post('AC','SNM027P_Insert',this.ParamAdd)
        .subscribe(res =>{
           console.log(res)
            if (res.Table[0].STATUS == 'Done') {
                this.modal.info('Transaction complete: applied and saved.', this.viewref);
                this.Search();
                this.ParamAdd = this.global.ClearObject(this.ParamAdd)
                console.log('add',this.ParamAdd)
                this.dialogAdd.Close();

            } else if (res.Table[0].STATUS == 'Duplicate') {
                this.modal.warning('No change to save. Found duplicate record.', this.viewref);
            }
            else {
                this.modal.error('No change to save. Something went wrong.', this.viewref);
            }
        },err => {
            this.modal.error('Found an error, please contact support team', this.viewref);
        })
    }


    Edit(data){

        this.CurrencyCodeControl.reset();
        this.ParamEdit = data
       
        this.dialogEdit.OpenDialog()
    }

    SaveEdit(){
        this.modal.confirm("Do you want to save changed you have made?",this.viewref,this.ConfirmEdit)
    
    }

    ConfirmEdit = () => {

        this.http.post('AC','SNM027P_Update',this.ParamEdit)
        .subscribe(res =>{
           console.log(res)
            if (res.Table[0].STATUS == 'Done') {
                this.modal.info('Transaction complete: applied and saved.', this.viewref);
                this.Search();
                this.dialogEdit.Close();
            } 
            else {
                console.log(res)
                this.modal.error('No change to save. Something went wrong.', this.viewref);
            }
        },err =>{
            this.modal.error('Found an error, please contact support team', this.viewref);
        })
    }

    CancleEdit(){
        this.dialogEdit.Close();
    }


    Delete(data){
        this.modal.confirm("Do you want to delete record?",this.viewref, () => this.ConfirmDelete(data) )
    }

    ConfirmDelete = data => {

        this.http.post('AC','SNM027P_Delete',data)
        .subscribe(res =>{
           
            if (res.Table[0].STATUS == 'Done') {
                this.modal.info('Transaction complete: applied and saved.', this.viewref);
                this.Search();
            } 
            else {
                console.log(res)
                this.modal.error('No change to save. Something went wrong.', this.viewref);
            }
        },err =>{
            this.modal.error('Found an error, please contact support team', this.viewref);
        })     
    }


}

