import { Component, ElementRef, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { ModalService } from 'src/app/core/modal.service';

@Component({
    selector: 'SNM149',
    templateUrl: 'SNM149.component.html',
    styleUrls: ['SNM149.component.css']
})

export class SNM149Component implements OnInit {
    constructor(
        private http: HttpService,
        private router: Router,
        private global: Globals,
        private modal: ModalService,
        private viewref: ViewContainerRef
  ) { }

  @ViewChild("dialogAction", { static: false }) dialogAction: any;
  @ViewChild("fileInput") fileInput: ElementRef;
  @ViewChild("dialogUpload", { static: false }) dialogUpload: any;

  public paramSearch: any = {};
  public formData: any = {};
  public tableData: Array<any> = [];
  
  //Upload File
  public FileName: string = "";
  private File : any;
  public tableUpload = []
  public tableUploadFilter = []
  public total_error :number = 0;
  public error_list = []

  public lookupPDIBaseModelConfigAll: any = {
    ColName: "LOOKUP_BASE_MODEL",
    PlaceholderText: "Select base model",
    SourceController: "AC",
    SourceMethodName: "SNM149_GetPDIBaseModelAll",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public lookupPDIBaseModelConfig: any = {
    ColName: "LOOKUP_BASE_MODEL",
    PlaceholderText: "Select base model",
    SourceController: "AC",
    SourceMethodName: "SNM149_GetPDIBaseModel",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedPDIBaseModel(val: any) {
    if(val){
      this.paramSearch.BASE_MODEL = val.BASE_MODEL;
      this.paramSearch.MODEL_NAME = val.MODEL_NAME;
      this.Search();
    }else{
      this.paramSearch.MODEL_NAME = null;
    }
  }

  public SetSelectedPDIBaseModelDialog(val: any) {
    if(val){
      this.formData.BASE_MODEL = val.BASE_MODEL;
      this.formData.MODEL_NAME = val.MODEL_NAME;
      this.formData.CAR_VENDOR_TYPE = val.CAR_VENDOR_TYPE;
      this.formData.BASE_MODEL_TEMP = val.BASE_MODEL;
      this.formData.MODEL_NAME_TEMP = val.MODEL_NAME;
      this.formData.CAR_VENDOR_TYPE_TEMP = val.CAR_VENDOR_TYPE;
    }else{
      this.formData.BASE_MODEL = null;
      this.formData.MODEL_NAME = null;
      this.formData.CAR_VENDOR_TYPE = null;
      this.formData.BASE_MODEL_TEMP = this.formData.BASE_MODEL;
      this.formData.MODEL_NAME_TEMP = null;
      this.formData.CAR_VENDOR_TYPE_TEMP = null;
    }
  }

  public SetCancelPDIBaseModelDialog(val: any) {
    this.formData.BASE_MODEL = this.formData.BASE_MODEL_TEMP ? this.formData.BASE_MODEL_TEMP : null ;
    this.formData.MODEL_NAME = this.formData.MODEL_NAME_TEMP ? this.formData.MODEL_NAME_TEMP : null ;
    this.formData.CAR_VENDOR_TYPE = this.formData.CAR_VENDOR_TYPE_TEMP ? this.formData.CAR_VENDOR_TYPE_TEMP : null ;
  }

  ngOnInit() {
    this.Search();
  }

  public Search() {
    let basemodel = this.global.EscapeCharacter(this.paramSearch.BASE_MODEL ? this.paramSearch.BASE_MODEL : "NULL")
    this.http.get('AC', 'SNM149_GetData', basemodel)
    .subscribe(res => {
        this.tableData = res.set.Table;
    },(err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contract support team", this.viewref);
  });
  }
  
  public Add() {
    this.formData = {}
    this.formData.TYPE = "ADD";
    this.dialogAction.width = "450px" 
    this.dialogAction.height = "500px" 
    this.dialogAction.title = "Add PDI K9 Base model" 
    this.dialogAction.OpenDialog();
  }

  public Edit(data) {
    this.formData = { ...data }
    this.formData.TYPE = "EDIT";
    this.dialogAction.width = "450px" 
    this.dialogAction.height = "525px" 
    this.dialogAction.title = "Edit PDI K9 Base model" 
    this.dialogAction.OpenDialog();
  }

  public Delete(data) {
    this.modal.confirm("Do you want to delete record<br>Base model: "+ data.BASE_MODEL, this.viewref,()=> ConfirmDelete())

    let ConfirmDelete = () => {
      const params = { BASE_MODEL : data.BASE_MODEL }
      this.http.post("AC", "SNM149_Delete", params)
      .subscribe(res =>{
        if (res.status == 'DONE') {
          this.Search();
          this.modal.info(res.message, this.viewref);
        } else {
          this.modal.error(res.message, this.viewref);
        }
      },err =>{
        this.modal.error('Found an error, please contract support team.', this.viewref);
      })
    }
  }

  public SaveAdd() {
    if(this.ValidateNotNullField() === false){
      return;
    }
    this.modal.confirm("Do you want to save change you have made?", this.viewref, () => ConfirmAdd());
    
    let ConfirmAdd = () =>  {
      this.http.post('AC', 'SNM149_Insert', this.formData)
      .subscribe(res => {
        if (res.status == 'DONE') {
          this.Search();
          this.dialogAction.Close();
          this.modal.info(res.message, this.viewref);
        }  
        else {
          this.modal.error(res.message, this.viewref);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewref);
      })
    }
  }

  public CancelAdd() {
    this.dialogAction.Close();
  }

  public SaveEdit() {
    if(this.ValidateNotNullField() === false){
      return;
    }
    this.modal.confirm("Do you want to save change you have made?", this.viewref, () => ConfirmEdit());

    let ConfirmEdit = () => {
      this.http.post('AC', 'SNM149_Update', this.formData)
      .subscribe(res => {
        if (res.status == 'DONE') {
          this.Search();
          this.dialogAction.Close();
          this.modal.info(res.message, this.viewref);
        } else {
          this.modal.error(res.message, this.viewref);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
    }
  }

  public CancleEdit() {
    this.dialogAction.Close();
  }

  public ValidateNotNullField(): boolean{
    if(!this.formData.BASE_MODEL){
      this.modal.warning("Please select base model.",this.viewref);
      return;
    }

    return true;
  }
  
  public OpenUpload(){
    this.total_error = 0;
    this.FileName = "";
    this.error_list = [];
    this.tableUpload = [];
    this.tableUploadFilter = [];
    this.dialogUpload.height="850px";
    this.dialogUpload.width="1375px";
    this.dialogUpload.title = "Upload PDI K9 Base model";
    this.dialogUpload.OpenDialog()
  }

  public DownloadTemplate(){
    this.global.GoToExport("PMS_RPT_PDI_SNM149_UPLOAD_TEMPLATE",
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      }, true, "EXCELOPENXML")
  }
  
  public openFileBrowser() {
    this.FileName = "";
    this.fileInput.nativeElement.value = '';
    this.fileInput.nativeElement.click();
  }

  public selectFile(evt) {
    let Files: Array<File> = evt.target.files;
    if (Files.length > 0) {
      this.File = Files[0];
      this.FileName = this.File.name;
    }
  }

  public PreView() {
    if (!this.FileName) {
      this.modal.warning("Please Open File First...", this.viewref)
      return;
    }
    
    let formData = new FormData();
    formData.append('file', this.File);

    this.tableUpload = []
    this.error_list = []
    this.http.postFile("AC", "SNM149_UploadFile", formData)
      .subscribe(result => {
        this.tableUpload = result;
        this.tableUploadFilter = this.tableUpload.filter(x => x.ERR_FLAG == 'N')
        let countrow = 0;
        this.tableUpload.map((x,i) => {
          if(x.ERR_FLAG == 'Y'){
              countrow += 1;
              this.error_list.push({
                  record : i + 1,
                  message : x.ERR_MSG
              })
          } 
          this.total_error = countrow;
      })
    }, err => {
      this.modal.error('Found an error, please contract support team.', this.viewref);
    })
  }

  public SaveUpload(){
    this.modal.confirm("Do you want to save change you have made?",this.viewref,() => ConfirmSave())

    let ConfirmSave = () => {
      this.http.post("AC","SNM149_SaveByUpload",this.tableUploadFilter)
      .subscribe(res => {
        if(res.status == "DONE"){
          this.Search();
          this.dialogUpload.Close();
          this.modal.info(res.message,this.viewref);
        }else{
          this.modal.error(res.message,this.viewref)
        }
      },err => {
        this.modal.error('Found an error, please contract support team.', this.viewref);
      })
    }
  }
}

function isNumber(str: string): boolean{
  return !Number.isNaN(Number(str));
}

function isDecimal(str: string): boolean{
  if(!isNumber){
    return false;
  }

  var number = Number(str);
  if (number !== Math.floor(number)) {
    return true;
 } else {
  return false;
 }
}