import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewContainerRef,ViewChild } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { ModalService } from 'src/app/core/modal.service';

@Component({
  selector: 'SNPE043',
  templateUrl: './SNPE043.component.html',
  styleUrls: ['./SNPE043.component.css']
})

export class SNPE043Component implements OnInit {


  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewRef: ViewContainerRef,
    private router: Router
  ) { }


  public INVOICE_NO: string = '';
  public INVOICE_DATE: string = '';
  public VENDOR_CODE: string = '';
  public mtCurrencyCode: any = [];
  public dataHeader: any = [];
  public dataDetail: any = {};
  public dataSummary: any = [];
  public dataPartList: any = {};  
  public calDetail: any = {};

  public VendorConfig: any = {
    ColName: "VENDOR_TEXT",
    ColValue: "",
    PlaceholderText: "Select Vendor Code",
    SourceController: "IC",
    SourceMethodName: "SNPR019_FindFVendor",
    NoOfShowRecords: 50,
    MinLengthSearch: 2,
    UpperCase: true
  }

  public InvoiceConfig: any = {
    ColName: "INVOICE_VENDOR",
    ColValue: "",
    PlaceholderText: "Select Invoice No.",
    SourceController: "wPMS",
    SourceMethodName: "GetInvoiceImport",
    NoOfShowRecords: 50,
    MinLengthSearch: 3
  }


  public tblFooter: any = [
    {
      fieldName: "ACCEPT_PART_NO",
      value: "Total",
      show: true
    },
    {
      fieldName: "CIF_FREIGHT_AMT_B",
      
      show: true
    },
    {
      fieldName: "CIF_INSURANCE_AMT_B",
      
      show: true
    },
    {
      fieldName: "CIF_OTHER_AMT_B",
      
      show: true
    },
    {
      fieldName: "EXP_CLEANRANCE_AMT_B",
      
      show: true
    },
    {
      fieldName: "EXP_FREIGHT_AMT_B",
      
      show: true
    },
    {
      fieldName: "EXP_OTHER_AMT_B",
      
      show: true
    },
    {
      fieldName: "INCOME_TAX",
      
      show: true
    },
    {
      fieldName: "EXCISE_TAX",
      
      show: true
    },
    {
      fieldName: "INTERIOR_TAX",
      
      show: true
    },
    {
      fieldName: "RACK_DUTY",
      
      show: true
    },
    {
      fieldName: "OTHER_TAX",
      
      show: true
    },
    {
      fieldName: "TOT_AMT_B",
      
      show: true
    },
    {
      fieldName: "TOT_AMT_C",
      
      show: true
    },
    {
      fieldName: "FREIGHT_AMT_B",
      
      show: true
    },
    {
      fieldName: "INS_AMT_B",
      
      show: true
    },
    {
      fieldName: "EXPENSE_AMT_B",
      
      show: true
    },
    {
      fieldName: "DUTY_AMT_B",
      
      show: true
    },
    {
      fieldName: "OTHER_AMT_B",
      
      show: true
    },
    {
      fieldName: "TOT_AMT_CIF_B",
      
      show: true
    }
  ]
  ngOnInit() {




  }


  public InvoiceChanged(value: any) {
    
    this.INVOICE_NO = value.INVOICE_NO;
    this.INVOICE_DATE = value.INVOICE_DATE;
    this.VENDOR_CODE = value.VENDOR_CODE;
    this.GetInvData(0);
  }

  private GetInvData(p_Cal) {
    var tmp = '';
    tmp = this.dataHeader.C_AUTO_CAL_DUTY;

    this.http.get("AC", "SNPE007_GetInvoiceInfo", this.INVOICE_NO, this.INVOICE_DATE, this.VENDOR_CODE)
      .subscribe(result => {
        this.dataHeader = result.Table[0];
        this.dataDetail = result.Table1;
        if (p_Cal != 1) {
        this.dataSummary = result.Table2[0];
        }        
        this.dataHeader.C_AUTO_CAL_DUTY = tmp;
      })
  }

  private SetAmount() {
    //--- OTHER_AMT_C separate to (new) CIF_FREIGHT_AMT_C + CIF_INSURANCE_AMT_C + CIF_OTHER_AMT_C
    this.dataHeader.OTHER_AMT_B = (this.dataHeader.CIF_FREIGHT_AMT_C + this.dataHeader.CIF_INSURANCE_AMT_C + this.dataHeader.CIF_OTHER_AMT_C)
      * (this.dataHeader.EXCHANGE_RATE / this.dataHeader.DP_EXCHANGE_UNIT);
    //--- EXPENSE_AMT_B [Total (3)] separate to
    this.dataHeader.EXPENSE_AMT_B = this.dataHeader.EXP_CLEANRANCE_AMT_B + this.dataHeader.EXP_FREIGHT_AMT_B + this.dataHeader.EXP_OTHER_AMT_B;
    //--- 
    this.dataHeader.DUTY_AMT_B = this.dataHeader.INCOME_TAX + this.dataHeader.EXCISE_TAX + this.dataHeader.INTERIOR_TAX + this.dataHeader.RACK_DUTY + this.dataHeader.OTHER_TAX;
    //this.dataHeader.DUTY_AMT_B = this.dataHeader.INCOME_TAX;
  }
  public Calculation() {


    if (this.dataHeader.C_AUTO_CAL_DUTY) {
      this.dataHeader.AUTO_CAL_DUTY = 'Y';
    } else {
      this.dataHeader.AUTO_CAL_DUTY = 'N';
    }

    //--- Set amount ----
    this.SetAmount();
    this.http.get("AC", "SNPE007_Validate", this.INVOICE_NO, this.INVOICE_DATE, this.VENDOR_CODE)
      .subscribe(result => {
        if (result == 'DONE') {
          this.http.post("AC", "SNPE007_BTM_CAL", JSON.stringify(this.dataHeader))
            .subscribe(result => {            
              if (result != 'Error') {
                this.dataSummary = result.Table[0];              
                this.GetInvData(1);
                this.modal.info("Calculate operation successfully", this.viewRef);
              } else {
                this.modal.warning("Found an error, please contract support team", this.viewRef);
              }           

            })
        } else if (result == 'NO DATA FOR CALCULATE') {
          this.modal.warning("No received part for calculation", this.viewRef);
        } else {
          this.modal.warning("Found an error, please contract support team", this.viewRef);
        }
      })     
  }


  public Confirm() {      
    this.SetAmount();
    this.modal.confirm("Are you sure to confirm this invoice : " + this.INVOICE_NO + " ?", this.viewRef,
      () => {

    this.http.post("AC", "SNPE007_Confirm", JSON.stringify(this.dataHeader))
      .subscribe(result => {
        if (result == "DONE") {
          this.modal.info("Confirm operation successfully : " + result, this.viewRef);
        } else {
          this.modal.warning("Found an error, please contract support team", this.viewRef);
        }
      }, (err) => {
          console.log(err, 'err')
          this.modal.warning("Found an error, please contract support team", this.viewRef);
      })
      }, () => { })
  }
  
  public SaveData() {

    this.SetAmount();
    this.http.post("AC", "SNPE007_Save", JSON.stringify(this.dataHeader))
      .subscribe(result => {
        if (result == "DONE") {
          this.GetInvData(0);
          this.modal.info("Save successfully : " + result, this.viewRef);
        } else {
          this.modal.warning("Found an error, please contract support team", this.viewRef);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contract support team", this.viewRef);
      })


  }

  public SendByChanged() {

  }


  public GetpartList() {

    this.http.get("AC", "SNPE007_GetPartExpList", this.INVOICE_NO, this.INVOICE_DATE, this.dataHeader.VENDOR_CODE)
      .subscribe(result => {
        if (result != 'Error') {
          this.dataPartList = result.Table;
        } else {
          this.modal.warning("Found an error, please contract support team", this.viewRef);
        }
     
      })

  }

  public SaveDetail() {

  }

  public Report(){
}
}
