import { Component, OnInit, ViewContainerRef } from "@angular/core";
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';
import { MatDatepickerInputEvent } from '@angular/material/datepicker';
import { Globals } from 'src/app/core/global';


@Component({
    selector : 'SNPP014_M',
    templateUrl : './SNPP104_M.component.html',
    styleUrls : ['./SNPP104_M.component.css']
})

export class SNPP104_MComponent implements OnInit{

    constructor(
        private http : HttpService,
        private modal : ModalService,
        private viewref : ViewContainerRef,
        private global : Globals
    ){}

    public tableData : any = [];
    public ConditionDate =  new Date();
    public Params = {
        CONDITION_DATE : new Date(),
        STOCK_VALUE : 0,
        STOCK_ITEMS : 0,
        CS_STK_VLU : 0

    }


    public ConfigManModel: any = {
        ColName: "LOOKUP",
        PlaceholderText: "Select Main Model",
        SourceController: "AC",
        SourceMethodName: "SNPP104_M_GetMainModel",
        NoOfShowRecords: 50,
        MinLengthSearch: 1,
        SourceParams: {
            CONDITION_DATE : this.FormatDate(new Date())
        },
    }

    public ConfigPart: any = {
        ColName: "LOOKUP",
        PlaceholderText: "Select Part",
        SourceController: "AC",
        SourceMethodName: "SNPP104_M_GetPartNo",
        NoOfShowRecords: 50,
        SourceParams: {
            CONDITION_DATE : this.FormatDate(new Date())
        },
        UpperCase: true
    }
    private files: any = [];
    public FileName: string = ""
    ngOnInit(){
        this.CreateTableRow(0)
    }

    Confirm(event){
        //console.log(event);
        this.modal.confirm("Do you want to insert dead stock ?",this.viewref,() => {event.click()})
        //event.click();
    }

    OnFileSelect(fileInput) {
        console.log(fileInput)
        this.files = fileInput.target.files;
        this.FileName = this.files[0].name;
        this.UpLoad();
      }

      UpLoad(){
        let formData = new FormData();
        formData.append('file', this.files[0]);

        this.http.postFile('AC', 'SNPP104_M_Upload', formData)
        .subscribe(res => {
            console.log(res)
            if(res == 'DONE'){
                this.InsertDeadStockFromUpload()
            }else{
                this.modal.error("Upload Fail",this.viewref);
            }
   
        },(err) => {
            this.modal.error("Upload Fail",this.viewref);
        })
      }


    InsertDeadStockFromUpload(){
        let ConditionDate = this.FormatDate(this.Params.CONDITION_DATE);
        this.http.get("AC","SNPP104_M_InsertDeadStockFromUpload",ConditionDate)
        .subscribe(res => {
            console.log(res)
            if(res.Table[0].STATUS == 'Done'){
                this.modal.info("Process Complete....",this.viewref,() => {
                    this.http.get("AC","SNPP104_M_FindStock",ConditionDate,'AFTER_INSERT')
                    .subscribe(res =>{
                        this.Params.STOCK_ITEMS = res.Table[0].STOCK_ITEM
                        this.Params.STOCK_VALUE = res.Table[0].STOCK_VALUE
                        this.Params.CS_STK_VLU = res.Table[0].CS_STK_VLU
                     })
                })
            }else{
                this.modal.error("Process Not Complete....",this.viewref)
            }
        },(err) => {
            this.modal.error("Process Not Complete....",this.viewref)
        })
    }

    InsertDeadStock(){

        this.modal.confirm("Do you want to insert dead stock ?",this.viewref,this.ConfirmInsertDeadStock)
    }

    ConfirmInsertDeadStock = () => {
        let ConditionDate = this.FormatDate(this.Params.CONDITION_DATE);
        let UPDATE = this.tableData.filter(x => x.MAIN_MODEL || x.PART_NO).map(x => {
            return {
                MAIN_MODEL : x.MAIN_MODEL,
                PART_NO : x.PART_NO,
                CONDITION_DATE : ConditionDate
            }
        })
        let INSERT = {CONDITION_DATE : ConditionDate}

        this.http.post("AC","SNPP104_M_InsertDeadStock",{'INSERT' : INSERT,'UPDATE' : UPDATE})
        .subscribe(res =>{
            if(res.Table[0].STATUS == 'Done'){
                this.modal.info("Process Complete....",this.viewref,() => {
                    this.http.get("AC","SNPP104_M_FindStock",ConditionDate,'AFTER_INSERT')
                    .subscribe(res =>{
                        this.Params.STOCK_ITEMS = res.Table[0].STOCK_ITEM
                        this.Params.STOCK_VALUE = res.Table[0].STOCK_VALUE
                        this.Params.CS_STK_VLU = res.Table[0].CS_STK_VLU
                     })
                })
               
            }else{
                this.modal.error("Process Not Complete....",this.viewref)
            }
           
        },(err) => {
            this.modal.error("Process Not Complete....",this.viewref)
        })
    }

    LockSales(){
        this.modal.confirm("Do you want to update lock sales (999)?",this.viewref,this.ConfirmLockSales)
    }

    ConfirmLockSales = () => {
        this.http.post("AC","SNPP104_M_UpdateLockDead",{'CONDITION_DATE' : this.FormatDate(this.Params.CONDITION_DATE)})
        .subscribe(res =>{
           
            if(res.Table[0].STATUS == 'Done'){
                this.modal.info("Process Complete....",this.viewref)
            }else{
                this.modal.error("Process Not Complete....",this.viewref)
            }
            
        },(err) => {
            this.modal.error("Process Not Complete....",this.viewref)
        })
    }

    UpdateDeadStack(){
        this.modal.confirm("Do you want to update dead stock ?",this.viewref,this.ConfirmUpdateDeadStock)
    }

    ConfirmUpdateDeadStock = () => {
        this.http.post("AC","SNPP104_M_ConfirmDeleteDeadStock",{'CONDITION_DATE' : this.FormatDate(this.Params.CONDITION_DATE)})
        .subscribe(res =>{
            console.log(res)
            if(res.Table[0].STATUS == 'Done'){
                this.modal.info("Process Complete....",this.viewref)
            }else{
                this.modal.error("Process Not Complete....",this.viewref)
            }
           
        },(err) => {
            this.modal.error("Process Not Complete....",this.viewref)
        })
    }

    Print(type){
        switch(type){
            case 'IC' :
              
                    this.global.GoToReport("PMS_RPT_ACC_SNPP104R1",
                    {
                      P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
                      P_CONDITION_DATE: this.FormatDate2(this.Params.CONDITION_DATE),
                    });

                    this.global.GoToReport("PMS_RPT_ACC_SNPP104R12",
                    {
                      P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
                      P_CONDITION_DATE: this.ConditionDate,
                    });
                  
                break;
            case 'AC' :
                    this.global.GoToReport("PMS_RPT_ACC_SNPP104R2",
                    {
                        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
                        P_CONDITION_DATE: this.FormatDate2(this.Params.CONDITION_DATE),
                    });

                    this.global.GoToReport("PMS_RPT_ACC_SNPP104R3",
                    {
                        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
                        P_CONDITION_DATE: this.FormatDate2(this.Params.CONDITION_DATE),
                    });

                    this.global.GoToReport("PMS_RPT_ACC_SNPP104R4",
                    {
                        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
                        P_CONDITION_DATE: this.FormatDate2(this.Params.CONDITION_DATE),
                    });
                break;
            case 'ALL' :
                this.global.GoToExport("PMS_RPT_ACC_SNPP104R1", {
                    P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
                    P_CONDITION_DATE: this.FormatDate2(this.Params.CONDITION_DATE),
          
                  }, true, "pdf")

                  this.global.GoToExport("PMS_RPT_ACC_SNPP104R2", {
                    P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
                    P_CONDITION_DATE: this.FormatDate2(this.Params.CONDITION_DATE),
                  }, true, "pdf")

                  this.global.GoToExport("PMS_RPT_ACC_SNPP104R3", {
                    P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
                    P_CONDITION_DATE: this.FormatDate2(this.Params.CONDITION_DATE),
                  }, true, "pdf")

                  this.global.GoToExport("PMS_RPT_ACC_SNPP104R4", {
                    P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
                    P_CONDITION_DATE: this.FormatDate2(this.Params.CONDITION_DATE),
                  }, true, "pdf")

                  this.global.GoToExport("PMS_RPT_ACC_SNPP104R12", {
                    P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
                    P_CONDITION_DATE: this.FormatDate2(this.Params.CONDITION_DATE),
                  }, true, "pdf")

                  this.global.GoToExport("PMS_RPT_ACC_SNPP104R6", {
                    P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
                    P_CONDITION_DATE: this.FormatDate2(this.Params.CONDITION_DATE),
                  }, true, "pdf")
                break;
            default :
                console.log("type not macth")
                break;
        }
    }

    DateChange(event){
        let Dateformat = this.FormatDate(event);
        this.ConfigManModel.SourceParams.CONDITION_DATE = Dateformat;
        this.ConfigPart.SourceParams.CONDITION_DATE = Dateformat;
      
        this.http.get("AC","SNPP104_M_FindStock",Dateformat,'DATE_CHANGE')
            .subscribe(res =>{
                this.Params.STOCK_ITEMS = res.Table[0].STOCK_ITEM
                this.Params.STOCK_VALUE = res.Table[0].STOCK_VALUE
                this.Params.CS_STK_VLU = res.Table[0].CS_STK_VLU
              
            })

    }

    CheckTableLength(index : number){
        let CheckLenngth = this.tableData.length - (index + 1);
        if(CheckLenngth == 0){
            this.CreateTableRow(index + 1)
        } 
    }
 

    CreateTableRow(index : number){
     
        let length = index % 10;
        if(length == 0){
            while(length < 10) {
                this.tableData.push({
                    MAIN_MODEL : null,
                    PART_NO : null
                })
                length++;
            }
            this.tableData = this.tableData.slice();
        }
    }

    CheckMainModel(index : number){
        let active = true;
        if(index > 0){
            let tmp = this.tableData[index - 1]
            active = tmp.MAIN_MODEL ? true : false;
        }
        return active
    }

    CheckPart(index : number){
        let active = true;
        if(index > 0){
            let tmp = this.tableData[index - 1]
            active = tmp.PART_NO ? true : false;
        }
        return active
    }


    FormatDate(date) {

        let d = new Date(date);
        let Day = d.getDate().toString();
        let NewDay = Day.toString().length < 2 ? '0' + Day.toString() : Day.toString()
        let Month = d.getMonth() + 1;
        let NewMonth = Month.toString().length < 2 ? '0' + Month.toString() : Month.toString()
        let Year = d.getFullYear().toString();
        return Year + NewMonth + NewDay;
  }

  FormatDate2(date){
      
      let monthText = ["JAN", "FEB", "MAR", "APR", "MAY", "JUN","JUL", "AUG", "SEP", "OCT", "NOV", "DEC"];

      let d = new Date(date);
      let Day = d.getDate().toString();
      let NewDay = Day.toString().length < 2 ? '0' + Day.toString() : Day.toString()
      let Month = d.getMonth();
      let MonthText = monthText[Month]
      let Year = d.getFullYear().toString().substr(-2);
      return NewDay + MonthText + Year;
  }
}