import { Component, ElementRef, EventEmitter, Input, OnInit, Output, ViewChild, ViewContainerRef } from '@angular/core';
import { Globals } from 'src/app/core/global';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';

@Component({
    selector: 'SNPP104_NP-upload',
    templateUrl: 'SNPP104_NP-upload.component.html',
    styleUrls: ['./../SNPP104_NP.component.css'],
})

export class SNPP104_NPUploadComponent implements OnInit {
    constructor(
        private http: HttpService,
        private modal: ModalService,
        private viewref: ViewContainerRef,
        private global: Globals) { }

    private files: any = [];
    public FileName: string = "";
    public DataUploadList = [];
    @ViewChild("fileUpload") fileUpload: ElementRef;
    @Input() showUpload;
    @Output() showUploadChange: EventEmitter<boolean> = new EventEmitter<boolean>();
    @Output() uploadCallBack: EventEmitter<boolean> = new EventEmitter<boolean>();


    ngOnInit() { }

    SelectUploadFile() {
        this.fileUpload.nativeElement.value = null;
        this.fileUpload.nativeElement.click();
    }

    OnFileSelect(fileInput) {
        this.files = fileInput.target.files;
        this.FileName = this.files[0].name;

        if (this.files.length == 0) {
            this.modal.warning('Please Open xlsx File First...', this.viewref)
        } else {
            this.DataUploadList = []
            let formData = new FormData();
            formData.append('file', this.files[0]);

            this.http.postFile('AC', 'SNPP104_NP_Upload', formData)
                .subscribe(res => {
                    if(res.status === "Done") {
                        this.DataUploadList = res.data.Table;
                    } else {
                        this.modal.error(res.message, this.viewref);
                    }
                });
        }
    }

    Upload() {
        let errorRecs = this.DataUploadList.filter(v => v.STATUS == "N");
        let uploadableRecs = this.DataUploadList.filter(v => v.STATUS == "Y");

        this.modal.confirm("Are you sure to confirm upload?" + (errorRecs.length > 0 ? "<br/> ***Error records will not be inserted." : ""), this.viewref,
            () => {
                if (uploadableRecs.length > 0) {
                    this.http.get("AC", "SNPP104_NP_ConfirmUpload")
                        .subscribe(result => {
                            if(result.status === "Done") {
                                this.modal.info("Upload data completed.", this.viewref, () => {
                                    setTimeout(() => {
                                        this.CloseUploadDeadStock();
                                        this.uploadCallBack.emit(true);
                                    }, 50)
                                });
                            } else {
                              this.modal.error(result.message, this.viewref)
                            }
                        }, err => {
                            this.modal.error('Un-handled error, please contact administrator.', this.viewref);
                        })
                } else {
                    this.modal.warning("No records to be uploaded.", this.viewref);
                }
            }, () => { })
    }

    CloseUploadDeadStock() {
        this.showUpload = false;
        this.showUploadChange.emit(this.showUpload);
    }

    DownloadTemplate() {
        let link = "assets/templates/DeadStock_Upload_Template.xlsx"
        window.open(link, '_blank')
    }
    
    DownloadResultReport() {
        this.global.GoToReport("PMS_RPT_ACC_SNPP104_NP_Upload_Result", {
            "P_COMPANY_CODE": this.global.GetTokenDetail("ssComCode"),
            "P_CREATE_BY": this.global.GetTokenDetail("ssUserName")
        })
    }
}