import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { ModalService } from '../../../core/modal.service';

@Component({
  selector: 'SNSR015',
  templateUrl: './SNSR015.component.html',
  styleUrls: ['./SNSR015.component.css']
})



export class SNSR015Component implements OnInit {


  constructor(
    private http: HttpService,
    private router: Router,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private global: Globals
  ) { }
  @ViewChild("dialogDoc", { static: false }) dialogDoc: any;
  @ViewChild("dialogPart", { static: false }) dialogPart: any;
  @ViewChild("dialogCus", { static: false }) dialogCus: any;

  public CustomerList: any = [];
  public data: any = {};
  public dialogDocStatus: any;
  public dialogPartStatus: any;
  public dialogCusStatus: any;
  public sDocData: any;
  public sPartData: any;
  public sCusData: any;
  public param: any = {
    DOCUMENT_FROM: null,
    DOCUMENT_TO: null,
    DOC_DATE_FROM: null,
    DOC_DATE_TO: null,
    PART_FROM: null,
    PART_TO: null,
    CUS_FROM: null,
    CUS_TO: null
  }

  public ConfigDoc: any = {
    ColName: "DOCUMENT_NO",
    ColValue: "DOCUMENT_NO",
    PlaceholderText: "Select Document",
    SourceController: "AC",
    SourceMethodName: "SNSR015_GetDoc",
    NoOfShowRecords: 100,
    MinLengthSearch: 5,
    UpperCase: false
  }
  public ConfigPart: any = {
    ColName: "LOOKUP",
    ColValue: "PART_NO",
    PlaceholderText: "Select Part",
    SourceController: "AC",
    SourceMethodName: "SNSR015_GetPart",
    NoOfShowRecords: 30,
    MinLengthSearch: 1,
    UpperCase: false
  }
  public ConfigCus: any = {
    ColName: "LOOKUP",
    ColValue: "CUSTOMER_CODE",
    PlaceholderText: "Select Customer",
    SourceController: "AC",
    SourceMethodName: "SNSR015_GetCustomer",
    NoOfShowRecords: 30,
    MinLengthSearch: 1,
    UpperCase: false
  }

  ngOnInit() {

  }

  Print() {
    if (this.param.DOCUMENT_TO  < this.param.DOCUMENT_FROM) {
      this.modal.warning("Document From  is not larger than Document To", this.viewref)
      return;
    }
    if (this.param.DOC_DATE_TO < this.param.DOC_DATE_FROM) {
      this.modal.warning("Date From  is not larger than Date To", this.viewref)
      return;
    }
    if (this.param.PART_TO < this.param.PART_FROM) {
      this.modal.warning("Part From  is not larger than Part To", this.viewref)
      return;
    }
    if (this.param.CUS_TO < this.param.CUS_FROM) {
      this.modal.warning("Customer From  is not larger than Customer To", this.viewref)
      return;
    }
   
    this.param.DOC_DATE_FROM = this.getDateParam(this.param.DOC_DATE_FROM);
    this.param.DOC_DATE_TO = this.getDateParam(this.param.DOC_DATE_TO);
    this.global.GoToReport("PMS_RPT_ACC_SNSR015_new",
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_DOCUMENT_NO_FROM: this.param.DOCUMENT_FROM,
        P_DOCUMENT_NO_TO: this.param.DOCUMENT_TO,
        // P_DOC_DATE_FROM: this.param.DOC_DATE_FROM,
        // P_DOC_DATE_TO: this.param.DOC_DATE_TO,
        // P_PART_FROM: this.param.PART_FROM,
        // P_PART_TO: this.param.PART_TO,
        // P_CUS_FROM: this.param.CUS_FROM,
        // P_CUS_TO: this.param.CUS_TO
      });
  }
  getDateParam(P_data) {
    if (P_data !== null && P_data != undefined) {
      let dt = new Date(P_data);
      let year = dt.getFullYear();
      let month = (1 + dt.getMonth()).toString().padStart(2, '0');
      let day = dt.getDate().toString().padStart(2, '0');
      var p_Date = year + '-' + month + '-' + day;
      return p_Date;
    } else {
      return null;
    }
  }

 
  FindDoc(evt,p) {
    if (p === "F") {
      this.param.DOCUMENT_FROM = evt;
    } else {
      this.param.DOCUMENT_TO = evt;
    }
  }
  FindPart(evt, p) {
    if (p === "F") {
      this.param.PART_FROM = evt;
    } else {
      this.param.PART_TO = evt;
    }
  }
  FindCus(evt, p) {
    if (p === "F") {
      this.param.CUS_FROM = evt;
    } else {
      this.param.CUS_TO = evt;
    }
  }

  OpenDocDialog(p) {
    this.dialogDocStatus = p;
    this.http.get("AC", "SNPE015_GetDoc")
      .subscribe(result => {
        this.sDocData = result.Table;
        this.dialogDoc.title = "Search";
        this.dialogDoc.OpenDialog();
      });
  }
  OpenPartDialog(p) {
    this.dialogPartStatus = p;
    this.http.get("AC", "SNPE015_GetPart")
      .subscribe(result => {
        this.sPartData = result.Table;
        this.dialogPart.title = "Search";
        this.dialogPart.OpenDialog();
      });
  }
  OpenCusDialog(p) {
    this.dialogCusStatus = p;
    this.http.get("AC", "SNPE015_GetCus")
      .subscribe(result => {
        this.sCusData = result.Table;
        this.dialogCus.title = "Search";
        this.dialogCus.OpenDialog();
      });
  }
  SelectDialogDoc(evt) {
    if (this.dialogDocStatus === "F") {
      this.param.DOCUMENT_FROM = evt.DOCUMENT_NO;
    } else {
      this.param.DOCUMENT_TO = evt.DOCUMENT_NO;
    }
    this.dialogDoc.Close();
  }
  SelectDialogPart(evt) {
    if (this.dialogPartStatus === "F") {
      this.param.PART_FROM = evt.PART_NO;
    } else {
      this.param.PART_TO = evt.PART_NO;
    }
    this.dialogPart.Close();
  }
  SelectDialogCus(evt) {
    if (this.dialogCusStatus === "F") {
      this.param.CUS_FROM = evt.CUSTOMER_CODE;
    } else {
      this.param.CUS_TO = evt.CUSTOMER_CODE;
    }
    this.dialogCus.Close();
  }
}
