import { Component, OnInit, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';


@Component({
  selector: 'snba009_uss',
  templateUrl: 'SNBA009_USS.component.html',
  styleUrls: ['../domsale.component.css']
})

export class SNBA009_USSComponent implements OnInit {

  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  public paramsControl: any = {};
  public paramsAllPart: any = {};
  public paramsGroupPart: any = {};

  public tableData: any = [];
  public tableData_Ref: any = [];

  public ConfigGroupPartNo: any = {
    ColName: "LOOKUP_GROUP_PART_NO",
    PlaceholderText: "Select Group Part No.",
    SourceController: "SL",
    SourceMethodName: "SNBA009_USS_GetGroupPartNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetGroupPartNo(value: any) {
    this.paramsGroupPart.GROUP_PART_NO = value.GROUP_PART_NO;
  }

  ngOnInit() {
    this.GetData();
  }

  public GetData() {
    this.http.get('SL', 'SNBA009_USS_GetControl')
      .subscribe(res => {
        this.paramsControl = res.Table[0];

        this.paramsControl.REF_START_DATE = this.paramsControl.START_DATE;
        this.paramsControl.REF_END_DATE = this.paramsControl.END_DATE;
        this.paramsControl.REF_BATCH_STATUS = this.paramsControl.BATCH_STATUS;
      }, (err) => {
        this.modal.warning("Found an error, please contract support team", this.viewref);
      });
  }

  public GetPercent() {
    this.http.get('SL', 'SNBA009_USS_GetPercent')
      .subscribe(res => {
        this.paramsAllPart = res.Table[0];
      }, (err) => {
        this.modal.warning("Found an error, please contract support team", this.viewref);
      });
  }

  public Search() {
    this.tableData = [];
    this.http.post('SL', 'SNBA009_USS_GetData', this.paramsGroupPart)
      .subscribe(res => {
        this.tableData = res.Table;
        this.tableData_Ref = JSON.parse(JSON.stringify(this.tableData));

      })
  }

  public tabClick(tab: any) {
    if (tab == 0) {
      this.GetData();
    }
    else if (tab == 1) {
      this.GetPercent();
    }
    else if (tab == 2) {

    }
  }

  public Save(type) {
    if (type == '1') {
      if (this.paramsControl.REF_START_DATE == this.paramsControl.START_DATE && this.paramsControl.REF_END_DATE == this.paramsControl.END_DATE && this.paramsControl.REF_BATCH_STATUS == this.paramsControl.BATCH_STATUS) {
        this.modal.warning("There is no data change", this.viewref);
        return;
      }
      if (this.paramsControl.START_DATE == null || this.paramsControl.END_DATE == null) {
        this.modal.warning('Start data and End date can not blank!!', this.viewref);
        return;
      }
      let startDate = new Date(this.paramsControl.START_DATE).getTime()
      let endDate = new Date(this.paramsControl.END_DATE).getTime()
      if (startDate > endDate) {
        this.modal.warning('Start date over End date!!', this.viewref);
        return;
      }
      this.modal.confirm("Do you want to save change you have made?", this.viewref, this.ConfirmSaveControl)
    }
    else if (type == '2') {
      if (this.paramsAllPart.USS_PERCENT == null) {
        this.modal.warning('Value cannot to by empty!', this.viewref);
        return;
      }
      this.modal.confirm("Do you want to save change you have made?", this.viewref, this.ConfirmSaveAllPart)
    }
    else if (type == '3') {
      let notchange = (JSON.stringify(this.tableData_Ref) == JSON.stringify(this.tableData))
      if (notchange) {
        this.modal.warning('There is no data change.', this.viewref)
        return;
      }
      this.modal.confirm("Do you want to save change you have made?", this.viewref, this.ConfirmSaveGroupPart)
    }
  }

  private ConfirmSaveControl = () => {
    this.http.post("SL", "SNBA009_USS_UpdateControl", this.paramsControl)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.GetData();
        }
        else {
          this.modal.warning("Found an error, please contract support team", this.viewref);
        }
      }, (err) => {
        console.log(err, 'err');
        this.modal.warning("Found an error, please contract support team", this.viewref);
      });
  }

  private ConfirmSaveAllPart = () => {
    this.http.post("SL", "SNBA009_USS_UpdateAllPart", this.paramsAllPart)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
        }
        else {
          this.modal.warning("Found an error, please contract support team", this.viewref);
        }
      }, (err) => {
        console.log(err, 'err');
        this.modal.warning("Found an error, please contract support team", this.viewref);
      });
  }

  private ConfirmSaveGroupPart = () => {
    this.http.post("SL", "SNBA009_USS_UpdateGroupPart", this.tableData)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
        }
        else {
          this.modal.warning("Found an error, please contract support team", this.viewref);
        }
      }, (err) => {
        console.log(err, 'err');
        this.modal.warning("Found an error, please contract support team", this.viewref);
      });
  }

  public CalculateAQty(data, type) {
    if (type == 1) {
      if (data.BCONFIRM_PERCENT != null) {
        data.BCONFIRM_QTY = null;
        data.AQTY = Math.ceil(data.MONTH_DEMAND * (data.BCONFIRM_PERCENT / 100));
      }
      else {
        data.BCONFIRM_PERCENT = null;
        data.AQTY = data.BCONFIRM_QTY;
      }
    } else {
      if (data.BCONFIRM_QTY != null) {
        data.BCONFIRM_PERCENT = null;

        data.AQTY = data.BCONFIRM_QTY;

      } else {
        data.AQTY = Math.ceil(data.MONTH_DEMAND * (data.BCONFIRM_PERCENT / 100));
      }
    }
  }
}
