import { Component, OnInit, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';
import { SelectionModel } from '@angular/cdk/collections';

@Component({
  selector: 'SNSE011_N',
  templateUrl: './SNSE011_N.component.html',
  styleUrls: ['./SNSE011_N.component.css']
})



export class SNSE011_NComponent implements OnInit {

  public params: any = {};

  public TOTAL_QUANTITY: number = 0;
  public TOTAL_AMOUNT: number = 0;
  public IsSearch: boolean = true;
  public selection = new SelectionModel<any>(true, []);

  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  public DataIsSelected: any = [];

  public orderHeader: any = {};
  public orderList: any = [];
  public orderStatus: any = [];

  ngOnInit() {}

  public lookupCustomerCodeConfig: any = {
    ColName: "LOOKUP_CUSTOMER_NAME",
    PlaceholderText: "Select Customer Code",
    SourceController: "SL",
    SourceMethodName: "SNSE011_getCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public CustSearchConfig: any = {
    ColName: "CUSTOMER",
    PlaceholderText: "Select Customer Code",
    SourceController: "SL",
    SourceMethodName: "SNSE011_GetCustSearch",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }



  public BranchLookupConfig: any = {
    ColName: "BRANCH",
    PlaceholderText: "Select Branch Code",
    SourceController: "SL",
    SourceMethodName: "SNSE011_GetSearchBranch",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public OrderNoSearchConfig: any = {
    ColName: "LOOKUP_ORDER_NO",
    PlaceholderText: "Select Order No",
    SourceController: "SL",
    SourceMethodName: "SNSE011_GetSearchOrder",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public lookupOrderNoConfig: any = {
    ColName: "ORDER_NO",
    PlaceholderText: "Select Order No",
    SourceController: "SL",
    SourceMethodName: "SNSE011_getOrderNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public SetCustCode(value: any) {
    this.params.CUSTOMER_CODE = value.CUSTOMER_CODE;
    this.params.CUSTOMER_NAME = value.CUSTOMER_NAME;
    this.params.BRANCH_CODE = value.BRANCH_CODE;
    this.params.BRANCH_NAME_TH = value.BRANCH_NAME;
  }

  public SetBranchLookup(values: any) {
    this.params.BRANCH_CODE = values.BRANCH_CODE;
    this.params.BRANCH_NAME_TH = values.BRANCH_NAME_TH;
  
  }

  public SetOrderNo(value: any) {
    this.params.ORDER_NO = value.ORDER_NO;
  }

  public Search = () => {
    this.orderList = [];
    this.http.post("SL", "SNSE011_N_GetOrderList", this.params)
      .subscribe(res => {
        this.orderList = res.Table;
      }, (err) => {
        console.log(err)
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
  }

  public ViewOrder(orderHeader) {
    this.orderHeader = orderHeader;
    this.selection.clear();
    this.DataIsSelected = [];
    this.TOTAL_AMOUNT = 0;
    this.TOTAL_QUANTITY = 0;
    this.orderStatus = [];
    this.IsSearch = false;

    if (this.orderHeader.ORDER_CLASS == '1') {
      this.orderHeader.ORDER_CLASS_SH = this.orderHeader.ORDER_CLASS + ' : Hot Line';
    }
    else if (this.orderHeader.ORDER_CLASS == '2') {
      this.orderHeader.ORDER_CLASS_SH = this.orderHeader.ORDER_CLASS + ' : Emergency Order';
    }
    else if (this.orderHeader.ORDER_CLASS == '3') {
      this.orderHeader.ORDER_CLASS_SH = this.orderHeader.ORDER_CLASS + ' : New Model';
    }
    else if (this.orderHeader.ORDER_CLASS == '4') {
      this.orderHeader.ORDER_CLASS_SH = this.orderHeader.ORDER_CLASS + ' : Regular Order';
    }
    else if (this.orderHeader.ORDER_CLASS == '5') {
      this.orderHeader.ORDER_CLASS_SH = this.orderHeader.ORDER_CLASS + ' : Conditional Order';
    }
    else if (this.orderHeader.ORDER_CLASS == '7') {
      this.orderHeader.ORDER_CLASS_SH = this.orderHeader.ORDER_CLASS + ' : OIL';
    }


    this.http.post("SL", "SNSE011_N_GetDetail", orderHeader)
      .subscribe(res => {
        this.orderStatus = res.Table;
      }, (err) => {
        console.log(err)
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
  }

  public isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.orderStatus.length;
    return numSelected === numRows;
  }

  public Toggle() {
    if (this.isAllSelected()) {
      this.selection.clear()
      this.orderStatus.map(x => {
        this.DataIsSelected = [];
        this.TOTAL_AMOUNT = 0
        this.TOTAL_QUANTITY = 0
      })
    } else {
      this.orderStatus.forEach(row => this.selection.select(row));
      this.DataIsSelected = [];
      this.TOTAL_AMOUNT = 0
      this.TOTAL_QUANTITY = 0
      this.orderStatus.map(x => {
        this.DataIsSelected.push(x);
        this.TOTAL_AMOUNT += x.NET_AMT_B
        this.TOTAL_QUANTITY += x.ACCEPT_QTY
      })
    }
  }

  public CheckBoxChanged(event, data) {
    if (event.checked) {
      this.TOTAL_AMOUNT += data.NET_AMT_B
      this.TOTAL_QUANTITY += data.ACCEPT_QTY
      this.DataIsSelected.push(data);
    } else {
      this.TOTAL_AMOUNT -= data.NET_AMT_B
      this.TOTAL_QUANTITY -= data.ACCEPT_QTY
      this.DataIsSelected.splice(this.DataIsSelected.indexOf(data), 1);

      if (this.TOTAL_AMOUNT < 0) { this.TOTAL_AMOUNT = 0 }
      if (this.TOTAL_QUANTITY < 0) { this.TOTAL_QUANTITY = 0 }
    }
  }

  public ConfirmSave() {
    if (this.DataIsSelected.length > 0) {
      this.modal.confirm('Are you sure to cancel selected rows?', this.viewref, this.Save)
    } else {
      this.modal.warning("Please select at least 1 item.", this.viewref);
      return;
    }
  }

  private Save = () => {
    this.DataIsSelected.forEach((e) => {
      e.HEADER_CUSTOMER_CODE = this.orderHeader.CUSTOMER_CODE;
      e.HEADER_ORDER_NO = this.orderHeader.ORDER_NO;
    });

    this.http.post('SL', 'SNSE011_N_Process', this.DataIsSelected)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info("Cancel back order completed.", this.viewref);
          this.IsSearch = true;
          this.Search();
        }
      }, (err) => {
        console.log(err)
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
  }

  public BackToGrid() {
    this.IsSearch = true;
  }
}
