import { Component, OnInit, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';


@Component({
  selector: 'snse015d',
  templateUrl: './SNSE015_D.component.html',
  styleUrls: ['./SNSE015_D.component.css']
})

export class SNSE015_DComponent implements OnInit {

  constructor(
    private Http: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  public params: any = {}
  public tableData: any = [];
  public isConfirmAllocate: boolean = false;

  public lookupCustomerCodeConfig: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "SL",
    SourceMethodName: "SNSE015_D_GetCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public lookupBranchConfig: any = {
    ColName: "LOOKUP_BRANCH_NAME",
    PlaceholderText: "Select Branch",
    SourceController: "wPMS",
    SourceMethodName: "GetCustomerBranch",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      CUSTOMER_CODE: null
    },
    UpperCase: true
  };

  public lookupOrderNoConfig: any = {
    ColName: "LOOKUP_ORDER_NO",
    PlaceholderText: "Select Order No",
    SourceController: "SL",
    SourceMethodName: "SNSE015_D_GetOrderNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      CUSTOMER_CODE: null,
      BRANCH_CODE: null
    },
    UpperCase: true
  }

  ngOnInit() {
    this.params.CHK_PRINT_PICKING_CARD = 'Y'
  }

  public SetSelectedCustomerCode(values: any) {
    this.params.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.params.CUSTOMER_NAME = values.CUSTOMER_NAME;
    this.params.BRANCH_NAME = values.BRANCH_NAME;
    this.params.BRANCH_CODE = values.BRANCH_CODE;
    this.params.LOCK_CUSTOMER = values.LOCK_CUSTOMER;
    this.lookupBranchConfig.SourceParams.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.lookupOrderNoConfig.SourceParams.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.lookupOrderNoConfig.SourceParams.BRANCH_CODE = values.BRANCH_CODE;
  }

  public SetBranchLookup(values: any) {
    this.params.BRANCH_NAME = values.BRANCH_NAME_TH;
    this.params.BRANCH_CODE = values.BRANCH_CODE;
    this.lookupOrderNoConfig.SourceParams.BRANCH_CODE = values.BRANCH_CODE;
  }

  public SetSelectedOrderNo(values: any) {
    this.params.ORDER_NO = values.ORDER_NO;
    this.params.ORDER_CLASS_TEXT = values.ORDER_CLASS_TEXT;
    this.params.ORDER_CLASS = values.ORDER_CLASS;
    this.params.ORDER_DATE = values.ORDER_DATE;
    this.params.BO_FLAG = values.BO_FLAG;
    this.params.DSP_BRANCH_STATUS = values.V_DSP_BRANCH_STATUS;
    this.params.DSP_BRANCH_STATUS_DESC = values.V_DSP_BRANCH_STATUS + " - " + values.V_DSP_BRANCH_STATUS_DESC;
    this.params.DSP_CREDIT_LIMIT = values.V_DSP_CREDIT_LIMIT;
    this.params.DSP_CREDIT_AVAILABLE = values.V_DSP_CREDIT_AVAILABLE;

    this.params.ROUTE_CODE = values.ROUTE_CODE;
    this.params.TRANSPORT_CODE = values.TRANSPORT_CODE;


    this.params.CUR_ROUTE_CODE = values.ROUTE_CODE;
    this.params.CUR_TRANSPORT_CODE = values.TRANSPORT_CODE;

    this.params.ORDER_TYPE = values.ORDER_TYPE;

    this.ChangeRouteCustLookupConfig.SourceParams.ORDER_CLASS = this.params.ORDER_CLASS;
    this.ChangeRouteCustLookupConfig.SourceParams.ORDER_TYPE = this.params.ORDER_TYPE;
    this.Search();
  }

  public ChangeRouteCustLookupConfig: any = {
    ColName: "LOOKUP_CUST",
    PlaceholderText: "Select Route No",
    SourceController: "SL",
    SourceMethodName: "SNSE015_D_GetChangeRouteCust",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      ORDER_CLASS: null,
      ORDER_TYPE: null
    },
    UpperCase: true
  }


  public SetChangeRouteCustLookup(cust: any) {
    console.log(cust)
    if (cust) {
      this.params.CHANGE_ROUTE_CUSTOMER = cust.CUSTOMER_CODE;
      this.params.DSP_CHANGE_ROUTE_CUST_NAME = cust.DSP_CUST_NAME;
      this.params.CHANGE_ROUTE_BRANCH = cust.BRANCH_CODE;
      this.params.ROUTE_CODE = cust.ROUTE_CODE;
      this.params.TRANSPORT_CODE = cust.TRANSPORT_CODE;
    }


    if (!this.params.CHANGE_ROUTE_CUSTOMER) {
        this.params.CHANGE_ROUTE_BRANCH = null;
        this.params.DSP_CHANGE_ROUTE_CUST_NAME = '';
        this.params.ROUTE_CODE = this.params.CUR_ROUTE_CODE;
        this.params.TRANSPORT_CODE = this.params.CUR_TRANSPORT_CODE;
    }
  }

  private Search = () => {
    this.tableData = [];
    this.isConfirmAllocate = false;
    this.Http.post('SL', 'SNSE015_D_getData', this.params)
      .subscribe(res => {
        this.tableData = res.Table;

        var V_ORDER_AMT = 0;
        var sum_INVOICE_AMT = 0;
        var V_ORDER_QTY = 0

        this.tableData.forEach((e) => {
          if (e.STATUS_CODE == 'N') {
            V_ORDER_QTY = e.ORDER_QTY;
          }
          else {
            V_ORDER_QTY = e.ACCEPT_QTY;
          }
          if (e.LOCK_SALES == 0 && e.OH_QTY > 0) {

            if (e.OH_QTY >= e.ORDER_QTY) {
              V_ORDER_AMT = e.ORDER_QTY * e.UNIT_PRICE_B
            }
            else {
              V_ORDER_AMT = e.OH_QTY * e.UNIT_PRICE_B;
            }
            sum_INVOICE_AMT += V_ORDER_AMT
          }
        });
        this.params.EST_INVOICE_AMT = sum_INVOICE_AMT;
      }, (err) => {
        console.log(err, 'err')
        this.modal.error("Get data error, please contract support team", this.viewref);
      });
  }

  public CheckboxChange(event) {
    if (event.checked) {
      this.params.CHK_PRINT_PICKING_CARD = 'Y'
    }
    else {
      this.params.CHK_PRINT_PICKING_CARD = 'N'
    }
  }

  public ConfirmAllocate() {
    this.modal.confirm('Do you want to allocate this order?', this.viewref, this.AllocateOrder)
  }

  private AllocateOrder = () => {
    this.Http.post('SL', 'SNSE015_D_Allocate', this.params)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE' && res.Table[0].DSP_FROM_INVOICE && res.Table[0].DSP_TO_INVOICE) {
          this.modal.info(res.Table[0].MSG, this.viewref);
          this.Search();

          this.params.DSP_FROM_INVOICE = res.Table[0].DSP_FROM_INVOICE;
          this.params.DSP_TO_INVOICE = res.Table[0].DSP_TO_INVOICE;
          this.params.DSP_CREDIT_LIMIT = res.Table[0].DSP_CREDIT_LIMIT;
          this.params.DSP_CREDIT_AVAILABLE = res.Table[0].DSP_CREDIT_AVAILABLE;
          this.params.ACT_INVOICE_AMT = res.Table[0].DSP_ACT_INVOICE_AMT;
          this.params.EST_INVOICE_AMT = res.Table[0].DSP_EST_INVOICE_AMT;

          this.isConfirmAllocate = true;
        }
        else if (res.Table[0].STATUS == 'FAIL') {
          console.log(res.Table[0].MESSAGE, 'err')
          this.modal.error("Allocate error, please contract support team", this.viewref);
        }
        else {
          this.modal.warning(res.Table[0].MSG, this.viewref);
          this.Search();
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.error("Allocate error, please contract support team", this.viewref);
      });
  }

  public ClearForm() {
    this.params = {};
    this.params.CHK_PRINT_PICKING_CARD = 'Y'
    this.tableData = [];
  }
}
