import { Component, OnInit, ViewContainerRef } from "@angular/core";
import { Subject } from "rxjs";
import { filter, take } from "rxjs/operators";
import { HttpService } from "src/app/core/http.service";
import { ModalService } from "src/app/core/modal.service";

@Component({
  selector: "SNSE015_V",
  templateUrl: "SNSE015_V.component.html",
  styleUrls: ["SNSE015_V.component.css"],
})
export class SNSE015_VComponent implements OnInit {
  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewRef: ViewContainerRef
  ) { }

  public orderHeader: any = {};
  public orderDetail: Array<any> = [];
  public isReadyToAllocate: boolean = false;

  private criteriaChange: Subject<boolean> = new Subject<boolean>();

  public CustomerLookupConfig: any = {
    ColName: "LOOKUP_VALUE",
    PlaceholderText: "Select Customer",
    SourceController: "SL",
    SourceMethodName: "SNSE015_V_GetCustomer",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true,
  };



  public BranchLookupConfig: any = {
    ColName: "BRANCH",
    PlaceholderText: "Select Branch Code",
    SourceController: "SL",
    SourceMethodName: "SNSE011_GetSearchBranch",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      CUSTOMER_CODE: this.orderHeader.CUSTOMER_CODE,
      BRANCH_CODE: this.orderHeader.BRANCH_CODE,
    },
    UpperCase: true
  }

  public OrderLookupConfig: any = {
    ColName: "LOOKUP_VALUE",
    PlaceholderText: "Select Order",
    SourceController: "SL",
    SourceMethodName: "SNSE015_V_GetOrder",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true,
    SourceParams: {},
  };

  ngOnInit() {
    this.criteriaChange.subscribe((v) => {
      if (v && this.orderHeader.CUSTOMER_CODE && this.orderHeader.ORDER_NO) {
        this.CheckOrder();
      }
    });
    this.orderHeader.CHK_PRINT_PICKING_CARD = "Y";
  }

  public SetCustomerLookup(cust: any) {
    this.orderHeader = {};
    this.orderHeader.CHK_PRINT_PICKING_CARD = "Y";
    this.orderHeader.CUSTOMER_CODE = cust.CUSTOMER_CODE;
    this.orderHeader.CUSTOMER_NAME = cust.CUSTOMER_NAME;
    this.orderHeader.BRANCH_CODE = cust.BRANCH_CODE;
    this.orderHeader.BRANCH_NAME = cust.BRANCH_NAME;

    this.OrderLookupConfig.SourceParams = {
      CUSTOMER_CODE: cust.CUSTOMER_CODE,
      BRANCH_CODE: cust.BRANCH_CODE,
    };


    this.orderHeader.ORDER_NO = '';
    //this.criteriaChange.next(true);
    if (!this.orderHeader.CUSTOMER_CODE || !this.orderHeader.BRANCH_CODE || !this.orderHeader.ORDER_NO) {
      this.orderDetail = [];
    }
  }


  public SetBranchLookup(values: any) {
    this.orderHeader.BRANCH_CODE = values.BRANCH_CODE;
    this.orderHeader.BRANCH_NAME_TH = values.BRANCH_NAME_TH;

    this.OrderLookupConfig.SourceParams = {
      CUSTOMER_CODE: this.orderHeader.CUSTOMER_CODE,
      BRANCH_CODE: values.BRANCH_CODE,
    };
    this.orderHeader.ORDER_NO = '';
    //this.criteriaChange.next(true);
  }

  public SetOrderLookup(order: any) {
    this.orderHeader.ORDER_NO = order.ORDER_NO;
    this.orderHeader.ORDER_DATE = order.ORDER_DATE;
    if (!this.orderHeader.CUSTOMER_CODE || !this.orderHeader.BRANCH_CODE || !this.orderHeader.ORDER_NO) {
      this.orderDetail = [];
    }

    this.criteriaChange.next(true);
  }

  public CheckPickingCardChange(chkBox) {
    this.orderHeader.CHK_PRINT_PICKING_CARD = chkBox.checked ? "Y" : "N";
  }

  public CheckOrder() {
    this.orderDetail = [];
    this.isReadyToAllocate = false;
    this.http
      .get(
        "SL",
        "SNSE015_V_GetOrderDetail",
        this.orderHeader.CUSTOMER_CODE,
        this.orderHeader.BRANCH_CODE,
        this.orderHeader.ORDER_NO
      )
      .subscribe(
        (res) => {
          if (res.Header?.length > 0) {
            this.orderHeader.BO_FLAG = res.Header[0].BO_FLAG;
            this.orderHeader.ORDER_CLASS = res.Header[0].ORDER_CLASS;
            this.orderHeader.ORDER_CLASS_NAME = res.Header[0].ORDER_CLASS_NAME;
            this.orderHeader.BRANCH_STATUS_DESC =
              res.Header[0].BRANCH_STATUS_DESC;
            this.orderHeader.CREDIT_LIMIT = res.Header[0].CREDIT_LIMIT;
            this.orderHeader.CREDIT_AVAILABLE = res.Header[0].CREDIT_AVAILABLE;
            this.orderDetail = res.Detail;
            this.isReadyToAllocate = true;
          }
        },
        (err) => {
        
          this.modal.warning(
            "Found an error, please contact support team",
            this.viewRef
          );
        }
      );
  }

  public BeginAllocate() {
    this.modal.confirm(
      "Are you sure to confirm Allocate?",
      this.viewRef,
      () => {
        this.http.post("SL", "SNSE015_V_BeginAllocate", this.orderHeader)
          .subscribe(res => {
            this.CheckOrder();
            if (res.Status === "Fail") {             
              this.modal.error(res.Message, this.viewRef);
            } else {
              this.modal.info(res.Message, this.viewRef);
              this.orderHeader.DSP_INVOICE_FROM = res.InvoiceFrom;
              this.orderHeader.DSP_INVOICE_TO = res.InvoiceTo;
              this.orderHeader.DSP_INVOICE_AMT = res.InvoiceAmount;
            }
          },
            (err) => {
              this.CheckOrder();
              this.modal.warning(
                "Found an error, please contact support team",
                this.viewRef
              );
            })
      },
      () => { }
    );
  }

  public SumEstimatedInvoiceAmt() {
    return this.orderDetail.reduce((v, o) => v + (o.ORDER_AMT || 0), 0)
  }
}
