import { Component, OnInit, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { ModalService } from '../../../core/modal.service';

@Component({
  selector: 'snse063r_a4',
  templateUrl: './SNSE063R_A4.component.html',
  styleUrls: ['./SNSE063R_A4.component.css']
})



export class SNSE063R_A4Component implements OnInit {


  constructor(
    private http: HttpService,
    private router: Router,
    private global: Globals,
    private modal: ModalService,
    private viewRef: ViewContainerRef
  ) { }

  public params: any = {};

  ngOnInit() {
    this.params.DOCUMENT_TYPE = 'DN'
    this.params.PRINT_FORMAT = 'NMT'
  }

  public ConfigDocStart: any = {
    ColName: "DOC_FROM",
    ColValue: "",
    PlaceholderText: "Select From Document No",
    SourceController: "SL",
    SourceMethodName: "SNSE063R_A4_GetDocumentStart",
    NoOfShowRecords: 50,
    MinLengthSearch: 5,
    UpperCase: true,
    SourceParams: {
      DOCUMENT_TYPE: "DN"
    },
  }

  public ConfigDocEnd: any = {
    ColName: "DOC_TO",
    ColValue: "",
    PlaceholderText: "Select To Document No End",
    SourceController: "SL",
    SourceMethodName: "SNSE063R_A4_GetDocumentEnd",
    NoOfShowRecords: 50,
    MinLengthSearch: 5,
    UpperCase: true,
    SourceParams: {
      DOCUMENT_TYPE: "DN"
    },
  }

  public DocumentTypeChange(event){
    this.ConfigDocStart.SourceParams.DOCUMENT_TYPE = event
    this.ConfigDocEnd.SourceParams.DOCUMENT_TYPE = event
    //console.log(event);
  }

  public RunReport() {
    if ((this.params.FROM_DOCUMENT_NO && this.params.TO_DOCUMENT_NO)) {

      this.http.post('SL', 'SNSE063R_A4_SetPrintData', this.params)
      .subscribe(res => {
        if(res === "Exists") {
          this.modal.info("Please wait for printing.", this.viewRef);
        } else {
          this.modal.info("Not found data for printing.", this.viewRef);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contract support team", this.viewRef);
      })


    }
    else {
      this.modal.warning("Please fill all data for print report!!", this.viewRef);
    }
  }
  public PreviewReport() {
    this.global.GoToReport("PMS_RPT_SALES_SNSE063R_A4", {
      P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      P_DOCUMENT_TYPE: this.params.DOCUMENT_TYPE,
      P_DOCUMENT_NO_FROM: this.params.FROM_DOCUMENT_NO,
      P_DOCUMENT_NO_TO: this.params.TO_DOCUMENT_NO,
      P_PRINT_FORMAT: this.params.PRINT_FORMAT
    })
  }
}
