import { Component, OnInit, ViewChild, ViewContainerRef } from "@angular/core";
import { HttpService } from '../../../core/http.service';
import { Router } from '@angular/router';
import { MatTableDataSource } from '@angular/material/table';
import { SelectionModel } from "@angular/cdk/collections";
import { Globals } from "src/app/core/global";
import { ModalService } from "src/app/core/modal.service";


@Component({
    selector: 'snse142',
    templateUrl: 'SNSE142.component.html',
    styleUrls: ['SNSE142.component.css']
})

export class SNSE142Component implements OnInit {

    constructor(
        private http: HttpService,
        private router: Router,
        private global : Globals,
        private modal :ModalService,
        private viewref : ViewContainerRef
    ) { }

    public ConfigSupplier: any = {
        ColName: "LOOKUP",
        ColValue: "",
        PlaceholderText: "Select Vendor Code",
        SourceController: "TI",
        SourceMethodName: "SNSE142_GET_VENDOR",
        NoOfShowRecords: 50,
        MinLengthSearch: 1,
        UpperCase: false
      }

      public ConfigPart: any = {
        ColName: "LOOKUP",
        ColValue: "",
        PlaceholderText: "Select Part No",
        SourceController: "TI",
        SourceMethodName: "SNSE142_GET_PART",
        NoOfShowRecords: 50,
        MinLengthSearch: 0,
        UpperCase: false,
        SourceParams: {
            VENDOR_CODE: null
          },
      }

    public CustomerList: any = [];
    private loaded: boolean = false;

    public tableData: any;
    public tableName: string;
    public headerList: Array<any> = [];
    public dataList: any;
    public displayedColumns: string[] = [];
    public paramSearch : any = {}

    public selection = new SelectionModel<any>(true, []);
    public LogList : any = [];
    @ViewChild("dialogProcessLog",{static: false}) dialogProcessLog : any;


    ngOnInit() {

    }


    public Search(){

        this.http.post("TI",'SNSE142_SEARCH',this.paramSearch)
        .subscribe(res =>{
            this.tableData = res.Table;
           this.CreateLog([]);
        })
    }

    public Save(){


        if(this.selection.selected.length == 0){
            this.modal.warning("Pleas select data",this.viewref)
            return
        }


        this.modal.confirm("Do you want to update current price",this.viewref,() => ConfirmSave())

        let ConfirmSave = () => {
            //console.log(this.selection.selected)
            let data = {
                DETAIL : this.selection.selected
            }
    
            this.http.post("TI","SNSE142_Save",data)
            .subscribe(res => {
                if(res.STATUS == 'DONE'){
                    this.modal.info("Update data complete",this.viewref)
                    this.GetProcessLog()
                    this.selection.clear();
                    this.Search();
                }else{
                    this.modal.error("Found eror, please contact support team.", this.viewref);
                }
                
            },err => {
                this.modal.error("Found eror, please contact support team.", this.viewref);
            })
        }
        
    }

    public ExportExcel(){

        this.selection.selected.map((x,index) => {
            x.SEQ = index + 1
            x.ADOPTED_DATE_FROM_PRINT = this.FormateDate(x.ADOPTED_DATE_FROM_CONVERT)
            x.ADOPTED_DATE_TO_PRINT = this.FormateDate(x.ADOPTED_DATE_TO_CONVERT)
        })
       
        this.http.Download("TI","SNSE142_ExportExcel",this.selection.selected)
        .subscribe(res =>{
            this.WriteContents(res)
            
        })
    }

    public WriteContents(content) {
        const a = document.createElement('a');
        const file = new Blob([content], { type: content.type });
        a.href = URL.createObjectURL(file);
        a.download = "SNSE142" + '_' + this.global.CurrentDate() + '' + ".xlsx";
        //a.download = "SNSE142.xlsx"
        a.click();
      }

    public isAllSelected() {
        const numSelected = this.selection.selected.length;
        const numRows = this.tableData.length;
        return numSelected === numRows;
      }
    
      public Toggle() {
    
        this.isAllSelected() ?
          this.selection.clear() :
          this.tableData.forEach(row => this.selection.select(row));
    
      }


      private FormateDate(date) {

        let d = new Date(date)
        let day = d.getDate();
        let newDay = day.toString().length < 2 ? 0 + '' + day.toString() : day.toString();
        let m = d.getMonth() + 1;
        let newMonth = m.toString().length < 2 ? 0 + '' + m.toString() : m.toString();
        let y = d.getFullYear();
  
        return  newDay + '-' + newMonth + '-' + y;
    }

    private GetProcessLog(){
        this.http.get("TI","SNSE142_GetProcessLog")
        .subscribe(res => {
          this.CreateLog(res.Table)
        })
      }


    private CreateLog(array : Array<any>){

        if(array.length > 0){
          this.LogList.push({
            LOG_DESCRIPTION : null
          })
    
          array.forEach(x =>{
            this.LogList.push({
              LOG_DESCRIPTION : x.LOG_DESCRIPTION
            })
          })
    
        }else{
         
        
          if(this.LogList.length > 0){
            this.LogList.push({
              LOG_DESCRIPTION : null
            })
          }
      
          this.LogList.push(
          {
            LOG_DESCRIPTION : 'Loading TPM_CURRENT_PRICE_PO...'
          },
          {
            LOG_DESCRIPTION : this.tableData.length + ' records loaded...'
          })
        }
      }

      public ShowLog(){
        this.dialogProcessLog.OpenDialog();
      }


      private SetFormateDate(d_date) {

        let d = new Date(d_date);
        let Day = d.getDate().toString().length < 2 ? '0' + d.getDate().toString() : d.getDate().toString();
        let Month = d.getMonth() + 1;
        let NewMonth = Month.toString().length < 2 ? '0' + Month.toString() : Month.toString()
        let Year = d.getFullYear().toString();
        let hours = d.getHours();
        let minute = d.getMinutes().toString().length < 2 ? '0' + d.getMinutes().toString() : d.getMinutes().toString();
        let seconds = d.getSeconds().toString();
    
        return Day + '/' + NewMonth + '/' + Year + ' ' + hours + ':' + minute + ':' + seconds;
      }

}
