import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { FormControl, Validators } from '@angular/forms';
import { ModalService } from 'src/app/core/modal.service';
import { SelectionModel } from '@angular/cdk/collections';


@Component({
  selector: 'snse163',
  templateUrl: 'SNSE163.component.html',
  styleUrls: ['SNSE163.component.css']
})

export class SNSE163Component implements OnInit {

  public params: any = {}
  public selectedrow: any;
  public PROCESS_LOG: any = [];
  public formData: any = [];

  constructor(
    private Http: HttpService,
    private router: Router,
    private global: Globals,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  @ViewChild("dialogProcess", { static: false }) dialogProcess: any;
  @ViewChild("dialogEffective", { static: false }) dialogEffective: any;

  public tableData: any = [];
  public DataIsSelected: any = [];

  public selection = new SelectionModel<any>(true, []);

  public selection2 = new SelectionModel<any>(true, []);

  ngOnInit() {
    this.params.OPP_GR_RATE = '0';
    this.params.COMPLETE_STATUS = '';
    this.params.SETTING_TYPE = '';
    this.params.CAL_DIS_RATE = 'D';
    this.params.CONFIRM_STATUS = 'N';
    this.params.EFFECTIVE_DATE = new Date();
  }

  public lookupCustomerCodeConfig: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "SL",
    SourceMethodName: "SNSE163_getCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public lookupPartNoConfig: any = {
    ColName: "LOOKUP_PART_NO",
    PlaceholderText: "Select Part No",
    SourceController: "SL",
    SourceMethodName: "SNSE163_getPartNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public lookupModelCodeConfig: any = {
    ColName: "LOOKUP_MODEL_CODE",
    PlaceholderText: "Select Mode Code",
    SourceController: "SL",
    SourceMethodName: "SNSE163_getModelCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedCustomerCode(values: any) {
    this.params.CUSTOMER_CODE = values.CUSTOMER_CODE;
  }

  public SetSelectedPartNo(values: any) {
    this.params.PART_NO = values.PART_NO;
  }

  public SetSelectedModelCode(values: any) {
    this.params.MODEL_CODE = values.MODEL_CODE;
  }

  Search() {
    this.Http.post('SL', 'SNSE163_getData', this.params)
      .subscribe(res => {
        this.tableData = res.Table;
        this.PROCESS_LOG.push('Loading TPM_FOB_PRICE_MASTER... ' + this.tableData.length + ' records loaded...');
        this.selection.clear()
        this.DataIsSelected = [];
        this.formData = [];
      });
  }

  rowClick(row) {
    this.params.MESSAGE_ERROR = row.MESSAGE_ERROR
  }

  isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.tableData.length;
    return numSelected === numRows;
  }

  Toggle() {
    if (this.isAllSelected()) {
      this.selection.clear()
      this.tableData.map(x => {
        this.DataIsSelected = [];
      })
    } else {
      this.tableData.forEach(row => this.selection.select(row));
      this.DataIsSelected = [];
      this.tableData.map(x => {
        this.DataIsSelected.push(x);
      })
    }
    this.params.CNT_SEL = this.DataIsSelected.length;
  }

  CheckboxChange(event, data) {
    if (event.checked) {
      this.DataIsSelected.push(data);
    }
    else {
      this.DataIsSelected.splice(this.DataIsSelected.indexOf(data), 1);
    }
    this.params.CNT_SEL = this.DataIsSelected.length;
  }

  radioChange(data, type) {
    if (type === 1) {
      data.RADIO1 = 'true'
      data.RADIO2 = 'false'
    }
    else {
      data.RADIO2 = 'true'
      data.RADIO1 = 'false'
    }
  }

  radioChangeAll(type) {
    this.tableData.forEach((e) => {
      if (type === 'G') {
        e.FOB_PRICE_FLAG = 'G'
      }
      else if (type === 'P') {
        e.FOB_PRICE_FLAG = 'P'
      }
    });
  }

  clickProcessLog() {
    this.dialogProcess.OpenDialog();
  }

  calculateAdjRate() {
    this.formData = [];
    if (this.params.PMS_ADJ_RATE) {
      this.tableData.forEach((e) => {
        e.PMS_ADJ_RATE = this.params.PMS_ADJ_RATE
        this.formData.push(e)
      });
      this.Http.post('SL', 'SNSE163_CalAdjRate', this.formData)
        .subscribe(res => {
          if (res.Table[0].STATUS == 'DONE') {
            this.modal.info("Calculate new Adjust Rate(%) completed.", this.viewref);
            this.Search();
            this.formData = [];
          }
        });
    } else {
      this.modal.warning("Please fill Adjust Rate(%) for calculate!", this.viewref);
    }
  }

  calculateDiscountRate() {
    this.formData = [];
    this.tableData.forEach((e) => {
      e.CAL_DIS_RATE = this.params.CAL_DIS_RATE
      this.formData.push(e)
    });
    this.Http.post('SL', 'SNSE163_CalDisRate', this.formData)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info("Calculate new Discount Rate(%) completed.", this.viewref);
          this.Search();
          this.formData = [];
        }
        else {
          this.modal.warning("Calculate Fail!", this.viewref);
        }
      });
  }

  ExportExcel() {
    this.Http.Download('SL', "SNSE163_ExportExcel", JSON.stringify(this.tableData))
      .subscribe(res => {
        if (res) {
          this.WriteContents(res)
          this.PROCESS_LOG.push('Export complete ' + this.tableData.length + ' records.');
        } else {
          this.modal.error('Download not complete', this.viewref)
        }
      })
  }

  WriteContents(content) {
    const a = document.createElement('a');
    const file = new Blob([content], { type: content.type });
    a.href = URL.createObjectURL(file);
    a.download = "SNSE163" + ".xlsx";
    a.click();
  }

  OpenConfirmModal() {
    this.formData = [];
    if (this.DataIsSelected.length > 0) {
      this.dialogEffective.OpenDialog();
    } else {
      this.modal.warning("Please select data for confirm registration.", this.viewref);
    }
  }

  ConfirmRegis() {
    this.dialogEffective.Close();
    this.formData = [];
    this.DataIsSelected.forEach((e) => {
      e.EFFECTIVE_DATE = this.params.EFFECTIVE_DATE
      this.formData.push(e)
    });
    this.Http.post('SL', 'SNSE163_RegisConfirm', this.formData)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info("Comfirm registration completed.", this.viewref);
          this.PROCESS_LOG.push('Update data complete : ' + this.formData.length);
          this.Search();
          this.formData = [];
        }
        else {
          this.modal.warning("Confirm Registration Fail!", this.viewref);
        }
      });
  }

  closeModal() {
    this.dialogEffective.Close();
  }
}
