import { Component, OnInit, ViewChild, ViewContainerRef } from "@angular/core";
import { NgForm } from "@angular/forms";
import { Globals } from "src/app/core/global";
import { HttpService } from "src/app/core/http.service";
import { ModalService } from "src/app/core/modal.service";

@Component({
  selector: "SNSE204_S",
  templateUrl: "SNSE204_S.component.html",
  styleUrls: ['../domsale.component.css']
})

export class SNSE204_SComponent implements OnInit {
  constructor(
    private http: HttpService,
    private global: Globals,
    private modal: ModalService,
    private viewRef: ViewContainerRef
  ) { }

  @ViewChild("headerForm") headerForm: NgForm;
  public borrowHeader: any = {};
  public borrowDetail: Array<any> = [];
  public borrowList: Array<any> = [];
  public IsEdit: boolean = false;
  public IsSearch: boolean = true;
  public paramsearch: any = {};
  public hideCols: Array<string> = [];

  public CustomerSearchLookupConfig: any = {
    ColName: "LOOKUP_VALUE",
    PlaceholderText: "Select Customer",
    SourceController: "SL",
    SourceMethodName: "SNSE204_S_GetCustomer",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true,
  };

  public BranchSearchLookupConfig: any = {
    ColName: "LOOKUP_VALUE",
    PlaceholderText: "Select Branch",
    SourceController: "SL",
    SourceMethodName: "SNSE204_S_GetBranch",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true,
    SourceParams: {
      CUSTOMER_CODE: null
    },
  };

  public OrderSearchLookupConfig: any = {
    ColName: "ORDER_NO",
    PlaceholderText: "Select Order",
    SourceController: "SL",
    SourceMethodName: "SNSE204_S_GetOrder",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true,
    SourceParams: {
      CUSTOMER_CODE: null,
      BRANCH_CODE: null
    },
  };

  public CustomerLookupConfig: any = {
    ColName: "LOOKUP_VALUE",
    PlaceholderText: "Select Customer",
    SourceController: "SL",
    SourceMethodName: "SNSE204_S_GetCustomer",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true,
  };

  public BranchLookupConfig: any = {
    ColName: "LOOKUP_VALUE",
    PlaceholderText: "Select Branch",
    SourceController: "SL",
    SourceMethodName: "SNSE204_S_GetBranch",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true,
    SourceParams: {},
  };

  public OrderLookupConfig: any = {
    ColName: "ORDER_NO",
    PlaceholderText: "Select Order",
    SourceController: "SL",
    SourceMethodName: "SNSE204_S_GetOrder",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true,
    SourceParams: {},
  };

  public BRLookupConfig: any = {
    ColName: "BR_NO",
    PlaceholderText: "Select Borrow No.",
    SourceController: "SL",
    SourceMethodName: "SNSE204_S_GetBRNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
  };

  public PartNoLookupConfig: any = {
    ColName: "LOOKUP_VALUE",
    PlaceholderText: "Select Part",
    SourceController: "SL",
    SourceMethodName: "SNSE204_S_GetPart",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {},
  };

  ngOnInit() { }

  public AddOrder() {
    this.hideCols = [];
    this.IsSearch = false;
    this.IsEdit = true;

    this.borrowHeader = {};
    this.borrowDetail = [];
    this.CreateDetailRow(0);
  }

  public Search() {
    this.http.post("SL", "SNSE204_S_GetBorrowList", this.paramsearch).subscribe(
      (res) => {
        this.borrowList = res.Table;
      },
      (err) => {
        console.log(err, "err");
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewRef
        );
      }
    );
  }

  public ViewDetail(borrow: any) {
    this.borrowHeader = {};
    this.borrowDetail = [];

    this.http.post("SL", "SNSE204_S_GetDetail", borrow).subscribe(
      (res) => {
        this.borrowHeader = res.Table[0];
        this.borrowDetail = res.Table1;
        this.IsSearch = false;
        this.IsEdit = false;

        this.borrowDetail.forEach((v) => {
          v._PART_NO = v.ORDER_PART_NO;
        });
      },
      (err) => {
        console.log(err, "err");
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewRef
        );
      }
    );
  }

  public ConfirmSave() {


    let detailRows = this.borrowDetail.filter((v) => v.ORDER_PART_NO);

    if (detailRows.length == 0) {
      this.modal.warning("An Order Entry must have more or equal than 1 detail", this.viewRef)
      return;
    }

    if (detailRows.find((v) => !v.BORROW_QTY || v.BORROW_QTY === 0)) {
      this.modal.warning("Some record in borrow detail has unfinished data.", this.viewRef);
      return;
    }
    if (this.headerForm.valid) {

      this.modal.confirm("Do you want to save change you have made?", this.viewRef, this.Save)
    } else {
      this.modal.error("Please input all required fields.", this.viewRef);
    }
  }

  private Save = () => {
    let detailRows = this.borrowDetail.filter((v) => v.ORDER_PART_NO);
    let data = {
      CUSTOMER_CODE: this.borrowHeader.CUSTOMER_CODE,
      BRANCH_CODE: this.borrowHeader.BRANCH_CODE,
      ORDER_NO: this.borrowHeader.ORDER_NO,
      VOR_STATUS: this.borrowHeader.VOR_STATUS,
      PART_LIST: detailRows,
    };
    this.http.post("SL", "SNSE204_S_Save", data).subscribe(
      (res) => {
        this.borrowHeader.BR_NO = res.BR_NO;
        this.borrowHeader.UPDATE_BY = this.global.GetTokenDetail("ssNameEN")
        this.borrowHeader.UPDATE_DATE = new Date();
        this.IsEdit = false;
      },
      (err) => {
        console.log(err, "err");
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewRef
        );
      }
    );
  }

  public SetSearchCustomerLookup(cust: any) {
    this.paramsearch.CUSTOMER_CODE = cust.CUSTOMER_CODE;
    this.BranchSearchLookupConfig.SourceParams.CUSTOMER_CODE = cust.CUSTOMER_CODE;
    this.OrderSearchLookupConfig.SourceParams.CUSTOMER_CODE = cust.CUSTOMER_CODE;
  }

  public SetSearchBranchLookup(branch: any) {
    this.paramsearch.BRANCH_CODE = branch.BRANCH_CODE;
    this.OrderSearchLookupConfig.SourceParams.BRANCH_CODE = branch.BRANCH_CODE;
  }

  public SetCustomerLookup(cust: any) {
    this.borrowHeader.CUSTOMER_CODE = null;
    this.borrowHeader.CUSTOMER_NAME = null;
    this.BranchLookupConfig.SourceParams.CUSTOMER_CODE = null;
    this.OrderLookupConfig.SourceParams.CUSTOMER_CODE = null;
    this.borrowHeader.BRANCH_CODE = null;
    this.borrowHeader.BRANCH_NAME = null;
    this.OrderLookupConfig.SourceParams.BRANCH_CODE = null;

    if (cust.LOCK_CUSTOMER != 0) {
      this.modal.error("This customer is lock customer!", this.viewRef);
      return;
    }
    this.borrowHeader.CUSTOMER_CODE = cust.CUSTOMER_CODE;
    this.borrowHeader.CUSTOMER_NAME = cust.CUSTOMER_NAME;
    this.BranchLookupConfig.SourceParams.CUSTOMER_CODE = cust.CUSTOMER_CODE;
    this.OrderLookupConfig.SourceParams.CUSTOMER_CODE = cust.CUSTOMER_CODE;
  }

  public SetBranchLookup(branch: any) {
    this.borrowHeader.BRANCH_CODE = branch.BRANCH_CODE;
    this.borrowHeader.BRANCH_NAME = branch.BRANCH_NAME;
    this.OrderLookupConfig.SourceParams.BRANCH_CODE = branch.BRANCH_CODE;
  }

  public SetOrderLookup(order: any) {
    this.borrowHeader.ORDER_NO = order.ORDER_NO;

    const { CUSTOMER_CODE, BRANCH_CODE, ORDER_NO } = this.borrowHeader;

    this.PartNoLookupConfig.SourceParams = {
      CUSTOMER_CODE,
      BRANCH_CODE,
      ORDER_NO,
    };

    if (this.borrowHeader.CUSTOMER_CODE && this.borrowHeader.BRANCH_CODE && this.borrowHeader.ORDER_NO) {

      this.http.post("SL", "SNSE204_S_GetPartList", this.borrowHeader)
        .subscribe((res) => {
          this.borrowDetail = res.Table;

          if (this.borrowDetail.length > 0) {
            this.borrowDetail.forEach((e) => {
              e._PART_NO = e.ORDER_PART_NO
            });

          }

        },
          (err) => {
            console.log(err, "err");
            this.modal.warning(
              "Found an error, please contact support team",
              this.viewRef
            );
          }
        );




    }


  }

  public SetNewPartNo(part: any, data: any) {
    if (part.ORDER_PART_NO) {
      data._PART_NO = part.ORDER_PART_NO
      Object.assign(data, part);
      let foundDup = this.borrowDetail.filter(x => x._PART_NO == part.ORDER_PART_NO)
      if (foundDup.length > 1) {
        this.modal.warning("Order Part No. : " + part.ORDER_PART_NO + " is duplicated!", this.viewRef)
        data.ITEM_NO = null
        data._PART_NO = null
        data.PART_NAME = null
        data.OH_QTY = null
        data.LOCATION_NO = null
        data.ORDER_QTY = null
        data.BORROW_QTY = null
        return
      }
    }
    else {
      data.ITEM_NO = null
      data._PART_NO = null
      data.PART_NAME = null
      data.OH_QTY = null
      data.LOCATION_NO = null
      data.ORDER_QTY = null
      data.BORROW_QTY = null
    }
  }

  public CheckVORChange(chkBox) {
    this.borrowHeader.CHK_VOR = chkBox.checked ? "Y" : "N";
  }

  public CheckActiveRow(index, data) {
    if (this.headerForm.valid && data.ORDER_PART_NO) {
      this.CreateDetailRow(index);
      return true;
    }
    return false;
  }

  private CreateDetailRow(tblIndex) {
    let currentMaxRow: number = this.borrowDetail.length || 0;
    let nextMaxRow: number = (Math.floor(currentMaxRow / 10) + 1) * 10;

    if (currentMaxRow - tblIndex <= 2) {
      for (let i = currentMaxRow; i < nextMaxRow; i++) {
        this.borrowDetail.push({});
      }

      this.borrowDetail = this.borrowDetail.slice();
    }
  }

  public SumBorrowQty() {
    return this.borrowDetail.reduce(
      (oldVal, currentData) => (currentData.BORROW_QTY || 0) + oldVal,
      0
    );
  }

  public BackToGrid() {
    this.IsSearch = true;
  }

  public OpenReport() {
    if (this.borrowHeader.NEW_REP) {
      this.global.GoToReport("PMS_RPT_SALES_SNSE_204_R_A4", {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_BR_NO_FROM: this.borrowHeader.BR_NO,
        P_BR_NO_TO: this.borrowHeader.BR_NO,
        P_DELIVERY_CODE: this.borrowHeader.DELIVERY_CODE,
        P_RE_PRINT: null,
      })
    } else {
      this.global.GoToReport("PMS_RPT_SALES_SNSE_204_R", {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_BR_NO_FROM: this.borrowHeader.BR_NO,
        P_BR_NO_TO: this.borrowHeader.BR_NO,
        P_DELIVERY_CODE: this.borrowHeader.DELIVERY_CODE,
        P_RE_PRINT: null,
      });
    }
  }

  public CheckQTY(data) {
    if (data.BORROW_QTY > data.OH_QTY) {
      this.modal.error("Total Borrow Qty. more than OH Stock", this.viewRef);
      data.BORROW_QTY = data.OH_QTY;
      return;
    }

    if (data.BORROW_QTY <= 0) {
      this.modal.error("Order Qty. must Not Null and more than 0!", this.viewRef);
      data.BORROW_QTY = null;
      return;
    }

    if (data.BORROW_QTY > data.ORDER_QTY) {
      this.modal.error("Total Borrow Qty > Order Qty!", this.viewRef);
      data.BORROW_QTY = data.ORDER_QTY;
      return;
    }
  }


  public DeleteRow(index) {
    this.modal.confirm("Are you sure to remove this row?", this.viewRef
      , () => {
        this.borrowDetail.splice(index, 1);
        this.borrowDetail = [...this.borrowDetail];
      }, () => { })
  }
}
