import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { DialogTemplateComponent } from 'src/app/components/shared/dialog-template/dialog-template.component';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';


@Component({
  selector: 'snse205',
  templateUrl: 'SNSE205.component.html',
  styleUrls: ['../domsale.component.css']
})

export class SNSE205Component implements OnInit {

  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  public params: any = {}
  public tableData: any = [];
  public dataIsSelected: any = [];

  public showEdit: boolean = false;
  public headerData: any = {};
  public detailData: any = [];
  // @ViewChild('detailDialog') detailDialog: DialogTemplateComponent;

  public ConfigCustomerCode: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "SL",
    SourceMethodName: "SNSE205_GetCustomer",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetCustomerCode(values: any) {
    this.params.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.params.CUSTOMER_NAME = values.CUSTOMER_NAME;
    this.ConfigBranchCode.SourceParams.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.ConfigOrderNo.SourceParams.CUSTOMER_CODE = values.CUSTOMER_CODE;
  }

  public ConfigBranchCode: any = {
    ColName: "LOOKUP_BRANCH_CODE",
    PlaceholderText: "Select Branch Code",
    SourceController: "SL",
    SourceMethodName: "SNSE205_GetBranch",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true,
    SourceParams: {
      CUSTOMER_CODE: null
    },
  }

  public SetBranchCode(values: any) {
    this.params.BRANCH_CODE = values.BRANCH_CODE;
    this.params.BRANCH_NAME = values.BRANCH_NAME
    this.ConfigOrderNo.SourceParams.BRANCH_CODE = values.BRANCH_CODE
  }

  public ConfigOrderNo: any = {
    ColName: "ORDER_NO",
    PlaceholderText: "Select Order No",
    SourceController: "SL",
    SourceMethodName: "SNSE205_GetOrderNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: false,
    SourceParams: {
      CUSTOMER_CODE: null,
      BRANCH_CODE: null
    },
  }

  public SetOrderNo(values: any) {
    this.params.ORDER_NO = values.ORDER_NO;
  }

  public ConfigBRNo: any = {
    ColName: "BR_NO",
    PlaceholderText: "Select Borrow No",
    SourceController: "SL",
    SourceMethodName: "SNSE205_GetBorrowNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true,
  }

  public SetBorrowNo(values: any) {
    this.params.BR_NO = values.BR_NO;
    this.params.CUSTOMER_CODE = values.CUSTOMER_CODE
    this.params.CUSTOMER_NAME = values.CUSTOMER_NAME
    this.params.BRANCH_CODE = values.BRANCH_CODE
    this.params.BRANCH_NAME = values.BRANCH_NAME
    this.params.ORDER_NO = values.ORDER_NO
    this.ConfigBranchCode.SourceParams.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.ConfigOrderNo.SourceParams.CUSTOMER_CODE = values.CUSTOMER_CODE;
  }

  public tblFooter: any = [
    {
      fieldName: "SUB_CASE_NO",
      value: "Total",
      show: true
    },
    {
      fieldName: "ORDER_QTY",
      show: true
    },
    {
      fieldName: "ACCEPT_QTY",
      show: true
    }
  ]

  ngOnInit() { }

  public Search() {
    this.tableData = []
    this.tblFooter[2].value = 0;
    //this.tableData = this.tableData.slice();
    this.http.post('SL', 'SNSE205_GetBRList', this.params)
      .subscribe(res => {
        this.tableData = res.Table;
      }, (err) => {
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
  }

  public Save() {
    if (this.detailData.filter(x => x.ACCEPT_QTY != null).length == 0) {
      this.modal.warning("There is no data change", this.viewref)
      return;
    }
    this.modal.confirm("Do you want to save change you have made?", this.viewref, this.ConfirmSave)
  }

  private ConfirmSave = () => {
    let DetailSave = this.detailData.filter(x => x.ACCEPT_QTY != null)
    this.http.post("SL", "SNSE205_Save", DetailSave)
      .subscribe(res => {
        if (res.status == "fail") {
          this.modal.error(res.massage, this.viewref)
        } else {
          this.Search();
          this.modal.info("Transaction complete record apply and save", this.viewref)
          // this.detailDialog.Close();
          this.showEdit = false;
        }
      }, (err) => {
        console.log(err, 'err');
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
  }

  public CheckConfirmQty(data) {
    if (data.ACCEPT_QTY > data.ORDER_QTY) {
      this.modal.warning("Confirm QTY more than Order QTY !", this.viewref);
      data.ACCEPT_QTY = null;
    }

    var iQTY = 0;
    iQTY = this.detailData.map(x => x.ACCEPT_QTY).reduce((prev, next) => prev + next)
    this.tblFooter[2].value = iQTY
    this.detailData = this.detailData.slice();
  }

  public EditBR(headerData) {
    this.headerData = headerData;
    this.showEdit = true;
    // this.detailDialog.OpenDialog();

    this.detailData = []

    this.http.post('SL', 'SNSE205_GetData', this.headerData)
      .subscribe(res => {
        this.detailData = res.Table;
      }, (err) => {
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
  }

  public Back() {
    this.headerData = {};
    this.detailData = [];
    this.showEdit = false;
  }

}

