import { Component, OnInit, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';
import { SelectionModel } from '@angular/cdk/collections';


@Component({
  selector: 'snse209_d',
  templateUrl: 'SNSE209_D.component.html',
  styleUrls: ['../domsale.component.css']
})

export class SNSE209_DComponent implements OnInit {

  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  public params: any = {};
  public dsp: any = {};
  public tableData: any = [];
  public DataIsSelected: any = [];
  public formData: any = [];

  public selection = new SelectionModel<any>(true, []);

  public ConfigCustomerCode: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "SL",
    SourceMethodName: "SNSE209_D_GetCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true,
    SourceParams: {
      ORDER_NO: null,
      ACCEPT_PART_NO: null
    }
  }

  public SetCustomerCode(values: any) {
    this.params.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.params.CUSTOMER_NAME = values.CUSTOMER_NAME;
    this.ConfigBranchCode.SourceParams.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.ConfigOrderNo.SourceParams.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.ConfigPartNo.SourceParams.CUSTOMER_CODE = values.CUSTOMER_CODE;

  }

  public ConfigBranchCode: any = {
    ColName: "LOOKUP_BRANCH_CODE",
    PlaceholderText: "Select Branch Code",
    SourceController: "SL",
    SourceMethodName: "SNSE209_D_GetBranch",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true,
    SourceParams: {
      CUSTOMER_CODE: null,
      ORDER_NO: null,
      ACCEPT_PART_NO: null
    }
  }

  public SetBranchCode(values: any) {
    this.params.BRANCH_CODE = values.BRANCH_CODE;
    this.params.BRANCH_NAME = values.BRANCH_NAME
    this.ConfigOrderNo.SourceParams.BRANCH_CODE = values.BRANCH_CODE;
    this.ConfigPartNo.SourceParams.BRANCH_CODE = values.BRANCH_CODE;
  }

  public ConfigOrderNo: any = {
    ColName: "LOOKUP_ORDER_NO",
    PlaceholderText: "Select Order No",
    SourceController: "SL",
    SourceMethodName: "SNSE209_D_GetOrderNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true,
    SourceParams: {
      CUSTOMER_CODE: null,
      BRANCH_CODE: null,
      ACCEPT_PART_NO: null
    }
  }

  public SetOrderNo(values: any) {
    this.params.ORDER_NO = values.ORDER_NO;
    this.ConfigBranchCode.SourceParams.BRANCH_CODE = values.BRANCH_CODE;
    this.ConfigPartNo.SourceParams.BRANCH_CODE = values.BRANCH_CODE;
  }

  public ConfigPartNo: any = {
    ColName: "LOOKUP_PART_NO",
    PlaceholderText: "Select Accept Part No",
    SourceController: "SL",
    SourceMethodName: "SNSE209_D_GetPart",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true,
    SourceParams: {
      CUSTOMER_CODE: null,
      BRANCH_CODE: null,
      ORDER_NO: null
    }
  }

  public SetGroupPartNo(values: any) {
    this.params.ACCEPT_PART_NO = values.PART_NO;
    this.params.PART_NAME = values.PART_NAME;
    this.ConfigCustomerCode.SourceParams.ACCEPT_PART_NO = values.PART_NO;
    this.ConfigBranchCode.SourceParams.ACCEPT_PART_NO = values.PART_NO;
    this.ConfigOrderNo.SourceParams.ACCEPT_PART_NO = values.PART_NO;
  }

  ngOnInit() {
    this.params.ORDER_CLASS = "";
  }

  public Search() {
    this.tableData = [];
    this.DataIsSelected = [];
    this.selection.clear();
    this.dsp = {};
    this.http.post('SL', 'SNSE209_D_GetData', this.params)
      .subscribe(res => {
        this.tableData = res.Table;
        if (this.tableData.length > 0) {
          this.tableData.forEach((e) => {
            if (e.DSP_OVERQUOTA == 'Y') {
              this.selection.select(e);
              e.CHK_SELECT = 1;
            } else {
              e.CHK_SELECT = 0;
            }
          }); 
        }
      }, (err) => {
        console.log(err, 'err');
        this.modal.warning("Found an error, please contract support team", this.viewref);
      });
  }

  public Save() {
    this.formData = this.tableData.filter(e => e.CHK_SELECT == 0)
    if (this.formData.length <= 0) {
      this.modal.error("There is no data change.", this.viewref)
      return;
    }
    this.modal.confirm("Do you want to save change you have made?", this.viewref, this.ConfirmSave)
  }

  private ConfirmSave = () => {
    this.http.post("SL", "SNSE209_D_Update", this.formData)
      .subscribe(res => {
        console.log(res)
        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
        }
        else {
          this.modal.warning("Found an error, please contract support team", this.viewref);
        }
      }, (err) => {
        console.log(err, 'err');
        this.modal.warning("Found an error, please contract support team", this.viewref);
      });
  }

  public isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.tableData.length;
    return numSelected === numRows;
  }

  public Toggle() {
    if (this.isAllSelected()) {
      this.selection.clear()
      this.tableData.map(x => {
        this.DataIsSelected = [];
        x.CHK_SELECT = 0;
      })
    } else {
      this.tableData.forEach(row => this.selection.select(row));
      this.DataIsSelected = [];
      this.tableData.map(x => {
        this.DataIsSelected.push(x);
        x.CHK_SELECT = 1;
      })
    }
    this.params.CNT_SEL = this.DataIsSelected.length;
  }

  public CheckboxChange(event, data) {
    if (event.checked) {
      data.CHK_SELECT = 1;
      this.DataIsSelected.push(data);
    }
    else {
      data.CHK_SELECT = 0;
      this.DataIsSelected.splice(this.DataIsSelected.indexOf(data), 1);
    }
    this.params.CNT_SEL = this.DataIsSelected.length;
  }

 public RowClick(data) {
    this.dsp.GROUP_PART_NO = data.GROUP_PART_NO;
    this.dsp.OH_QTY = data.OH_QTY;
    this.dsp.INDENT_QTY = data.INDENT_QTY;
    this.dsp.REMAIN_QUOTA_QTY = data.REMAIN_QUOTA_QTY;
    this.dsp.AVAILABLE_QTY = data.AVAILABLE_QTY;
  }
}
