import { Component, OnInit, ViewContainerRef, ViewChild, ElementRef } from "@angular/core";
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from '../../../core/modal.service';
import { SelectionModel } from '@angular/cdk/collections';


@Component({
  selector: 'snse211',
  templateUrl: './SNSE211.component.html',
  styleUrls: ['./SNSE211.component.css']
})

export class SNSE211Component implements OnInit {

  public params: any = {};
  public DataUploadList: any = [];
  public file: any;
  public fileName: any;

  public DataIsSelected: any = [];
  public selection = new SelectionModel<any>(true, []);

  public tableData: any = [];
  public isSaved: boolean = false;

  @ViewChild("dialogLog", { static: false }) dialogLog: any;

  constructor(
    private Http: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  ngOnInit() {
    this.GetData();
    this.params.TOTAL_RECORD = 0;
    this.params.TOTAL_SELECTED = 0;
    this.params.TOTAL_ERROR = 0;
  }

  @ViewChild("fileUpload") fileUpload: ElementRef;

  public OpenFileBrowser() {
    this.params.TOTAL_RECORD = 0;
    this.params.TOTAL_SELECTED = 0;
    this.params.TOTAL_ERROR = 0;
    this.isSaved = false;
    this.DataUploadList = [];
    this.DataIsSelected = [];
    this.fileName = "";
    this.fileUpload.nativeElement.value = '';
    this.fileUpload.nativeElement.click();
  }

  public SelectFile(evt) {
    this.file = null;
    let Files: Array<File> = evt.target.files;

    if (Files.length > 0) {
      this.file = Files[0];
      this.fileName = this.file.name;
    }
  }

  public UpLoad() {
    this.isSaved = false;
    this.params.TOTAL_RECORD = 0;
    this.params.TOTAL_SELECTED = 0;
    this.params.TOTAL_ERROR = 0;
    this.DataIsSelected = [];
    this.DataUploadList = [];
    this.selection.clear();
    if (!this.fileName) {
      this.modal.error('Please Open .xlsx File First...', this.viewref)
    }
    else {
      let formData = new FormData();
      formData.append('file', this.file);
      this.Http.postFile('SL', 'SNSE211_Upload', formData)
        .subscribe(res => {
          this.DataUploadList = [];
          this.Http.get('SL', 'SNSE211_GetTempData')
            .subscribe(res => {
              this.DataUploadList = res.Table;
              if (this.DataUploadList.length > 0) {
                this.params.TOTAL_RECORD = this.DataUploadList.length
                this.DataUploadList.forEach((e, index) => {
                  if (e.ERROR_MSG) {
                    this.params.TOTAL_ERROR++;
                  }
                });
              }
            });
        }, (err) => {
          this.modal.error("Upload error! Please check file or data for upload.", this.viewref);
        });
    }
  }

  public ConfirmClear() {
    this.modal.confirm('Do you want to clear list?', this.viewref, this.ClearData)
  }

  public ClearData = () => {
    this.isSaved = false;
    this.DataUploadList = [];
    this.DataIsSelected = [];
    this.tableData = [];
    this.params.TOTAL_RECORD = 0;
    this.params.TOTAL_SELECTED = 0;
    this.params.TOTAL_ERROR = 0;
    this.DataIsSelected = [];
    this.selection.clear()
    this.fileName = "";
    this.fileUpload.nativeElement.value = '';

    this.Http.get('SL', 'SNSE211_ClearOldData')
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info("Process was completed!", this.viewref);
          this.GetData();
        } else {
          this.modal.error("Found error, please contact support team.", this.viewref);
        }
      }, (err) => {
        console.log(err);
        this.modal.error("Found error, please contact support team.", this.viewref);
      });
  }

  public CheckboxChange(event, data) {
    if (event.checked) {
      this.DataIsSelected.push(data);
    }
    else {
      this.DataIsSelected.splice(this.DataIsSelected.indexOf(data), 1);
    }
    this.params.TOTAL_SELECTED = this.DataIsSelected.length;
  }

  public isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.DataUploadList.filter(e => !e.ERROR_MSG).length;
    return numSelected === numRows;
  }

  public Toggle() {
    if (this.isAllSelected()) {
      this.selection.clear()
      this.DataUploadList.map(x => {
        this.DataIsSelected = [];
      })
    } else {
      this.DataIsSelected = [];
      this.DataUploadList.forEach((e) => {
        if (!e.ERROR_MSG) {
          this.selection.select(e)
          this.DataIsSelected.push(e);
        }
      });
    }
    this.params.TOTAL_SELECTED = this.DataIsSelected.length;
  }

  public ConfirmSave() {
    if (this.DataIsSelected.length > 0) {
      this.modal.confirm('Do you want to update selected : [' + this.params.TOTAL_SELECTED + '] items?', this.viewref, this.Save)
    }
    else {
      this.modal.info('No record selected!', this.viewref)
    }
  }

  public Save = () => {
    this.Http.post('SL', 'SNSE211_Update', this.DataIsSelected)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info("Process was completed.", this.viewref);
          this.isSaved = true;
          this.DataUploadList = [];
          this.DataIsSelected = [];
          this.selection.clear();
          this.GetData();
        } else {
          this.modal.warning(res.Table[0].ERR_MESSAGE, this.viewref);
        }
      }, (err) => {
        console.log(err);
        this.modal.error("Found error, please contact support team.", this.viewref);
      });
  }

  public Export() {
    if (this.DataUploadList.length > 0) {
      this.Http.Download("SL", "SNSE211_getDataForExport", JSON.stringify(this.params))
        .subscribe(result => {
          if (result) {
            this.download(result)
            this.modal.info('Export completed!', this.viewref)
          }
        }, (err) => {
          console.log(err, 'err')
        })
    }
    else {
      this.modal.warning('There is no record to export!', this.viewref)
    }
  }

  private download(content) {
    const a = document.createElement('a');
    const file = new Blob([content], { type: content.type })
    a.href = URL.createObjectURL(file);
    a.download = "SNSE211.csv"
    a.click()
  }

  public DownloadTemplate() {
    let link = "assets/templates/SNSE211_Upload_Template.xlsx"
    window.open(link, '_blank')
  }
  public GetData() {
    this.Http.get('SL', 'SNSE211_GetData')
      .subscribe(res => {
        this.tableData = res.Table;
      }, (err) => {
        console.log(err);
        this.modal.error("Found error, please contact support team.", this.viewref);
      });
  }
}
