import { Component, OnInit, ViewContainerRef, ViewChild, ElementRef } from "@angular/core";
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from '../../../core/modal.service';
import { SelectionModel } from '@angular/cdk/collections';
import { Globals } from "src/app/core/global";


@Component({
  selector: 'snse221',
  templateUrl: './SNSE221.component.html',
  styleUrls: ['./SNSE221.component.css']
})

export class SNSE221Component implements OnInit {

  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private global : Globals
  ) { }

  public ConfigPart: any = {
    ColName: "LOOKUP_PART_NAME",
    ColValue: "",
    PlaceholderText: "Select Part No.",
    SourceController: "wPMS",
    SourceMethodName: "GetPartNo",
    NoOfShowRecords: 60,
    MinLengthSearch: 3
  }

  public ConfigCustomer: any = {
    ColName: "LOOKUP_CUST",
    PlaceholderText: "Select Customer Code",
    SourceController: "SL",
    SourceMethodName: "SNSE221_GetCustomer",
    NoOfShowRecords: 50,
    MinLengthSearch: 2,
    UpperCase: true
  }

  public ConfigBranch: any = {
    ColName: "BRANCH",
    PlaceholderText: "Select Branch",
    SourceController: "SL",
    SourceMethodName: "SNSE221_GetBranch",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      CUSTOMER_CODE: null
    },
    UpperCase: true
  };

  public ConfigOrder: any = {
    ColName: "LOOKUP_ORDER_NO",
    PlaceholderText: "Select Order No",
    SourceController: "SL",
    SourceMethodName: "SNSE221_GetOrderNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 2,
    SourceParams: {
      CUSTOMER_CODE: null,
      BRANCH_CODE: null
    },
    UpperCase: true
  }

  public selection = new SelectionModel<any>(true, []);
  public paramSearch : any = {}
  public tableDetail : Array<any> = []
  public paramsData : any = {};
  public tableAllocate : Array<any> = []
  public selectionAllocate = new SelectionModel<any>(true, []);
  public isAllocate : boolean = false;
  ngOnInit() {
   
  }
  
  //------------------------------------------Start Reverse Transaction--------------------------------------------------//
  public Search(){
   
    this.http.get("SL","SNSE221_GetData",this.global.EscapeCharacter(this.paramSearch.PART_NO))
    .subscribe(res => {
      this.selection.clear()
      this.tableDetail = res.Table
    })
    
  }

  public ReverseQtyChange(event : any,data : any){
    if(event.target.value != data.ACCEPT_QTY){
      data.REVERSE_QTY = data.ACCEPT_QTY
      this.modal.warning("Reverse qty can't over net qty",this.viewref);
    }
  }

  public Save(){
    let check = this.selection.selected.some(x => !x.REVERSE_QTY)
    if(check){
      this.modal.warning("Some record data net complete",this.viewref)
      return
    }
    this.modal.confirm("Do you want to reverse document?",this.viewref,this.ConfirmSave)
  }

  private ConfirmSave = () =>{
    this.http.post("SL","SNSE221_Reverse",this.selection.selected)
    .subscribe(res => {
      this.modal.confirm("Reverse document complete",this.viewref);
      this.paramsData.DocNoFrom = res.Table[0].TR_DOCUMENT_NO
      this.paramsData.DocNoTo = res.Table[res.Table.length - 1].TR_DOCUMENT_NO
      
      for (var item of res.Table) {
        let index = this.tableDetail.findIndex(
          x => x.DOCUMENT_NO == item.DOCUMENT_NO &&
               x.CUSTOMER_CODE == item.CUSTOMER_CODE &&
               x.ORDER_NO == item.ORDER_NO &&
               x.ITEM_NO == item.ITEM_NO &&
               x.SUB_ITEM_NO == item.SUB_ITEM_NO &&
               x.ITEM_NO_ORDER_STATUS == item.ITEM_NO_ODS &&
               x.SUB_ITEM_NO_ORDER_STATUS == item.SUB_ITEM_ODS
        )

        if (index > -1) {
          this.tableDetail[index].REVERSE_DOC_NO = item.TR_DOCUMENT_NO
        }
      }

      this.tableDetail.map(x =>{
        if(x.REVERSE_QTY){
          x.ACCEPT_QTY = x.ACCEPT_QTY - x.REVERSE_QTY
          x.REVERSE_QTY = null
        }
      })

      this.tableDetail.slice();
      this.selection.clear();
    },err => {
      this.modal.confirm("Reverse document not complete, please contact support team",this.viewref);
    })
  }


   //------------------------------------------END Reverse  Transaction--------------------------------------------------//



   //------------------------------------------ Start Allocate Manual ---------------------------------------------------//


   public SetSelectedCustomerCode(values: any) {
    this.paramSearch.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.paramSearch.CUSTOMER_NAME = values.CUST_NAME_TH;
    this.paramSearch.BRANCH_NAME = values.BRANCH_NAME;
    this.paramSearch.BRANCH_CODE = values.BRANCH_CODE;
    this.paramSearch.LOCK_CUSTOMER = values.LOCK_CUSTOMER;
    this.ConfigBranch.SourceParams.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.ConfigOrder.SourceParams.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.ConfigOrder.SourceParams.BRANCH_CODE = values.BRANCH_CODE;
    if(this.tableAllocate.length > 0){
      this.tableAllocate = []
    }
    
  }

  public SetBranchLookup(values: any) {
    this.paramSearch.BRANCH_NAME = values.BRANCH_NAME;
    this.paramSearch.BRANCH_CODE = values.BRANCH_CODE;
    this.ConfigOrder.SourceParams.BRANCH_CODE = values.BRANCH_CODE;
    if(this.tableAllocate.length > 0){
      this.tableAllocate = []
    }
  }

  public SetSelectedOrderNo(values: any) {
    this.paramSearch.ORDER_NO = values.ORDER_NO;
    this.paramSearch.ORDER_CLASS_TEXT = values.ORDER_CLASS_TEXT;
    this.paramSearch.ORDER_CLASS = values.ORDER_CLASS;
    this.paramSearch.ORDER_DATE = values.ORDER_DATE;
    this.paramSearch.BO_FLAG = values.BO_FLAG;
    this.paramSearch.ROUTE_CODE = values.ROUTE_CODE;
    this.paramSearch.TRANSPORT_CODE = values.TRANSPORT_CODE;
    if(this.tableAllocate.length > 0){
      this.tableAllocate = []
    }
    //this.Search();
  }

  public SearchOrder() {

    if(!this.paramSearch.CUSTOMER_CODE || !this.paramSearch.BRANCH_CODE || !this.paramSearch.ORDER_NO ){
      this.modal.warning("Please input customer code branch code and order no",this.viewref)
      return
    }


    this.http.post("SL","SNSE221_GetOrderData",this.paramSearch)
    .subscribe(res =>{
      this.isAllocate = false;
      this.selectionAllocate.clear();
      this.tableAllocate = res.Table
    })
  }

  public Allocate(){
    this.modal.confirm("Do you want to allocate order",this.viewref,this.ConfirmAllocate)
    
  }

  private ConfirmAllocate = () =>{

    let paramObject = {
      CUSTOMER_CODE : this.paramSearch.CUSTOMER_CODE,
      BRANCH_CODE : this.paramSearch.BRANCH_CODE,
      ORDER_NO : this.paramSearch.ORDER_NO,
      DETAIL : this.selectionAllocate.selected
    }


    this.http.post("SL","SNSE221_Allocate",paramObject)
    .subscribe(res =>{
      
      if(res.STATUS == "DONE"){
        this.selection.clear()
        this.isAllocate = true;
        this.modal.info("Allocate complete",this.viewref)
        this.SearchOrder();
        
      }else{
        this.modal.error("Allocate fail, please contact support team",this.viewref)
      }
     
    },err =>{
      this.modal.error("Allocate fail, please contact support team",this.viewref)
    })
  }


  isAllSelected() {
    const numSelected = this.selectionAllocate.selected.length;
    const numRows = this.tableAllocate.length;
    return numSelected === numRows;
  }

  Toggle() {
    if (this.isAllSelected()) {
      this.selectionAllocate.clear();
      return;
    }

    this.selectionAllocate.select(...this.tableAllocate);
  }


   //------------------------------------------ End Allocate Manual ---------------------------------------------------//

  
}
