import { Component, OnInit, ElementRef, ViewChild, ViewContainerRef, CUSTOM_ELEMENTS_SCHEMA } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from '../../../core/modal.service';
import { FormControl, Validators } from '@angular/forms';
import { Globals } from 'src/app/core/global';

@Component({
  selector: 'SNM168',
  templateUrl: './SNM168.component.html',
  styleUrls: ['./SNM168.component.css'],
})


export class SNM168Component implements OnInit {

  public error_list: any = []

  constructor(
    public http: HttpService,
    public modal: ModalService,
    public global: Globals,
    public viewRef: ViewContainerRef
  ) { }

  public ParamAdd: any = {};
  public ParamGroupAdd: any = {};
  public ParamGroupEdit: any = {};
  public params: any = {};
  public paramsGroup  : any = {};


  public tableData: any = [];
  public tableDataGroup: any = [];
  public showList: Boolean;

  public formList: Array<any>

  CustomerCodeControl = new FormControl('', [Validators.required]);
  CustomerGruopControl = new FormControl('', [Validators.required]);
  
  @ViewChild("dialogAdd", { static: false }) dialogAdd: any;
  @ViewChild("dialogEdit", { static: false }) dialogEdit: any;
  @ViewChild("dialogAddGruop", { static: false }) dialogAddGruop: any;
  @ViewChild("dialogEditGroup", { static: false }) dialogEditGroup: any;
  @ViewChild("dialogCopyGroup", { static: false }) dialogCopyGroup: any;

  ngOnInit(): void {
    this.showList = true;
    this.GetGroupDetail();
    this.GetGroupMapping();
  }

  public lookupCustomerGroupConfig: any = {
    ColName: "LOOKUP_INVOICE_EXPORT_MASTER_GROUP",
    PlaceholderText: "Select Customer Group",
    SourceController: "SL",
    SourceMethodName: "SNM168_GetInvoiceExportMasterGroup",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }
  public lookupCustomerCodeConfig: any = {
    ColName: "LOOKUP_INVOICE_EXPORT_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "SL",
    SourceMethodName: "SNM168_GetInvoiceExportCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }
  public lookupCustomerCodeAddConfig: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "SL",
    SourceMethodName: "SNM168_GetCustomerCodeForAdd",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedCustomerGroup(value: any,tab) {
    if(tab == 'C'){
      this.ParamAdd.CUSTOMER_GROUP_CODE = value.CUSTOMER_GROUP_CODE;
      this.ParamAdd.CUSTOMER_GROUP_NAME = value.CUSTOMER_GROUP_NAME;
    }else if(tab == 'G'){
      this.paramsGroup.CUSTOMER_GROUP_CODE = value.CUSTOMER_GROUP_CODE;
      this.paramsGroup.CUSTOMER_GROUP_NAME = value.CUSTOMER_GROUP_NAME;
    }else{
      this.params.CUSTOMER_GROUP_CODE = value.CUSTOMER_GROUP_CODE;
      this.params.CUSTOMER_GROUP_NAME = value.CUSTOMER_GROUP_NAME;
    } 
  }
  public SetSelectedCustomerCode(value: any) {
    this.params.CUSTOMER_CODE = value.CUSTOMER_CODE;
    this.params.CUSTOMER_NAME = value.CUSTOMER_NAME;
  }
  public SetSelectedCustomerCodeAdd(value: any) {
    this.ParamAdd.CUSTOMER_CODE = value.CUSTOMER_CODE;
    this.ParamAdd.CUSTOMER_NAME = value.CUSTOMER_NAME;
  }

  public GetGroupDetail() {
    const param = {
      CUSTOMER_GROUP_CODE: ''  ,
    }
    this.http.post("SL", "SNM168_GetInvoiceExportMaster", param)
      .subscribe(res => {
        this.tableDataGroup = res.Table;
      }, (err) => {
        console.log(err, "err")
        this.modal.warning("Found an error, please contact support team", this.viewRef);
        return;
      })
  }

  openAddGruopDialog() {
    this.CustomerGruopControl.reset();
    this.ParamGroupAdd = this.global.ClearObject(this.ParamGroupAdd)
    this.ParamGroupAdd.CUSTOMER_GROUP_CODE = null
    this.dialogAddGruop.OpenDialog(); //แสดง popup add
  }

  public SaveGroupAdd(Type) {
    if (!this.ParamGroupAdd.CUSTOMER_GROUP_CODE ) {
      this.modal.warning('Please enter the group code information.', this.viewRef);
      return;
    }
    
    this.modal.confirm('Do you want to save?', this.viewRef,
      () => {
        
        this.http.post("SL", "SNM168_InsertInvoiceExportMaster", this.ParamGroupAdd)
          .subscribe(res => {
            if (res.Table[0].STATUS == 'DONE') {
              this.modal.info("Save data complete", this.viewRef);
              this.paramsGroup = {}
              this.GetGroupDetail();
              this.ParamGroupAdd = this.global.ClearObject(this.ParamGroupAdd);
              if(Type == 'A'){
                this.dialogAddGruop.Close();
              }else{
                this.dialogCopyGroup.Close();
              }
            }
            else if (res.Table[0].ERROR_MSG != '') {
              this.modal.warning(res.Table[0].ERROR_MSG, this.viewRef);
            }
            else {
              console.log(res.Table[0].MESSAGE, "err")
              this.modal.warning("Found an error, please contact support team", this.viewRef);
            }
          }, (err) => {
            console.log(err, "err")
            this.modal.warning("Found an error, please contact support team", this.viewRef);
          });
        },
      () => { }
    )
  }

  public CancelGroupAdd() {
    this.dialogAddGruop.Close();
  }

  public GroupEditRow(data) {
    this.paramsGroup = data;
    this.dialogEditGroup.OpenDialog();
    this.GetGroupDataForEdit('E');
  }
  
  private GetGroupDataForEdit(Type) {
    this.http.get("SL", "SNM168_GetDataInvoiceExportMaster", this.paramsGroup.CUSTOMER_GROUP_CODE)
      .subscribe(res => {
        console.log(res,'res');
        if (Type == 'E') {
          this.ParamGroupEdit = res.Table[0];
          this.ParamGroupEdit.FLAG_CONFIRM_TEMPLATE_CHK = res.Table[0].FLAG_CONFIRM_TEMPLATE;
        }else{
          this.ParamGroupAdd = res.Table[0];
          this.ParamGroupAdd.CUSTOMER_GROUP_CODE = '';
          this.ParamGroupAdd.FLAG_CONFIRM_TEMPLATE = '';
        }
      })
  }

  public SaveGroupEdit() {
    if (!this.paramsGroup.CUSTOMER_GROUP_CODE ) {
      this.modal.warning('Please enter the group code information.', this.viewRef);
      return;
    }
     
    this.modal.confirm('Do you want to save?', this.viewRef,
      () => {
        this.http.post("SL", "SNM168_UpdateInvoiceExportMaster", this.ParamGroupEdit)
          .subscribe(res => {
            if (res.Table[0].STATUS == 'DONE') {
              this.modal.info("Save data complete", this.viewRef);
              this.GetGroupDetail();
              this.dialogEditGroup.Close();
            }
            else if (res.Table[0].ERROR_MSG != '') {
              this.modal.warning(res.Table[0].ERROR_MSG, this.viewRef);
            }
            else {
              console.log(res.Table[0].MESSAGE, "err")
              this.modal.warning("Found an error, please contact support team", this.viewRef);
            }
          }, (err) => {
            console.log(err, "err")
            this.modal.warning("Found an error, please contact support team", this.viewRef);
          });
      },
      () => { }
    )
  }

  public CancleGroupEdit() {
    this.dialogEditGroup.Close();
  }

  public GroupDelete(data) {
    this.modal.confirm(
      "Do you want to delete this record?",
      this.viewRef,
      () => {
        this.http.post("SL", "SNM168_DeleteInvoiceExportMaster", data).subscribe((res) => {
          if (res.STATUS_MSG == "DONE") {
            this.modal.info(
              "Transaction complete: 1 record applied and deleted.",
              this.viewRef
            );
            this.GetGroupDetail();
          } else {
            this.modal.warning(
              "No change to save. Something went wrong.",
              this.viewRef
            );
          }
        });
      }
    );
  }

  public GroupCopyRow(data) {
    this.paramsGroup = data;
    this.dialogCopyGroup.OpenDialog();
    this.GetGroupDataForEdit('C');
  }

  public CancleGroupCopy() {
    this.dialogCopyGroup.Close();
  }

  public GetGroupMapping() {
    const param = {
      CUSTOMER_CODE: ''  ,
    }
    this.http.post("SL", "SNM168_GetDataInvoiceExportCustomerGroup", param)
      .subscribe(res => {
        this.tableData = res.Table;
      }, (err) => {
        console.log(err, "err")
        this.modal.warning("Found an error, please contact support team", this.viewRef);
        return;
      })
  }

  openDialog() {
    this.CustomerCodeControl.reset();
    this.ParamAdd = this.global.ClearObject(this.ParamAdd)
    this.ParamAdd.CUSTOMER_CODE = null;
    this.dialogAdd.OpenDialog(); //แสดง popup add
  }

  public SaveAdd() {
    if (!this.ParamAdd.CUSTOMER_CODE ) {
      this.modal.warning('Please enter the customer code information.', this.viewRef);
      return;
    }
    if (!this.ParamAdd.CUSTOMER_GROUP_CODE ) {
      this.modal.warning('Please enter the group code information.', this.viewRef);
      return;
    }

    if (!this.ParamAdd.ORDER_TYPE ) {
      this.modal.warning('Please enter the order type information.', this.viewRef);
      return;
    }


    this.http.post("SL", "SNM168_CheckCustomerGroupMapping", this.ParamAdd)
            .subscribe(result => {
              if (result.Table.length > 0) {
                this.modal.warning('There is duplicate group code in system. Please check!!!', this.viewRef);
                this.ParamAdd.CUSTOMER_GROUP_CODE = '';
                this.ParamAdd.CUSTOMER_GROUP_NAME = '';
              } else {
                this.modal.confirm('Do you want to save?', this.viewRef,
                  () => {
                    
                    this.http.post("SL", "SNM168_InsertInvoiceExportCustomerGroup", this.ParamAdd)
                      .subscribe(res => {
                        if (res.Table[0].STATUS == 'DONE') {
                          this.modal.info("Save data complete", this.viewRef);
                          this.params = {}
                          this.GetGroupMapping();
                          this.ParamAdd = this.global.ClearObject(this.ParamAdd);
                          this.dialogAdd.Close();
                        }
                        else if (res.Table[0].ERROR_MSG != '') {
                          this.modal.warning(res.Table[0].ERROR_MSG, this.viewRef);
                        }
                        else {
                          console.log(res.Table[0].MESSAGE, "err")
                          this.modal.warning("Found an error, please contact support team", this.viewRef);
                        }
                      }, (err) => {
                        console.log(err, "err")
                        this.modal.warning("Found an error, please contact support team", this.viewRef);
                      });
                    },
                  () => { }
                )
              }
            })
  }

  public CancelAdd() {
    this.dialogAdd.Close();
  }

  public EditRow(data) {
    this.params = data;
    this.params.CUSTOMER_GROUP_CODE_OLD = this.params.CUSTOMER_GROUP_CODE;
    this.dialogEdit.OpenDialog();
  }

  public SaveEdit() {
    if (!this.params.CUSTOMER_CODE ) {
      this.modal.warning('Please enter the customer code information.', this.viewRef);
      return;
    }
    if (!this.params.CUSTOMER_GROUP_CODE ) {
      this.modal.warning('Please enter the group code information.', this.viewRef);
      return;
    }
    
    this.http.post("SL", "SNM168_CheckCustomerGroupMapping", this.params)
      .subscribe(result => {
        if (result.Table.length > 0 && (this.params.CUSTOMER_GROUP_CODE_OLD != this.params.CUSTOMER_GROUP_CODE)) {
          this.modal.warning('There is duplicate group code in system. Please check!!!', this.viewRef);
          this.params.CUSTOMER_GROUP_CODE = '';
          this.params.CUSTOMER_GROUP_NAME = '';
        } else {
          this.modal.confirm('Do you want to save?', this.viewRef,
            () => {
              this.http.post("SL", "SNM168_UpdateInvoiceExportCustomerGroup", this.params)
                .subscribe(res => {
                  if (res.Table[0].STATUS == 'DONE') {
                    this.modal.info("Save data complete", this.viewRef);
                    this.GetGroupMapping();
                    this.dialogEdit.Close();
                  }
                  else if (res.Table[0].ERROR_MSG != '') {
                    this.modal.warning(res.Table[0].ERROR_MSG, this.viewRef);
                  }
                  else {
                    console.log(res.Table[0].MESSAGE, "err")
                    this.modal.warning("Found an error, please contact support team", this.viewRef);
                  }
                }, (err) => {
                  console.log(err, "err")
                  this.modal.warning("Found an error, please contact support team", this.viewRef);
                });
            },
            () => { }
          )
        }
      })
  }

  public CancleEdit() {
    this.dialogEdit.Close();
    this.GetGroupMapping();
  }

  public Delete(data) {
    this.modal.confirm(
      "Do you want to delete this record?",
      this.viewRef,
      () => {
        this.http.post("SL", "SNM168_DeleteInvoiceExportCustomerGroup", data).subscribe((res) => {
          if (res.STATUS_MSG == "DONE") {
            this.modal.info(
              "Transaction complete: 1 record applied and deleted.",
              this.viewRef
            );
            this.GetGroupMapping();
          } else {
            this.modal.warning(
              "No change to save. Something went wrong.",
              this.viewRef
            );
          }
        });
      }
    );
  }

  public CheckGruopCode() {
    // this.ParamGroupAdd.CUSTOMER_GROUP_CODE = this.ParamGroupAdd.CUSTOMER_GROUP_CODE.replace(/\s/g, "");

    this.http.post("SL", "SNM168_CheckGruopCode", this.ParamGroupAdd)
      .subscribe(result => {
        if (result.Table.length > 0) {
          this.modal.warning('There is duplicate group code in system. Please check!!!', this.viewRef);
          this.ParamGroupAdd.CUSTOMER_GROUP_CODE = '';
        };

      })

  }

  public CheckConfirmTemplate(event, Type) {
    if (event.checked) {
      if(Type == 'E'){
        this.ParamGroupEdit.FLAG_CONFIRM_TEMPLATE = 'Y';
      }else{
        this.ParamGroupAdd.FLAG_CONFIRM_TEMPLATE = 'Y';
      }
    }
    else {
      if(Type == 'E'){
        this.ParamGroupEdit.FLAG_CONFIRM_TEMPLATE = 'N';
      }else{
        this.ParamGroupAdd.FLAG_CONFIRM_TEMPLATE = 'N';
      }
    }
  }

}

