import { SelectionModel } from "@angular/cdk/collections";
import { Component, Inject, OnInit } from "@angular/core";
import { MatDialogRef, MAT_DIALOG_DATA } from "@angular/material/dialog";
import { Subject } from "rxjs";
import { debounceTime, distinctUntilChanged } from "rxjs/operators";
import { Globals } from "src/app/core/global";

@Component({
  selector: "email-conf-vendor-select",
  templateUrl: "vendorSelect.component.html",
  styleUrls: ["SNIC001.component.css"],
})
export class VendorSelectComponent implements OnInit {
  constructor(
    public dialogRef: MatDialogRef<VendorSelectComponent>,
    public global: Globals,
    @Inject(MAT_DIALOG_DATA) public data: any
  ) {}
  private filterVendorChangeSubject: Subject<string> = new Subject();
  public filterVendor: string = "";
  public vendorList: any[];
  public vendorListFiltered: any[] = [];
  public unavailableVendors: string[];
  //   public selectedList: string[];

  public selectedList: SelectionModel<string> = new SelectionModel<string>(
    true,
    []
  );

  ngOnInit(): void {
    this.filterVendorChangeSubject
      .pipe(debounceTime(500), distinctUntilChanged())
      .subscribe((filterVendor: string) => {
        this.FilterVendorList(filterVendor);
      });

    this.vendorList = this.data.vendorList;
    this.vendorListFiltered = this.vendorList;
    
    this.selectedList.select(...this.data.selectedList);
    this.unavailableVendors = this.data.unavailableVendors;
  }

  public onNoClick(): void {
    this.dialogRef.close();
  }

  public FilterVendorChanges(filterVendor: string) {
    this.filterVendorChangeSubject.next(filterVendor);
  }

  private FilterVendorList(filterVendor: string) {
    const vendorListFiltered = this.vendorList.filter((vendor) =>
      Object.keys(vendor).some(
        (k) =>
          vendor[k] &&
          vendor[k]
            .toString()
            .toLowerCase()
            .includes(filterVendor.toLowerCase())
      )
    );

    this.vendorListFiltered = vendorListFiltered;
  }

  public ToggleSelectVendor(vendorCode: string) {
    this.selectedList.toggle(vendorCode);
  }
}
