import { Component, ElementRef, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from 'src/app/core/global';

@Component({
  selector: 'snic002',
  templateUrl: './SNIC002.component.html',
  styleUrls: ['./SNIC002.component.css']
})



export class SNIC002Component implements OnInit {


  constructor(
    private http: HttpService,
    private router: Router,
    private modal : ModalService,
    private viewref : ViewContainerRef,
    private global : Globals
  ) { }

  public ConfigVendor: any = {
    ColName: "LOOKUP",
    ColValue: "",
    PlaceholderText: "Select Vendor Code",
    SourceController: "ICMS",
    SourceMethodName: "SNIC002_GET_VENDOR_MASTER",
    NoOfShowRecords: 50,
    MinLengthSearch: 1,
    UpperCase: true
  }

  public ConfigVendorInfo: any = {
    ColName: "LOOKUP",
    ColValue: "",
    PlaceholderText: "Select Vendor Code",
    SourceController: "ICMS",
    SourceMethodName: "SNIC002_GET_VENDOR_INFO",
    NoOfShowRecords: 50,
    MinLengthSearch: 1,
    UpperCase: true
  }

  @ViewChild("dialog",{static: false}) dialog : any;
  @ViewChild("file") fileSelect: ElementRef;
  public ParamSearch :any ={};
  public ParamData :any ={};
  public tabledata : any = [];
  public tableUpload : any = []
  public isAdd : boolean = false;
  public checkInvoice : boolean = true;
  public checkBusinessplace : boolean = true;
  public files: any = [];
  public fileName: string = ""
  public total_error : number = 0
  public hideCore : Array<string> = ['DELETE','VENDOR_NAME_EN','LAST_UPD_BY','LAST_UPD_DATE'];

  ngOnInit() {
    
  }

  public Search(){
    this.tabledata = []
    let params =  this.global.EscapeCharacter(this.ParamSearch.VENDOR_CODE)
    this.http.get("ICMS","SNIC002_GET_VENDOR_LIST",this.global.EscapeCharacter(this.ParamSearch.VENDOR_CODE))
    .subscribe(res =>{
          this.tabledata = res.Table
    })

  }

  public SelectVendorCode(event){
    
    if(event){
      this.ParamData.VENDOR_CODE = event.VENDOR_CODE
      this.ParamData.VENDOR_NAME_EN = event.VENDOR_NAME_EN
    }else{
      this.ParamData.VENDOR_CODE = ""
    }
  }
 

  public Add(){
    this.ParamData = {}
    this.isAdd = true
    this.ParamData.ENABLED_FLAG = 'Y';
    this.dialog.title = "Add Vendor Configuration"
    this.dialog.OpenDialog();
  }

  public EditRow(data){

    this.http.get("ICMS","SNIC002_GET_VENDOR_LIST",this.global.EscapeCharacter(data.VENDOR_CODE))
    .subscribe(res =>{

      //console.log(res);
      if(res.Table.length > 0){
        this.isAdd = false;
        this.ParamData = res.Table[0];
        this.dialog.title = "Edit Vendor Info"
        this.dialog.OpenDialog();
      }else{
        this.modal.warning("Vendor code not found",this.viewref)
      }
    })
  }

  public Delete(data){
    this.modal.confirm("Do you want to delete racord?",this.viewref,() =>{
      this.http.post("ICMS","SNIC002_DELETE",data)
      .subscribe(res =>{
        if (res.STATUS_MSG == 'DONE') {
          this.modal.info('Delete data successfully', this.viewref);
          this.Search();
          this.dialog.Close();
            
        }
        else {
            this.modal.warning('Delete fail.', this.viewref);
        }
      },err => {
        this.modal.warning('Delete fail.', this.viewref);
      })
    })
  }


  public Save(){
    this.modal.confirm("Do you want to save change you have made?",this.viewref,this.ConfirmSave)
  }

  private ConfirmSave = () =>{

    if(this.isAdd){
      this.http.post("ICMS","SNIC002_INSERT",this.ParamData)
      .subscribe(res => {
        if (res.STATUS_MSG == 'DONE') {
          this.modal.info('Save data successfully', this.viewref);
          if(this.tabledata.length > 0){
            this.Search();
          }
          this.dialog.Close();                                 
        } else if (res.STATUS_MSG == 'DUPPLICATE') {
            this.modal.info('No change to save. Found duplicate record.', this.viewref);
        }
        else {
            this.modal.warning('No change to save. Add fail.', this.viewref);
        }
      },(err)=>{
        this.modal.warning('No change to save. Add fail.', this.viewref);
      })
    }else{
      this.http.post("ICMS","SNIC002_UPDATE",this.ParamData)
      .subscribe(res => {
        if (res.STATUS_MSG == 'DONE') {
          this.modal.info('Update data successfully', this.viewref);
          this.Search();
          this.dialog.Close();
            
        } else {
            this.modal.warning('No change to save. Update fail.', this.viewref);
        }
      },(err)=>{
        this.modal.warning('No change to save. update fail.', this.viewref);
      })
    }

  }

  Cancel(){
    this.dialog.Close();
  }


public DownLoadTemplate() {
    let link = "assets/templates/SNIC002_TEMPLATE.xlsx";
    window.open(link, "_blank");
}

public OpenFileBrowser() {
    this.fileSelect.nativeElement.value = "";
    this.fileSelect.nativeElement.click();
    //this.files = [];
    //this.fileName = "";
  }

public FileChange(fileInput) {
    this.fileName = "";
    this.files = fileInput.target.files;
    this.fileName = this.files[0].name;

    if(this.fileName){
      this.UpLoad();
    }
    
}

private UpLoad() {
  let formData = new FormData();
  formData.append("file", this.files[0]);

  this.http.postFile("ICMS", "SNIC002_UPLOAD", formData).subscribe(
    (res) => {
      this.tableUpload = res.filter((x) => x.VENDOR_CODE);
    },
    (err) => {
      this.modal.error("Upload error", this.viewref);
    }
  );
}


public DeleteRow(Item) {
    
  let index = this.tableUpload.findIndex(x => x == Item)
  this.tableUpload.splice(index, 1);
  this.tableUpload = this.tableUpload.slice();

}

public UpdateData(){
  this.modal.confirm("Do you want to update date",this.viewref,this.ConfirmUpdate)
}

private ConfirmUpdate = () => {

  this.http.post("ICMS","SNIC002_SAVE_UPLOAD",{DETAIL : this.tableUpload})
  .subscribe(res => {
      if(res.STATUS_MSG == 'DONE'){
          this.modal.info('Update data complet', this.viewref);
          this.tableUpload = []
      }else{
          this.modal.error('Update data fail, please contact support team', this.viewref);
      }
  },err =>{
      this.modal.error('Update data fail, please contact support team', this.viewref);
  })
}
  
  

}
