import { Component, ElementRef, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from 'src/app/core/global';
import * as moment from "moment";

@Component({
  selector: 'SNIC003',
  templateUrl: './SNIC003.component.html',
  styleUrls: ['./SNIC003.component.css']
})
export class SNIC003Component implements OnInit {
  constructor(
    private http: HttpService,
    private router: Router,
    private modal : ModalService,
    private viewref : ViewContainerRef,
    private global : Globals
  ) { }

  public months:any[] = [];
  public vendortypes:any[] = [];
  public paramSearch:any = { MONTH_FROM:"", MONTH_TO:"", G1: {VENDOR_TYPE: ""}, G2: {VENDOR_TYPE: ""} };
  public paramReport:any = { MONTH_FROM:"", MONTH_TO:"", G1: {VENDOR_TYPE: ""}, G2: {VENDOR_TYPE: ""} };
  public tables:any = {};

  public reports:any[] = [
    { LABEL: "Report 1",           GROUP:"G1", TABLE_NAME: "SNIC003_R1",           REPORT_NAME:"PMS_RPT_SNIC003_R1" },
    { LABEL: "Report 1 by month",  GROUP:"G1", TABLE_NAME: "SNIC003_R1_BY_MONTH",  REPORT_NAME:"PMS_RPT_SNIC003_R1_BY_MONTH" },
    { LABEL: "Report 1 by vendor", GROUP:"G1", TABLE_NAME: "SNIC003_R1_BY_VENDOR", REPORT_NAME:"PMS_RPT_SNIC003_R1_BY_VENDOR" },
    { LABEL: "Report 2",           GROUP:"G2", TABLE_NAME: "SNIC003_R2",           REPORT_NAME:"PMS_RPT_SNIC003_R2" },
    { LABEL: "Report 2 by month",  GROUP:"G2", TABLE_NAME: "SNIC003_R2_BY_MONTH",  REPORT_NAME:"PMS_RPT_SNIC003_R2_BY_MONTH" },
    { LABEL: "Report 2 by vendor", GROUP:"G2", TABLE_NAME: "SNIC003_R2_BY_VENDOR", REPORT_NAME:"PMS_RPT_SNIC003_R2_BY_VENDOR" },
  ];

  ngOnInit() {
    this.GetMonths();
    this.GetDataMaster();
  }

  private GetMonths(){
    const startDate = moment("01 Jan 2022","DD MMM YYYY").toDate();
    const endDate = moment().toDate();
    let monthDiff = endDate.getMonth() - startDate.getMonth() + (12 * (endDate.getFullYear() - startDate.getFullYear()));
    let currentDate = endDate;
    let dates = [];
    while(monthDiff >= 0){
      const text = moment(currentDate).format("MMM YYYY");
      const value = moment(currentDate).format("YYYYMM");
      dates.push({TEXT: text, VALUE: value})
      currentDate = moment(currentDate).add(-1,'M').toDate();
      monthDiff -= 1;
    }
    this.months = dates;
    this.paramSearch.MONTH_FROM = moment(endDate).format("YYYYMM");
    this.paramSearch.MONTH_TO = moment(endDate).format("YYYYMM");
  }

  private GetDataMaster(){
    this.http.get("ICMS", "SNIC003_GetVendorType")
      .subscribe(res => {
        if(res.message == "Done"){
          this.vendortypes = res.set.Table;
          console.log(this.vendortypes);
        }
        else{
          this.modal.warning(res.message, this.viewref);
        }
      }, (err) => {
        console.log(err, 'err');
        this.modal.warning("Found an error, please contract support team", this.viewref);
      })
  }

  public Search(){
    const param = {
      MONTH_FROM: this.paramSearch.MONTH_FROM,
      MONTH_TO: this.paramSearch.MONTH_TO,
    }
    this.http.post("ICMS", "SNIC003_GetRPT", param)
      .subscribe(res => {
        if(res.message == "Done"){
          this.tables.table1 = res.set.Table;
          this.tables.table2 = res.set.Table1;
          this.tables.table4 = res.set.Table2;
          this.tables.table5 = res.set.Table3;
          this.paramReport.MONTH_FROM = param.MONTH_FROM;
          this.paramReport.MONTH_TO = param.MONTH_TO;
        }
        else{
          this.modal.warning(res.message, this.viewref);
        }
      }, (err) => {
        console.log(err, 'err');
        this.modal.warning("Found an error, please contract support team", this.viewref);
      })
  }

  public SearcByVendor(group: string){
    const param = {
      MONTH_FROM: this.paramSearch.MONTH_FROM,
      MONTH_TO: this.paramSearch.MONTH_TO,
      VENDOR_TYPE: this.paramSearch[group].VENDOR_TYPE,
    }
    this.http.post("ICMS", "SNIC003_GetRPTByVendor", param)
      .subscribe(res => {
        if(res.message == "Done"){
          if(group == "G1"){
            this.tables.table3 = res.set.Table;
            this.paramReport.G1.VENDOR_TYPE = param.VENDOR_TYPE;
          }
          else if(group == "G2"){
            this.tables.table6 = res.set.Table1;
            this.paramReport.G2.VENDOR_TYPE = param.VENDOR_TYPE;
          }
        }
        else{
          this.modal.warning(res.message, this.viewref);
        }
      }, (err) => {
        console.log(err, 'err');
        this.modal.warning("Found an error, please contract support team", this.viewref);
      })
  }

  public Data(name: string){
    let table;
    switch(name) { 
      case "SNIC003_R1": { 
        table = this.tables.table1;
        break; 
      } 
      case "SNIC003_R1_BY_MONTH": { 
        table = this.tables.table2;
        break; 
      } 
      case "SNIC003_R1_BY_VENDOR": { 
        table = this.tables.table3;
        break; 
      } 
      case "SNIC003_R2": { 
        table = this.tables.table4;
        break; 
      } 
      case "SNIC003_R2_BY_MONTH": { 
        table = this.tables.table5;
        break; 
      } 
      case "SNIC003_R2_BY_VENDOR": { 
        table = this.tables.table6;
        break; 
      } 
    } 
    return table;
  }

  public Report(name: string, group: string) {
    let report = name;
    let params = {
      P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      P_MONTH_FROM: this.paramReport.MONTH_FROM,
      P_MONTH_TO: this.paramReport.MONTH_TO
    };
    if(report == "PMS_RPT_SNIC003_R1_BY_VENDOR" || report == "PMS_RPT_SNIC003_R2_BY_VENDOR"){
      params = { ...params, ...{ P_VENDOR_TYPE: this.paramReport[group].VENDOR_TYPE } }
    }

    this.global.GoToReport(report, params, true, false);
  }

}
