import { Component, OnInit, ViewContainerRef, ViewChild } from "@angular/core";
import { HttpService } from "src/app/core/http.service";
import { ModalService } from "src/app/core/modal.service";
import { ActivatedRoute } from '@angular/router';
import { Globals } from 'src/app/core/global';

@Component({
    selector: 'snm031p',
    templateUrl: './snm031p.component.html',
    styleUrls: ['./snm031p.component.css']
})
export class SNM031PComponent implements OnInit {

    constructor(
        private httpService: HttpService,
        public modal: ModalService,
        public viewref: ViewContainerRef,
        private route: ActivatedRoute,
        private global: Globals
    ) {
    }

    public searchCriteria = { VendorCode: '', VendorName: '', LeadtimeOnline: '' };
    public Vendor = "";
    public VendorCode = "";
    public LeadtimeOnline = "";

    public searchResult: any = [];
    public dataList: Array<any> = [];
    public headerList: any;
    public displayedColumns: string[] = [];
    public fulfillmentList: any = [];
    public systemControl = { LastUpdateBy: '', LastUpdateDate: '' };
    public disableSave: boolean = true;
    public params: any = {}
    public categoryList = [];
    public fluctuateList = [];
    public fluctuateMaster = [];
    @ViewChild("dialog", { static: false }) dialog: any;


    ngOnInit() {
        //this.getTableHeader();
        this.GetFulfillmentList();
    }

    public LookupVendorConfig: any = {
        ColName: "LOOKUP_VENDOR_NAME",
        PlaceholderText: "Select Vendor Code",
        SourceController: "wPMS",
        SourceMethodName: "GetVendorCode",
        NoOfShowRecords: 50,
        UpperCase: true
    }


    GetFulfillmentList() {
        this.httpService.get("IC", "SNM031P_GetFulfillmentList")
            .subscribe(result => {
                console.log('GetFulfillmentList', result);
                if (result.Table.length > 0) {
                    this.fulfillmentList = result.Table;
                    this.categoryList = result.Table1
                    this.fluctuateMaster = result.Table2
                    //console.log('SNM031P_GetFulfillmentList',this.fulfillmentList);
                }
                else {
                    this.fulfillmentList = [];
                    //this.modal.error("There is no vendor information!", this.viewref);
                }
            })


    }

    getVendorInfo() {
        this.LeadtimeOnline = "";
        //console.log("getVendorInfo => ", this.VendorCode);
        this.httpService.get("IC", "SNM031P_GetVendorInfo", !this.VendorCode ? "" : this.VendorCode)
            .subscribe(result => {
                //console.log("getVendorInfo => " , result);
                if (result.Table.length > 0) {
                    this.LeadtimeOnline = result.Table[0].LEAD_TIME_ON;

                }
                else {
                    this.LeadtimeOnline = "";
                }
            });
    }

    SetVendorCodeLookup(event) {
        //this.searchCriteria.VendorCode = event;
        this.Vendor = event.LOOKUP_VENDOR_NAME;
        this.VendorCode = event.VENDOR_CODE;
        this.getVendorInfo();
        this.getOrderFactor();
    }

    ValidateSearchVendor(autoComplete) {
        autoComplete.query()

        if (!this.Vendor) {
            this.VendorCode = "";
            this.systemControl.LastUpdateBy = "";
            this.systemControl.LastUpdateDate = "";
            this.getVendorInfo();
            this.getOrderFactor();
        }
    }

    OnFulfillmentChange(row) {
        row.SAFETY_ALLOWANCE = this.fulfillmentList.filter(v => v.FULFILL_RATE == row.FULFILL_RATE)[0].SAFE_ALLOWANCE;
        //console.log('OnFulfillmentChange',row);
    }

    getOrderFactor() {
        this.dataList = [];
        this.disableSave = true;
        this.httpService.get("IC", "SNM031P_GetOrderFactor", !this.VendorCode ? "" : this.VendorCode)
            .subscribe(result => {
                //console.log(result);
                this.disableSave = result.Table.length > 0 ? false : true;
                this.dataList = result.Table;

                this.dataList.forEach((e) => {
                    if (typeof e === "object") {
                        e["_RecheckFulfillmentRate"] = e.FULFILL_RATE,
                            e["_RecheckSTDSafetyStock"] = e.STD_SAFETY_STOCK,
                            e["_RecheckOrderFrequency"] = e.ORDER_FREQUENCY,
                            e["_RecheckAllowanceRate"] = e.ALLOWANCE_RATE
                    }
                });
            });
    }

    onClickRow(row) {

        this.systemControl.LastUpdateBy = row.LAST_UPD_BY;
        this.systemControl.LastUpdateDate = row.LAST_UPD_DATE;
    }

    ValidateStdSafetyStock(row, elm) {

        if (!row.STD_SAFETY_STOCK) {
            this.modal.error("Please input Standard Safety Stock (SSS)!", this.viewref, () => {
                elm.srcElement.focus();
            });
        }
    }

    ValidateOrderFrequency(row, elm) {
        if (!row.ORDER_FREQUENCY) {
            this.modal.error("Please input Order Frequency!", this.viewref, () => {
                elm.srcElement.focus();
            });
        }
    }

    ValidateAllowanceRate(row, elm) {
        if (!row.ALLOWANCE_RATE) {
            this.modal.error("Please input Allowance Rate!", this.viewref, () => {
                elm.srcElement.focus();
            });
        }
    }
    NumericKeyDown(event) {
        //console.log('Keydonw',event);
        let reg = /^[0-9.]$/;

        if (event.keyCode == 8 || event.keyCode == 46
            || event.keyCode == 37 || event.keyCode == 39) {
            return true;
        }

        return reg.test(event.key);
    }

    SaveChange = () => {


        var i;
        let dirtyList: any = [];
        //console.log(this.dataList);

        for (i = 0; i < this.dataList.length; i++) {

            if (this.dataList[i]._RecheckFulfillmentRate != this.dataList[i].FULFILL_RATE ||
                this.dataList[i]._RecheckSTDSafetyStock != this.dataList[i].STD_SAFETY_STOCK ||
                this.dataList[i]._RecheckOrderFrequency != this.dataList[i].ORDER_FREQUENCY ||
                this.dataList[i]._RecheckAllowanceRate != this.dataList[i].ALLOWANCE_RATE
            ) {
                dirtyList.push(this.dataList[i]);
            }
        }


        if (dirtyList.length > 0) {
            this.httpService.post('IC', 'SNM031P_SaveChange', JSON.stringify(dirtyList))
                .subscribe(res => {
                    if (res === "Done") {
                        this.modal.info('Success', this.viewref)
                        this.getOrderFactor();
                        //this.openDialog('Message from the system', 'Success')
                    } else {
                        this.modal.error('Failed', this.viewref)
                    }

                });
        }
        else {
            this.modal.info("There is no dirty record to save!", this.viewref);
        }

    }


    public Add() {
        this.params = {}
        this.params.VENDOR_CODE = null
        this.params.VENDOR_NAME = null
        this.params.CATEGORY = null
        this.params.FLUCTUATE_CODE = null
        this.params.FULFILL_RATE = null
        this.params.SAFETY_ALLOWANCE = null
        this.params.STD_DEVIATION = null
        this.params.ALLOWANCE_RATE = null
        this.params.SAFETY_STOCK = null
        this.params.ORDER_FREQUENCY = null
        this.dialog.OpenDialog()
    }


    public SaveAdd() {

        this.modal.confirm("Do you want to save",this.viewref,()=> ConfirmSave())

        let ConfirmSave = () => {
            this.httpService.post("IC", "SNM031P_SaveAdd", this.params)
                .subscribe(res => {
                    if (res.result == 'DONE') {
                        this.modal.info("Save data complete", this.viewref)
                        this.dialog.Close();
                        if(this.VendorCode){
                            this.getOrderFactor()
                        }
                    }
                    else if (res.result == "DUPPLICATE") {
                        this.modal.info('No change to save. Found duplicate record.', this.viewref);
                    }
                    else {
                        this.modal.error("Found an error, please contact support team", this.viewref);
                    }
                },err =>{
                    this.modal.error("Found an error, please contact support team", this.viewref);
                })
        }
    }

    public CancelAdd() {

    }

    public SetVendorCodeAdd(event) {
        this.params.VENDOR_NAME = event.LOOKUP_VENDOR_NAME;
        this.params.VENDOR_CODE = event.VENDOR_CODE;
    }

    public FulfillmentChange(event) {
        console.log(event)
        this.params.SAFETY_ALLOWANCE = this.fulfillmentList.find(v => v.FULFILL_RATE == event).SAFE_ALLOWANCE;
        //console.log('OnFulfillmentChange',row);
    }

    public CatChange(event) {
        this.params.FLUCTUATE_CODE = null
        this.fluctuateList = this.fluctuateMaster.filter(x => x.PART_CATEGORY == event)
    }

    public CheckValidObject() {

        for (var key in this.params) {
            if (this.params.hasOwnProperty(key)) {
                if (!this.params[key]) {
                    return false
                }
            }
        }
        return true;
    }
}
