import { Component, ElementRef, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { ModalService } from 'src/app/core/modal.service';

@Component({
    selector: 'SNM147',
    templateUrl: 'SNM147.component.html',
    styleUrls: ['SNM147.component.css']
})

export class SNM147Component implements OnInit {
    constructor(
        private http: HttpService,
        private router: Router,
        private global: Globals,
        private modal: ModalService,
        private viewref: ViewContainerRef
  ) { }

  @ViewChild("dialogAction", { static: false }) dialogAction: any;

  public paramSearch: any = {CASE_TYPE: ""};
  public formData: any = {};
  public tableData: Array<any> = [];

  public lookupVendorCodeConfig: any = {
    ColName: "LOOKUP_VENDOR_NAME",
    PlaceholderText: "Select Vendor code",
    SourceController: "IC",
    SourceMethodName: "SNM147_GetVendorCode",
    NoOfShowRecords: 30,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedVendorCode(val: any) {
    if(val){
      this.paramSearch.VENDOR_CODE = val.VENDOR_CODE;
      this.paramSearch.VENDOR_NAME = val.VENDOR_NAME;
      this.Search();
    }else{
      this.paramSearch.VENDOR_NAME = null;
    }
  }

  public SetSelectedVendorCodeDialog(val: any) {
    if(val){
      this.formData.VENDOR_CODE = val.VENDOR_CODE;
      this.formData.VENDOR_NAME_TH = val.VENDOR_NAME_TH;
      this.formData.VENDOR_NAME_EN = val.VENDOR_NAME_EN;
      this.formData.VENDOR_CODE_TEMP = val.VENDOR_CODE;
      this.formData.VENDOR_NAME_TH_TEMP = val.VENDOR_NAME_TH;
      this.formData.VENDOR_NAME_EN_TEMP = val.VENDOR_NAME_EN;
    }else{
      this.formData.VENDOR_CODE = this.formData.VENDOR_CODE;
      this.formData.VENDOR_NAME_TH = null;
      this.formData.VENDOR_NAME_EN = null;
      this.formData.VENDOR_CODE_TEMP = this.formData.VENDOR_CODE;
      this.formData.VENDOR_NAME_TH_TEMP = null;
      this.formData.VENDOR_NAME_EN_TEMP = null;
    }
  }

  public SetCancelVendorCodeDialog(val: any) {
    this.formData.VENDOR_CODE = this.formData.VENDOR_CODE_TEMP ? this.formData.VENDOR_CODE_TEMP : null ;
    this.formData.VENDOR_NAME_TH = this.formData.VENDOR_NAME_TH_TEMP ? this.formData.VENDOR_NAME_TH_TEMP : null ;
    this.formData.VENDOR_NAME_EN = this.formData.VENDOR_NAME_EN_TEMP ? this.formData.VENDOR_NAME_EN_TEMP : null ;
  }

  ngOnInit() {
    this.Search();
  }

  public Search() {
    let vendorcode = this.global.EscapeCharacter(this.paramSearch.VENDOR_CODE ? this.paramSearch.VENDOR_CODE : "NULL")
    this.http.get('IC', 'SNM147_GetData', vendorcode)
    .subscribe(res => {
        this.tableData = res.set.Table;
    },(err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contract support team", this.viewref);
  });
  }
  
  public Add() {
    this.formData = {}
    this.formData.TYPE = "ADD";
    this.dialogAction.width = "450px" 
    this.dialogAction.height = "425px" 
    this.dialogAction.title = "Add FQO Vendor" 
    this.dialogAction.OpenDialog();
  }

  public Edit(data) {
    this.formData = { ...data }
    this.formData.TYPE = "EDIT";
    this.dialogAction.width = "450px" 
    this.dialogAction.height = "4505x" 
    this.dialogAction.title = "Edit FQO Vendor" 
    this.dialogAction.OpenDialog();
  }

  public Delete(data) {
    this.modal.confirm("Do you want to delete record<br>Vendor code: "+ data.VENDOR_CODE, this.viewref,()=> ConfirmDelete())

    let ConfirmDelete = () => {
      const params = { VENDOR_CODE : data.VENDOR_CODE }
      this.http.post("IC", "SNM147_Delete", params)
      .subscribe(res =>{
        if (res.result == 'DONE') {
          this.modal.info('Delete record complete', this.viewref);
          this.Search();
        } else {
          this.modal.error('Found an error, please contract support team.', this.viewref);
        }
      },err =>{
        this.modal.error('Found an error, please contract support team.', this.viewref);
      })
    }
  }

  public SaveAdd() {

    if(!this.formData.VENDOR_CODE){
      this.modal.warning("Please select vendor code.",this.viewref);
      return;
    }
    else if(!this.formData.STATUS){
      this.modal.warning("Please select status.",this.viewref);
    }

    this.modal.confirm("Do you want to save change you have made?", this.viewref, this.ConfirmAdd);
  }

  public ConfirmAdd = () => {
    this.http.post('IC', 'SNM147_Insert', this.formData)
      .subscribe(res => {
        if (res.result == 'DONE') {
          this.Search();
          this.dialogAction.Close();
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
        } else if (res.result == 'DUP') {
          this.modal.warning('No change to save. Found duplicate record.', this.viewref);
        } else {
          this.modal.error('Found an error, please contact support team.', this.viewref);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewref);
      })
  }

  public CancelAdd() {
    this.dialogAction.Close();
  }

  public SaveEdit() {

    if(!this.formData.VENDOR_CODE){
      this.modal.warning("Please select vendor code.",this.viewref);
      return;
    }
    else if(!this.formData.STATUS){
      this.modal.warning("Please select status.",this.viewref);
    }

    this.modal.confirm("Do you want to save change you have made?", this.viewref, this.ConfirmEdit);
  }

  public ConfirmEdit = () => {
    this.http.post('IC', 'SNM147_Update', this.formData)
      .subscribe(res => {
        if (res.result == 'DONE') {
          this.Search();
          this.dialogAction.Close();
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
        } else {
          this.modal.error('Found an error, please contact support team.', this.viewref);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
  }

  public CancleEdit() {
    this.dialogAction.Close();
  }
}