import { Component, ElementRef, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { ModalService } from 'src/app/core/modal.service';

@Component({
    selector: 'SNM148',
    templateUrl: 'SNM148.component.html',
    styleUrls: ['SNM148.component.css']
})

export class SNM148Component implements OnInit {
    constructor(
        private http: HttpService,
        private router: Router,
        private global: Globals,
        private modal: ModalService,
        private viewref: ViewContainerRef
  ) { }

  @ViewChild("dialogAction", { static: false }) dialogAction: any;

  public paramSearch: any = {CASE_TYPE: ""};
  public formData: any = {};
  public tableData: Array<any> = [];

  public lookupPartCategoryConfigAll: any = {
    ColName: "LOOKUP_PART_CATEGORY",
    PlaceholderText: "Select Part category",
    SourceController: "IC",
    SourceMethodName: "SNM148_GetPartCategoryAll",
    NoOfShowRecords: 30,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public lookupPartCategoryConfig: any = {
    ColName: "LOOKUP_PART_CATEGORY",
    PlaceholderText: "Select Part category",
    SourceController: "IC",
    SourceMethodName: "SNM148_GetPartCategory",
    NoOfShowRecords: 30,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedPartCategory(val: any) {
    if(val){
      this.paramSearch.PART_CATEGORY = val.PART_CATEGORY;
      this.paramSearch.CATEGORY_DESC = val.CATEGORY_DESC;
      this.Search();
    }else{
      this.paramSearch.CATEGORY_DESC = null;
    }
  }

  public SetSelectedPartCategoryDialog(val: any) {
    if(val){
      this.formData.PART_CATEGORY = val.PART_CATEGORY;
      this.formData.CATEGORY_DESC = val.CATEGORY_DESC;
      this.formData.CATEGORY_REM = val.CATEGORY_REM;
      this.formData.PART_CATEGORY_TEMP = val.PART_CATEGORY;
      this.formData.CATEGORY_DESC_TEMP = val.CATEGORY_DESC;
      this.formData.CATEGORY_REM_TEMP = val.CATEGORY_REM;
    }else{
      this.formData.PART_CATEGORY = this.formData.PART_CATEGORY;
      this.formData.CATEGORY_DESC = null;
      this.formData.CATEGORY_REM = null;
      this.formData.PART_CATEGORY_TEMP = this.formData.PART_CATEGORY;
      this.formData.CATEGORY_DESC_TEMP = null;
      this.formData.CATEGORY_REM_TEMP = null;
    }
  }

  public SetCancelPartCategoryDialog(val: any) {
    this.formData.PART_CATEGORY = this.formData.PART_CATEGORY_TEMP ? this.formData.PART_CATEGORY_TEMP : null ;
    this.formData.CATEGORY_DESC = this.formData.CATEGORY_DESC_TEMP ? this.formData.CATEGORY_DESC_TEMP : null ;
    this.formData.CATEGORY_REM = this.formData.CATEGORY_REM_TEMP ? this.formData.CATEGORY_REM_TEMP : null ;
  }

  ngOnInit() {
    this.Search();
  }

  public Search() {
    let partcategory = this.global.EscapeCharacter(this.paramSearch.PART_CATEGORY ? this.paramSearch.PART_CATEGORY : "NULL")
    this.http.get('IC', 'SNM148_GetData', partcategory)
    .subscribe(res => {
        this.tableData = res.set.Table;
    },(err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contract support team", this.viewref);
  });
  }
  
  public Add() {
    this.formData = {}
    this.formData.TYPE = "ADD";
    this.dialogAction.width = "450px" 
    this.dialogAction.height = "425px" 
    this.dialogAction.title = "Add FQO Part Category" 
    this.dialogAction.OpenDialog();
  }

  public Edit(data) {
    this.formData = { ...data }
    this.formData.TYPE = "EDIT";
    this.dialogAction.width = "450px" 
    this.dialogAction.height = "4505x" 
    this.dialogAction.title = "Edit FQO Part Category" 
    this.dialogAction.OpenDialog();
  }

  public Delete(data) {
    this.modal.confirm("Do you want to delete record<br>Part category: "+ data.PART_CATEGORY, this.viewref,()=> ConfirmDelete())

    let ConfirmDelete = () => {
      const params = { PART_CATEGORY : data.PART_CATEGORY }
      this.http.post("IC", "SNM148_Delete", params)
      .subscribe(res =>{
        if (res.result == 'DONE') {
          this.modal.info('Delete record complete', this.viewref);
          this.Search();
        } else {
          this.modal.error('Found an error, please contract support team.', this.viewref);
        }
      },err =>{
        this.modal.error('Found an error, please contract support team.', this.viewref);
      })
    }
  }

  public SaveAdd() {

    if(!this.formData.PART_CATEGORY){
      this.modal.warning("Please select part category.",this.viewref);
      return;
    }
    else if(!this.formData.STATUS){
      this.modal.warning("Please select status.",this.viewref);
    }

    this.modal.confirm("Do you want to save change you have made?", this.viewref, this.ConfirmAdd);
  }

  public ConfirmAdd = () => {
    this.http.post('IC', 'SNM148_Insert', this.formData)
      .subscribe(res => {
        if (res.result == 'DONE') {
          this.Search();
          this.dialogAction.Close();
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
        } else if (res.result == 'DUP') {
          this.modal.warning('No change to save. Found duplicate record.', this.viewref);
        } else {
          this.modal.error('Found an error, please contact support team.', this.viewref);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewref);
      })
  }

  public CancelAdd() {
    this.dialogAction.Close();
  }

  public SaveEdit() {

    if(!this.formData.PART_CATEGORY){
      this.modal.warning("Please select part category.",this.viewref);
      return;
    }
    else if(!this.formData.STATUS){
      this.modal.warning("Please select status.",this.viewref);
    }

    this.modal.confirm("Do you want to save change you have made?", this.viewref, this.ConfirmEdit);
  }

  public ConfirmEdit = () => {
    this.http.post('IC', 'SNM148_Update', this.formData)
      .subscribe(res => {
        if (res.result == 'DONE') {
          this.Search();
          this.dialogAction.Close();
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
        } else {
          this.modal.error('Found an error, please contact support team.', this.viewref);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
  }

  public CancleEdit() {
    this.dialogAction.Close();
  }
}