import { Component, ElementRef, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { FormControl, Validators } from '@angular/forms';
import { ModalService } from 'src/app/core/modal.service';
import { SelectionModel } from '@angular/cdk/collections';

@Component({
  selector: 'SNM171',
  templateUrl: './SNM171.component.html',
  styleUrls: ['./SNM171.component.css']
})



export class SNM171Component implements OnInit {


  constructor(
    private http: HttpService,
    private router: Router,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  public ConfigPart: any = {
    ColName: "LOOKUP",
    PlaceholderText: "Select Part No.",
    SourceController: "IC",
    SourceMethodName: "SNM171_GetPart",
    NoOfShowRecords: 30,
  }

  public ConfigVendor: any = {
    ColName: "LOOKUP",
    PlaceholderText: "Select Vendor ",
    SourceController: "IC",
    SourceMethodName: "SNM171_GetVendor",
    NoOfShowRecords: 30,
    MinLengthSearch : 1
  }

  public ConfigCategory: any = {
    ColName: "LOOKUP",
    PlaceholderText: "Select Category.",
    SourceController: "IC",
    SourceMethodName: "SNM171_GetCategory",
    NoOfShowRecords: 30,
    MinLengthSearch : 0
  }

  @ViewChild("dialogEditPart", { static: false }) dialogEditPart: any;
  @ViewChild("dialogUploadPart", { static: false }) dialogUploadPart: any;
  @ViewChild("fileInputPart") fileInputPart: ElementRef;
  public selectionPart = new SelectionModel<any>(true, []);
  public ParamSearch: any = {};
  public Params: any = {};
  public tabledata: any = [];
  public isAdd: boolean = false;
  public tableUploadPart: Array<any> = [];
  public FileNamePart: string = "";
  private FilePart: any;


  ngOnInit() {

  }

  public SearchPart() {
    this.tabledata = []
    this.http.post("IC", "SNM171_GetDataPart", this.ParamSearch)
      .subscribe(res => {
        this.tabledata = res.Table
      })

  }

  public TabChange(event) {
  }

  public isAllSelectedPart() {
    const numSelected = this.selectionPart.selected.length;
    const numRows = this.tabledata.length;
    return numSelected === numRows;
  }

  public TogglePart() {
    this.isAllSelectedPart() ?
      this.selectionPart.clear() :
      this.tabledata.forEach(row => {this.selectionPart.select(row)});
  }


  public AddPart() {
    this.Params = {}
    this.isAdd = true
    this.dialogEditPart.title = "New Part Configure"
    this.dialogEditPart.OpenDialog();
  }

  public EditRowPart(datarow) {

    this.isAdd = false;
    this.Params = datarow;
    this.dialogEditPart.title = "Edit Part Configure"
    this.dialogEditPart.OpenDialog();

  }

  public DownloadTemplate(template : number){
    
    let link = ''
    if (template == 1) {
      link = "assets/templates/SNM171_Upload_Part_Template.xlsx"
    } else {
      link = "assets/templates/SNM171_Upload_Vendor_Template.xlsx"
    }

    window.open(link, '_blank')
  }

  public UploadPart() {
    this.tableUploadPart = []
    this.FileNamePart = "";
    this.dialogUploadPart.title = "Upload Part Part"
    this.dialogUploadPart.OpenDialog()
  }
  
  public OpenFileBrowserPart(){
    this.FileNamePart = "";
    this.fileInputPart.nativeElement.value = '';
    this.fileInputPart.nativeElement.click();
  }

  public SelectFilePart(evt : any){
    let Files: Array<File> = evt.target.files;

    if (Files.length > 0) {
      //let File: File = Files[0];
      this.FilePart = Files[0];
      this.FileNamePart = this.FilePart.name;
    }
  }

  public PreViewPart(){
    if (!this.FileNamePart) {
      this.modal.warning("Please Open File First...", this.viewref)
      return;
    }

    let formData = new FormData();
    formData.append('file', this.FilePart);
    this.tableUploadPart = []
    this.http.postFile("IC", "SNM171_UploadPart", formData)
      .subscribe(result => {
        this.tableUploadPart = result.filter(x => x.PART_NO)
      }, err => {
        this.modal.error("Upload not complete", this.viewref);
      })
  }

  public SaveUploadPart(){
    const fill = this.tableUploadPart.filter(x => x.STATUS_TEXT == "OK")
    if(fill.length == 0){
      this.modal.warning("No data for save",this.viewref)
      return;
    }

    this.modal.confirm("Do you want to save data",this.viewref,()=> confirm())

    let confirm = () => {
      this.http.post("IC","SNM171_SaveUploadPart",fill)
      .subscribe(res =>{

        if(res.STATUS == "DONE"){
          this.modal.info("Save data " + fill.length + " record complete",this.viewref)
          this.dialogUploadPart.Close()
          this.SearchPart()
        }else{
          this.modal.error("Save data not complete. Please contact administrator",this.viewref)
        }

      },err => {
        this.modal.error("Save data not complete. Please contact administrator",this.viewref)
      })
    }
  }


  public DeletePart() {

    this.modal.confirm("Do you want to delete " + this.selectionPart.selected.length + " racord?", this.viewref, ()=> confirm())

    let confirm = () => {
      this.http.post("IC", "SNM171_DeletePart", this.selectionPart.selected)
        .subscribe(res => {

          if (res.STATUS_MSG == 'DONE') {
            this.modal.info("Transaction complete: " + this.selectionPart.selected.length + " record applied and deleted.", this.viewref);
            this.SearchPart();
            this.selectionPart.clear()
          } else {
            this.modal.warning('Delete fail.', this.viewref);
          }
        })
      }
  }


  public SavePart() {

    this.modal.confirm("Do you want to save change you have made?", this.viewref, () => ConfirmSave())

    let ConfirmSave = () => {

      if (this.isAdd) {

        this.http.post("IC", "SNM171_InsertPart", this.Params)
          .subscribe(res => {

            if (res.STATUS_MSG == 'DONE') {
              this.modal.info('Transaction complete: applied and saved.', this.viewref);
              if (this.tabledata.length > 0) {
                this.SearchPart();
              }
              this.dialogEditPart.Close();
            } else if (res.STATUS_MSG == 'DUPLICATE') {
              this.modal.info('No change to save. Found duplicate record.', this.viewref);
            }
            else {
              this.modal.warning('No change to save. Add fail.', this.viewref);
            }
          }, (err) => {
            this.modal.warning('No change to save. Add fail.', this.viewref);
          })
      } else {


        this.http.post("IC", "SNM171_UpdatePart", this.Params)
          .subscribe(res => {
            if (res.STATUS_MSG == 'DONE') {
              this.modal.info('Transaction complete: applied and saved.', this.viewref);
              this.SearchPart();
              this.dialogEditPart.Close();
            } else {
              this.modal.error('No change to save. Update fail.', this.viewref);
            }
          }, err => {
            this.modal.error('No change to save. Update fail.', this.viewref);
          })
      }

    }
  }

  public CancelPart() {
    this.dialogEditPart.Close();
  }



  //-------------------------------- Vendor ---------------------------------------------------------//

  @ViewChild("dialogEditVendor", { static: false }) dialogEditVendor: any;
  @ViewChild("dialogUploadVendor", { static: false }) dialogUploadVendor: any;
  @ViewChild("fileInputVendor") fileInputVendor: ElementRef;
  public selectionVendor = new SelectionModel<any>(true, []);

  public ParamSearchVendor: any = {};
  public ParamVendor : any = {};
  public tabledataVendor: any = [];
  public tableUploadVendor: Array<any> = [];
  public FileNameVendor: string = "";
  private FileVendor: any;


  public SearchVendor() {
    this.tabledataVendor = []
    this.http.post("IC", "SNM171_GetDataVendor", this.ParamSearchVendor)
      .subscribe(res => {
        this.tabledataVendor = res.Table
      })

  }

  public isAllSelectedVendor() {
    const numSelected = this.selectionVendor.selected.length;
    const numRows = this.tabledataVendor.length;
    return numSelected === numRows;
  }

  public ToggleVendor() {
    this.isAllSelectedVendor() ?
      this.selectionVendor.clear() :
      this.tabledataVendor.forEach(row => {this.selectionVendor.select(row)});
  }


  public AddVendor() {
    this.ParamVendor = {}
    this.isAdd = true
    this.dialogEditVendor.title = "New Part Percent"
    this.dialogEditVendor.OpenDialog();
  }

  public EditVendor(datarow) {

    this.isAdd = false;
    this.ParamVendor = datarow;
    this.dialogEditVendor.title = "Edit Part Percent"
    this.dialogEditVendor.OpenDialog();

  }

  public UploadVendor() {
    this.tableUploadVendor = []
    this.FileNameVendor = "";
    this.dialogUploadVendor.title = "Upload Vendor Vendor"
    this.dialogUploadVendor.OpenDialog()
  }
  
  public OpenFileBrowserVendor(){
    this.FileNameVendor = "";
    this.fileInputVendor.nativeElement.value = '';
    this.fileInputVendor.nativeElement.click();
  }

  public SelectFileVendor(evt : any){
    let Files: Array<File> = evt.target.files;

    if (Files.length > 0) {
      //let File: File = Files[0];
      this.FileVendor = Files[0];
      this.FileNameVendor = this.FileVendor.name;
    }
  }

  public PreViewVendor(){
    if (!this.FileNameVendor) {
      this.modal.warning("Please Open File First...", this.viewref)
      return;
    }

    let formData = new FormData();
    formData.append('file', this.FileVendor);
    this.tableUploadVendor = []
    this.http.postFile("IC", "SNM171_UploadVendor", formData)
      .subscribe(result => {
        this.tableUploadVendor = result.filter(x => x.VENDOR_CODE)
      }, err => {
        this.modal.error("Upload not complete", this.viewref);
      })
  }

  public SaveUploadVendor(){
    const fill = this.tableUploadVendor.filter(x => x.STATUS_TEXT == "OK")
    if(fill.length == 0){
      this.modal.warning("No data for save",this.viewref)
      return;
    }

    this.modal.confirm("Do you want to save data",this.viewref,()=> confirm())

    let confirm = () => {
      this.http.post("IC","SNM171_SaveUploadVendor",fill)
      .subscribe(res =>{

        if(res.STATUS == "DONE"){
          this.modal.info("Save data " + fill.length + " record complete",this.viewref)
          this.dialogUploadVendor.Close()
          this.SearchVendor()
        }else{
          this.modal.error("Save data not complete. Please contact administrator",this.viewref)
        }

      },err => {
        this.modal.error("Save data not complete. Please contact administrator",this.viewref)
      })
    }
  }


  public DeleteVendor() {
    this.modal.confirm("Do you want to delete " + this.selectionVendor.selected.length + " racord?", this.viewref, ()=> confirm())

    let confirm = () => {
      this.http.post("IC", "SNM171_DeleteVendor", this.selectionVendor.selected)
        .subscribe(res => {

          if (res.STATUS_MSG == 'DONE') {
            this.modal.info("Transaction complete: " + this.selectionVendor.selected.length + " record applied and deleted.", this.viewref);
            this.SearchVendor();
            this.selectionVendor.clear()

          } else {
            this.modal.warning('Delete fail.', this.viewref);
          }
        })
    }
  }


  public SaveVendor() {

    this.modal.confirm("Do you want to save change you have made?", this.viewref, () => ConfirmSave())

    let ConfirmSave = () => {

      if (this.isAdd) {

        this.http.post("IC", "SNM171_InsertVendor", this.ParamVendor)
          .subscribe(res => {

            if (res.STATUS_MSG == 'DONE') {
              this.modal.info('Transaction complete: applied and saved.', this.viewref);
              if (this.tabledata.length > 0) {
                this.SearchVendor();
              }
              this.dialogEditVendor.Close();
            } else if (res.STATUS_MSG == 'DUPLICATE') {
              this.modal.info('No change to save. Found duplicate record.', this.viewref);
            }
            else {
              this.modal.warning('No change to save. Add fail.', this.viewref);
            }
          }, (err) => {
            this.modal.warning('No change to save. Add fail.', this.viewref);
          })
      } else {


        this.http.post("IC", "SNM171_UpdateVendor", this.ParamVendor)
          .subscribe(res => {
            if (res.STATUS_MSG == 'DONE') {
              this.modal.info('Transaction complete: applied and saved.', this.viewref);
              this.SearchVendor();
              this.dialogEditVendor.Close();
            } else {
              this.modal.error('No change to save. Update fail.', this.viewref);
            }
          }, err => {
            this.modal.error('No change to save. Update fail.', this.viewref);
          })
      }

    }
  }

  public CancelVendor() {
    this.dialogEditVendor.Close();
  }

  //-------------------------- Category ----------------------------------------------------//


  @ViewChild("dialogEditCat", { static: false }) dialogEditCat: any;

  public ParamSearchCat: any = {};
  public ParamCat : any = {};
  public tabledataCat: any = [];


  public SearchCat() {
    this.tabledataCat = []
    this.http.post("IC", "SNM171_GetDataCat", this.ParamSearchCat)
      .subscribe(res => {
        this.tabledataCat = res.Table
      })

  }

  public AddCat() {
    this.ParamVendor = {}
    this.isAdd = true
    this.dialogEditCat.title = "New Category"
    this.dialogEditCat.OpenDialog();
  }

  public EditCat(datarow) {

    this.isAdd = false;
    this.ParamVendor = datarow;
    this.dialogEditCat.title = "Edit Category"
    this.dialogEditCat.OpenDialog();

  }


  public DeleteCat(data) {
    this.modal.confirm("Do you want to delete racord?", this.viewref, () => {
      this.http.post("IC", "SNM171_DeleteCat", data)
        .subscribe(res => {

          if (res.STATUS_MSG == 'DONE') {
            this.modal.info('Transaction complete: 1 record applied and deleted.', this.viewref);
            this.SearchCat();

          } else {
            this.modal.warning('Delete fail.', this.viewref);
          }
        })
    })
  }


  public SaveCat() {

    this.modal.confirm("Do you want to save change you have made?", this.viewref, () => ConfirmSave())

    let ConfirmSave = () => {

      if (this.isAdd) {

        this.http.post("IC", "SNM171_InsertCat", this.ParamCat)
          .subscribe(res => {

            if (res.STATUS_MSG == 'DONE') {
              this.modal.info('Transaction complete: applied and saved.', this.viewref);
              if (this.tabledata.length > 0) {
                this.SearchCat();
              }
              this.dialogEditCat.Close();
            } else if (res.STATUS_MSG == 'DUPLICATE') {
              this.modal.info('No change to save. Found duplicate record.', this.viewref);
            }
            else {
              this.modal.warning('No change to save. Add fail.', this.viewref);
            }
          }, (err) => {
            this.modal.warning('No change to save. Add fail.', this.viewref);
          })
      } else {


        this.http.post("IC", "SNM171_UpdateCat", this.ParamCat)
          .subscribe(res => {
            if (res.STATUS_MSG == 'DONE') {
              this.modal.info('Transaction complete: applied and saved.', this.viewref);
              this.SearchCat();
              this.dialogEditCat.Close();
            } else {
              this.modal.error('No change to save. Update fail.', this.viewref);
            }
          }, err => {
            this.modal.error('No change to save. Update fail.', this.viewref);
          })
      }

    }
  }

  public CancelCat() {
    this.dialogEditCat.Close();
  }


}

