import { Component, OnInit, ViewContainerRef, ViewChild } from "@angular/core";
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from '../../../core/modal.service';
import { SelectionModel } from '@angular/cdk/collections';
import { ActivatedRoute } from '@angular/router';
import { Globals } from 'src/app/core/global';


@Component({
  selector: 'snpe044',
  templateUrl: './SNPE044.component.html',
  styleUrls: ['./SNPE044.component.css']
})

export class SNPE044Component implements OnInit {

  constructor(
    private Http: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private route: ActivatedRoute,
    private global: Globals
  ) {
  }

  private data: any;
  private files: any = [];
  public FileName: string = ""
  private tableData: any;
  public headerList: Array<any> = [];
  public dataList: any = [];
  public displayedColumns: string[] = [];
  public selection = new SelectionModel<any>(true, []);
  public qCheckSet: boolean = false;
  public totalUpload: number = 0;
  public totalError: number = 0;
  public totalSelect: number;

  ngOnInit() {

    this.getTableHeader();

  }

  getTableHeader() {
    this.Http.get("System", "GetHeaderGridView", 'SNPE044')
      .subscribe(result => {
        this.headerList = result.filter(v => v.VISIBILITY === true);
        this.displayedColumns = this.headerList.map(v => v.FIELD_NAME);

      })
  }

  OnFileSelect(fileInput) {

    this.files = fileInput.target.files;
    this.FileName = this.files[0].name;
  }


  UpLoad() {

    if (this.files.length == 0) {

      this.modal.error('Please Open CSV File First...', this.viewref)
    } else {
      this.dataList = [];
      let formData = new FormData();
      formData.append('file', this.files[0]);

      this.Http.postFile('IC', 'SNPE044_UploadandGet', formData)
        .subscribe(res => {
          // res.Table.map(x => {
          //   if(x.ETD_CONFIRM){
          //     x.ETD_CONFIRM_SHOW = this.FormateDate(x.ETD_CONFIRM)
          //   }
          // })
          
          this.dataList = res.Table
          this.totalUpload = this.dataList.length;
          this.totalError = this.dataList.filter(x => x.ERR_MASSAGE != null).length;
        })
    }
  }

  Save() {

    this.modal.confirm("Do you want to save changed you have made?", this.viewref, this.ConfirmSave);
  }

  ConfirmSave = () => {

    if (this.selection.selected.length == 0) {
      this.modal.error("No record selected!", this.viewref)
    } else {
      this.Http.post("IC", "SNPE044_SAVE_ETD", this.selection.selected)
        .subscribe(res => {

          if (res.Table[0].STATUS == "DONE") {
            this.modal.info('Transaction complete: ' + this.selection.selected.length + ' record applied and saved.', this.viewref, this.ClearData);
            this.selection.clear();
          } else {
            this.modal.error('No change to save. Something went wrong.', this.viewref);
          }
        })
    }
  }


  isAllSelected() {
    const numSelected = this.selection.selected.length;
    //const numRows = this.dataList.data.length;
    const numRows = this.dataList.filter(x => !x.ERR_MASSAGE).length;
    return numSelected === numRows;
  }

  Toggle() {
    this.isAllSelected() ?
      this.selection.clear() :
      //this.dataList.data.forEach(row => this.selection.select(row));
      this.dataList.forEach(row => {
        if (!row.ERR_MASSAGE) {
          this.selection.select(row)
        }
      });
  }

  Export() {

    this.Http.Download('IC', 'SNPE044_Export', JSON.stringify(this.dataList))
      .subscribe(res => {
        if (res) {
          this.WriteContents(res)
        } else {
          this.modal.error('EXPORT NOT COMPLETE', this.viewref)
        }

      })
  }

  WriteContents(content) {
    const a = document.createElement('a');
    const file = new Blob([content], { type: content.type });
    a.href = URL.createObjectURL(file);
    a.download = "SNPE044.csv";
    a.click();
  }


  ClearData = () => {
    this.dataList = [];
    this.files = [];
    this.FileName = '';
    this.totalError = 0;
    this.totalSelect = 0;
    this.totalUpload = 0;
    this.selection.clear();
  }

  Clear(){
    this.ClearData()
  }

  FormateDate(date) {
    let x = date.split("-")
    let d = new Date(x[2]+'-'+x[1]+'-'+x[0]);
    return d
  }
}

