import {
  Component,
  ElementRef,
  OnInit,
  ViewChild,
  ViewContainerRef,
} from "@angular/core";
import { Globals } from "src/app/core/global";
import { HttpService } from "src/app/core/http.service";
import { ModalService } from "src/app/core/modal.service";

@Component({
  selector: "SNPE049",
  templateUrl: "SNPE049.component.html",
})
export class SNPE049Component implements OnInit {
  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewRef: ViewContainerRef,
    private global: Globals
  ) {}

  @ViewChild("fileUpload") fileUpload: ElementRef;
  private files: any = [];
  public FileName: string = "";
  public DataUploadList = [];
  public IsError: boolean = true;

  ngOnInit() {}

  public SelectUploadFile() {
    this.fileUpload.nativeElement.value = null;
    this.fileUpload.nativeElement.click();
  }

  public SaveFileSelect() {
    let formData = new FormData();
    formData.append("file", this.files[0]);

    this.modal.confirm(
      "Are you sure to save ETD?",
      this.viewRef,
      () => {
        this.http
          .postFile("IC", "SNPE049_Save_Upload", formData)
          .subscribe((res) => {
            if (res.status === "Done") {
              this.modal.info("Update ETD date completed.", this.viewRef);
              this.ClearData();
            } else {
              this.modal.error(res.message, this.viewRef);
            }
          });
      },
      () => {}
    );
  }

  public OnFileSelect(fileInput) {
    this.files = fileInput.target.files;
    this.FileName = this.files[0].name;

    if (this.files.length == 0) {
      this.modal.warning("Please Open xlsx File First...", this.viewRef);
    } else {
      this.DataUploadList = [];
      let formData = new FormData();
      formData.append("file", this.files[0]);

      this.http.postFile("IC", "SNPE049_Upload", formData).subscribe((res) => {
        if (res.status === "Done") {
          this.ArrangeData(res.data.Table);
        } else {
          this.modal.error(res.message, this.viewRef);
        }
      });
    }
  }

  private ArrangeData(dataList) {
    this.IsError = false;
    this.DataUploadList = dataList.map((data) => {
      if (data.IS_ERROR === "Y") this.IsError = true;

      return data;
    });
  }

  public DownloadTemplate() {
    location.href = "/assets/templates/Upload_ETD_Template.xlsx"
  }

  public ClearData() {
    this.fileUpload.nativeElement.value = null;
    this.files = null;
    this.FileName = null;
    this.DataUploadList = [];
  }
}
