import { Component, OnInit, ViewContainerRef } from "@angular/core";
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';
import { ActivatedRoute } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { SelectionModel } from "@angular/cdk/collections";
import * as moment from "moment";


@Component({
  selector: 'snpp203',
  templateUrl: './snpp203.component.html',
  styleUrls: ['./snpp203.component.css']
})
export class SNPP203Component implements OnInit {

  constructor(
    private http: HttpService,
    public modal: ModalService,
    public viewref: ViewContainerRef,
    private route: ActivatedRoute,
    private global: Globals
  ) {}

  public LookupVendorConfig: any = {
    ColName: "LOOKUP_VENDOR_NAME",
    PlaceholderText: "Select Vendor Code",
    SourceController: "wPMS",
    SourceMethodName: "GetVendorCode",
    NoOfShowRecords: 50,
    UpperCase: true
  }
  public param : any = {}
  public tableData: any = [];
  public selection = new SelectionModel<any>(true, []);
  public stickyColArray = ['SELECT', 'VENDOR', 'ACCEPT_PART_NO', 'PART_NAME', 'ORDER_QTY', 'ACCEPT_QTY', 'REMARKS'];
  public po_no : string = null;
  ngOnInit() {
    this.param.PIC = this.global.GetTokenDetail("ssUserName");
    this.Search();
   }

  

  public Search(){
    this.http.post("IC","SNPP203_GetData",this.param)
    .subscribe(res => {
      this.tableData = res.Table;
    })


  }

  public Save(){
    
    if(this.selection.isEmpty()){
      this.modal.warning("Please select some PO befire confirm",this.viewref)
      return
    }

    let find = this.selection.selected.some(x => x.ACCEPT_QTY < 1)
    if(find){
      this.modal.warning("Accept Qty must more than 0",this.viewref)
      return;
    }

    let findRemark = this.selection.selected.some(x => x.ACCEPT_QTY != x.ORDER_QTY && !x.REMARKS)
    if(findRemark){
      this.modal.warning("In case of edit accpet qty. Pleas input remarks",this.viewref)
      return;
    }

    let findRemarkLockPo = this.selection.selected.some(x => x.LOCK_PO != "0" && !x.REMARKS)
    if(findRemarkLockPo){
      this.modal.warning("In case of part lock po. Pleas input remarks",this.viewref)
      return;
    }

    this.modal.confirm("Do you want to create new PO",this.viewref,() => ConfirmSave())

    let ConfirmSave = () =>{
      this.http.post("IC","SNPP203_CreatePO",this.selection.selected)
      .subscribe(res =>{
        if(res.STATUS == "DONE"){
          this.modal.info("Create new PO complete <br> PO No = " + res.FROM_PO + " - " + res.TO_PO,this.viewref);
          this.po_no = res.FROM_PO
          this.selection.clear()
          this.Search();
        }else{
          this.modal.error("Found error please contact support team",this.viewref);
        }
      }, err =>{
        this.modal.error("Found error please contact support team",this.viewref);
      })
    }
  }

  public SelectVendor(event) {
    this.param.VENDOR_NAME = event.LOOKUP_VENDOR_NAME;
    this.param.VENDOR_CODE = event.VENDOR_CODE;
  }

  public isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.tableData.length;
    return numSelected === numRows;
  }

  public Toggle() {
    this.isAllSelected() ?
      this.selection.clear() :
      this.tableData.forEach(row =>this.selection.select(row));
  }

  public PoReport() {
   
    this.global.GoToExportName("PMS_RPT_IC_SNPP203", {
            P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
            P_USER: this.global.GetTokenDetail("ssUserName")

      } , "PO_DATA-" + moment().format("DD-MMM-YYYY"), "EXCELOPENXML"
    ); 
  }



  
}
