import { Component, OnInit, ViewChild, ViewContainerRef } from "@angular/core";
import { animate, state, style, transition, trigger } from "@angular/animations";
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';
import { ActivatedRoute } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { SelectionModel } from "@angular/cdk/collections";
import * as moment from 'moment';
import { MatTableDataSource } from "@angular/material/table";
import { MatPaginator } from "@angular/material/paginator";

@Component({
  selector: 'snpp204',
  templateUrl: './snpp204.component.html',
  styleUrls: ['./snpp204.component.css'],
  animations: [
    trigger('detailExpand', [
      state('collapsed', style({height: '0px', minHeight: '0'})),
      state('expanded', style({height: '*'})),
      transition('expanded <=> collapsed', animate('225ms cubic-bezier(0.4, 0.0, 0.2, 1)')),
    ]),
  ],
})
export class SNPP204Component implements OnInit {

  constructor(
    private http: HttpService,
    public modal: ModalService,
    public viewref: ViewContainerRef,
    private route: ActivatedRoute,
    private global: Globals
  ) {}

  public ConfigVendor: any = {
    ColName: "LOOKUP_VENDOR_NAME",
    ColValue: "",
    PlaceholderText: "Select Vendor",
    SourceController: "wPMS",
    SourceMethodName: "GetVendorCode",
    NoOfShowRecords: 30,
    MinLengthSearch: 1,
    UpperCase: true
  }

  public ConfigPart: any = {
    ColName: "LOOKUP_PART_VALUE",
    PlaceholderText: "Select Part",
    SourceController: "IC",
    SourceMethodName: "SNSQ005_GetPart",
    NoOfShowRecords: 50,
    UpperCase: true
  }

  public params : any = {}
  public tableData: any = [];
  public tableDataVendor: any = [];
  public tableDetail: any = [];
  public selection = new SelectionModel<any>(true, []);
  public columnsToDisplay = [];
  public expandedElement: null;
  public expandedElementV: null;
  public headerList: Array<any> = [];
  public standardData : any = {};
  public dataListVendor: any = [];
  @ViewChild("paginatorVendor", { static: true }) paginatorVendor: MatPaginator;
  public dataList: any = [];
  public cindex : number = -1;
  //@ViewChild("paginator") paginator: MatPaginator;

  ngOnInit() {
    this.http.get("System","GetHeaderGridView","SNPP204_RESULT")
    .subscribe(res => {
      this.headerList = res.filter(x => x.VISIBILITY == true)
      this.columnsToDisplay = this.headerList.filter(x => ["PART_NO","VENDOR_CODE"].indexOf(x.FIELD_NAME) < 0).map(v => v.FIELD_NAME);
    })
    this.params.FROM_DATE = moment().subtract(3,'months');
    this.params.TO_DATE = moment();
    this.params.VENDOR_TYPE = "ALL"
    //this.Search();
   }

  

   public ExpandTableVendor(element,index){
    if(this.expandedElementV == element){
      this.expandedElementV = null
    }else{
      this.http.post("IC","SNPP204_GetDataVendorCode",element)
      .subscribe(res => {
        
        this.tableData = res.Table;
        this.expandedElementV = element
        this.cindex = index;
      })
    } 
   }

  public Search(){
    this.http.post("IC","SNPP204_GetData",this.params)
    .subscribe(res => {
      this.tableDataVendor = res.Table;
      this.dataListVendor = new MatTableDataSource<any>(this.tableDataVendor || []);
      // this.dataListVendor.paginator = this.paginatorVendor;
    })
  }

  public SelectMonthAndYearFrom(event: any, datepicker: any) {
    this.params.FROM_DATE = event;
    datepicker.close();

  }

  public SelectMonthAndYearTo(event: any, datepicker: any) {
    this.params.TO_DATE = event;
    datepicker.close();

  }

  public SetSelectedPart(value: any) {
    this.params.PART_NO = value.PART_NO;
  }

  public SetSelectedVendor(value: any) {
    this.params.VENDOR_CODE = value.VENDOR_CODE;
  }

  public compareRow(row1: any, row2: any) {
    return JSON.stringify(row1) === JSON.stringify(row2);
  }


  public DownLoad(){
    if(this.tableDataVendor.length == 0){
      return false;
    }
    this.http.Download("IC","SNPP204_Download",{})
    .subscribe(res => {
      console.log(res,'ressssssssssss')
      this.WriteContents(res);
    })
  }

  private WriteContents(content) {
    const a = document.createElement('a');
    const file = new Blob([content], { type: content.type });
    a.href = URL.createObjectURL(file);
    a.download = "DashboardData.xlsx";
    a.click();
    //this.modal.info("Generate data complete",this.viewref)
  }

}
