import { Component, Input, OnInit, SimpleChanges, ViewChild, ViewContainerRef } from "@angular/core";
import { animate, state, style, transition, trigger } from "@angular/animations";
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';
import { ActivatedRoute } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { SelectionModel } from "@angular/cdk/collections";
import * as moment from 'moment';
import { MatTableDataSource } from "@angular/material/table";
import { MatPaginator } from "@angular/material/paginator";

@Component({
  selector: 'snpp204vendor',
  templateUrl: './snpp204vendor.component.html',
  styleUrls: ['./snpp204vendor.component.css'],
  animations: [
    trigger('detailExpand', [
      state('collapsed', style({height: '0px', minHeight: '0'})),
      state('expanded', style({height: '*'})),
      transition('expanded <=> collapsed', animate('225ms cubic-bezier(0.4, 0.0, 0.2, 1)')),
    ]),
  ],
})
export class SNPP204VENDORComponent implements OnInit {

  constructor(
    private http: HttpService,
    public modal: ModalService,
    public viewref: ViewContainerRef,
    private route: ActivatedRoute,
    private global: Globals
  ) {}


  @Input("tableData") tableData: Array<any> = [];
  @Input("tableHeader") tableHeader: Array<any> = [];


  public tableDetail: any = [];
  public selection = new SelectionModel<any>(true, []);
  public columnsToDisplay = [];
  public expandedElement: null;
  public headerList: Array<any> = [];
  public standardData : any = {};
  public headerPO : any = [];
  @ViewChild("paginator", { static: true }) paginator: MatPaginator;
  public dataList: any = [];

  ngOnInit() {
      this.headerList = this.tableHeader;
      this.ArrangeShowColumn(this.headerList);
   }

   ngOnChanges(changes: SimpleChanges): void {
    if (!changes["tableData"].isFirstChange() && this.tableData) {
      if (this.tableData.length === 0) {
      
    }
    }

    console.log(this.tableData,"tableData");
    this.dataList = new MatTableDataSource<any>(this.tableData || []);
    this.dataList.paginator = this.paginator;
    this.ArrangeShowColumn(this.headerList);

  }

   public ExpandTable(element){
    
    if(this.expandedElement === element){
      this.expandedElement = null
    }else{
      this.http.post("IC","SNPP204_GetDataPart",element)
      .subscribe(res => {

        this.tableDetail = res.Table
        this.expandedElement = element

      })
    } 
   }

  ArrangeShowColumn(data) {
    this.columnsToDisplay = data.filter(v => ["VENDOR_TYPE","PART_NO"].indexOf(v.FIELD_NAME) < 0)
      .map(v => v.FIELD_NAME);
  }


}
