import { Component, OnInit, ViewChild, ViewContainerRef } from "@angular/core";
import { animate, state, style, transition, trigger } from "@angular/animations";
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';
import { ActivatedRoute } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { DateAdapter, MAT_DATE_FORMATS, MAT_DATE_LOCALE } from "@angular/material/core";
import { MAT_MOMENT_DATE_ADAPTER_OPTIONS, MomentDateAdapter } from "@angular/material-moment-adapter";
import * as moment from 'moment';
import { MatTableDataSource } from "@angular/material/table";
import { MatPaginator } from "@angular/material/paginator";

export const MY_FORMATS = {
  parse: {
    dateInput: ['MM-YYYY', 'MM/YYYY', 'MMYYYY', 'MMM-YY', 'MMM-YYYY'],
  },
  display: {
    dateInput: 'MMM-YYYY',
    monthYearLabel: 'MMM YYYY',
    dateA11yLabel: 'LL',
    monthYearA11yLabel: 'MMMM YYYY',
  },
};

@Component({
  selector: 'snpp206',
  templateUrl: './snpp206.component.html',
  styleUrls: ['./snpp206.component.scss'],
  providers: [
    {
      provide: DateAdapter,
      useClass: MomentDateAdapter,
      deps: [MAT_DATE_LOCALE, MAT_MOMENT_DATE_ADAPTER_OPTIONS],
    },

    { provide: MAT_DATE_FORMATS, useValue: MY_FORMATS },
  ],
  animations: [
    trigger('detailExpand', [
      state('collapsed', style({height: '0px', minHeight: '0'})),
      state('expanded', style({height: '*'})),
      transition('expanded <=> collapsed', animate('225ms cubic-bezier(0.4, 0.0, 0.2, 1)')),
    ]),
  ],
})
export class SNPP206Component implements OnInit {

  constructor(
    private http: HttpService,
    public modal: ModalService,
    public viewref: ViewContainerRef,
    private route: ActivatedRoute,
    private global: Globals
  ) {}

  public paramsSearch : any = {};
  public paramsReport : any = {};

  //PO
  public cPOindex : number = -1;
  public headerListPO: Array<any> = [];
  public columnsToDisplayPO: any = [];
  public headerSubListPOColor: string;

  public dataListPO: any = [];
  public tableDataPO: any = [];
  public tableNamePODetail: string;
  public tableDataPODetail: any = [];
  
  public expandedElementPO: null;
  public expandedElementPOType: null;

  //ETD
  public cETDindex : number = -1;
  public headerListETD: Array<any> = [];
  public columnsToDisplayETD: any = [];
  public headerSubListETDColor: string;

  public dataListETD: any = [];
  public tableDataETD: any = [];
  public tableNameETDDetail: string;
  public tableDataETDDetail: any = [];
  
  public expandedElementETD: null;
  public expandedElementETDType: null;

  //OverDue
  public cOverDueindex : number = -1;
  public headerListOverDue: Array<any> = [];
  public columnsToDisplayOverDue: any = [];

  public dataListOverDue: any = [];
  public tableDataOverDue: any = [];
  public tableNameOverDueDetail: string;
  public tableDataOverDueDetail: any = [];
  
  public expandedElementOverDue: null;
  public expandedElementOverDueType: null;

  //SUM
  public tableDataPOAll: any = [];
  public tableDataETDAll: any = [];
  public tableDataOverDueAll: any = [];

  @ViewChild("paginatorPO", { static: true }) paginatorPO: MatPaginator;
  @ViewChild("paginatorETD", { static: true }) paginatorETD: MatPaginator;
  @ViewChild("paginatorOverDue", { static: true }) paginatorOverDue: MatPaginator;

  ngOnInit() {
    this.paramsSearch.FROM_DATE = moment().subtract(3,'months');
    this.paramsSearch.TO_DATE = moment();

    this.http.get("System", "GetHeaderGridView", "SNPP206_PO_SUMMARY")
    .subscribe(res => {
      this.headerListPO = res.filter(x => x.VISIBILITY == true)
      this.columnsToDisplayPO = this.headerListPO.map(v => v.FIELD_NAME);
      this.headerSubListPOColor = this.headerListPO.find(item => item.LINK_FN !== null).LINK_FN;
    })

    this.http.get("System", "GetHeaderGridView", "SNPP206_ETD_SUMMARY")
    .subscribe(res => {
      this.headerListETD = res.filter(x => x.VISIBILITY == true)
      this.columnsToDisplayETD = this.headerListETD.map(v => v.FIELD_NAME);
      this.headerSubListETDColor = this.headerListETD.find(item => item.LINK_FN !== null).LINK_FN;
    })

    this.http.get("System", "GetHeaderGridView", "SNPP206_OVERDUE")
    .subscribe(res => {
      this.headerListOverDue = res.filter(x => x.VISIBILITY == true)
      this.columnsToDisplayOverDue = this.headerListOverDue.map(v => v.FIELD_NAME);
    })

    this.Search();
   }

   public SelectMonthAndYearFrom(event: any, datepicker: any) {
    this.paramsSearch.FROM_DATE = event;
    datepicker.close();
   }
 
   public SelectMonthAndYearTo(event: any, datepicker: any) {
    this.paramsSearch.TO_DATE = event;
    datepicker.close();
   }

  public Search(){
    this.http.post("IC", "SNPP206_GetData", this.paramsSearch)
    .subscribe(res => {
      this.tableDataPO = res.Table;
      this.dataListPO = new MatTableDataSource<any>(this.tableDataPO || []);
      this.dataListPO.paginator = this.paginatorPO;

      this.tableDataETD = res.Table1;
      this.dataListETD = new MatTableDataSource<any>(this.tableDataETD || []);
      this.dataListETD.paginator = this.paginatorETD;

      this.tableDataOverDue = res.Table2;
      this.dataListOverDue = new MatTableDataSource<any>(this.tableDataOverDue || []);
      this.dataListOverDue.paginator = this.paginatorOverDue;

      this.tableDataPOAll = res.Table3;
      this.tableDataETDAll = res.Table4;
      this.tableDataOverDueAll = res.Table5;

      this.paramsSearch.FROM_DATE_SEARCH = this.paramsSearch.FROM_DATE;
      this.paramsSearch.TO_DATE_SEARCH = this.paramsSearch.TO_DATE;

      this.paramsReport.VENDOR_CODE = this.paramsSearch.VENDOR_CODE;
      this.paramsReport.FROM_DATE = moment(this.paramsSearch.FROM_DATE._d).format("DD-MMM-YYYY");
      this.paramsReport.TO_DATE = moment(this.paramsSearch.TO_DATE._d).format("DD-MMM-YYYY");
    }, (err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contact support team", this.viewref);
    });
  }

  public ExpandTablePOConfirmOnDue(element, index, type){
    if(this.expandedElementPO == element && this.expandedElementPOType == type){
      this.expandedElementPO = null;
    }
    else{
      const params = {...this.paramsSearch, ...element}
      this.http.post("IC", "SNPP206_GetPOConfirmOnDue", params)
      .subscribe(res => {
        this.tableNamePODetail = "SNPP206_PO_CONFIRM_ON_DUE";
        this.tableDataPODetail = res.Table;
        this.expandedElementPO = element;
        this.expandedElementPOType = type;
        this.cPOindex = index;
        this.paramsReport.PO_VENDOR_CODE = element.VENDOR_CODE;
        this.paramsReport.PO_STORED_NAME = "SP_NP_SNPP206_GET_PO_RPT_BY_VENDOR_ONDUE";
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
    } 
  }

  public ExpandTablePOConfirmOverDue(element, index, type){
    if(this.expandedElementPO == element && this.expandedElementPOType == type){
      this.expandedElementPO = null;
    }
    else{
      const params = {...this.paramsSearch, ...element}
      this.http.post("IC", "SNPP206_GetPOConfirmOverDue", params)
      .subscribe(res => {
        this.tableNamePODetail = "SNPP206_PO_CONFIRM_OVER_DUE";
        this.tableDataPODetail = res.Table;
        this.expandedElementPO = element;
        this.expandedElementPOType = type;
        this.cPOindex = index;
        this.paramsReport.PO_VENDOR_CODE = element.VENDOR_CODE;
        this.paramsReport.PO_STORED_NAME = "SP_NP_SNPP206_GET_PO_RPT_BY_VENDOR_OVERDUE";
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
    } 
  }

  public ExpandTablePONotConfirm(element, index, type){
    if(this.expandedElementPO == element && this.expandedElementPOType == type){
      this.expandedElementPO = null;
    }
    else{
      const params = {...this.paramsSearch, ...element}
      this.http.post("IC", "SNPP206_GetPONotConfirm", params)
      .subscribe(res => {
        this.tableNamePODetail = "SNPP206_PO_NOT_CONFIRM";
        this.tableDataPODetail = res.Table;
        this.expandedElementPO = element;
        this.expandedElementPOType = type;
        this.cPOindex = index;
        this.paramsReport.PO_VENDOR_CODE = element.VENDOR_CODE;
        this.paramsReport.PO_STORED_NAME = "SP_NP_SNPP206_GET_PO_RPT_BY_VENDOR_NOTCON";
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
    } 
  }

  public ExpandTableETDConfirmOnDue(element, index, type){
    if(this.expandedElementETD == element && this.expandedElementETDType == type){
      this.expandedElementETD = null;
    }
    else{
      const params = {...this.paramsSearch, ...element}
      this.http.post("IC", "SNPP206_GetETDConfirmOnDue", params)
      .subscribe(res => {
        this.tableNameETDDetail = "SNPP206_ETD_CONFIRM_ON_DUE";
        this.tableDataETDDetail = res.Table;
        this.expandedElementETD = element;
        this.expandedElementETDType = type;
        this.cETDindex = index;
        this.paramsReport.ETD_VENDOR_CODE = element.VENDOR_CODE;
        this.paramsReport.PO_STORED_NAME = "SP_NP_SNPP206_GET_ETD_RPT_BY_VENDOR_ONDUE";
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
    } 
  }

  public ExpandTableETDConfirmOverDue(element, index, type){
    if(this.expandedElementETD == element && this.expandedElementETDType == type){
      this.expandedElementETD = null;
    }
    else{
      const params = {...this.paramsSearch, ...element}
      this.http.post("IC", "SNPP206_GetETDConfirmOverDue", params)
      .subscribe(res => {
        this.tableNameETDDetail = "SNPP206_ETD_CONFIRM_OVER_DUE";
        this.tableDataETDDetail = res.Table;
        this.expandedElementETD = element;
        this.expandedElementETDType = type;
        this.cETDindex = index;
        this.paramsReport.ETD_VENDOR_CODE = element.VENDOR_CODE;
        this.paramsReport.PO_STORED_NAME = "SP_NP_SNPP206_GET_ETD_RPT_BY_VENDOR_OVERDUE";
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
    } 
  }

  public ExpandTableETDNotConfirm(element, index, type){
    if(this.expandedElementETD == element && this.expandedElementETDType == type){
      this.expandedElementETD = null;
    }
    else{
      const params = {...this.paramsSearch, ...element}
      this.http.post("IC", "SNPP206_GetETDNotConfirm", params)
      .subscribe(res => {
        this.tableNameETDDetail = "SNPP206_ETD_NOT_CONFIRM";
        this.tableDataETDDetail = res.Table;
        this.expandedElementETD = element;
        this.expandedElementETDType = type;
        this.cETDindex = index;
        this.paramsReport.ETD_VENDOR_CODE = element.VENDOR_CODE;
        this.paramsReport.PO_STORED_NAME = "SP_NP_SNPP206_GET_ETD_RPT_BY_VENDOR_NOTCON";
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
    } 
  }

  public ExpandTableOverDueNotice(element, index, type){
    if(this.expandedElementOverDue == element && this.expandedElementOverDueType == type){
      this.expandedElementOverDue = null;
    }
    else{
      const params = {...this.paramsSearch, ...element}
      this.http.post("IC", "SNPP206_GetOverDueNotice", params)
      .subscribe(res => {
        this.tableNameOverDueDetail = "SNPP206_OVERDUE_NOTICE";
        this.tableDataOverDueDetail = res.Table;
        this.expandedElementOverDue = element;
        this.expandedElementOverDueType = type;
        this.cOverDueindex = index;
        this.paramsReport.OVERDUE_VENDOR_CODE = element.VENDOR_CODE || '-';
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
    } 
  }

  public OpenReport(report: number){
    switch(report){
      case 1:
          this.global.GoToReport("PMS_RPT_IC_SNPP206_PO_SUMMARY",
          {
            P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
            P_VENDOR_CODE: this.paramsReport.VENDOR_CODE,
            P_FROM_DATE: this.paramsReport.FROM_DATE,
            P_TO_DATE: this.paramsReport.TO_DATE,
          });
        break;
      case 2:
          this.global.GoToReport("PMS_RPT_IC_SNPP206_ETD_SUMMARY",
          {
            P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
            P_VENDOR_CODE: this.paramsReport.VENDOR_CODE,
            P_FROM_DATE: this.paramsReport.FROM_DATE,
            P_TO_DATE: this.paramsReport.TO_DATE,
          });
        break;
      case 3:
          this.global.GoToReport("PMS_RPT_IC_SNPP206_OVERDUE_SUMMARY",
          {
            P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
            P_VENDOR_CODE: this.paramsReport.VENDOR_CODE,
            P_FROM_DATE: this.paramsReport.FROM_DATE,
            P_TO_DATE: this.paramsReport.TO_DATE,
          });
        break;
      case 4:
        this.global.GoToReport("PMS_RPT_IC_SNPP206_PO_BY_VENDOR",
        {
          P_STORED_NAME: this.paramsReport.PO_STORED_NAME,
          P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
          P_VENDOR_CODE: this.paramsReport.PO_VENDOR_CODE,
          P_FROM_DATE: this.paramsReport.FROM_DATE,
          P_TO_DATE: this.paramsReport.TO_DATE,
        });
      break;
      case 5:
        this.global.GoToReport("PMS_RPT_IC_SNPP206_ETD_BY_VENDOR",
        {
          P_STORED_NAME: this.paramsReport.PO_STORED_NAME,
          P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
          P_VENDOR_CODE: this.paramsReport.ETD_VENDOR_CODE,
          P_FROM_DATE: this.paramsReport.FROM_DATE,
          P_TO_DATE: this.paramsReport.TO_DATE,
        });
      break;
      case 6:
        this.global.GoToReport("PMS_RPT_IC_SNPP206_OVERDUE_BY_VENDOR",
        {
          P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
          P_VENDOR_CODE: this.paramsReport.OVERDUE_VENDOR_CODE,
          P_FROM_DATE: this.paramsReport.FROM_DATE,
          P_TO_DATE: this.paramsReport.TO_DATE,
        });
      break;
    }
  }
}
