import { Component, Input, OnChanges, OnInit, SimpleChanges, ViewChild, ViewContainerRef } from "@angular/core";
import { animate, state, style, transition, trigger } from "@angular/animations";
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';
import { ActivatedRoute } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { MatTableDataSource } from "@angular/material/table";
import { MatPaginator } from "@angular/material/paginator";
import * as moment from 'moment';



@Component({
  selector: 'snpp206overdue',
  templateUrl: './SNPP206OVERDUE.component.html',
  styleUrls: ['./SNPP206OVERDUE.component.scss'],
  animations: [
    trigger('detailExpand', [
      state('collapsed', style({height: '0px', minHeight: '0'})),
      state('expanded', style({height: '*'})),
      transition('expanded <=> collapsed', animate('225ms cubic-bezier(0.4, 0.0, 0.2, 1)')),
    ]),
  ],
})
export class SNPP206OVERDUEComponent implements OnChanges {

  constructor(
    private http: HttpService,
    public modal: ModalService,
    public viewref: ViewContainerRef,
    private route: ActivatedRoute,
    private global: Globals
  ) {}

  @Input("params") params: any = {}
  @Input("tableData") tableData: Array<any> = [];

  public paramsReport : any = {};
  public headerList: Array<any> = [];
  public columnsToDisplay = [];
  public headerSubListColor: string;

  public dataList: any = [];
  public tableDetail: any = [];
  
  public expandedElement: null;

  @ViewChild("paginator", { static: true }) paginator: MatPaginator;

  ngOnInit() {
    this.http.get("System", "GetHeaderGridView", "SNPP206_OVERDUE_NOTICE")
    .subscribe(res => {
      this.headerList = res.filter(x => x.VISIBILITY == true)
      this.columnsToDisplay = this.columnsToDisplay.map(v => v.FIELD_NAME);
      this.headerSubListColor = this.headerList.find(item => item.LINK_FN !== null).LINK_FN;
      this.ArrangeShowColumn(this.headerList);
    })
   }

   ngOnChanges(changes: SimpleChanges): void {
    if (!changes["tableData"].isFirstChange() && this.tableData) {
      if (this.tableData.length === 0) {
      
      }
    }
    this.dataList = new MatTableDataSource<any>(this.tableData || []);
    this.dataList.paginator = this.paginator;
    this.ArrangeShowColumn(this.headerList);
  }

   public ExpandTable(element){
    if(this.expandedElement === element){
      this.expandedElement = null
    }
    else{
      const params = {...this.params, ...element}
      this.http.post("IC", "SNPP206_GetOverDueNoticeByPO", params)
      .subscribe(res => {
        this.tableDetail = res.Table
        this.expandedElement = element

        this.paramsReport.VENDOR_CODE = element.VENDOR_CODE;
        this.paramsReport.PO_NO = element.PO_NO;
        this.paramsReport.ACCEPT_PART_NO = element.ACCEPT_PART_NO;
        this.paramsReport.FROM_DATE = moment(this.params.FROM_DATE_SEARCH._d).format("DD-MMM-YYYY");
        this.paramsReport.TO_DATE = moment(this.params.TO_DATE_SEARCH._d).format("DD-MMM-YYYY");
      })
    } 
   }

   ArrangeShowColumn(data) {
     this.columnsToDisplay = data.map(v => v.FIELD_NAME);
   }

   public OpenReport(){
    this.global.GoToReport("PMS_RPT_IC_SNPP206_OVERDUE_BY_PO",
    {
      P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      P_VENDOR_CODE: this.paramsReport.VENDOR_CODE,
      P_PO_NO: this.paramsReport.PO_NO,
      P_ACCEPT_PART_NO: this.paramsReport.ACCEPT_PART_NO,
      P_FROM_DATE: this.paramsReport.FROM_DATE,
      P_TO_DATE: this.paramsReport.TO_DATE,
    });
  }

}
