import { Component, OnInit, ViewContainerRef, ViewChild, ElementRef, Inject } from "@angular/core";
import * as moment from "moment";
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';
import { ActivatedRoute } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { SelectionModel } from "@angular/cdk/collections";
import * as XLSX from 'xlsx';
import { LoaderService } from "src/app/core/loader.service";

@Component({
  selector: 'snpp210',
  templateUrl: './snpp210.component.html',
  styleUrls: ['./snpp210.component.css']
})
export class SNPP210Component implements OnInit {

  constructor(
    @Inject(LoaderService) private loaderService: LoaderService,
    private http: HttpService,
    public modal: ModalService,
    public viewref: ViewContainerRef,
    private route: ActivatedRoute,
    private global: Globals
  ) {}
  public param : any = {}
  public LookupVendorConfig: any = {
    ColName: "LOOKUP_VENDOR_NAME",
    PlaceholderText: "Select Vendor Code",
    SourceController: "wPMS",
    SourceMethodName: "GetVendorCode",
    NoOfShowRecords: 50,
    UpperCase: true
  }

  public SelectVendor(event) {
    this.param.VENDOR_NAME = event.LOOKUP_VENDOR_NAME;
    this.param.VENDOR_CODE = event.VENDOR_CODE;
  }

  public SelectVendorHistory(event) {
    this.paramHistory.VENDOR_NAME = event.LOOKUP_VENDOR_NAME;
    this.paramHistory.VENDOR_CODE = event.VENDOR_CODE;
  }

  public lookupPartNoConfig: any = {
    ColName: "LOOKUP_PART_NO",
    PlaceholderText: "Select Part No.",
    SourceController: "IC",
    SourceMethodName: "SNPP210_GetPartNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.param,
    },
    UpperCase: true,
  };

  public SetSelectedPartNo(value: any) {
    if(value){
      this.param.PART_NO = value.PART_NO;
      this.param.PART_NAME = value.PART_NAME;
      //this.Search();
    } else {
      this.param.PART_NO = null;
      this.param.PART_NAME = null;
      //this.Search();
    }
  }
 
  public paramHistory : any = {}
  public paramHistoryDetail : any = {}
  public tableData: any = [];
  public tableDataHistory: any = [];
  public tableDataHistoryDetail: any = [];
  public selection = new SelectionModel<any>(true, []);
  @ViewChild("dialogHistoryDetail", { static: false }) dialogHistoryDetail: any;

  ngOnInit() {
    this.param.PIC = this.global.GetTokenDetail("ssUserName");
    this.paramHistory.PIC = this.global.GetTokenDetail("ssUserName");
    this.paramHistory.TYPE_DATE = 'LAST6MONTH'
    this.http.post('WH', 'GetDateByFormat', this.paramHistory)
      .subscribe(res => {
        this.paramHistory.START_DATE = res.Table[0].LAST6MONTH;
        this.paramHistory.END_DATE = moment();
      });
    this.Search();
   }

   public TabChange($event) {
     if ($event.index == 0) {
       //this.GetPartReLocationStatus();
     } else if ($event.index == 1) {
       //this.GetPartReLocation1();
     } 
   }

  public Search(){
    this.http.post("IC", "SNPP210_GetData", this.param)
    .subscribe(res => {
      this.selection.clear();
      this.tableData = res.Table;
    }, err => {
      console.log(err, 'err');
      this.modal.error("Found error please contact support team",this.viewref);
    })
  }

  public SearchHistory(){
    if(!this.paramHistory.START_DATE || !this.paramHistory.END_DATE){
      this.modal.warning("กรุณาใส่วันที่เพื่อกำหนดช่วงข้อมูล", this.viewref);
      return;
    }
    this.http.post("IC", "SNPP210_GetDataHistory", this.paramHistory)
    .subscribe(res => {
      this.tableDataHistory = res.Table;
    }, err => {
      console.log(err, 'err');
      this.modal.error("Found error please contact support team",this.viewref);
    })
  }
  
  public ViewDetailPOHistory(data: any) {
    this.http.post('IC', 'SNPP210_GetDetailHistory', data)
      .subscribe(res => {
        this.tableDataHistoryDetail = res.Table;
        this.dialogHistoryDetail.title = "PO Detail - " + data.PO_NO + " " + moment(data.PO_DATE).format("DD-MMM-YYYY");
        this.dialogHistoryDetail.OpenDialog();
      }, (err) => {
        console.log(err, 'err');
        this.modal.warning("Found an error, please contact support team", this.viewref);
      })
  }

  public ReportHistory() {
      this.global.GoToExport("PMS_RPT_IC_SNPP210_GET_HISTORY", {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_VENDOR_CODE: this.paramHistory.VENDOR_CODE,
        P_PIC: this.paramHistory.PIC,
        P_START_DATE: moment(this.paramHistory.START_DATE).format("DD-MMM-YYYY"),
        P_END_DATE: moment(this.paramHistory.END_DATE).format("DD-MMM-YYYY"),
      }, true, "EXCELOPENXML"
      );
  }

  public ReportHistoryDetail() {
      this.global.GoToExport("PMS_RPT_IC_SNPP210_GET_HISTORY_DETAIL", {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_VENDOR_CODE: this.paramHistory.VENDOR_CODE,
        P_PIC: this.paramHistory.PIC,
        P_START_DATE: moment(this.paramHistory.START_DATE).format("DD-MMM-YYYY"),
        P_END_DATE: moment(this.paramHistory.END_DATE).format("DD-MMM-YYYY"),
      }, true, "EXCELOPENXML"
      );
  }

  public ReportDialog() {
      this.global.GoToExport("PMS_RPT_IC_SNPP210_GET_DETAIL_HISTORY", {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_PO_NO: this.paramHistoryDetail.PO_NO,
        P_PO_DATE: moment(this.paramHistoryDetail.PO_DATE).format("DD-MMM-YYYY"),
      }, true, "EXCELOPENXML"
      );
  }

  public Save(){
    if(this.selection.isEmpty()){
      this.modal.warning("Please select some PO befire confirm",this.viewref)
      return
    }

    let find = this.selection.selected.some(x => x.ACCEPT_QTY < 1)
    if(find){
      this.modal.warning("Accept Qty must more than 0",this.viewref)
      return;
    }

    // let findRemark = this.selection.selected.some(x => x.ACCEPT_QTY != x.ORDER_QTY && !x.REMARKS)
    // if(findRemark){
    //   this.modal.warning("In case of edit accpet qty. Pleas input remarks",this.viewref)
    //   return;
    // }

    this.modal.confirm("Do you want to create new PO",this.viewref,() => ConfirmSave())

    let ConfirmSave = () =>{
      const params = {
        POList: this.selection.selected
      }
      this.http.post("IC", "SNPP210_CreatePO", params)
      .subscribe(res =>{
        if(res.STATUS == "DONE"){
          this.modal.info("Create new PO complete <br> PO No = " + res.FROM_PO + " - " + res.TO_PO,this.viewref);
          this.selection.clear()
          this.Search();
        }else{
          this.modal.error("Found error please contact support team",this.viewref);
        }
      }, err =>{
        console.log(err, 'err');
        this.modal.error("Found error please contact support team",this.viewref);
      })
    }
  }

  public isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.tableData.filter((x)=> x.LOCK_PO_FLAG != "Y").length;
    return numSelected === numRows;
  }

  public Toggle() {
    this.isAllSelected() ?
      this.selection.clear() :
      this.tableData.forEach(
        row => {
          if(row.LOCK_PO_FLAG != "Y"){
            this.selection.select(row)
          }
        }
      );
  }

  ////////////////////// UPLOAD //////////////////////
  @ViewChild("dialogUpload", { static: false }) dialogUpload: any;
  @ViewChild('fileUpload') fileUpload : ElementRef;
  public files: any = [];
  public FileName: string = ""

  
  public OpenDailogUpload(){
    if(this.tableData.length == 0){
      this.modal.warning("No data for upload",this.viewref)
      return
    }
    this.dialogUpload.OpenDialog()
  }


  public OnFileSelect() {
    this.FileName = ""
    this.files = []
    this.fileUpload.nativeElement.value = '';
    this.fileUpload.nativeElement.click();
  }

  public SelectFile(evt: any, img: string) {
    let files: Array<File> = evt.target.files;
    if (files.length > 0) {
      this.files.push(files[0]);
      this.FileName = this.files[0].name;
    }
  }

  public UploadFile(){
    if(this.files.length == 0){
      this.modal.warning("Please upload file",this.viewref)
      return
    }
    this.showLoader()
    const reader: FileReader = new FileReader();

    reader.readAsArrayBuffer(this.files[0]);
    reader.onload = (e: any) => {
      // upload file
      const binarystr = new Uint8Array(e.target.result);
      const wb: XLSX.WorkBook = XLSX.read(binarystr, { type: 'array', raw: true, cellFormula: false });
      const wsname = wb.SheetNames[0];
      let data = XLSX.utils.sheet_to_json(wb.Sheets[wsname]);
      console.log(data)

      this.tableData.map(x =>{
        let find : any = data.find((z : any) => z.PART_NO == x.ACCEPT_PART_NO)
        if(find){
          x.ACCEPT_QTY = find.SUGGEST_QTY
        }
      })

      this.tableData = this.tableData.slice()
      this.hideLoader()
      this.dialogUpload.Close()
      this.modal.info("Upload Complete",this.viewref)
    }
  }


  public Export(){

    let dataExport = []
    this.tableData.map(x => {
      dataExport.push(
        {
          PART_NO : x.ACCEPT_PART_NO,
          AVALIABLE_OH : x.AVALIABLE_OH,
          PO_QTY : x.PO_QTY,
          BO_QTY : x.ORDER_QTY,
          SUGGEST_QTY : x.ACCEPT_QTY,
          PO_PACKAGE : x.PO_PACKAGE

        }

      )
    })

    const workBook = XLSX.utils.book_new(); 
    const workSheet = XLSX.utils.json_to_sheet(dataExport);
    const fileName = "SuggestComponentPO" + moment().format("YYYYMMDDHHMMSS") + ".xlsx"
    XLSX.utils.book_append_sheet(workBook, workSheet, 'data'); 
    XLSX.writeFile(workBook, fileName); 
  }

  private showLoader(): void {
    this.loaderService.show();
  }

  private hideLoader(): void {
    this.loaderService.hide();
  }
}
