import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router, ActivatedRoute } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { ModalService } from '../../../core/modal.service';
import * as cloneDeep from 'lodash/cloneDeep';

@Component({
  selector: 'snse155',
  templateUrl: './snse155.component.html',
  styleUrls: ['./snse155.component.css']
})



export class SNSE155Component implements OnInit {


  constructor(
    private http: HttpService,
    private modal: ModalService,
    private router: Router,
    private route: ActivatedRoute,
    private global: Globals,
    private viewref: ViewContainerRef
  ) { 

  }

  public ConfigCatalogModel: any = {
    ColName: "CATALOG_MODEL_PFPM",
    PlaceholderText: "Select Catalog Model",
    SourceController: "IC",
    SourceMethodName: "SNSE155_getCatalogModel",
    NoOfShowRecords: 20,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public ConfigMainModelPMS: any = {
    ColName: "LOOKUP_MAIN_MODEL_PMS",
    PlaceholderText: "Select Main Model PMS",
    SourceController: "IC",
    SourceMethodName: "SNSE155_getMainModelPMS",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public tabledata: any = [];
  public PROCESS_LOG: any = [];
  public MainModelPMSDetail: any = {};


  @ViewChild("dialogEditMainModelPMS") dialogEditMainModelPMS: any

  public params : any = {}
  public isAdd : boolean = false;

  ngOnInit() {

  }

  public Search() {
    this.tabledata = [];
    this.http.post("IC", "SNSE155_getSearch", this.params)
      .subscribe(res => {
        this.tabledata = res.Table;
      })
  }

  public ExportExcel() {
    this.http.Download("IC", "SNSE155_Export_Excel", JSON.stringify(this.tabledata))
      .subscribe(res => {
        if (res) {
          this.WriteContents(res)
          this.PROCESS_LOG.push('Export complete ' + this.tabledata.length + ' records.');
        } else {
          this.modal.error('Export not complete', this.viewref)
        }
      })
  }

  public WriteContents(content) {
    const a = document.createElement('a');
    const file = new Blob([content], { type: content.type });
    var date_export = new Date();
    a.href = URL.createObjectURL(file);
    a.download = "SNSE155" + "_" + date_export.getFullYear() + "/" + (date_export.getMonth() + 1) + "/" + date_export.getDate() + ".csv";
    a.click();
  }


  public Add(){
    this.isAdd = true
    this.MainModelPMSDetail = {}
    this.dialogEditMainModelPMS.title = "Add Main Model (PMS)"
    this.dialogEditMainModelPMS.OpenDialog();
  }


  public editRow(row: any) {
    
    this.http.post("IC", "SNSE155_getSearch", row)
      .subscribe(res => {
        if(res.Table.length > 0){
          this.isAdd = false;
          this.MainModelPMSDetail = res.Table[0]
          this.dialogEditMainModelPMS.title = "Update Main Model (PMS)";
          this.dialogEditMainModelPMS.OpenDialog();
        }else{
          this.modal.warning("Main model mapping not found",this.viewref)
        }
 
      })
    
  }

  public Delete(row){
    this.modal.confirm("Do you want to delete record?", this.viewref,() => ConfirmDelete())

    let ConfirmDelete = () =>{
      this.http.post('IC', 'SNSE155_Delete', row)
      .subscribe(res => {
        if (res.STATUS_MSG === "DONE") {
          this.modal.info('Delete successfully', this.viewref)
          this.Search();
          this.dialogEditMainModelPMS.Close();
        }else{
          this.modal.error('Delete fail', this.viewref)
        }
      }, (err) => {
        this.modal.error('Delete fail', this.viewref)
      })
    }
  }

  public SaveMainModelMapping() {

    if(this.isAdd){

      this.modal.confirm("Do you want to save?", this.viewref,() => ConfirmSave())

      let ConfirmSave = () => {
        this.http.post('IC', 'SNSE155_Insert', this.MainModelPMSDetail)
        .subscribe(res => {
          if (res.STATUS_MSG === "DONE") {
            this.modal.info('Save successfully', this.viewref)
            this.Search();
            this.dialogEditMainModelPMS.Close();
          }
          else if(res.STATUS_MSG == 'DUPLICATE'){
            this.modal.info('No change to save found duplicate record', this.viewref)
          }
          else{
            this.modal.error('Save Not Complete',this.viewref)
          }
        }, (err) => {
          this.modal.error('Save Not Complete',this.viewref)
        })
      }

    }
    else{

      this.modal.confirm("Do you want to save your change?", this.viewref,() => ConfirmUpdate())

      let ConfirmUpdate = () => {
        this.http.post('IC', 'SNSE155_Update', this.MainModelPMSDetail)
          .subscribe(res => {
            if (res.STATUS_MSG === "DONE") {
              this.modal.info('Update successfully', this.viewref)
              this.Search();
              this.dialogEditMainModelPMS.Close();
            }else{
              this.modal.error('Update fail', this.viewref)
            }
          }, (err) => {
            this.modal.error('Update fail', this.viewref)
          })
      }
    }
  }





  public SetCatalogModel(values: any) {
    this.params.CATALOG_MODEL_PFPM = values.CATALOG_MODEL_PFPM;
  }


  public SetMainModelPMS(event,data,action){
  
    if(action == "select"){
      if(event){
        this.MainModelPMSDetail.MAIN_MODEL_PMS = event.MAIN_MODEL_PMS
        this.MainModelPMSDetail.MAIN_MODEL_NAME = event.MAIN_MODEL_NAME
      }else{
        this.modal.warning("Main Model not found in data base",this.viewref)
        this.MainModelPMSDetail.MAIN_MODEL_PMS = null
        this.MainModelPMSDetail.MAIN_MODEL_NAME = null
      }
    }
    else if(action == "cancel"){
     
        if (!data){
          //this.modal.warning("Main Model is not null",this.viewRef)
          this.MainModelPMSDetail.MAIN_MODEL_PMS = null;
          this.MainModelPMSDetail.MAIN_MODEL_NAME = null
          return;
        }

      this.http.get("IC","SNSE155_getMainModelPMS",this.global.EscapeCharacter(data),'20')
      .subscribe(res =>{
        if(res.Table.length > 0){
          this.MainModelPMSDetail.MAIN_MODEL_PMS = res.Table[0].MAIN_MODEL_PMS
          this.MainModelPMSDetail.MAIN_MODEL_NAME = res.Table[0].MAIN_MODEL_NAME
        }else{
          //this.modal.warning("Tariff Code not found in data base",this.viewRef)
          this.MainModelPMSDetail.MAIN_MODEL_PMS = null;
          this.MainModelPMSDetail.MAIN_MODEL_NAME = null
        }
      })

    }
  }

}
