import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from '../../../core/modal.service';
import { Globals } from 'src/app/core/global';

@Component({
  selector: 'snse162',
  templateUrl: './snse162.component.html',
  styleUrls: ['./snse162.component.css']
})



export class SNSE162Component implements OnInit {


  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private global: Globals,
  ) { }
  @ViewChild("dialog", { static: false }) dialog: any;
  public tabledata: any = [];
  public process_log: any = [];
  public data: any = {};
  public isAdd: boolean = false;

  public params : any  = {}

  ngOnInit() {

  }

  public ConfigSourcingCode: any = {
    ColName: "LOOK_UP_SOURCING_CODE",
    PlaceholderText: "Select Sourcing Code",
    SourceController: "IC",
    SourceMethodName: "SNSE162_getSourcingCode",
    NoOfShowRecords: 20,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public ConfigVendorCode: any = {
    ColName: "LOOK_UP_VENDOR_NAME",
    PlaceholderText: "Select Vendor Code",
    SourceController: "IC",
    SourceMethodName: "SNSE162_getVendorCode",
    NoOfShowRecords: 20,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public ConfigOriginCode: any = {
    ColName: "LOOK_UP_ORIGIN_CODE",
    PlaceholderText: "Select Origin Code",
    SourceController: "IC",
    SourceMethodName: "SNSE162_getOriginCode",
    NoOfShowRecords: 20,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public Search() {
    this.tabledata = [];
    this.http.post("IC", "SNSE162_getSearch", this.params)
      .subscribe(res => {
        this.tabledata = res.Table;
      })
  }


  public ExportExcel() {
    this.http.Download("TI", "SNSE162_Download", this.tabledata)
      .subscribe(res => {
        if (res) {
          this.WriteContents(res)
          this.process_log.push('Export complete ' + this.tabledata.length + ' records.');
        } else {
          this.modal.error('Download not complete', this.viewref)
        }
      }, err => {
          this.modal.error('Download not complete', this.viewref)
      })
  }

  public WriteContents(content) {
    const a = document.createElement('a');
    const file = new Blob([content], { type: content.type });
    a.href = URL.createObjectURL(file);
    a.download = "SNSE162" + '_' + this.global.CurrentDate() + '' + ".xlsx";
    a.click();
  }



  public SetSourcingCode(values: any) {
    this.params.SOURCING_CODE = values.SOURCING_CODE;
  }
  // public SetVendorCode(values) {
  //   this.params.VENDOR_CODE = values.VENDOR_CODE;
  // }

  public SetVendorCode(event,data,action){

    if(action == "select"){
      
      if(event){
        this.data.VENDOR_CODE = event.VENDOR_CODE;
        
      }else{
        this.modal.warning("Vendor Code not found in data base",this.viewref)
        this.data.VENDOR_CODE = null;
        
      }
    }
    else if(action == "cancel"){
        if (!data){
          //this.modal.warning("Main Model is not null",this.viewRef)
          this.data.VENDOR_CODE = null;
         
          return;
        }
      this.http.get("IC","SNSE162_getVendorCode",this.global.EscapeCharacter(data),'20')
      .subscribe(res =>{
        if(res.Table.length > 0){
          this.data.VENDOR_CODE = res.Table[0].VENDOR_CODE;
         
          
        }else{
          //this.modal.warning("Vendor Code not found in data base",this.viewRef)
          this.data.VENDOR_CODE = null;
         
        }
      })
    }
  }



  public SetOriginCode(event,data,action) {
    if(action == "select"){
      
      if(event){
        this.data.ORIGIN_CODE = event.ORIGIN_CODE
      }else{
        this.modal.warning("Origin Code not found in data base",this.viewref)
        this.data.ORIGIN_CODE = null
      }
    }
    else if(action == "cancel"){
        if (!data){
          //this.modal.warning("Main Model is not null",this.viewRef)
          this.data.ORIGIN_CODE = null;
          return;
        }
      this.http.get("IC","SNSE162_getOriginCode",this.global.EscapeCharacter(data),'20')
      .subscribe(res =>{
        if(res.Table.length > 0){
          this.data.ORIGIN_CODE = res.Table[0].ORIGIN_CODE         
        }else{
          //this.modal.warning("Origin Code not found in data base",this.viewRef)
          this.data.ORIGIN_CODE = null;        
        }
      })
    }
  }
  // public SetOriginCode(values) {
  //   this.params.ORIGIN_CODE = values.ORIGIN_CODE;
  // }



  public EditRow(data) {
    

    this.http.post("IC", "SNSE162_getSearch", data)
      .subscribe(res => {
        if(res.Table.length > 0){
          this.isAdd = false;
          this.data = res.Table[0];
          this.dialog.title = "Edit Sourcing Code"
          this.dialog.OpenDialog();
        }else{
          this.modal.warning("Sourcing code not found",this.viewref)
        }
        
      })
    
  }

  public AddRow() {
    this.data = {}
    this.isAdd = true
    this.dialog.title = "Add Sourcing Code"
    this.dialog.OpenDialog();
  }

  public Cancel() {
    this.dialog.Close();
  }

  public Save() {
    this.modal.confirm("Do you want to save change you have made?", this.viewref, this.ConfirmSave)
  }

  public ConfirmSave = () => {

    if (this.isAdd) {
      this.http.post("TI", "SNSE162_Insert", this.data)
        .subscribe(res => {
          if (res.Table[0].STATUS == 'Done') {
            this.modal.info('Transaction complete: applied and saved.', this.viewref);
            if (this.tabledata.length > 0) {
              this.Search();
            }
            this.dialog.Close();
          } else if (res.Table[0].STATUS == 'Duplicate') {
            this.modal.info('No change to save. Found duplicate record.', this.viewref);
          }
          else {
            this.modal.warning('No change to save. Add fail.', this.viewref);
          }
        })
    } else {
      this.http.post("TI", "SNSE162_Update", this.data)
        .subscribe(res => {
          if (res.Table[0].STATUS == 'Done') {
            this.modal.info('Transaction complete: applied and saved.', this.viewref);
            this.Search();
            this.dialog.Close();

          } else {
            this.modal.warning('No change to save. Update fail.', this.viewref);
          }
        })
    }

  }

  public Delete(data) {
    this.modal.confirm("Do you want to delete racord?", this.viewref, () => {
      this.http.get("TI", "SNSE162_Delete", data.SOURCING_CODE)
        .subscribe(res => {
          if (res.Table[0].STATUS == 'Done') {
            this.modal.info('Transaction complete: 1 record applied and deleted.', this.viewref);
            this.Search();
            this.dialog.Close();

          } else {
            this.modal.warning('Delete fail.', this.viewref);
          }
        })
    })
  }

}
