import { Component, OnInit, ViewContainerRef, ViewChild, ElementRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from 'src/app/core/global';
import { DialogTemplateComponent } from 'src/app/components/shared/dialog-template/dialog-template.component';
import { FormGroup, FormControl, Validators } from '@angular/forms';

@Component({
    selector: 'SNM118P',
    templateUrl: 'SNM118P.component.html',
    styleUrls: ['SNM118P.component.css', '../k9.component.css']
})

export class SNM118PComponent implements OnInit {
    constructor(
        private http: HttpService,
        private modal: ModalService,
        private viewref: ViewContainerRef,
        private global: Globals
    ) { }

    public endItem: string;
    public modelList: Array<any>;
    public mode: string;
    public FileName: string = ""
    public File : any ;
    public tableDataUpload: any = [];
    @ViewChild("fileUpload") fileUpload: ElementRef;
    @ViewChild("dialog") dialog: DialogTemplateComponent;
    @ViewChild("dialogUpload") dialogUpload: DialogTemplateComponent;

    public modelForm: FormGroup = new FormGroup({
        END_ITEM_18: new FormControl('', Validators.required),
        MAIN_MODEL: new FormControl('', Validators.required),
        END_ITEM_DESC: new FormControl('', Validators.required),
        LAST_UPD_BY: new FormControl(null),
        LAST_UPD_DATE: new FormControl(null),
    })

    public EndItemLookupConfig: any = {
        ColName: "LOOKUP_END_ITEM",
        PlaceholderText: "Select Model",
        SourceController: "wPMS",
        SourceMethodName: "GetEndItem",
        NoOfShowRecords: 50,
        UpperCase: true
    }

    ngOnInit() {
        this.GetModel();
    }

    GetModel() {
        this.modelList = [];
        this.http.get("K9", "SNM118P_GetModel", this.endItem)
            .subscribe(result => {
                this.modelList = result.Table;
            })
    }

    AddModel() {
        this.mode = "Add";
        this.modelForm.reset();
        this.modelForm.get("END_ITEM_18").enable();

        this.dialog.title = "Add Model";
        this.dialog.OpenDialog();
    }

    EditModel(row) {
        this.mode = "Edit";
        this.modelForm.reset();
        this.modelForm.get("END_ITEM_18").disable();
        this.modelForm.get("END_ITEM_18").setValue(row.END_ITEM_18);
        this.modelForm.get("MAIN_MODEL").setValue(row.MAIN_MODEL);
        this.modelForm.get("END_ITEM_DESC").setValue(row.END_ITEM_DESC);
        this.modelForm.get("LAST_UPD_BY").setValue(row.LAST_UPD_BY);
        this.modelForm.get("LAST_UPD_DATE").setValue(row.LAST_UPD_DATE);

        this.dialog.title = "Edit Model";
        this.dialog.OpenDialog();
    }

    AddEndItem() {
        this.modal.confirm("Are you sure to add to Vehicle Model master?", this.viewref, () => {
            let data = this.modelForm.getRawValue();
            this.http.post("K9", "SNM118P_SaveModel", data)
                .subscribe(result => {
                    this.modal.info("Add End Item complete.", this.viewref);
                    this.GetModel();
                    this.dialog.Close();
                }, (err) => {
                    this.modal.error(err.error, this.viewref);
                })
        }, () => { })
    }

    SaveEndItem() {
        this.modal.confirm("Are you sure to save this change?", this.viewref, () => {
            let data = this.modelForm.getRawValue();
            this.http.post("K9", "SNM118P_SaveModel".concat("/", data.END_ITEM_18), data)
                .subscribe(result => {
                    this.modal.info("Save End Item complete.", this.viewref);
                    this.GetModel();
                    this.dialog.Close();
                }, (err) => {
                    this.modal.error(err.error, this.viewref);
                })
        }, () => { })
    }

    DeleteEndItem(row) {
        this.modal.confirm("Are you sure to delete this record?", this.viewref, () => {
            this.http.post("K9", "SNM118P_DeleteModel".concat("/", row.END_ITEM_18), {})
                .subscribe(result => {
                    this.modal.info("Delete from Vehicle Model master complete.", this.viewref);
                    this.GetModel();
                    this.dialog.Close();
                }, (err) => {
                    this.modal.error(err.error, this.viewref);
                })
        }, () => { })
    }

    SetEndItem(value) {
        this.endItem = value.END_ITEM_18;
    }

    SetMainModel(endItem) {
        if(endItem.length > 10) {
            this.modelForm.get("MAIN_MODEL").setValue(endItem.substr(7,3));
        }
    }


    public AddModelByUpload(){
        this.tableDataUpload = [];
        this.FileName = "";
        this.dialogUpload.OpenDialog()
    }


    public DownLoadTemplate(){
        let link = 'assets/templates/SNM118P_Template.xlsx'
        window.open(link,'_blank')
     
    }
  
  
    public OpenFileBrowser() {
      this.FileName = "";
      this.fileUpload.nativeElement.value = '';
      this.fileUpload.nativeElement.click();
    }
  
    public SelectFile(evt) {
      let Files: Array<File> = evt.target.files;
  
      if (Files.length > 0) {
          //let File: File = Files[0];
          this.File = Files[0];
          this.FileName = this.File.name;
      }
    }

    public PreView(){

        if(!this.FileName){
            this.modal.warning("Please Select File First...",this.viewref)
            return;
        }
        
        let formData = new FormData();
        formData.append('file', this.File);
    
         this.http.postFile("K9", "SNM118P_UploadFile", formData)
          .subscribe(result => {
            this.tableDataUpload = result.filter(x => x.END_ITEM_18);
        }, err => {
            this.modal.error("Found eror, please contact support team.", this.viewref);
        })
      }

      public SaveUpload(){
        let find = this.tableDataUpload.some(x => x.STATUS == 'ERROR');

        if(find){
            this.modal.warning("No change to save found data error",this.viewref);
            return;
        }

        this.modal.confirm("Do you want to save",this.viewref,() => confirmSave());

        let confirmSave = () =>{
            this.http.post("K9","SNM118P_SaveUpload",this.tableDataUpload)
            .subscribe(res =>{
                //console.log('resss',res)
                if(res.STATUS_MSG == 'DONE'){
                    this.modal.info("Save complete",this.viewref)
                }else{
                    this.modal.error("Found eror, please contact support team.", this.viewref);
                }
            },err =>{
                this.modal.error("Found eror, please contact support team.", this.viewref);
            })
        }


      }

}