import { Component, ElementRef, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { FormGroup, FormControl, Validators } from '@angular/forms';
import { DialogTemplateComponent } from 'src/app/components/shared/dialog-template/dialog-template.component';
import { CdkDragDrop, moveItemInArray, transferArrayItem } from '@angular/cdk/drag-drop';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from 'src/app/core/global';

class BOMMaterial {
  MATERIAL_PART_NO: string | Array<BOMMaterial>;
  MATERIAL_QTY: number = 0;
  MATERIAL_TYPE: string;
  COLOR_CODE: string;
  _MATERIAL_PART_NAME: string;
  _IS_EDITABLE: boolean = false;
}

@Component({
  selector: 'SNM119P',
  templateUrl: 'SNM119P.component.html',
  styleUrls: ['SNM119P.component.css', '../k9.component.css']
})

export class SNM119PComponent implements OnInit {
  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private global: Globals) { }



  public BOMLookupConfig: any = {
    ColName: "LOOKUP_PART_NAME",
    PlaceholderText: "Select Assembly Parts No",
    SourceController: "wPMS",
    SourceMethodName: "GetBOMAssemblyPartNo",
    NoOfShowRecords: 50,
    UpperCase: true
  }

  public ConfigInstallPart: any = {
    ColName: "LOOKUP",
    PlaceholderText: "Select Install Part No.",
    SourceController: "K9",
    SourceMethodName: "SNM119P_GetInstallPart",
    NoOfShowRecords: 30
  }

  public ConfigMaterialPart: any = {
    ColName: "LOOKUP",
    PlaceholderText: "Select Material Part No.",
    SourceController: "K9",
    SourceMethodName: "SNM119P_GetMaterialPart",
    NoOfShowRecords: 30
  }

  public ConfigSpps: any = {
    ColName: "SPPS_CODE",
    ColValue: "",
    PlaceholderText: "Select Spps Code",
    SourceController: "K9",
    SourceMethodName: "SNM119P_GetSppsCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: false
  }

  public partno: string;
  public BOMList: Array<any>;
  public mode: string;
  public materialList: Array<BOMMaterial>;

  @ViewChild("dialogBOM") dialogBOM: DialogTemplateComponent;
  @ViewChild("dialogDetail") dialogDetail: DialogTemplateComponent;
  @ViewChild("dialogUpload") dialogUpload: DialogTemplateComponent;

  public FileName: string = "";

  @ViewChild("fileInput") fileInput: ElementRef;

  public tableDataDetail: any = [];
  public tableDataUpload: any = [];
  public tempData: any = [];
  public isAdd: boolean = false;
  public paramData: any = {}
  public BOMForm: FormGroup = new FormGroup({
    ASSEMBLY_TYPE: new FormControl('', Validators.required),
    ASSEMBLY_PART_NO: new FormControl('', Validators.required),
    ASSEMBLY_PART_NAME: new FormControl('', Validators.required),
    MATERIAL_PART_NO: new FormControl([]),
    LAST_UPD_BY: new FormControl(null),
    LAST_UPD_DATE: new FormControl(null),
  });

  private File: any;
  ngOnInit() {
    //this.GetBOM();
  }

  GetBOM() {
    this.BOMList = [];
    this.http.get("K9", "SNM119P_Search", this.partno)
      .subscribe(result => {
        this.BOMList = result.Table;
      })
  }

  AddMaterialList(val) {
    if (!this.materialList.find(v => v.MATERIAL_PART_NO === val.PART_NO)) {
      let material: BOMMaterial = {
        MATERIAL_PART_NO: val.PART_NO,
        MATERIAL_QTY: 0,
        MATERIAL_TYPE: 'COM',
        COLOR_CODE: null,
        _MATERIAL_PART_NAME: val.PART_NAME,
        _IS_EDITABLE: false
      }
      this.materialList.push(material)
    } else {
      this.modal.error("Unable to add existing Material Parts No.", this.viewref);
    }
  }

  Add() {
    // this.mode = "Add";
    // this.BOMForm.reset();
    // this.BOMForm.get("ASSEMBLY_PART_NO").enable();
    // this.materialList = [];
    // this.dialogBOM.title = "Add BOM";
    // this.dialogBOM.OpenDialog();
    this.isAdd = true
    this.tableDataDetail = []
    this.dialogDetail.title = "Add BOM";
    this.tableDataDetail.push({
      'ACTION': 'ADD',
      'MATERIAL_PART_NO': null,
    });
    this.dialogDetail.OpenDialog()


  }

  Edit(row) {
    this.isAdd = false;
    this.materialList = [];

    this.paramData = row

    this.http.get("K9", "SNM119P_GetDetail", row.INSTALL_PART_NO)
      .subscribe(result => {
        this.tableDataDetail = result.Table;
        //console.log('tableDataDetail',this.tableDataDetail)
        this.tableDataDetail.push({
          'ACTION': 'ADD',
          'MATERIAL_PART_NO': null
        });
        this.dialogDetail.title = "Edit BOM";
        this.dialogDetail.OpenDialog();
      })
  }

  AddBOM() {
    this.BOMForm.get("MATERIAL_PART_NO").setValue(this.materialList || []);

    this.modal.confirm("Are you sure to add to BOM master?", this.viewref, () => {
      let data = this.BOMForm.getRawValue();
      this.http.post("K9", "SNM119P_Add", data)
        .subscribe(result => {
          this.modal.info("Add BOM complete.", this.viewref);
          this.GetBOM();
          this.dialogBOM.Close();
        }, (err) => {
          this.modal.error(err.error, this.viewref);
        })
    }, () => { })

  }

  SaveBOM() {



    if (this.isAdd) {


      let find = this.tableDataDetail.some(x => x.MATERIAL_PART_NO && (!x.MATERIAL_QTY || !x.EXT_COLOR || !x.INT_COLOR))

      if (find) {
        this.modal.warning("This data not complete please recheck", this.viewref);
        return
      }


      this.paramData.Detail = this.tableDataDetail.filter(x => x.MATERIAL_PART_NO && x.MATERIAL_QTY)

      if (this.paramData.Detail.length == 0) {
        this.modal.warning("Please input material part", this.viewref);
        return;
      }

      this.modal.confirm("Are you sure to add BOM master", this.viewref, () => ConfirmSave())

      let ConfirmSave = () => {
        this.http.post("K9", "SNM119P_Add", this.paramData)
          .subscribe(res => {
            if (res.STATUS_MSG == 'DONE') {
              this.modal.info("Add BOM master complete", this.viewref)
            } else if (res.STATUS_MSG == 'DUPLICATE') {
              this.modal.warning("Can not add BOM master found duplicate record", this.viewref)
            } else {
              this.modal.error('No change to save. fail.', this.viewref);
            }
          }, err => {
            this.modal.error('No change to save. fail.', this.viewref);
          })
      }
    }
    else {


      this.tableDataDetail.map(x => {
        if (x.FLAG == 'U') {
          this.tempData.push(x)
        }
      })

      let find = this.tempData.some(x => x.MATERIAL_PART_NO && (!x.MATERIAL_QTY || !x.EXT_COLOR || !x.INT_COLOR))

      if (find) {
        this.modal.warning("This data not complete please recheck", this.viewref);
        return
      }

      this.paramData.Detail = this.tempData

      if (this.paramData.Detail.length == 0) {
        this.modal.warning("Please input material part", this.viewref);
        return;
      }


      this.modal.confirm("Are you sure to update BOM master", this.viewref, () => ConfirmSave())

      let ConfirmSave = () => {
        this.http.post("K9", "SNM119P_Update", this.paramData)
          .subscribe(res => {
            if (res.STATUS_MSG == 'DONE') {
              this.modal.info("Update BOM master complete", this.viewref)
              this.dialogDetail.Close()
              this.GetBOM()
            } else {
              this.modal.error('No change to save. fail.', this.viewref);
            }
          }, err => {
            this.modal.error('No change to save. fail.', this.viewref);
          })
      }

    }





  }

  DeleteBOM(data) {

    this.modal.confirm("Are you sure to delete from BOM master?", this.viewref, () => ConfirmDelete())


    let ConfirmDelete = () => {
      this.http.get("K9", "SNM119P_Delete", data.INSTALL_PART_NO)
        .subscribe(res => {
          if (res.STATUS_MSG == 'DONE') {
            this.modal.info("Delete BOM complete.", this.viewref);
            this.GetBOM();
          } else {
            this.modal.warning("Delete BOM fail.", this.viewref);
          }
        }, err => {
          this.modal.warning("Delete BOM fail.", this.viewref);
        })
    }
  }

  RemoveDetail(item, index) {
    this.modal.confirm("Are you sure to remove " + item.MATERIAL_PART_NO + " form the list?", this.viewref,
      () => {
        this.materialList.splice(index, 1);
      }, () => { })
  }

  SetPartNumber(val) {
    this.partno = val.PART_NO;
  }

  DetailDrop(event: CdkDragDrop<any>) {
    if (event.previousContainer === event.container) {
      moveItemInArray(event.container.data, event.previousIndex, event.currentIndex);
    } else {
      transferArrayItem(event.previousContainer.data,
        event.container.data,
        event.previousIndex,
        event.currentIndex);
    }
  }

  public GetAssemblyPart(part) {
    this.http.get("K9", "SNM119P_GetAssemblyPart", part)
      .subscribe(res => {
        console.log('resssssssss', res)
        if (res.Table.length > 0) {
          this.paramData.ASSEMBLY_PART_NO = res.Table[0].PART_NO
          this.paramData.ASSEMBLY_PART_NAME = res.Table[0].PART_NAME_EN
        } else {
          this.paramData.ASSEMBLY_PART_NO = this.paramData.INSTALL_PART_NO.replace(this.paramData.INSTALL_PART_NO.substring(1, 2), "8")
          this.paramData.ASSEMBLY_PART_NAME = null
        }
      })
  }

  public SelectInstallPart(event) {

    if (event) {

      this.paramData.INSTALL_PART_NO = event.PART_NO
      this.paramData.INSTALL_PART_NAME = event.PART_NAME_EN
      let AssemblyPart = event.PART_NO.replace(event.PART_NO.substring(1, 2), "8")
      this.GetAssemblyPart(AssemblyPart);

    } else {
      this.paramData.INSTALL_PART_NO = null
      this.paramData.INSTALL_PART_NAME = null
    }

  }

  public CancelInstallPart(event) {

    if (this.paramData.INSTALL_PART_NO) {
      this.http.get("K9", "SNM119P_GetInstallPart", this.paramData.INSTALL_PART_NO, "20")
        .subscribe(res => {
          if (res.Table.lenght > 0) {
            this.paramData.INSTALL_PART_NO = res.Table[0].PART_NO
            this.paramData.INSTALL_PART_NAME = res.Table[0].PART_NAME_EN

            let AssemblyPart = this.paramData.INSTALL_PART_NO.replace(this.paramData.INSTALL_PART_NO.substring(1, 2), "8")
            this.GetAssemblyPart(AssemblyPart);
          } else {
            this.modal.warning("Part no not found in data base", this.viewref)
            this.paramData.INSTALL_PART_NO = null
            this.paramData.INSTALL_PART_NAME = null
          }
        })
    }
  }


  public SelectMaterialPart(event, data, index) {

    if (event) {

      if (event.PART_NO == this.paramData.INSTALL_PART_NO) {
        this.modal.warning("Material part can not be like Install part", this.viewref);
        data.MATERIAL_PART_NO = null
        data.MATERIAL_PART_NAME = null
        data.MATERIAL_QTY = null
        data.EXT_COLOR = null
        data.INT_COLOR = null
        return
      }

      let duppart = this.tableDataDetail.filter((x, i) => x.MATERIAL_PART_NO == event.PART_NO && i != index);
      if (duppart.length > 0) {
        this.modal.warning("Part No" + ' - ' + event.PART_NO + ' is dupplicate', this.viewref)
        data.MATERIAL_PART_NO = null
        data.MATERIAL_PART_NAME = null
        data.MATERIAL_QTY = null
        data.EXT_COLOR = null
        data.INT_COLOR = null
        return

      }

      data.MATERIAL_PART_NO = event.PART_NO
      data.MATERIAL_PART_NAME = event.PART_NAME_EN

      if (!this.isAdd) {

        let ind = this.tempData.findIndex(x => x.MATERIAL_PART_NO == data.MATERIAL_PART_NO && data.FLAG == 'D')
        if (ind > -1) {
          this.tempData.splice(ind, 1);
        }

        data.FLAG = 'A'
        this.tempData.push(data)
      }
    } else {
      data.MATERIAL_PART_NO = null
      data.MATERIAL_PART_NAME = null
      data.MATERIAL_QTY = null
      data.EXT_COLOR = null
      data.INT_COLOR = null
    }

  }

  public CancelMaterialPart(event, data, index) {

    if (data.MATERIAL_PART_NO) {
      this.http.get("TI", "SNM119P_GetMaterialPart", data.MATERIAL_PART_NO, "20")
        .subscribe(res => {
          if (res.Table.lenght > 0) {
            data.MATERIAL_PART_NO = res.Table[0].PART_NO
            data.MATERIAL_PART_NAME = res.Table[0].PART_NAME_EN

          } else {
            //this.modal.warning("Part no not found in data base",this.viewref)
            data.MATERIAL_PART_NO = null
            data.MATERIAL_PART_NAME = null
            data.MATERIAL_QTY = null
            data.EXT_COLOR = null
            data.INT_COLOR = null
          }
        })
    }
  }

  public SelectSPPS(event) {
    if (event) {
      this.paramData.SPPS_CODE = event.SPPS_CODE;
      this.paramData.FILE_NAME = event.FILE_NAME
    } else {
      this.paramData.SPPS_CODE = null;
      this.paramData.FILE_NAME = null
    }

  }

  public CancelSPPS(event) {

    if (this.paramData.SPPS_CODE) {

      this.http.get("TI", "SNM119P_Spps_Code", this.paramData.SPPS_CODE, '20')
        .subscribe(res => {
          if (res.Table.length > 0) {
            this.paramData.SPPS_CODE = res.Table[0].SPPS_CODE
            this.paramData.FILE_NAME = res.Table[0].FILE_NAME
          } else {
            this.paramData.SPPS_CODE = null;
            this.paramData.FILE_NAME = null
          }
        })
    } else {
      this.paramData.SPPS_CODE = null;
      this.paramData.FILE_NAME = null
    }
  }

  public CheckQty(event, data) {
    if (event.target.valueAsNumber < 1) {
      this.modal.warning("Quantity must not be less than 1", this.viewref)
      data.ITEM_QTY = 1;
    }
    //console.log(event.target.valueAsNumber)
  }


  public AppendRow() {

    let find = this.tableDataDetail.some(x => !x.MATERIAL_PART_NO || !x.MATERIAL_QTY || !x.EXT_COLOR || !x.INT_COLOR)

    if (find) {
      this.modal.warning("this row data not complete please recheck before new row", this.viewref)
      return
    }

    for (var i = 0; i < this.tableDataDetail.length; i++) {
      if (this.tableDataDetail[i].ACTION === "ADD") {
        this.tableDataDetail[i].ACTION = 'DEL';
      }
    }
    this.tableDataDetail.push({
      'ACTION': 'ADD',
      'MATERIAL_PART_NO': null,
    });

    this.tableDataDetail = this.tableDataDetail.slice();


  }
  public DeleteRow(index, data) {

    if (!this.isAdd) {
      let ind = this.tempData.findIndex(x => x.PART_KIT_NO == data.PART_KIT_NO && data.FLAG == 'A')
      if (ind > -1) {
        this.tempData.splice(ind, 1);
      }
      data.FLAG = 'D'
      this.tempData.push(data)
    }

    //let index = this.tableDataDetail.findIndex(x => x == Item)
    this.tableDataDetail.splice(index, 1);
    this.tableDataDetail = this.tableDataDetail.slice();

  }


  public AddByUpload() {
    this.tableDataUpload = [];
    this.dialogUpload.title = "Upload BOM"
    this.dialogUpload.OpenDialog();
  }

  public DownloadTemplate() {

    let link = 'assets/templates/SNM119P_Upload_Template.xlsx'


    window.open(link, '_blank')
  }


  public OpenFileBrowser() {
    this.FileName = "";
    this.fileInput.nativeElement.value = '';
    this.fileInput.nativeElement.click();
  }

  public SelectFile(evt) {
    let Files: Array<File> = evt.target.files;

    if (Files.length > 0) {
      //let File: File = Files[0];
      this.File = Files[0];
      this.FileName = this.File.name;
    }
  }

  public PreView() {


    if (!this.FileName) {
      this.modal.warning("Please Open File First...", this.viewref)
      return;
    }


    let formData = new FormData();
    formData.append('file', this.File);
    this.tableDataUpload = []
    this.http.postFile("K9", "SNM119P_Upload", formData)
      .subscribe(result => {

        this.modal.info("Upload complete", this.viewref);

        this.tableDataUpload = result.filter(x => x.INSTALL_PART_NO)

        this.tableDataUpload.map((data, index) => {

          let find = this.tableDataUpload.some((x, i) => x.INSTALL_PART_NO == data.INSTALL_PART_NO && x.MATERIAL_PART_NO == data.MATERIAL_PART_NO && i != index)
          if (find) {
            if (data.ERROR_MSG) {
              data.ERROR_MSG = data.ERROR_MSG + ' , ' + data.MATERIAL_PART_NO + ' duplicate in file'
            } else {
              data.ERROR_MSG = data.MATERIAL_PART_NO + ' duplicate in file'
            }
          }

        })

      }, err => {
        this.modal.error("Upload not complete", this.viewref);
      })

  }


  public AddBOMByUpload() {

    if (this.tableDataUpload.some(x => x.ERROR_MSG)) {
      this.modal.warning("This data have error,please recheck data", this.viewref)
      return
    }

    this.modal.confirm("Do you want to save", this.viewref, () => confirmSave())

    let confirmSave = () => {
      this.http.post("K9", "SNM119P_SaveUpload", this.tableDataUpload)
        .subscribe(res => {
          if (res.STATUS_MSG == 'DONE') {
            this.modal.info('Transaction complete: applied and saved.', this.viewref);
            this.GetBOM();
            this.dialogUpload.Close();

          } else {
            this.modal.error('No change to save. fail.', this.viewref);
          }
        }, err => {
          this.modal.error('No change to save. fail.', this.viewref);
        })
    }
  }
}