import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { FormGroup, FormControl, Validators } from '@angular/forms';
import { DialogTemplateComponent } from 'src/app/components/shared/dialog-template/dialog-template.component';
import { CdkDragDrop, moveItemInArray, transferArrayItem } from '@angular/cdk/drag-drop';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from 'src/app/core/global';

class InstallParts {
    BOM_KEY: string;
    INSTALL_PART_NO: string;
    INSTALL_QTY: number = 0;
    TAKE_FROM: string; // NMT/PDI
    ISSUE_DOC_TYPE: string;
    CUSTOMER_TYPE: string; // FIX/DLR
    FIX_CUSTOMER_CODE: string;
    FIX_BRANCH_CODE: string;
    _PART_NAME: string;
    _BRANCH_CONF: any;
}

@Component({
    selector: 'SNM120P',
    templateUrl: 'SNM120P.component.html',
    styleUrls: ['SNM120P.component.css', '../k9.component.css']
})

export class SNM120PComponent implements OnInit {
    constructor(
        private http: HttpService,
        private modal: ModalService,
        private viewref: ViewContainerRef,
        private global: Globals) { }

    public endItem: string;
    public modelDescription: string;
    public HeaderList: Array<any>;
    public mode: string;
    public editHeader: boolean = true;
    public partList: Array<InstallParts>;

    @ViewChild("dialog") dialog: DialogTemplateComponent;

    public InstallForm: FormGroup = new FormGroup({
        BOM_KEY: new FormControl(''),
        END_ITEM_18: new FormControl('', Validators.required),
        EXT_COLOR: new FormControl(''),
        INT_COLOR: new FormControl(''),
        PDI_LOCATION_CODE: new FormControl(''),
        DESTINATION_CODE: new FormControl(''),
        INSTALL_PARTS: new FormControl([]),
        LAST_UPD_BY: new FormControl(null),
        LAST_UPD_DATE: new FormControl(null),
    });

    public EndItemLookupConfig: any = {
        ColName: "LOOKUP_END_ITEM",
        PlaceholderText: "Select Model",
        SourceController: "wPMS",
        SourceMethodName: "GetEndItem",
        NoOfShowRecords: 50,
        UpperCase: true
    }

    public BOMLookupConfig: any = {
        ColName: "LOOKUP_PART_NAME",
        PlaceholderText: "Select Assembly Parts No",
        SourceController: "K9",
        SourceMethodName: "SNM120P_GetBOMList",
        NoOfShowRecords: 50,
        UpperCase: true,
        SourceParams: {
            EXT_COLOR: null,
            INT_COLOR: null
        }
    }

    public PDILocationLookupConfig: any = {
        ColName: "LOOKUP_LOCATION",
        PlaceholderText: "Select PDI Location",
        SourceController: "wPMS",
        SourceMethodName: "GetPDILocationCode",
        NoOfShowRecords: 50,
        UpperCase: true,
        MinLengthSearch: 0
    }

    public CustomerLookupConfig: any = {
        ColName: "CODE_NAME",
        PlaceholderText: "Select Customer",
        SourceController: "wPMS",
        SourceMethodName: "GetCustomerCode",
        NoOfShowRecords: 50,
        UpperCase: true
    }

    public BranchLookupConfig: any = {
        ColName: "LOOKUP_BRANCH_NAME",
        PlaceholderText: "Select Branch",
        SourceController: "wPMS",
        SourceMethodName: "GetCustomerBranch",
        NoOfShowRecords: 50,
        UpperCase: true,
        MinLengthSearch: 0,
        SourceParams: {
            CUSTOMER_CODE: null
        }
    }

    ngOnInit() {
        this.GetList();
    }

    GetList() {
        this.HeaderList = [];
        this.http.get("K9", "SNM120P_Search")
            .subscribe(result => {
                this.HeaderList = result.Table;
            })
    }

    AddInstallParts(autoCompletePartsAdd) {
        if (this.editHeader) {
            this.modal.confirm(
                "You will not able to edit header. <br/> Are you sure to proceed to add detail?",
                this.viewref,
                () => {
                    this.editHeader = false
                    this.InstallForm.get("END_ITEM_18").disable();
                    this.InstallForm.get("EXT_COLOR").disable();
                    this.InstallForm.get("INT_COLOR").disable();
                    this.InstallForm.get("PDI_LOCATION_CODE").disable();
                    this.InstallForm.get("DESTINATION_CODE").disable();
                    this.BOMLookupConfig.SourceParams.EXT_COLOR = this.InstallForm.get("EXT_COLOR").value;
                    this.BOMLookupConfig.SourceParams.INT_COLOR = this.InstallForm.get("INT_COLOR").value;
                    autoCompletePartsAdd.OpenDialog();
                },
                () => { }
            )
        } else {
            autoCompletePartsAdd.OpenDialog();
        }
    }

    AddInstallPartList(val) {
        if (!this.partList.find(v => v.INSTALL_PART_NO === val.PART_NO)) {
            let installPart: InstallParts = {
                BOM_KEY: null,
                INSTALL_PART_NO: val.PART_NO,
                INSTALL_QTY: 0,
                TAKE_FROM: null,
                ISSUE_DOC_TYPE: null,
                CUSTOMER_TYPE: null,
                FIX_CUSTOMER_CODE: null,
                FIX_BRANCH_CODE: null,
                _PART_NAME: val.PART_NAME,
                _BRANCH_CONF: this.BranchLookupConfig
            }
            this.partList.push(installPart)
        } else {
            this.modal.error("Unable to add existing Install Parts No.", this.viewref);
        }
    }

    Add() {
        this.mode = "Add";
        this.editHeader = true;
        this.InstallForm.reset();
        this.InstallForm.get("END_ITEM_18").enable();
        this.InstallForm.get("EXT_COLOR").enable();
        this.InstallForm.get("INT_COLOR").enable();
        this.InstallForm.get("PDI_LOCATION_CODE").enable();
        this.InstallForm.get("DESTINATION_CODE").enable();

        this.partList = [];
        this.modelDescription = null;

        this.dialog.title = "Add Installation";
        this.dialog.OpenDialog();
    }

    Edit(row) {
        this.mode = "Edit";
        this.editHeader = false;
        this.partList = [];

        this.InstallForm.reset();
        this.InstallForm.get("END_ITEM_18").disable();
        this.InstallForm.get("EXT_COLOR").disable();
        this.InstallForm.get("INT_COLOR").disable();
        this.InstallForm.get("PDI_LOCATION_CODE").disable();
        this.InstallForm.get("DESTINATION_CODE").disable();
        this.InstallForm.get("BOM_KEY").setValue(row.BOM_KEY);
        this.InstallForm.get("END_ITEM_18").setValue(row.END_ITEM_18);
        this.InstallForm.get("EXT_COLOR").setValue(row.EXT_COLOR);
        this.InstallForm.get("INT_COLOR").setValue(row.INT_COLOR);
        this.InstallForm.get("PDI_LOCATION_CODE").setValue(row.PDI_LOCATION_CODE);
        this.InstallForm.get("DESTINATION_CODE").setValue(row.DESTINATION_CODE);
        this.InstallForm.get("LAST_UPD_BY").setValue(row.LAST_UPD_BY);
        this.InstallForm.get("LAST_UPD_DATE").setValue(row.LAST_UPD_DATE);

        this.modelDescription = row.END_ITEM_DESC;
        
        //Set BOM ext color
        this.BOMLookupConfig.SourceParams.EXT_COLOR = this.InstallForm.get("EXT_COLOR").value;
        this.BOMLookupConfig.SourceParams.INT_COLOR = this.InstallForm.get("INT_COLOR").value;

        this.http.get("K9", "SNM120P_GetDetail", row.BOM_KEY)
            .subscribe(result => {
                this.partList = result.Table
                    .map(v => {
                        v._BRANCH_CONF = this.BranchLookupConfig
                        v._BRANCH_CONF.SourceParams.CUSTOMER_CODE = v.CUSTOMER_CODE;

                        return v;
                    });

                this.dialog.title = "Edit Installation";
                this.dialog.OpenDialog();
            })
    }

    AddInstall() {
        this.InstallForm.get("INSTALL_PARTS").setValue(this.partList || []);

        this.modal.confirm("Are you sure to add to Install Parts master?", this.viewref, () => {
            let data = this.InstallForm.getRawValue();
            this.http.post("K9", "SNM120P_Add", data)
                .subscribe(result => {
                    this.modal.info("Add Install Parts complete.", this.viewref);
                    this.GetList();
                    this.dialog.Close();
                }, (err) => {
                    this.modal.error(err.error, this.viewref);
                })
        }, () => { })

    }

    SaveInstall() {
        this.InstallForm.get("INSTALL_PARTS").setValue(this.partList || []);

        this.modal.confirm("Are you sure to save changes?", this.viewref, () => {
            let data = this.InstallForm.getRawValue();
            this.http.post("K9", "SNM120P_Save".concat("/", this.InstallForm.get("BOM_KEY").value), data)
                .subscribe(result => {
                    this.modal.info("Save Install Parts complete.", this.viewref);
                    this.GetList();
                    this.dialog.Close();
                }, (err) => {
                    this.modal.error(err.error, this.viewref);
                })
        }, () => { })
    }

    DeleteInstall(data) {
        this.modal.confirm("Are you sure to delete from Install Parts master?", this.viewref, () => {
            this.http.post("K9", "SNM120P_Delete".concat("/", data.BOM_KEY), {})
                .subscribe(result => {
                    this.modal.info("Delete from Install Parts complete.", this.viewref);
                    this.GetList();
                    this.dialog.Close();
                }, (err) => {
                    this.modal.error(err.error, this.viewref);
                })
        }, () => { })
    }

    RemoveDetail(item, index) {
        this.modal.confirm("Are you sure to remove " + item.MATERIAL_PART_NO + " form the list?", this.viewref,
            () => {
                this.partList.splice(index, 1);
            }, () => { })
    }

    SetEndItem(val) {
        this.endItem = val.END_ITEM_18;
    }

    SetPDILocation(val) {
        this.InstallForm.get('PDI_LOCATION_CODE').setValue(val.PDI_LOCATION_CODE);
    }

    SetEndItemForm(val) {
        this.InstallForm.get('END_ITEM_18').setValue(val.END_ITEM_18);
        this.modelDescription = val.END_ITEM_DESC;
    }

    SetCustomerForm(val, item: InstallParts) {
        item.FIX_CUSTOMER_CODE = val.CUSTOMER_CODE;
        item.FIX_BRANCH_CODE = null;
        item._BRANCH_CONF.SourceParams.CUSTOMER_CODE = val.CUSTOMER_CODE;
    }

    SetBranchForm(val, item: InstallParts) {
        item.FIX_BRANCH_CODE = val.BRANCH_CODE;
    }

    customerTypeChange(val, item: InstallParts) {
        item.FIX_CUSTOMER_CODE = null;
        item.FIX_BRANCH_CODE = null;
    }

    DetailDrop(event: CdkDragDrop<any>) {
        if (event.previousContainer === event.container) {
            moveItemInArray(event.container.data, event.previousIndex, event.currentIndex);
        } else {
            transferArrayItem(event.previousContainer.data,
                event.container.data,
                event.previousIndex,
                event.currentIndex);
        }
    }
}