import { Component, ElementRef, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { ModalService } from 'src/app/core/modal.service';

@Component({
    selector: 'SNM150',
    templateUrl: 'SNM150.component.html',
    styleUrls: ['SNM150.component.css']
})

export class SNM150Component implements OnInit {
    constructor(
        private http: HttpService,
        private router: Router,
        private global: Globals,
        private modal: ModalService,
        private viewref: ViewContainerRef
  ) { }

  @ViewChild("dialogAction", { static: false }) dialogAction: any;
  @ViewChild("fileInput") fileInput: ElementRef;
  @ViewChild("dialogUpload", { static: false }) dialogUpload: any;

  public paramSearch: any = {};
  public formData: any = {};
  public tableData: Array<any> = [];
  
  //Upload File
  public FileName: string = "";
  private File : any;
  public tableUpload = []
  public total_error :number = 0;
  public error_list = []

  public lookupInstallPartNoConfig: any = {
    ColName: "LOOKUP_INSTALL_PART_NO",
    PlaceholderText: "Select install part no",
    SourceController: "K9",
    SourceMethodName: "SNM150_GetInstallPartNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedInstallPartNo(val: any) {
    if(val){
      this.paramSearch.INSTALL_PART_NO = val.INSTALL_PART_NO;
      this.paramSearch.INSTALL_PART_NAME_EN = val.INSTALL_PART_NAME_EN;
      this.paramSearch.INSTALL_PART_NAME_TH = val.INSTALL_PART_NAME_TH;
      this.Search();
    }else{
      this.paramSearch.INSTALL_PART_NO = null;
      this.paramSearch.INSTALL_PART_NAME_EN = null;
      this.paramSearch.INSTALL_PART_NAME_TH = null;
    }
  }

  public SetSelectedInstallPartNoDialog(val: any) {
    if(val){
      this.formData.INSTALL_PART_NO = val.INSTALL_PART_NO;
      this.formData.INSTALL_PART_NAME_EN = val.INSTALL_PART_NAME_EN;
      this.formData.INSTALL_PART_NAME_TH = val.INSTALL_PART_NAME_TH;
      this.formData.INSTALL_PART_NO_TEMP = val.INSTALL_PART_NO;
      this.formData.INSTALL_PART_NAME_EN_TEMP = val.INSTALL_PART_NAME_EN;
      this.formData.INSTALL_PART_NAME_TH_TEMP = val.INSTALL_PART_NAME_TH;
    }else{
      this.formData.INSTALL_PART_NO = null;
      this.formData.INSTALL_PART_NAME_EN = null;
      this.formData.INSTALL_PART_NAME_TH = null;
      this.formData.INSTALL_PART_NO_TEMP = this.formData.INSTALL_PART_NO;
      this.formData.INSTALL_PART_NAME_EN_TEMP = null;
      this.formData.INSTALL_PART_NAME_TH_TEMP = null;
    }
  }

  public SetCancelInstallPartNoDialog(val: any) {
    this.formData.INSTALL_PART_NO = this.formData.INSTALL_PART_NO_TEMP ? this.formData.INSTALL_PART_NO_TEMP : null ;
    this.formData.INSTALL_PART_NAME_EN = this.formData.INSTALL_PART_NAME_EN_TEMP ? this.formData.INSTALL_PART_NAME_EN_TEMP : null ;
    this.formData.INSTALL_PART_NAME_TH = this.formData.INSTALL_PART_NAME_TH_TEMP ? this.formData.INSTALL_PART_NAME_TH_TEMP : null ;
  }
  
  public lookupComponentPartNoConfig: any = {
    ColName: "LOOKUP_COMPONENT_PART_NO",
    PlaceholderText: "Select component part no",
    SourceController: "K9",
    SourceMethodName: "SNM150_GetComponentPartNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedComponentPartNo(val: any) {
    if(val){
      this.paramSearch.COMPONENT_PART_NO = val.COMPONENT_PART_NO;
      this.paramSearch.COMPONENT_PART_NAME_EN = val.COMPONENT_PART_NAME_EN;
      this.paramSearch.COMPONENT_PART_NAME_TH = val.COMPONENT_PART_NAME_TH;
      this.Search();
    }else{
      this.paramSearch.COMPONENT_PART_NO = null;
      this.paramSearch.COMPONENT_PART_NAME_EN = null;
      this.paramSearch.COMPONENT_PART_NAME_TH = null;
    }
  }

  public SetSelectedComponentPartNoDialog(val: any) {
    if(val){
      this.formData.COMPONENT_PART_NO = val.COMPONENT_PART_NO;
      this.formData.COMPONENT_PART_NAME_EN = val.COMPONENT_PART_NAME_EN;
      this.formData.COMPONENT_PART_NAME_TH = val.COMPONENT_PART_NAME_TH;
      this.formData.COMPONENT_PART_NO_TEMP = val.COMPONENT_PART_NO;
      this.formData.COMPONENT_PART_NAME_EN_TEMP = val.COMPONENT_PART_NAME_EN;
      this.formData.COMPONENT_PART_NAME_TH_TEMP = val.COMPONENT_PART_NAME_TH;
    }else{
      this.formData.COMPONENT_PART_NO = null;
      this.formData.COMPONENT_PART_NAME_EN = null;
      this.formData.COMPONENT_PART_NAME_TH = null;
      this.formData.COMPONENT_PART_NO_TEMP = this.formData.COMPONENT_PART_NO;
      this.formData.COMPONENT_PART_NAME_EN_TEMP = null;
      this.formData.COMPONENT_PART_NAME_TH_TEMP = null;
    }
  }

  public SetCancelComponentPartNoDialog(val: any) {
    this.formData.COMPONENT_PART_NO = this.formData.COMPONENT_PART_NO_TEMP ? this.formData.COMPONENT_PART_NO_TEMP : null ;
    this.formData.COMPONENT_PART_NAME_EN = this.formData.COMPONENT_PART_NAME_EN_TEMP ? this.formData.COMPONENT_PART_NAME_EN_TEMP : null ;
    this.formData.COMPONENT_PART_NAME_TH = this.formData.COMPONENT_PART_NAME_TH_TEMP ? this.formData.COMPONENT_PART_NAME_TH_TEMP : null ;
  }


  ngOnInit() {
    this.Search();
  }

  public Search() {
    const installpartno = this.global.EscapeCharacter(this.paramSearch.INSTALL_PART_NO ? this.paramSearch.INSTALL_PART_NO : "NULL")
    const componentpartno = this.global.EscapeCharacter(this.paramSearch.COMPONENT_PART_NO ? this.paramSearch.COMPONENT_PART_NO : "NULL")
    this.http.get("K9", 'SNM150_GetData', installpartno, componentpartno)
    .subscribe(res => {
        this.tableData = res.set.Table;
    },(err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contract support team", this.viewref);
  });
  }
  
  public Add() {
    this.formData = {};
    this.formData.TYPE = "ADD";
    this.dialogAction.width = "600px" ;
    this.dialogAction.height = "585px";
    this.dialogAction.title = "Add PDI K9 KIT bom" ;
    this.dialogAction.OpenDialog();
  }

  public Edit(data) {
    this.formData = { ...data };
    this.formData.TYPE = "EDIT";
    this.dialogAction.width = "600px";
    this.dialogAction.height = "600px";
    this.dialogAction.title = "Edit PDI K9 KIT bom";
    this.dialogAction.OpenDialog();
  }

  public Delete(data) {
    this.modal.confirm("Do you want to delete this record?<br>"
                        + "<br>Install part no: " + data.INSTALL_PART_NO 
                        + "<br>Position no: "+ data.POSITION_NO
                        + "<br>Component part no: "+ data.COMPONENT_PART_NO
                        + "<br>EXT Color: "+ data.EXT_COLOR
                        + "<br>INT Color: "+ data.INT_COLOR
                        , this.viewref
                        , () => ConfirmDelete()
                        , () => {}
                        , { height:"23rem", width:"33rem" })

    let ConfirmDelete = () => {
      const params = { 
          ID : data.ID
      }
      this.http.post("K9", "SNM150_Delete", params)
      .subscribe(res =>{
        if (res.status == 'DONE') {
          this.Search();
          this.modal.info(res.message, this.viewref);
        } else {
          this.modal.error(res.message, this.viewref);
        }
      },err =>{
        console.log(err, 'err')
        this.modal.error('Found an error, please contract support team.', this.viewref);
      })
    }
  }

  public SaveAdd(){
    if(this.ValidateNotNullField() === false){
      return;
    }
    this.modal.confirm("Do you want to save change you have made?", this.viewref, () => ConfirmAdd());

    let ConfirmAdd = () =>  {
      this.http.post("K9", 'SNM150_Insert', this.formData)
      .subscribe(res => {
        if (res.status == 'DONE') {
          this.Search();
          this.dialogAction.Close();
          this.modal.info(res.message, this.viewref, ()=>{}, { height:"22rem", width:"38rem" });
        }  
        else {
          this.modal.error(res.message, this.viewref, ()=>{}, { height:"22rem", width:"38rem" });
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewref);
      })
    }
  }

  public CancelAdd() {
    this.dialogAction.Close();
  }

  public SaveEdit() {
    if(this.ValidateNotNullField() === false){
      return;
    }
    this.modal.confirm("Do you want to save change you have made?", this.viewref, () => ConfirmEdit());

    let ConfirmEdit = () => {
      this.http.post("K9", 'SNM150_Update', this.formData)
      .subscribe(res => {
        if (res.status == 'DONE') {
          this.Search();
          this.dialogAction.Close();
          this.modal.info(res.message, this.viewref, ()=>{}, { height:"22rem", width:"38rem" });
        } else {
          this.modal.error(res.message, this.viewref, ()=>{}, { height:"22rem", width:"38rem" });
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
    }
  }

  public CancleEdit() {
    this.dialogAction.Close();
  }

  public ValidateNotNullField(): boolean{
    if(IsNullOrEmpty(this.formData.INSTALL_PART_NO)){
      this.modal.warning("Please fill Install part no.",this.viewref);
      return false;
    }
    else if(IsNullOrEmpty(this.formData.COMPONENT_PART_NO)){
      this.modal.warning("Please fill Component part no.",this.viewref);
      return false;
    }
    else if(IsNullOrEmpty(this.formData.COMPONENT_QTY)){
      this.modal.warning("Please fill Component qty.",this.viewref);
      return false;
    }
    else if(isDecimal(this.formData.COMPONENT_QTY)){
      this.modal.warning("Please fill Component qty in numberic only.",this.viewref);
      return false;
    }
    else if(IsNullOrEmpty((this.formData.EXT_COLOR))){
      this.modal.warning("Please fill EXT Color.",this.viewref);
      return false;
    }
    else if(IsNullOrEmpty((this.formData.INT_COLOR))){
      this.modal.warning("Please fill INT Color.",this.viewref);
      return false;
    }

    return true;
  }

  public OpenReport(report: number){
    switch(report){
      case 1:
          this.global.GoToReport("PMS_RPT_PDI_SNM150_EXCEL_REPORT",
          {
            P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
            P_INSTALL_PART_NO: this.paramSearch.INSTALL_PART_NO,
            P_COMPONENT_PART_NO: this.paramSearch.COMPONENT_PART_NO,
          });
        break;
    }
  }
  
  public OpenUpload(){
    this.total_error = 0;
    this.FileName = "";
    this.error_list = [];
    this.tableUpload = [];
    this.dialogUpload.width="1350px";
    this.dialogUpload.height="725px";
    this.dialogUpload.title = "Upload PDI K9 KIT bom";
    this.dialogUpload.OpenDialog()
  }

  public DownloadTemplate(){
    this.global.GoToExport("PMS_RPT_PDI_SNM150_UPLOAD_TEMPLATE",
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      }, true, "EXCELOPENXML")
  }
  
  public openFileBrowser() {
    this.FileName = "";
    this.fileInput.nativeElement.value = '';
    this.fileInput.nativeElement.click();
  }

  public selectFile(evt) {
    let Files: Array<File> = evt.target.files;
    if (Files.length > 0) {
      this.File = Files[0];
      this.FileName = this.File.name;
    }
  }

  public PreView() {
    if (!this.FileName) {
      this.modal.warning("Please Open File First...", this.viewref)
      return;
    }
    
    let formData = new FormData();
    formData.append('file', this.File);

    this.tableUpload = []
    this.error_list = []
    this.http.postFile("K9", "SNM150_UploadFile", formData)
      .subscribe(result => {
        this.tableUpload = result.set.Table;
        let countrow = 0;
        this.tableUpload.map((x,i) => {
          if(x.ERR_FLAG == 'Y'){
              countrow += 1;
              this.error_list.push({
                  record : i + 1,
                  message : x.ERR_MSG
              })
          } 
          this.total_error = countrow;
      })
    }, err => {
      console.log(err, 'err')
      this.modal.error('Found an error, please contract support team.', this.viewref);
    })
  }

  public SaveUpload(){
    this.modal.confirm("Do you want to save change you have made?",this.viewref,() => ConfirmSave())

    let ConfirmSave = () => {
      const params = {}
      this.http.post("K9", "SNM150_SaveByUpload", params)
      .subscribe(res => {
        if(res.status == "DONE"){
          this.Search();
          this.dialogUpload.Close();
          this.modal.info(res.message,this.viewref);
        }else{
          this.modal.error(res.message,this.viewref)
        }
      },err => {
        console.log(err, 'err')
        this.modal.error('Found an error, please contract support team.', this.viewref);
      })
    }
  }
}

function IsNullOrEmpty(value: any): boolean {
  if (value === '' || value === null || typeof value === 'undefined') {
    return true;
  } else {
    return false;
  }
}

function isNumber(str: string): boolean{
  return !Number.isNaN(Number(str));
}

function isDecimal(str: string): boolean{
  if(!isNumber){
    return false;
  }

  var number = Number(str);
  if (number !== Math.floor(number)) {
    return true;
 } else {
  return false;
 }
}