import { Component, ElementRef, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { ModalService } from 'src/app/core/modal.service';
import * as moment from 'moment';

@Component({
    selector: 'SNM154',
    templateUrl: 'SNM154.component.html',
    styleUrls: ['SNM154.component.css']
})

export class SNM154Component implements OnInit {
    constructor(
        private http: HttpService,
        private router: Router,
        private global: Globals,
        private modal: ModalService,
        private viewref: ViewContainerRef
  ) { }

  @ViewChild("dialogAction", { static: false }) dialogAction: any;
  @ViewChild("fileInput") fileInput: ElementRef;
  @ViewChild("dialogUpload", { static: false }) dialogUpload: any;

  public paramSearch: any = {};
  public formData: any = {};
  public tableData: Array<any> = [];

  //Upload File
  public FileName: string = "";
  private File : any;
  public tableUpload = []
  public tableUploadFilter = []
  public total_error :number = 0;
  public error_list = []

  public lookupDestinationConfig: any = {
    ColName: "LOOKUP_DESTINATION",
    PlaceholderText: "Select Destination",
    SourceController: "K9",
    SourceMethodName: "SNM154_GetDestination",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }
  public SetSelectedDestinationDialog(val: any) {
    if(val){
      this.formData.DESTINATION = val.DESTINATION;
      this.formData.DESTINATION_TEMP = val.DESTINATION;
      this.formData.DESTINATION_DESC = val.DESTINATION_DESC;
      this.formData.DESTINATION_DESC_TEMP = val.DESTINATION_DESC;
    }else{
      this.formData.DESTINATION = null;
      this.formData.DESTINATION_TEMP = this.formData.DESTINATION;
      this.formData.DESTINATION_DESC = null;
      this.formData.DESTINATION_DESC_TEMP = this.formData.DESTINATION_DESC;
    }
  }
  public SetCancelDestinationDialog(val: any) {
    this.formData.DESTINATION = this.formData.DESTINATION_TEMP ? this.formData.DESTINATION_TEMP : null ;
    this.formData.DESTINATION_DESC = this.formData.DESTINATION_DESC_TEMP ? this.formData.DESTINATION_DESC_TEMP : null ;
  }
  public lookupBaseModelConfig: any = {
    ColName: "LOOKUP_BASE_MODEL",
    PlaceholderText: "Select Base Model",
    SourceController: "K9",
    SourceMethodName: "SNM154_GetBaseModel",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }
  public SetSelectedBaseModelDialog(val: any) {
    if(val){
      this.formData.BASE_MODEL = val.BASE_MODEL;
      this.formData.BASE_MODEL_TEMP = val.BASE_MODEL;
      this.formData.BASE_MODEL_DESCRIPTIONS = val.BASE_MODEL_DESCRIPTIONS;
      this.formData.BASE_MODEL_DESCRIPTIONS_TEMP = val.BASE_MODEL_DESCRIPTIONS;
    }else{
      this.formData.BASE_MODEL = null;
      this.formData.BASE_MODEL_TEMP = this.formData.BASE_MODEL;
      this.formData.BASE_MODEL_DESCRIPTIONS = null;
      this.formData.BASE_MODEL_DESCRIPTIONS_TEMP = this.formData.BASE_MODEL_DESCRIPTIONS;
    }
  }
  public SetCancelBaseModelDialog(val: any) {
    this.formData.BASE_MODEL = this.formData.BASE_MODEL_TEMP ? this.formData.BASE_MODEL_TEMP : null ;
    this.formData.BASE_MODEL_DESCRIPTIONS = this.formData.BASE_MODEL_DESCRIPTIONS_TEMP ? this.formData.BASE_MODEL_DESCRIPTIONS_TEMP : null ;
  }
  ngOnInit() {
    this.Search();
  }

  public Search() {
    const optioncode = this.global.EscapeCharacter(this.paramSearch.OPTION_CODE ? this.paramSearch.OPTION_CODE : "NULL");
    const enditem18 = this.global.EscapeCharacter(this.paramSearch.END_ITEM_18 ? this.paramSearch.END_ITEM_18 : "NULL");
    const destination = this.global.EscapeCharacter(this.paramSearch.DESTINATION ? this.paramSearch.DESTINATION : "NULL");
    const speccode = this.global.EscapeCharacter(this.paramSearch.SPEC_CODE ? this.paramSearch.SPEC_CODE : "NULL");
    this.http.get("K9", 'SNM154_GetData', optioncode, enditem18, destination, speccode)
    .subscribe(res => {
        this.tableData = res.set.Table;
    },(err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contract support team", this.viewref);
    });
  }
  
  public Add() {
    this.formData = {}
    this.formData.TYPE = "ADD";

    this.dialogAction.width = "700px" 
    this.dialogAction.height = "475px" 
    this.dialogAction.title = "Add PDI K9 Option standard" 
    this.dialogAction.OpenDialog();
  }

  public Edit(data) {
    this.formData = { ...data }
    this.formData.TYPE = "EDIT";

    this.dialogAction.width = "700px" 
    this.dialogAction.height = "495px" 
    this.dialogAction.title = "Edit PDI K9 Option standard" 
    this.dialogAction.OpenDialog();
  }

  public Delete(data) {
    this.modal.confirm("Do you want to delete this record?<br>"
                        + "<br>Option code: " + data.OPTION_CODE
                        + "<br>End Item 18: " + data.END_ITEM_18
                        + "<br>Destination: " + data.DESTINATION
                        + "<br>Spec Code: " + data.SPEC_CODE
                        + "<br>Adopte Date From: " + moment(data.ADOPTED_DATE_FROM).format("DD-MMM-YYYY")
                        + "<br>Adopte Date To: " + moment(data.ADOPTED_DATE_TO).format("DD-MMM-YYYY")
                      , this.viewref
                      , () => ConfirmDelete()
                      , () => {}
                      , { height:"25rem" })

    let ConfirmDelete = () => {
      const params = { 
        ID : data.ID
      }
      this.http.post("K9", "SNM154_Delete", params)
      .subscribe(res =>{
        if (res.status == 'DONE') {
          this.Search();
          this.modal.info(res.message, this.viewref);
        } else {
          this.modal.error(res.message, this.viewref);
        }
      },err =>{
        console.log(err, 'err')
        this.modal.error('Found an error, please contract support team.', this.viewref);
      })
    }
  }

  public SaveAdd(){
    if(this.ValidateNotNullField() === false){
      return;
    }

    this.modal.confirm("Do you want to save change you have made?", this.viewref, () => ConfirmAdd());
    let ConfirmAdd = () =>  {
      this.http.post("K9", 'SNM154_Insert', this.formData)
      .subscribe(res => {
        if (res.status == 'DONE') {
          this.Search();
          this.dialogAction.Close();
          this.modal.info(res.message, this.viewref, ()=>{}, { height:"25.5rem", width:"32rem" });
        } else {
          this.modal.error(res.message, this.viewref, ()=>{}, { height:"25.5rem", width:"32rem" });
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewref);
      })
    }
  }

  public CancelAdd() {
    this.dialogAction.Close();
  }

  public SaveEdit() {
    if(this.ValidateNotNullField() === false){
      return;
    }
    this.modal.confirm("Do you want to save change you have made?", this.viewref, () => ConfirmEdit());

    let ConfirmEdit = () => {
      this.http.post("K9", 'SNM154_Update', this.formData)
      .subscribe(res => {
        if (res.status == 'DONE') {
          this.Search();
          this.dialogAction.Close();
          this.modal.info(res.message, this.viewref, ()=>{}, { height:"25.5rem", width:"32rem" });
        } else {
          this.modal.error(res.message, this.viewref, ()=>{}, { height:"25.5rem", width:"32rem" });
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
    }
  }

  public CancleEdit() {
    this.dialogAction.Close();
  }

  public ValidateNotNullField(): boolean{
    if(IsNullOrEmpty(this.formData.OPTION_CODE)){
      this.modal.warning("Please fill Option code.",this.viewref);
      return false;
    }
    else if(IsNullOrEmpty(this.formData.END_ITEM_18)){
      this.modal.warning("Please fill End item 18.",this.viewref);
      return false;
    }
    else if(IsNullOrEmpty(this.formData.DESTINATION)){
      this.modal.warning("Please fill Destination.",this.viewref);
      return false;
    }
    else if(IsNullOrEmpty(this.formData.SPEC_CODE)){
      this.modal.warning("Please fill Spec Code.",this.viewref);
      return false;
    }
    else if(IsNullOrEmpty(this.formData.ADOPTED_DATE_FROM)){
      this.modal.warning("Please select adopted date from.",this.viewref);
      return false;
    }
    else if(IsNullOrEmpty(this.formData.ADOPTED_DATE_TO)){
      this.modal.warning("Please select adopted date to.",this.viewref);
      return false;
    }

    return true;
  }

  public OpenReport(report: number){
    switch(report){
      case 1:
          this.global.GoToReport("PMS_RPT_PDI_SNM154_EXCEL_REPORT",
          {
            P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
            P_OPTION_CODE: this.paramSearch.OPTION_CODE,
            P_END_ITEN_18: this.paramSearch.END_ITEN_18,
            P_DESTINATION: this.paramSearch.DESTINATION,
            P_SPEC_CODE: this.paramSearch.SPEC_CODE,
          });
        break;
    }
  }

  public OpenUpload(){
    this.total_error = 0;
    this.FileName = "";
    this.error_list = [];
    this.tableUpload = [];
    this.tableUploadFilter = [];
    this.dialogUpload.width="1350px";
    this.dialogUpload.height="725px";
    this.dialogUpload.title = "Upload K9 PDI Option standard";
    this.dialogUpload.OpenDialog()
  }

  public DownloadTemplate(){
    this.global.GoToExport("PMS_RPT_PDI_SNM154_UPLOAD_TEMPLATE",
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      }, true, "EXCELOPENXML")
  }
  
  public openFileBrowser() {
    this.FileName = "";
    this.fileInput.nativeElement.value = '';
    this.fileInput.nativeElement.click();
  }

  public selectFile(evt) {
    let Files: Array<File> = evt.target.files;
    if (Files.length > 0) {
      this.File = Files[0];
      this.FileName = this.File.name;
    }
  }

  public PreView() {
    if (!this.FileName) {
      this.modal.warning("Please Open File First...", this.viewref)
      return;
    }
    
    let formData = new FormData();
    formData.append('file', this.File);

    this.tableUpload = []
    this.error_list = []
    this.http.postFile("K9", "SNM154_UploadFile", formData)
      .subscribe(result => {
        this.tableUpload = result.set.Table;
        this.tableUploadFilter = this.tableUpload.filter(x => x.ERR_FLAG == 'N')
        let countrow = 0;
        this.tableUpload.map((x,i) => {
          if(x.ERR_FLAG == 'Y'){
              countrow += 1;
              this.error_list.push({
                  record : i + 1,
                  message : x.ERR_MSG
              })
          } 
          this.total_error = countrow;
      })
    }, err => {
      console.log(err, 'err')
      this.modal.error('Found an error, please contract support team.', this.viewref);
    })
  }

  public SaveUpload(){
    this.modal.confirm("Do you want to save change you have made?",this.viewref,() => ConfirmSave())

    let ConfirmSave = () => {
      const params = {}
      this.http.post("K9", "SNM154_SaveByUpload", params)
      .subscribe(res => {
        if(res.status == "DONE"){
          this.Search();
          this.dialogUpload.Close();
          this.modal.info(res.message,this.viewref);
        }else{
          this.modal.error(res.message,this.viewref)
        }
      },err => {
        console.log(err, 'err')
        this.modal.error('Found an error, please contract support team.', this.viewref);
      })
    }
  }
}

function IsNullOrEmpty(value: any): boolean {
  if (value === '' || value === null || typeof value === 'undefined') {
    return true;
  } else {
    return false;
  }
}

function isNumber(str: string): boolean{
  return !Number.isNaN(Number(str));
}

function isDecimal(str: string): boolean{
  if(!isNumber){
    return false;
  }

  var number = Number(str);
  if (number !== Math.floor(number)) {
    return true;
 } else {
  return false;
 }
}