import { MatInput, } from '@angular/material/input';
import { Component, ElementRef, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { ModalService } from 'src/app/core/modal.service';
import { MatSelect } from '@angular/material/select';

@Component({
    selector: 'SNM156',
    templateUrl: 'SNM156.component.html',
    styleUrls: ['SNM156.component.css']
})

export class SNM156Component implements OnInit {
    constructor(
        private http: HttpService,
        private router: Router,
        private global: Globals,
        private modal: ModalService,
        private viewref: ViewContainerRef
  ) { }

  @ViewChild('destinationCode') destinationCode: ElementRef;

  @ViewChild("dialogAction", { static: false }) dialogAction: any;
  @ViewChild("fileInput") fileInput: ElementRef;
  @ViewChild("dialogUpload", { static: false }) dialogUpload: any;

  public paramSearch: any = {};
  public formData: any = {};
  public tableData: Array<any> = [];

  //Upload File
  public FileName: string = "";
  private File : any;
  public tableUpload = []
  public tableUploadFilter = []
  public total_error :number = 0;
  public error_list = []

  ngOnInit() {
    this.Search();
  }

  public Search() {
    const destinationCode = this.global.EscapeCharacter(this.paramSearch.DESTINATION_CODE ? this.paramSearch.DESTINATION_CODE : "NULL");
    const destinationDesc = this.global.EscapeCharacter(this.paramSearch.DESTINATION_DESC ? this.paramSearch.DESTINATION_DESC : "NULL");
    this.http.get("K9", 'SNM156_GetData', destinationCode, destinationDesc)
    .subscribe(res => {
        this.tableData = res.set.Table;
    },(err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contract support team", this.viewref);
  });
  }
  
  public Add() {
    this.formData = {}
    this.formData.TYPE = "ADD";
    this.dialogAction.width = "575px" 
    this.dialogAction.height = "450px" 
    this.dialogAction.title = "Add Destination Master" 
    this.dialogAction.OpenDialog();
  }

  public Edit(data) {
    this.formData = { ...data }
    this.formData.TYPE = "EDIT";
    this.dialogAction.width = "575px" 
    this.dialogAction.height = "485px" 
    this.dialogAction.title = "Edit Destination Master" 
    this.dialogAction.OpenDialog();
  }

  public Delete(data) {
    this.modal.confirm("Do you want to delete record"
                        + "<br>Destination Code: "  + data.DESTINATION_CODE
                      , this.viewref
                      , () => ConfirmDelete())

    let ConfirmDelete = () => {
      const params = { DESTINATION_CODE : data.DESTINATION_CODE }
      this.http.post("K9", "SNM156_Delete", params)
      .subscribe(res =>{
        if (res.status == 'DONE') {
          this.Search();
          this.modal.info(res.message, this.viewref);
        } else {
          this.modal.error(res.message, this.viewref);
        }
      },err =>{
        console.log(err, 'err')
        this.modal.error('Found an error, please contract support team.', this.viewref);
      })
    }
  }

  public SaveAdd(){
    if(this.ValidateNotNullField() === false){
      return;
    }
    this.modal.confirm("Do you want to save change you have made?", this.viewref, () => ConfirmAdd());

    let ConfirmAdd = () =>  {
      this.http.post("K9", 'SNM156_Insert', this.formData)
      .subscribe(res => {
        if (res.status == 'DONE') {
          this.Search();
          this.dialogAction.Close();
          this.modal.info(res.message, this.viewref);
        }  
        else {
          this.modal.error(res.message, this.viewref);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewref);
      })
    }
  }

  public CancelAdd() {
    this.dialogAction.Close();
  }

  public SaveEdit() {
    if(this.ValidateNotNullField() === false){
      return;
    }
    this.modal.confirm("Do you want to save change you have made?", this.viewref, () => ConfirmEdit());

    let ConfirmEdit = () => {
      this.http.post("K9", 'SNM156_Update', this.formData)
      .subscribe(res => {
        if (res.status == 'DONE') {
          this.Search();
          this.dialogAction.Close();
          this.modal.info(res.message, this.viewref);
        } else {
          this.modal.error(res.message, this.viewref);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
    }
  }

  public CancleEdit() {
    this.dialogAction.Close();
  }

  public ValidateNotNullField(): boolean{
    if(!this.formData.DESTINATION_CODE){
      this.modal.warning("Please fill Destination Code.",this.viewref,() => {this.destinationCode.nativeElement.focus()});
      return false;
    }
    
    return true;
  }

  public OpenReport(report: number){
    switch(report){
      case 1:
          this.global.GoToReport("PMS_RPT_PDI_SNM156_EXCEL_REPORT",
          {
            P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
            P_DESTINATION_CODE: this.paramSearch.DESTINATION_CODE,
            P_DESTINATION_DESC: this.paramSearch.DESTINATION_DESC,
          });
        break;
    }
  }

  public OpenUpload(){
    this.total_error = 0;
    this.FileName = "";
    this.error_list = [];
    this.tableUpload = [];
    this.tableUploadFilter = [];
    this.dialogUpload.width="1350px";
    this.dialogUpload.height="725px";
    this.dialogUpload.title = "Upload Destination master";
    this.dialogUpload.OpenDialog()
  }

  public DownloadTemplate(){
    this.global.GoToExport("PMS_RPT_PDI_SNM156_UPLOAD_TEMPLATE",
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      }, true, "EXCELOPENXML")
  }
  
  public openFileBrowser() {
    this.FileName = "";
    this.fileInput.nativeElement.value = '';
    this.fileInput.nativeElement.click();
  }

  public selectFile(evt) {
    let Files: Array<File> = evt.target.files;
    if (Files.length > 0) {
      this.File = Files[0];
      this.FileName = this.File.name;
    }
  }

  public PreView() {
    if (!this.FileName) {
      this.modal.warning("Please Open File First...", this.viewref)
      return;
    }
    
    let formData = new FormData();
    formData.append('file', this.File);

    this.tableUpload = []
    this.error_list = []
    this.http.postFile("K9", "SNM156_UploadFile", formData)
      .subscribe(result => {
        this.tableUpload = result;
        this.tableUploadFilter = this.tableUpload.filter(x => x.ERR_FLAG == 'N')
        let countrow = 0;
        this.tableUpload.map((x,i) => {
          if(x.ERR_FLAG == 'Y'){
              countrow += 1;
              this.error_list.push({
                  record : i + 1,
                  message : x.ERR_MSG
              })
          } 
          this.total_error = countrow;
      })
    }, err => {
      console.log(err, 'err')
      this.modal.error('Found an error, please contract support team.', this.viewref);
    })
  }

  public SaveUpload(){
    this.modal.confirm("Do you want to save change you have made?",this.viewref,() => ConfirmSave())

    let ConfirmSave = () => {
      this.http.post("K9","SNM156_SaveByUpload",this.tableUploadFilter)
      .subscribe(res => {
        if(res.status == "DONE"){
          this.Search();
          this.dialogUpload.Close();
          this.modal.info(res.message,this.viewref);
        }else{
          this.modal.error(res.message,this.viewref)
        }
      },err => {
        console.log(err, 'err')
        this.modal.error('Found an error, please contract support team.', this.viewref);
      })
    }
  }
}


function isNumber(str: string): boolean{
  return !Number.isNaN(Number(str));
}

function isDecimal(str: string): boolean{
  if(!isNumber){
    return false;
  }

  var number = Number(str);
  if (number !== Math.floor(number)) {
    return true;
 } else {
  return false;
 }
}