import { MatInput, } from '@angular/material/input';
import { Component, ElementRef, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { ModalService } from 'src/app/core/modal.service';
import { MatSelect } from '@angular/material/select';

@Component({
    selector: 'SNM157',
    templateUrl: 'SNM157.component.html',
    styleUrls: ['SNM157.component.css']
})

export class SNM157Component implements OnInit {
    constructor(
        private http: HttpService,
        private router: Router,
        private global: Globals,
        private modal: ModalService,
        private viewref: ViewContainerRef
  ) { }

  @ViewChild('chassisNo') chassisNo: ElementRef;
  @ViewChild('endItem18') endItem18: ElementRef;
  @ViewChild('optionType') optionType: MatSelect;

  @ViewChild("dialogAction", { static: false }) dialogAction: any;
  @ViewChild("fileInput") fileInput: ElementRef;
  @ViewChild("dialogUpload", { static: false }) dialogUpload: any;

  public paramSearch: any = {};
  public formData: any = {};
  public tableData: Array<any> = [];
  public listOptionType: any = [
    { TEXT: "STD", VALUE: "STD" },
    { TEXT: "DISPLAY", VALUE: "DISPLAY" },
    { TEXT: "DEMO", VALUE: "DEMO" },
    { TEXT: "PACKAGE", VALUE: "PACKAGE" }
  ];

  //Upload File
  public FileName: string = "";
  private File : any;
  public tableUpload = []
  public tableUploadFilter = []
  public total_error :number = 0;
  public error_list = []

  ngOnInit() {
    this.Search();
  }

  public Search() {
    const chassisNo = this.global.EscapeCharacter(this.paramSearch.CHASSIS_NO ? this.paramSearch.CHASSIS_NO : "NULL");
    const endItem18 = this.global.EscapeCharacter(this.paramSearch.END_ITEM_18 ? this.paramSearch.END_ITEM_18 : "NULL");
    const optionType = this.global.EscapeCharacter(this.paramSearch.OPTION_TYPE ? this.paramSearch.OPTION_TYPE : "NULL");
    this.http.get("K9", 'SNM157_GetData', chassisNo, endItem18, optionType)
    .subscribe(res => {
        this.tableData = res.set.Table;
    },(err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contract support team", this.viewref);
  });
  }
  
  public Add() {
    this.formData = {}
    this.formData.TYPE = "ADD";
    this.dialogAction.width = "575px" 
    this.dialogAction.height = "450px" 
    this.dialogAction.title = "Add Option apply" 
    this.dialogAction.OpenDialog();
  }

  public Edit(data) {
    this.formData = { ...data }
    this.formData.TYPE = "EDIT";
    this.dialogAction.width = "575px" 
    this.dialogAction.height = "475px" 
    this.dialogAction.title = "Edit Option apply" 
    this.dialogAction.OpenDialog();
  }

  public Delete(data) {
    this.modal.confirm("Do you want to delete record"
                        + "<br>Chassis no: "  + data.CHASSIS_NO
                        //+ "<br>End item 18: "  + data.END_ITEM_18
                      , this.viewref
                      , () => ConfirmDelete())

    let ConfirmDelete = () => {
      const params = { 
        CHASSIS_NO : data.CHASSIS_NO,
        END_ITEM_18 : data.END_ITEM_18
      }
      this.http.post("K9", "SNM157_Delete", params)
      .subscribe(res =>{
        if (res.status == 'DONE') {
          this.Search();
          this.modal.info(res.message, this.viewref);
        } else {
          this.modal.error(res.message, this.viewref);
        }
      },err =>{
        this.modal.error('Found an error, please contract support team.', this.viewref);
      })
    }
  }

  public SaveAdd(){
    if(this.ValidateNotNullField() === false){
      return;
    }
    this.modal.confirm("Do you want to save change you have made?", this.viewref, () => ConfirmAdd());

    let ConfirmAdd = () =>  {
      this.http.post("K9", 'SNM157_Insert', this.formData)
      .subscribe(res => {
        if (res.status == 'DONE') {
          this.Search();
          this.dialogAction.Close();
          this.modal.info(res.message, this.viewref);
        }  
        else {
          this.modal.error(res.message, this.viewref);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewref);
      })
    }
  }

  public CancelAdd() {
    this.dialogAction.Close();
  }

  public SaveEdit() {
    if(this.ValidateNotNullField() === false){
      return;
    }
    this.modal.confirm("Do you want to save change you have made?", this.viewref, () => ConfirmEdit());

    let ConfirmEdit = () => {
      this.http.post("K9", 'SNM157_Update', this.formData)
      .subscribe(res => {
        if (res.status == 'DONE') {
          this.Search();
          this.dialogAction.Close();
          this.modal.info(res.message, this.viewref);
        } else {
          this.modal.error(res.message, this.viewref);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
    }
  }

  public CancleEdit() {
    this.dialogAction.Close();
  }

  public ValidateNotNullField(): boolean{
    if(!this.formData.CHASSIS_NO){
      this.modal.warning("Please fill Chassis no.",this.viewref,() => {this.chassisNo.nativeElement.focus()});
      return false;
    }
    else if(!this.formData.END_ITEM_18){
      this.modal.warning("Please fill End item 18.",this.viewref,() => {this.endItem18.nativeElement.focus()});
      return false;
    }
    else if(!this.formData.OPTION_TYPE){
      this.modal.warning("Please select Option type.",this.viewref,() => {this.optionType.toggle()});
      return false;
    }
    return true;
  }

  public OpenUpload(){
    this.total_error = 0;
    this.FileName = "";
    this.error_list = [];
    this.tableUpload = [];
    this.tableUploadFilter = [];
    this.dialogUpload.height="850px";
    this.dialogUpload.width="1375px";
    this.dialogUpload.title = "Upload Option apply";
    this.dialogUpload.OpenDialog()
  }

  public DownloadTemplate(){
    this.global.GoToExport("PMS_RPT_PDI_SNM157_UPLOAD_TEMPLATE",
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      }, true, "EXCELOPENXML")
  }
  
  public openFileBrowser() {
    this.FileName = "";
    this.fileInput.nativeElement.value = '';
    this.fileInput.nativeElement.click();
  }

  public selectFile(evt) {
    let Files: Array<File> = evt.target.files;
    if (Files.length > 0) {
      this.File = Files[0];
      this.FileName = this.File.name;
    }
  }

  public PreView() {
    if (!this.FileName) {
      this.modal.warning("Please Open File First...", this.viewref)
      return;
    }
    
    let formData = new FormData();
    formData.append('file', this.File);

    this.tableUpload = []
    this.error_list = []
    this.http.postFile("K9", "SNM157_UploadFile", formData)
      .subscribe(result => {
        this.tableUpload = result;
        this.tableUploadFilter = this.tableUpload.filter(x => x.ERR_FLAG == 'N')
        let countrow = 0;
        this.tableUpload.map((x,i) => {
          if(x.ERR_FLAG == 'Y'){
              countrow += 1;
              this.error_list.push({
                  record : i + 1,
                  message : x.ERR_MSG
              })
          } 
          this.total_error = countrow;
      })
    }, err => {
      this.modal.error('Found an error, please contract support team.', this.viewref);
    })
  }

  public SaveUpload(){
    this.modal.confirm("Do you want to save change you have made?",this.viewref,() => ConfirmSave())

    let ConfirmSave = () => {
      this.http.post("K9","SNM157_SaveByUpload",this.tableUploadFilter)
      .subscribe(res => {
        if(res.status == "DONE"){
          this.Search();
          this.dialogUpload.Close();
          this.modal.info(res.message,this.viewref);
        }else{
          this.modal.error(res.message,this.viewref)
        }
      },err => {
        this.modal.error('Found an error, please contract support team.', this.viewref);
      })
    }
  }
}


function isNumber(str: string): boolean{
  return !Number.isNaN(Number(str));
}

function isDecimal(str: string): boolean{
  if(!isNumber){
    return false;
  }

  var number = Number(str);
  if (number !== Math.floor(number)) {
    return true;
 } else {
  return false;
 }
}
