import { Component, ElementRef, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { ModalService } from 'src/app/core/modal.service';
import * as moment from 'moment';

@Component({
    selector: 'SNM158',
    templateUrl: 'SNM158.component.html',
    styleUrls: ['SNM158.component.css']
})

export class SNM158Component implements OnInit {
    constructor(
        private http: HttpService,
        private router: Router,
        private global: Globals,
        private modal: ModalService,
        private viewref: ViewContainerRef
  ) { }

  @ViewChild("dialogAction", { static: false }) dialogAction: any;
  @ViewChild("fileInput") fileInput: ElementRef;
  @ViewChild("dialogUpload", { static: false }) dialogUpload: any;

  public fyObj = GetFYObject();
  public paramSearch: any = {};
  public formData: any = {};
  public tableData: Array<any> = [];
  
  //Upload File
  public FileName: string = "";
  private File : any;
  public tableUpload = []
  public total_error :number = 0;
  public error_list = []

  ngOnInit() {
    //this.Search();
  }

  public Search() {
    const exyear = this.global.EscapeCharacter(this.paramSearch.EX_YEAR ? this.paramSearch.EX_YEAR : "NULL")
    const exno = this.global.EscapeCharacter(this.paramSearch.EX_NO ? this.paramSearch.EX_NO : "NULL")
    const plant = this.global.EscapeCharacter(this.paramSearch.PLANT ? this.paramSearch.PLANT : "NULL")
    const domexp = this.global.EscapeCharacter(this.paramSearch.DOM_EXP ? this.paramSearch.DOM_EXP : "NULL")
    this.http.get("K9", 'SNM158_GetData', exyear, exno, plant, domexp)
    .subscribe(res => {
        this.tableData = res.set.Table;
    },(err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contract support team", this.viewref);
  });
  }
  
  public Add() {
    this.formData = {}
    this.formData.TYPE = "ADD";
    this.dialogAction.width = "925px" 
    this.dialogAction.height = "620px" 
    this.dialogAction.title = "Add PDI K9 Production Plan" 
    this.dialogAction.OpenDialog();
  }

  public Edit(data) {
    this.formData = { ...data }
    this.formData.TYPE = "EDIT";
    this.dialogAction.width = "925px" 
    this.dialogAction.height = "650px" 
    this.dialogAction.title = "Edit PDI K9 Production Plan" 
    this.dialogAction.OpenDialog();
  }

  public Delete(data) {
    this.modal.confirm("Do you want to delete record"
                        + "<br>EX year: "+ data.EX_YEAR
                        + "<br>EX no: "+ data.EX_NO
                        + "<br>Buyer Code: "+ data.BUYER_CODE
                        + "<br>Model - Prefix: "+ data.MODEL_PREFIX
                        + "<br>Model - Base: "+ data.MODEL_BASE
                        + "<br>Model - Suffix: "+ data.MODEL_SUFFIX
                        + "<br>Spec Code: "+ data.SPEC_CODE
                        , this.viewref
                        , () => ConfirmDelete()
                        , () => {}
                        , { height:"24rem", width:"38rem" })

    let ConfirmDelete = () => {
      const params = { 
        ID : data.ID
      }
      this.http.post("K9", "SNM158_Delete", params)
      .subscribe(res =>{
        if (res.status == 'DONE') {
          this.Search();
          this.modal.info(res.message, this.viewref);
        } else {
          this.modal.error(res.message, this.viewref);
        }
      },err =>{
        console.log(err, 'err')
        this.modal.error('Found an error, please contract support team.', this.viewref);
      })
    }
  }

  public SaveAdd(){
    if(this.ValidateNotNullField() === false){
      return;
    }
    this.modal.confirm("Do you want to save change you have made?", this.viewref, () => ConfirmAdd());

    let ConfirmAdd = () =>  {
      this.http.post("K9", 'SNM158_Insert', this.formData)
      .subscribe(res => {
        if (res.status == 'DONE') {
          this.Search();
          this.dialogAction.Close();
          this.modal.info(res.message, this.viewref);
        }  
        else {
          this.modal.error(res.message, this.viewref);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewref);
      })
    }
  }

  public CancelAdd() {
    this.dialogAction.Close();
  }

  public SaveEdit() {
    if(this.ValidateNotNullField() === false){
      return;
    }
    this.modal.confirm("Do you want to save change you have made?", this.viewref, () => ConfirmEdit());

    let ConfirmEdit = () => {
      this.http.post("K9", 'SNM158_Update', this.formData)
      .subscribe(res => {
        if (res.status == 'DONE') {
          this.Search();
          this.dialogAction.Close();
          this.modal.info(res.message, this.viewref);
        } else {
          this.modal.error(res.message, this.viewref);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
    }
  }

  public CancleEdit() {
    this.dialogAction.Close();
  }

  public ValidateNotNullField(): boolean{
    if(IsNullOrEmpty(this.formData.EX_YEAR)){
      this.modal.warning("Please fill EX Year.",this.viewref);
      return false;
    }
    else if(IsNullOrEmpty(this.formData.EX_NO)){
      this.modal.warning("Please fill EX No.",this.viewref);
      return false;
    }
    else if(IsNullOrEmpty(this.formData.MODEL_PREFIX)){
      this.modal.warning("Please fill Model - Prefix.",this.viewref);
      return false;
    }
    else if(IsNullOrEmpty(this.formData.MODEL_BASE)){
      this.modal.warning("Please fill Model - Base.",this.viewref);
      return false;
    }
    else if(IsNullOrEmpty(this.formData.MODEL_SUFFIX)){
      this.modal.warning("Please fill Model - Suffix.",this.viewref);
      return false;
    }
    else if(IsNullOrEmpty(this.formData.BUYER_CODE)){
      this.modal.warning("Please fill Buyer Code.",this.viewref);
      return false;
    }
    else if(IsNullOrEmpty(this.formData.SPEC_CODE)){
      this.modal.warning("Please fill Spec Code.",this.viewref);
      return false;
    }

    return true;
  }

  public OpenReport(report: number){
    switch(report){
      case 1:
          this.global.GoToReport("PMS_RPT_PDI_SNM158_EXCEL_REPORT",
          {
            P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
            P_EX_YEAR: this.paramSearch.EX_YEAR,
            P_EX_NO: this.paramSearch.EX_NO,
            P_PLANT: this.paramSearch.PLANT,
            P_DOM_EXP: this.paramSearch.DOM_EXP,
          });
        break;
    }
  }
  
  public OpenUpload(){
    this.total_error = 0;
    this.FileName = "";
    this.error_list = [];
    this.tableUpload = [];
    this.dialogUpload.width="1375px";
    this.dialogUpload.height="750px";
    this.dialogUpload.title = "Upload PDI K9 Production Plan";
    this.dialogUpload.OpenDialog()
  }

  public DownloadTemplate(){
    this.global.GoToExport("PMS_RPT_PDI_SNM158_UPLOAD_TEMPLATE",
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      }, true, "EXCELOPENXML")
  }
  
  public openFileBrowser() {
    this.FileName = "";
    this.fileInput.nativeElement.value = '';
    this.fileInput.nativeElement.click();
  }

  public selectFile(evt) {
    let Files: Array<File> = evt.target.files;
    if (Files.length > 0) {
      this.File = Files[0];
      this.FileName = this.File.name;
    }
  }

  public PreView() {
    if (!this.FileName) {
      this.modal.warning("Please Open File First...", this.viewref)
      return;
    }
    
    let formData = new FormData();
    formData.append('file', this.File);

    this.tableUpload = []
    this.error_list = []
    this.http.postFile("K9", "SNM158_UploadFile", formData)
      .subscribe(result => {
        this.tableUpload = result.set.Table;
        let countrow = 0;
        this.tableUpload.map((x,i) => {
          if(x.ERR_FLAG == 'Y'){
              countrow += 1;
              this.error_list.push({
                  record : i + 1,
                  message : x.ERR_MSG
              })
          } 
          this.total_error = countrow;
      })
    }, err => {
      console.log(err, 'err')
      this.modal.error('Found an error, please contract support team.', this.viewref);
    })
  }

  public SaveUpload(){
    this.modal.confirm("Do you want to save change you have made?",this.viewref,() => ConfirmSave())

    let ConfirmSave = () => {
      const params = {}
      this.http.post("K9","SNM158_SaveByUpload", params)
      .subscribe(res => {
        if(res.status == "DONE"){
          this.Search();
          this.dialogUpload.Close();
          this.modal.info(res.message,this.viewref);
        }else{
          this.modal.error(res.message,this.viewref)
        }
      },err => {
        console.log(err, 'err')
        this.modal.error('Found an error, please contract support team.', this.viewref);
      })
    }
  }
}

function IsNullOrEmpty(value: any): boolean {
  if (value === '' || value === null || typeof value === 'undefined') {
    return true;
  } else {
    return false;
  }
}

function isNumber(str: string): boolean{
  return !Number.isNaN(Number(str));
}

function isDecimal(str: string): boolean{
  if(!isNumber){
    return false;
  }

  var number = Number(str);
  if (number !== Math.floor(number)) {
    return true;
 } else {
  return false;
 }
}

function GetFYObject() {
  const fyObj: any = { FY: [], FYMonths: [] };
  const currentYear = moment().year();
  for (let _year = currentYear + 1; _year >= 2018; _year--) {
    const fy = _year.toString().substr(-2);
    fyObj.FY.push({
      fiscalYear: fy,
      fullYearNumber: _year,
      fullYearText: _year.toString(),
      CURRENT_YEAR: _year == currentYear,
    });
  }

  const _FYMonths = [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11];
  _FYMonths.forEach((item, key) => {
    const _fyMonth = new Date(1990, item, 1).toLocaleString('en-us', {
      month: 'long',
    });
    const _fyMonthShort = new Date(1990, item, 1).toLocaleString('en-us', {
      month: 'short',
    });
    const _fyMonthTH = new Date(1990, item, 1).toLocaleString('th-th', {
      month: 'long',
    });
    fyObj.FYMonths.push({
      MONTH_INDEX: key,
      MONTH: ('0' + (item + 1).toString()).substr(-2),
      MONTH_NAME: _fyMonth,
      MONTH_NAME_SHORT: _fyMonthShort,
      MONTH_NAME_TH: _fyMonthTH,
      AddYear: item < 3 ? 1 : 0,
      Month: item + 1,
      Quarter:
        item >= 3
          ? Math.ceil((item + 1) / 3) - 1
          : Math.ceil((item + 13) / 3) - 1, // Q1:3-5, Q2:6-8, Q3:9-11, Q4:0-2
      CURRENT_MONTH: item == moment().month() - 1,
    });
  });

  return fyObj;
}