import { Component, ElementRef, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { ModalService } from 'src/app/core/modal.service';

@Component({
    selector: 'SNM160',
    templateUrl: 'SNM160.component.html',
    styleUrls: ['SNM160.component.css']
})

export class SNM160Component implements OnInit {
    constructor(
        private http: HttpService,
        private router: Router,
        private global: Globals,
        private modal: ModalService,
        private viewref: ViewContainerRef
  ) { }

  @ViewChild('activityCode') activityCode: ElementRef;
  @ViewChild('enditem18') enditem18: ElementRef;
  @ViewChild('vin') vin: ElementRef;

  @ViewChild("dialogAction", { static: false }) dialogAction: any;
  @ViewChild("fileInput") fileInput: ElementRef;
  @ViewChild("dialogUpload", { static: false }) dialogUpload: any;

  public paramSearch: any = {};
  public formData: any = {};
  public tableData: Array<any> = [];

  //Upload File
  public FileName: string = "";
  private File : any;
  public tableUpload = []
  public tableUploadFilter = []
  public total_error :number = 0;
  public error_list = []
  public lookupActivityCodeConfig: any = {
    ColName: "LOOKUP_ACTIVITY_CODE",
    PlaceholderText: "Select acticity code",
    SourceController: "K9",
    SourceMethodName: "SNM160_GetActivityCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }
  public SetSelectedActivityCode(val: any) {
    if(val){
      this.paramSearch.ACTIVITY_CODE = val.ACTIVITY_CODE;
      this.paramSearch.ACTIVITY_CODE_TEMP = val.ACTIVITY_CODE;
      this.Search();
    }else{
      this.paramSearch.ACTIVITY_CODE = null;
      this.paramSearch.ACTIVITY_CODE_TEMP = this.formData.ACTIVITY_CODE;
      this.Search();
    }
  }
  public SetCancelActivityCode(val: any) {
    this.paramSearch.ACTIVITY_CODE = this.paramSearch.ACTIVITY_CODE_TEMP ? this.paramSearch.ACTIVITY_CODE_TEMP : null ;
  }
  public SetSelectedActivityCodeDialog(val: any) {
    if(val){
      this.formData.ACTIVITY_CODE = val.ACTIVITY_CODE;
      this.formData.ACTIVITY_DESC = val.ACTIVITY_DESC;
      this.formData.ACTIVITY_CODE_TEMP = val.ACTIVITY_CODE;
      this.formData.ACTIVITY_DESC_TEMP = val.ACTIVITY_DESC;
    }else{
      this.formData.ACTIVITY_CODE = null;
      this.formData.ACTIVITY_DESC = null;
      this.formData.ACTIVITY_CODE_TEMP = this.formData.ACTIVITY_CODE;
      this.formData.ACTIVITY_DESC_TEMP = this.formData.ACTIVITY_DESC;
    }
  }
  public SetCancelActivityCodeDialog(val: any) {
    this.formData.ACTIVITY_CODE = this.formData.ACTIVITY_CODE_TEMP ? this.formData.ACTIVITY_CODE_TEMP : null ;
    this.formData.ACTIVITY_DESC = this.formData.ACTIVITY_DESC_TEMP ? this.formData.ACTIVITY_DESC_TEMP : null ;
  }

  ngOnInit() {
    this.Search();
  }

  public Search() {
    const activityCode = this.global.EscapeCharacter(this.paramSearch.ACTIVITY_CODE ? this.paramSearch.ACTIVITY_CODE : "NULL");
    const enditem18 = this.global.EscapeCharacter(this.paramSearch.END_ITEM_18 ? this.paramSearch.END_ITEM_18 : "NULL");
    const vin = this.global.EscapeCharacter(this.paramSearch.VIN ? this.paramSearch.VIN : "NULL");
    this.http.get("K9", 'SNM160_GetData', activityCode, enditem18, vin)
    .subscribe(res => {
        this.tableData = res.set.Table;
    },(err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contract support team", this.viewref);
  });
  }
  
  public Add() {
    this.formData = {}
    this.formData.TYPE = "ADD";
    this.dialogAction.width = "525px" 
    this.dialogAction.height = "450px" 
    this.dialogAction.title = "Add Act Apply" 
    this.dialogAction.OpenDialog();
  }

  public Edit(data) {
    this.formData = { ...data }
    this.formData.ACTIVITY_CODE_TEMP = this.formData.ACTIVITY_CODE;
    this.formData.ACTIVITY_DESC_TEMP = this.formData.ACTIVITY_DESC;
    this.formData.TYPE = "EDIT";
    this.dialogAction.width = "525px" 
    this.dialogAction.height = "485px" 
    this.dialogAction.title = "Edit Act Apply" 
    this.dialogAction.OpenDialog();
  }

  public Delete(data) {
    this.modal.confirm("Do you want to delete record"
                        + "<br>Activity Code: "  + data.ACTIVITY_CODE
                        + "<br>End Item 18: "  + data.END_ITEM_18
                        + "<br>VIN: "  + data.VIN
                      , this.viewref
                      , () => ConfirmDelete()
                      , () => {}
                      , { height:"20rem", width:"30rem" })

    let ConfirmDelete = () => {
      const params = { 
        ID : data.ID
      }
      this.http.post("K9", "SNM160_Delete", params)
      .subscribe(res =>{
        if (res.status == 'DONE') {
          this.Search();
          this.modal.info(res.message, this.viewref);
        } else {
          this.modal.error(res.message, this.viewref);
        }
      },err =>{
        console.log(err, 'err')
        this.modal.error('Found an error, please contract support team.', this.viewref);
      })
    }
  }

  public SaveAdd(){
    if(this.ValidateNotNullField() === false){
      return;
    }
    this.modal.confirm("Do you want to save change you have made?", this.viewref, () => ConfirmAdd());

    let ConfirmAdd = () =>  {
      this.http.post("K9", 'SNM160_Insert', this.formData)
      .subscribe(res => {
        if (res.status == 'DONE') {
          this.Search();
          this.dialogAction.Close();
          this.modal.info(res.message, this.viewref, ()=>{}, { height:"20rem", width:"35rem" });
        }  
        else {
          this.modal.error(res.message, this.viewref, ()=>{}, { height:"20rem", width:"35rem" });
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewref);
      })
    }
  }

  public CancelAdd() {
    this.dialogAction.Close();
  }

  public SaveEdit() {
    if(this.ValidateNotNullField() === false){
      return;
    }
    this.modal.confirm("Do you want to save change you have made?", this.viewref, () => ConfirmEdit());

    let ConfirmEdit = () => {
      this.http.post("K9", 'SNM160_Update', this.formData)
      .subscribe(res => {
        if (res.status == 'DONE') {
          this.Search();
          this.dialogAction.Close();
          this.modal.info(res.message, this.viewref, ()=>{}, { height:"20rem", width:"35rem" });
        } else {
          this.modal.error(res.message, this.viewref, ()=>{}, { height:"20rem", width:"35rem" });
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
    }
  }

  public CancleEdit() {
    this.dialogAction.Close();
  }

  public ValidateNotNullField(): boolean{
    if(IsNullOrEmpty(this.formData.ACTIVITY_CODE)){
      this.modal.warning("Please fill Activity Code.", this.viewref,() => {this.activityCode.nativeElement.focus()});
      return false;
    }
    else if(IsNullOrEmpty(this.formData.END_ITEM_18)){
      this.modal.warning("Please fill End Item 18.", this.viewref,() => {this.enditem18.nativeElement.focus()});
      return false;
    }
    else if(IsNullOrEmpty(this.formData.VIN)){
      this.modal.warning("Please fill VIN.", this.viewref,() => {this.vin.nativeElement.focus()});
      return false;
    }
    
    return true;
  }

  public OpenReport(report: number){
    switch(report){
      case 1:
          this.global.GoToReport("PMS_RPT_PDI_SNM160_EXCEL_REPORT",
          {
            P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
            P_ACTIVITY_CODE: this.paramSearch.ACTIVITY_CODE,
          });
        break;
    }
  }

  public OpenUpload(){
    this.total_error = 0;
    this.FileName = "";
    this.error_list = [];
    this.tableUpload = [];
    this.tableUploadFilter = [];
    this.dialogUpload.width="1350px";
    this.dialogUpload.height="725px";
    this.dialogUpload.title = "Upload Activity Code";
    this.dialogUpload.OpenDialog()
  }

  public DownloadTemplate(){
    this.global.GoToExport("PMS_RPT_PDI_SNM160_UPLOAD_TEMPLATE",
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      }, true, "EXCELOPENXML")
  }
  
  public openFileBrowser() {
    this.FileName = "";
    this.fileInput.nativeElement.value = '';
    this.fileInput.nativeElement.click();
  }

  public selectFile(evt) {
    let Files: Array<File> = evt.target.files;
    if (Files.length > 0) {
      this.File = Files[0];
      this.FileName = this.File.name;
    }
  }

  public PreView() {
    if (!this.FileName) {
      this.modal.warning("Please Open File First...", this.viewref)
      return;
    }
    
    let formData = new FormData();
    formData.append('file', this.File);

    this.tableUpload = []
    this.error_list = []
    this.http.postFile("K9", "SNM160_UploadFile", formData)
      .subscribe(result => {
        this.tableUpload = result.set.Table;
        this.tableUploadFilter = this.tableUpload.filter(x => x.ERR_FLAG == 'N')
        let countrow = 0;
        this.tableUpload.map((x,i) => {
          if(x.ERR_FLAG == 'Y'){
              countrow += 1;
              this.error_list.push({
                  record : i + 1,
                  message : x.ERR_MSG
              })
          } 
          this.total_error = countrow;
      })
    }, err => {
      console.log(err, 'err')
      this.modal.error('Found an error, please contract support team.', this.viewref);
    })
  }

  public SaveUpload(){
    this.modal.confirm("Do you want to save change you have made?",this.viewref,() => ConfirmSave())

    let ConfirmSave = () => {
      const params = {}
      this.http.post("K9", "SNM160_SaveByUpload", params)
      .subscribe(res => {
        if(res.status == "DONE"){
          this.Search();
          this.dialogUpload.Close();
          this.modal.info(res.message,this.viewref);
        }else{
          this.modal.error(res.message,this.viewref)
        }
      },err => {
        console.log(err, 'err')
        this.modal.error('Found an error, please contract support team.', this.viewref);
      })
    }
  }
}

function IsNullOrEmpty(value: any): boolean {
  if (value === '' || value === null || typeof value === 'undefined') {
    return true;
  } else {
    return false;
  }
}


function isNumber(str: string): boolean{
  return !Number.isNaN(Number(str));
}

function isDecimal(str: string): boolean{
  if(!isNumber){
    return false;
  }

  var number = Number(str);
  if (number !== Math.floor(number)) {
    return true;
 } else {
  return false;
 }
}