import { Component, ElementRef, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { FormControl, Validators } from '@angular/forms';
import { ModalService } from 'src/app/core/modal.service';

@Component({
  selector: 'SNM161',
  templateUrl: './SNM161.component.html',
  styleUrls: ['./SNM161.component.css']
})



export class SNM161Component implements OnInit {


  constructor(
    private http: HttpService,
    private router: Router,
    private modal : ModalService,
    private viewref : ViewContainerRef
  ) { }

  public ConfigCustomer: any = {
    ColName: "CODE_NAME",
    ColValue: "",
    PlaceholderText: "Select Customer",
    SourceController: "wPMS",
    SourceMethodName: "GetCustomerCode",
    NoOfShowRecords: 25,
    MinLengthSearch: 1,
    UpperCase: true
  }


  public ConfigBranch: any = {
    ColName: "BRANCH_CODE",
    ColValue: "BRANCH_CODE",
    PlaceholderText: "Select Branch",
    SourceController: "K9",
    SourceMethodName: "SNM161_GetBranch",
    NoOfShowRecords: 30,
    MinLengthSearch: 0,
    UpperCase: false,
    SourceParams: {
      CUSTOMER_CODE: null
    },
  }

  public ConfigBranchAdd: any = {
    ColName: "BRANCH_CODE",
    ColValue: "BRANCH_CODE",
    PlaceholderText: "Select Branch",
    SourceController: "K9",
    SourceMethodName: "SNM161_GetBranch",
    NoOfShowRecords: 30,
    MinLengthSearch: 0,
    UpperCase: false,
    SourceParams: {
      CUSTOMER_CODE: null
    },
  }

  @ViewChild("dialog",{static: false}) dialog : any;
  public ParamSearch :any ={};
  public Params :any ={};
  public categoryList: any = [];
  public tabledata : any = [];
  public isAdd : boolean = true;
  public canEdit : boolean = false;
 

  ngOnInit() {

  }

  public Search(){
    this.tabledata = []
    this.http.post("K9","SNM161_GetData",this.ParamSearch)
    .subscribe(res =>{
      //console.log(res)
          this.tabledata = res.Table
    })

  }

  public SelectedCust(event) {
    this.ParamSearch.CUSTOMER_CODE = event.CUSTOMER_CODE
    this.ConfigBranch.SourceParams.CUSTOMER_CODE = event.CUSTOMER_CODE
  }

  public SelectedCustAdd(event) {
    this.Params.PMS_CUSTOMER_CODE = event.CUSTOMER_CODE
    this.ConfigBranchAdd.SourceParams.CUSTOMER_CODE = event.CUSTOMER_CODE
  }

  public Add(){
    this.Params = {}
    this.isAdd = true;
    this.dialog.title = "Add Customer Sap Code"
    this.dialog.OpenDialog();
  }

  public CheckSapBillTo(event){
    this.canEdit = false
    this.http.get("K9","CheckSapBillTo",event)
    .subscribe(res =>{
      if(res.Table.length == 0){
        this.Params.PMS_CUSTOMER_CODE = null
        this.Params.PMS_BRANCH_CODE = null
        this.canEdit = true
      }else{
        this.Params.PMS_CUSTOMER_CODE = res.Table[0].PMS_CUSTOMER_CODE
        this.Params.PMS_BRANCH_CODE = res.Table[0].PMS_BRANCH_CODE
      }

      
    })

    
  }

  public EditRow(data){
    this.canEdit = false;
    this.http.post("K9","SNM161_GetDataEdit",data)
    .subscribe(res =>{
      
      if(res.Table.length > 0){
        this.isAdd = false;
        this.Params = res.Table[0];
        if(this.Params.COUNT_BILL_TO == 1){
          this.canEdit = true;
        }
        this.dialog.title = "Edit Customer Sap Code"
        this.dialog.OpenDialog();
      }else{
        this.modal.warning("Customer code not found",this.viewref)
      }
    })
  }

  public Delete(data){
    this.modal.confirm("Do you want to delete racord?",this.viewref,() =>{
      this.http.post("K9","SNM161_Delete",data)
      .subscribe(res =>{
        if (res.STATUS_MSG == 'DONE') {
          this.modal.info('Transaction complete: 1 record applied and deleted.', this.viewref);
          this.Search();
          this.dialog.Close();
            
        }
        else {
            this.modal.warning('Delete fail.', this.viewref);
        }
      },err => {
        this.modal.warning('Delete fail.', this.viewref);
      })
    })
  }


  public Save(){
    this.modal.confirm("Do you want to save change you have made?",this.viewref,this.ConfirmSave)
  }

  private ConfirmSave = () =>{

    if(this.isAdd){
      this.http.post("K9","SNM161_Insert",this.Params)
      .subscribe(res => {
        if (res.STATUS_MSG == 'DONE') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          if(this.tabledata.length > 0){
            this.Search();
          }
          this.dialog.Close();                                 
        } else if (res.STATUS_MSG == 'DUPPLICATE') {
            this.modal.info('No change to save. Found duplicate record.', this.viewref);
        }
        else {
            this.modal.warning('No change to save. Add fail.', this.viewref);
        }
      },(err)=>{
        this.modal.warning('No change to save. Add fail.', this.viewref);
      })
    }else{
      this.http.post("K9","SNM161_Update",this.Params)
      .subscribe(res => {
        if (res.STATUS_MSG == 'DONE') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
          this.dialog.Close();
            
        } else {
            this.modal.warning('No change to save. Update fail.', this.viewref);
        }
      },(err)=>{
        this.modal.warning('No change to save. update fail.', this.viewref);
      })
    }

  }

  public Cancel(){
    this.dialog.Close();
  }
  
  

}
