import { Title } from '@angular/platform-browser';
import { find } from 'rxjs/operators';
import { MatSelect } from '@angular/material/select';
import { MatTabGroup } from '@angular/material/tabs';
import { Component, ElementRef, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { ModalService } from 'src/app/core/modal.service';

@Component({
    selector: 'SNM162',
    templateUrl: 'SNM162.component.html',
    styleUrls: ['SNM162.component.css']
})

export class SNM162Component implements OnInit {
    constructor(
        private http: HttpService,
        private router: Router,
        private global: Globals,
        private modal: ModalService,
        private viewref: ViewContainerRef
  ) { }

  @ViewChild("tabGroup", { static: true }) tabGroup: MatTabGroup;
  @ViewChild("searchDestination", { static: false }) searchDestination: MatSelect;
  @ViewChild("searchSpecCode", { static: false }) searchSpecCode: MatSelect;

  @ViewChild("dialogPopUp", { static: false }) dialogPopUp: any;

  public destinationOption: any = [];
  public specCodeOption: any = [];
  public specCodeOptionTemp: any = [];

  public paramSearch: any = {};
  public tableDataOptionApplied: Array<any> = [];

  public formDataVINApplied: any = {};
  public tableDataVINApplied: Array<any> = [];
  
  public formDataVINActivity: any = {};
  public tableDataVINActivity: Array<any> = [];

  public formDataBOMDetail: any = {};
  public tableDataBOMDetail: Array<any> = [];

  public formDataVehicleStatus: any = {};
  public tableDataVehicleStatus: Array<any> = [];

  public formDataPopUp: any = {};
  public tableDataPopUp: Array<any> = [];

  public lookupEndItem18Config: any = {
    ColName: "LOOKUP_END_ITEM_18",
    PlaceholderText: "Select End Item 18",
    SourceController: "K9",
    SourceMethodName: "SNM162_GetEndItem18",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public async SetSelectedEndItem18(val: any) {
    if(val){
      this.paramSearch.END_ITEM_18 = val.END_ITEM_18;
      this.paramSearch.END_ITEM_18_TEMP = val.END_ITEM_18;
      const end_item_18 = this.paramSearch.END_ITEM_18 ? this.paramSearch.END_ITEM_18 : "NULL";
      if(end_item_18 == "NULL") {
        this.paramSearch = {};
        this.destinationOption = [];
        this.specCodeOption = [];
        this.specCodeOptionTemp = [];
        await this.SearchOptionApplied();
      }else{
        await 
        this.http.get("K9", 'SNM162_GetEndItem18Sub', end_item_18)
        .subscribe(res => {
            const dataDestination = res.Table;
            const dataSpecCode = res.Table1;
            this.destinationOption = dataDestination;
            this.paramSearch.DESTINATION = dataDestination[0].DESTINATION;
            this.specCodeOptionTemp = dataSpecCode;
            this.specCodeOption = dataSpecCode.filter((item) => item.DESTINATION == this.paramSearch.DESTINATION);
            this.paramSearch.SPEC_CODE = dataSpecCode[0].SPEC_CODE;
            const dataBaseModel = res.Table2.find((item) => 
                                  item.DESTINATION == this.paramSearch.DESTINATION
                                  && item.SPEC_CODE == this.paramSearch.SPEC_CODE
                              );
            this.paramSearch.BASE_MODEL = dataBaseModel.BASE_MODEL;
            this.paramSearch.BASE_MODEL_NAME = dataBaseModel.BASE_MODEL_NAME;
            this.SearchOptionApplied();
        },(err) => {
          console.log(err, 'err')
          this.modal.warning("Found an error, please contract support team", this.viewref);
        });
      }
    }
    else{
      this.paramSearch = {};
      this.destinationOption = [];
      this.specCodeOption = [];
      this.specCodeOptionTemp = [];
    }
  }

  public async SetCancelEndItem18(val: any) {
    this.paramSearch.END_ITEM_18 = this.paramSearch.END_ITEM_18_TEMP ? this.paramSearch.END_ITEM_18_TEMP : null ;
  }

  public async SelectionDestination(event){
    this.specCodeOption = this.specCodeOptionTemp.filter((item) => item.DESTINATION == this.paramSearch.DESTINATION);
    await this.SearchOptionApplied();
  }

  public async SelectionSpecCode(event){
    await this.SearchOptionApplied();
  }

  ngOnInit() {
  }

  public async SearchOptionApplied() {
    this.tabGroup.selectedIndex = 0;
    const data = {
      END_ITEM_18: this.global.EscapeCharacter(this.paramSearch.END_ITEM_18 ? this.paramSearch.END_ITEM_18 : "NULL"),
      DESTINATION: this.global.EscapeCharacter(this.paramSearch.DESTINATION ? this.paramSearch.DESTINATION : "NULL"),
      SPEC_CODE: this.global.EscapeCharacter(this.paramSearch.SPEC_CODE ? this.paramSearch.SPEC_CODE : "NULL")
    };
    this.formDataVINApplied = {};
    this.formDataVINActivity = {};
    this.formDataBOMDetail = {};
    this.tableDataVINApplied = [];
    this.tableDataBOMDetail = [];
    await this.GetDataOptionAppiled(data);
    await this.GetDataVINActivity(data);
    await this.GetDataVehicleStatus(data);
  }

  public GetDataOptionAppiled(data: any){
    const enditem18 =  data.END_ITEM_18;
    const destination = data.DESTINATION;
    const speccode = data.SPEC_CODE;
    this.http.get("K9", 'SNM162_GetOptionApplied', enditem18, destination, speccode)
    .subscribe(res => {
        this.tableDataOptionApplied = res.set.Table;
    },(err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contract support team", this.viewref);
    });
  }

  public async ViewVINData(data: any){
    this.tabGroup.selectedIndex = 1;
    await this.GetDataVINAppiled(data);
  }

  public GetDataVINAppiled(data: any){
    this.formDataVINApplied = data;
    const optioncode = data.OPTION_CODE;
    const enditem18 = data.END_ITEM_18;
    this.http.get("K9", 'SNM162_GetVINApplied', optioncode, enditem18)
    .subscribe(res => {
        this.tableDataVINApplied = res.set.Table;
        this.formDataVINApplied.COUNT_VIN_1 = res.set.Table.length;
    },(err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contract support team", this.viewref);
    });
    
  }

  public GetDataVINActivity(data: any){
    this.formDataVINActivity = data;
    const enditem18 = data.END_ITEM_18;
    this.http.get("K9", 'SNM162_GetVINActivity', enditem18)
    .subscribe(res => {
        this.tableDataVINActivity = res.set.Table;
        this.formDataVINActivity.COUNT_VIN_2 = res.set.Table.length;
    },(err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contract support team", this.viewref);
    });
    
  }
  
  public async ViewBOMDetail(data: any){
    this.tabGroup.selectedIndex = 3;
    await this.GetDataBomDetail(data);
  }

  public GetDataBomDetail(data: any){
    this.formDataBOMDetail = data;
    const optioncode = data.OPTION_CODE;
    this.http.get("K9", 'SNM162_GetBOMDetail', optioncode)
    .subscribe(res => {
        let total_item: number = 0;
        let total_qty: number = 0;
        let total_std_amt: number = 0.00;
        let total_avg_amt: number = 0.00;
        this.tableDataBOMDetail = res.set.Table;
        this.tableDataBOMDetail.forEach((item, i) => {
          total_item += 1;
          total_qty += item.COMPONENT_QTY;
          total_std_amt += Number.parseFloat(item.STANDARD_AMOUNT);
          total_avg_amt += Number.parseFloat(item.AVERAGE_AMOUNT);
        });
        this.formDataBOMDetail.TOTAL_ITEM = total_item;
        this.formDataBOMDetail.TOTAL_QTY = total_qty;
        // this.formDataBOMDetail.TOTAL_STD_AMT = Math.round(total_std_amt).toFixed(2);
        // this.formDataBOMDetail.TOTAL_AVG_AMT = Math.round(total_avg_amt).toFixed(2);
        this.formDataBOMDetail.TOTAL_STD_AMT = Math.round((total_std_amt + Number.EPSILON) * 100) / 100;
        this.formDataBOMDetail.TOTAL_AVG_AMT = Math.round((total_avg_amt + Number.EPSILON) * 100) / 100;

    },(err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contract support team", this.viewref);
    });
    
  }

  public GetDataVehicleStatus(data: any){
    const enditem18 = data.END_ITEM_18;
    this.http.get("K9", 'SNM162_GetVehicleStatus', enditem18)
    .subscribe(res => {
      if(res.set.Table.length > 0){
        const data = res.set.Table;
        this.tableDataVehicleStatus = data
        this.formDataVehicleStatus.TOTAL_VIN = data.length;
        this.formDataVehicleStatus.TOTAL_COMPLETE = data.filter((item) => item.ACCESSORY_STATUS_CODE == "D1" || item.WHOLESALES_STATUS_CODE == "D1").length;
        this.formDataVehicleStatus.TOTAL_ERROR = data.filter((item) => item.ACCESSORY_STATUS_CODE == "E" || item.WHOLESALES_STATUS_CODE == "E").length;
        this.formDataVehicleStatus.COMPONENT_COMPLETE_VIN = data.filter((item) => item.ACCESSORY_STATUS_CODE == "D1").length;
        this.formDataVehicleStatus.COMPONENT_ERROR_VIN = data.filter((item) => item.ACCESSORY_STATUS_CODE == "E").length;
        this.formDataVehicleStatus.WHOLESALES_COMPLETE_VIN = data.filter((item) => item.WHOLESALES_STATUS_CODE == "D1").length;
        this.formDataVehicleStatus.WHOLESALES_ERROR_VIN = data.filter((item) => item.WHOLESALES_STATUS_CODE == "E").length;
      }else{
        this.formDataVehicleStatus = {};
      }
    },(err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contract support team", this.viewref);
    });
    
  }

  public async ViewVehiclePopUp(data: any, type: string){
    this.dialogPopUp.width="1350px";
    this.dialogPopUp.height="725px";
    switch(type){
      case "COMPONENT":
        this.formDataPopUp.TABLE_NAME = "SNM162_POPUP_COMPONENT";
        await this.GetDataPopUpComponent(data);
        this.dialogPopUp.title = "PMS Accessory Status";
        this.dialogPopUp.OpenDialog();
        break;
      case "WHOLESALES":
        this.formDataPopUp.TABLE_NAME = "SNM162_POPUP_WHOLESALES";
        await this.GetDataPopUpWholeSales(data);
        this.dialogPopUp.title = "PMS Wholesales Status";
        this.dialogPopUp.OpenDialog();
        break;
      case "ERROR":
        this.formDataPopUp.TABLE_NAME = "SNM162_POPUP_ERROR_LOG";
        await this.GetDataPopUpErrorLog(data);
        this.dialogPopUp.title = "Error Log";
        this.dialogPopUp.OpenDialog();
        break;
    }
  }

  public GetDataPopUpComponent(data){
    const vin = data.VIN;
    this.http.get("K9", 'SNM162_GetPopUpComponent', vin)
    .subscribe(res => {
        this.tableDataPopUp = res.set.Table;
    },(err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contract support team", this.viewref);
    });
  }

  public GetDataPopUpWholeSales(data){
    const vin = data.VIN;
    this.http.get("K9", 'SNM162_GetPopUpWholeSales', vin)
    .subscribe(res => {
        this.tableDataPopUp = res.set.Table;
    },(err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contract support team", this.viewref);
    });
  }

  public GetDataPopUpErrorLog(data){
    const vin = data.VIN;
    this.http.get("K9", 'SNM162_GetPopUpErrorLog', vin)
    .subscribe(res => {
        this.tableDataPopUp = res.set.Table;
    },(err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contract support team", this.viewref);
    });
  }

}

function IsNullOrEmpty(value: any): boolean {
  if (value === '' || value === null || typeof value === 'undefined' || value === 0) {
    return true;
  } else {
    return false;
  }
}

function isNumber(str: string): boolean{
  return !Number.isNaN(Number(str));
}

function isDecimal(str: string): boolean{
  if(!isNumber){
    return false;
  }

  var number = Number(str);
  if (number !== Math.floor(number)) {
    return true;
 } else {
  return false;
 }
}