import { Component, ElementRef, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { ModalService } from 'src/app/core/modal.service';
import { MatTabGroup } from '@angular/material/tabs';
import * as moment from 'moment';
import { SelectionModel } from '@angular/cdk/collections';

@Component({
    selector: 'SNM164',
    templateUrl: 'SNM164.component.html',
    styleUrls: ['SNM164.component.css']
})

export class SNM164Component implements OnInit {
    constructor(
        private http: HttpService,
        private router: Router,
        private global: Globals,
        private modal: ModalService,
        private viewref: ViewContainerRef
  ) { }

  public param: any = {};
  public formData: any = {
    COMPONENT_TAB: {}
  };
  public tableDataOrderTab: Array<any> = [];
  public tableDataComponentTab: Array<any> = [];
  public tableDataTransferTab: Array<any> = [];
  public listVOMStatus: any = [];
  public selection = new SelectionModel<any>(true, []);
  public isP : boolean = false;

  @ViewChild("tabGroup", { static: true }) tabGroup: MatTabGroup;

  ngOnInit() {
    //this.Search();
    this.GetDataMaster();
  }
  public GetDataMaster(){
    this.http.get("K9", 'SNM164_GetVOMStatus')
    .subscribe(res => {
        this.param.VOM_STATUS = 'P';
        this.listVOMStatus = res.set.Table;
    },(err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contract support team", this.viewref);
    });
  }
  public SelectVOMStatusOption(){
    this.Search();
  }

  public Search() {
    this.tabGroup.selectedIndex = 0;
    const param: any = this.param;
    const orderdate = this.global.EscapeCharacter(param.ORDER_DATE ? moment(param.ORDER_DATE).format("DD-MMM-YYYY") : "NULL");
    const optioncode = this.global.EscapeCharacter(param.OPTION_CODE ? param.OPTION_CODE : "NULL");
    const enditem18 = this.global.EscapeCharacter(param.END_ITEM_18 ? param.END_ITEM_18 : "NULL");
    const vin = this.global.EscapeCharacter(param.VIN ? param.VIN : "NULL");
    const pmscustomer = this.global.EscapeCharacter(param.PMS_CUSTOMER_CODE ? param.PMS_CUSTOMER_CODE : "NULL");
    const vomstatus = this.global.EscapeCharacter(param.VOM_STATUS ? param.VOM_STATUS : "NULL");
    this.http.get("K9", 'SNM164_GetOrderTabData', orderdate, optioncode, enditem18, vin, pmscustomer, vomstatus)
    .subscribe(res => {
      this.tableDataOrderTab = res.set.Table;
      this.tableDataTransferTab = res.set.Table1;
      this.formData = {
        COMPONENT_TAB: {}
      };
      this.tableDataComponentTab = [];
      this.isP = this.tableDataOrderTab.some(x => x.STATUS_CODE == 'P')
    },(err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contract support team", this.viewref);
    });
  }

  public async ViewComponentData(data: any){
    await this.GetComponentTabData(data);
    //await this.GetTransferTabData(data);
    this.tabGroup.selectedIndex = 1;
  }

  private GetComponentTabData(data): void{
    this.formData.COMPONENT_TAB = data;
    const vin = this.global.EscapeCharacter(data.VIN ? data.VIN : "NULL");
    const optioncode = this.global.EscapeCharacter(data.OPTION_CODE ? data.OPTION_CODE : "NULL");
    this.http.get("K9", 'SNM164_GetComponentTabData', vin, optioncode)
    .subscribe(res => {
        this.tableDataComponentTab = res.set.Table;
    },(err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contract support team", this.viewref);
    });
  }

  private GetTransferTabData(data): void{
    this.formData.TRANSFER_TAB = data;
    const vin = this.global.EscapeCharacter(data.VIN ? data.VIN : "NULL");
    const optioncode = this.global.EscapeCharacter(data.OPTION_CODE ? data.OPTION_CODE : "NULL");
    this.http.get("K9", 'SNM164_GetTransferData', vin, optioncode)
      .subscribe(res =>{
        this.tableDataTransferTab = res.set.Table;
          
    },(err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contract support team", this.viewref);
    });
    }

    public IssueTF(){

      if(this.selection.selected.length == 0){
        this.modal.warning("Please select data before process",this.viewref)
        return
      }
      
      this.modal.confirm("Do you want confirm process",this.viewref,()=> Confirm())
  
      let Confirm = () => {
        this.http.post("K9","SNM164_IssueTF",this.selection.selected)
        .subscribe(res =>{
          if(res.STATUS == "DONE"){
            if(res.DOC_FROM){
              this.modal.info("Process complete <br> Document No = " + res.DOC_FROM,this.viewref)
            }else{
              this.modal.info("Process complete, No document create",this.viewref)
            }
            
          }else{
            this.modal.warning("Process not complete, please contact support team",this.viewref)
          }
        },err =>{
          this.modal.warning("Process not complete, please contact support team",this.viewref)
        })
      }
  
     
    }

    isAllSelected() {
      const numSelected = this.selection.selected.length;
      const numRows = this.tableDataOrderTab.filter(x => x.STATUS_CODE == 'P').length;
      return numSelected === numRows;
    }
  
    Toggle() {
      this.isAllSelected() ?
        this.selection.clear() :
        this.tableDataOrderTab.forEach(row => {
            if(row.STATUS_CODE == 'P'){
              this.selection.select(row)
            }
          });
    }

    public Report(type: string, data: any): void{
      switch(type){
        case "BO":
            this.global.GoToReport("PMS_RPT_PDI_SNM164_BO_EXCEL",
            {
              P_ORDER_DATE: this.global.EscapeCharacter(this.param.ORDER_DATE ? moment(this.param.ORDER_DATE).format("DD-MMM-YYYY") : "NULL"),
              P_OPTION_CODE: this.global.EscapeCharacter(this.param.OPTION_CODE ? this.param.OPTION_CODE : "NULL"),
              P_END_ITEM_18: this.global.EscapeCharacter(this.param.END_ITEM_18 ? this.param.END_ITEM_18 : "NULL"),
              P_VIN: this.global.EscapeCharacter(this.param.VIN ? this.param.VIN : "NULL"),
              P_PMS_CUSTOMER_CODE: this.global.EscapeCharacter(this.param.PMS_CUSTOMER_CODE ? this.param.PMS_CUSTOMER_CODE : "NULL"),
              P_VOM_STATUS: this.global.EscapeCharacter(this.param.VOM_STATUS ? this.param.VOM_STATUS : "NULL"),
            });
          break;
        case "TF_MEMO":
            this.global.GoToReport("PMS_RPT_PDI_SNM164_TF_MEMO",
            {
              P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
              P_DOCUMENT_DATE: data.DOCUMENT_DATE,
              P_DOCUMENT_NO: data.DOCUMENT_NO,
            });
          break;
      }
    }
   
}