import { Component, ElementRef, Input, OnChanges, OnInit, SimpleChanges, ViewChild, ViewContainerRef } from '@angular/core';
import { DialogTemplateComponent } from 'src/app/components/shared/dialog-template/dialog-template.component';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from 'src/app/core/global';
import { SelectionModel } from '@angular/cdk/collections';


@Component({
    selector: 'SNPE051_DISASSEMBLE',
    templateUrl: 'SNPE051_DISASSEMBLE.component.html',
    styleUrls: ['../SNPE051.component.css', '../../k9.component.css']
})

export class SNPE051DisAssembleComponent implements OnChanges {
    constructor(
        private http: HttpService,
        private modal: ModalService,
        private viewref: ViewContainerRef,
        private global: Globals) { }

     public ConfigPart: any = {
        ColName: "LOOKUP_PART",
        PlaceholderText: "Select Part No.",
        SourceController: "AC",
        SourceMethodName: "SNPE051_GetPart",
        MinLengthSearch: 3,
        NoOfShowRecords: 30
      }

    public paramsSearch : any = {};
    public tableData : any =[];
    public data : any ={};
    public showSearch : boolean = true;
    public isSave : boolean = false;
    public tableDetail : any = []
    public selection = new SelectionModel<any>(true, []);
    @Input("tabChange") tabChange: string = '';
    @ViewChild("dialog") dialog: DialogTemplateComponent;


   
    ngOnChanges(changes: SimpleChanges): void {
        if(this.tableData.length > 0){
            this.tableData = []
        }
        
    }
    ngOnInit(){

    }

    public Search(){
        this.http.post("K9","SNPE051_GetDataDisassemble",this.paramsSearch)
        .subscribe(res =>{
            console.log(res)
            this.tableData = res.Table
        })
    }

    public Save(){

       if(this.selection.isEmpty()){
        this.modal.warning("Please select data",this.viewref);
        return
       }

       this.modal.confirm("Do you want to start process",this.viewref,() => Confirm())

        let Confirm = () => {
            this.http.post("K9","SNPE051_ProcessDisAssemble",this.selection.selected)
            .subscribe(res => {
                if(res.STATUS == "DONE"){
                    this.modal.info("Process complete",this.viewref);
                    this.selection.clear()
                    this.Search();
                  }else{
                    this.modal.error("Found error please contact support team",this.viewref);
                  }
            },err=>{
                this.modal.error("Found error please contact support team",this.viewref);
            })
        }
    }

    public isAllSelected() {
      const numSelected = this.selection.selected.length;
      const numRows = this.tableData.length;
      return numSelected === numRows;
    }
  
    public Toggle() {
      this.isAllSelected() ?
        this.selection.clear() :
        this.tableData.forEach(row => this.selection.select(row));
    }

}