import { Component, Input, OnChanges, OnInit, SimpleChanges, ViewChild, ViewContainerRef } from '@angular/core';
import { DialogTemplateComponent } from 'src/app/components/shared/dialog-template/dialog-template.component';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from 'src/app/core/global';
import * as moment from 'moment';


@Component({
    selector: 'SNPE051_RECEIVE',
    templateUrl: 'SNPE051_RECEIVE.component.html',
    styleUrls: ['../SNPE051.component.css', '../../k9.component.css']
})

export class SNPE051ReceiveComponent implements OnChanges {
    constructor(
        private http: HttpService,
        private modal: ModalService,
        private viewref: ViewContainerRef,
        private global: Globals) { }

    public ConfigDoc: any = {
        ColName: "DOCUMENT_NO",
        ColValue: "",
        PlaceholderText: "Select Document",
        SourceController: "K9",
        SourceMethodName: "SNPE035_M_GetDoc",
        NoOfShowRecords: 30,
        MinLengthSearch: 5,
        UpperCase: true
    }

    public paramsSearch : any = {};
    public tableData : any =[];
    public data : any ={};
    public showSearch : boolean = true;
    public isSave : boolean = false;
    public tableDetail : any = []
    @Input("tabChange") tabChange: string = '';
    @ViewChild("dialog") dialog: DialogTemplateComponent;
   
    ngOnChanges(changes: SimpleChanges): void {
        if(this.tableData.length > 0){
            this.tableData = []
        }
        
    }
    ngOnInit(){
        this.paramsSearch.DATE_FROM = moment().subtract(1,"days");
        this.paramsSearch.DATE_TO = moment();
    }

    public Search(){
        this.http.post("K9","SNPE051_GetDataForReceive",this.paramsSearch)
        .subscribe(res =>{
            console.log(res)
            this.tableData = res.Table
        })
    }

    public Save(){
        this.modal.confirm("Do you want to save document",this.viewref,()=>Confirm())

        let Confirm = () => {
            this.http.post("K9","SNPE051_ConfirmReceive",this.data)
            .subscribe(res => {
                if(res.STATUS == "DONE"){
                    this.modal.info("Save document successfully",this.viewref);
                    let findData = this.tableData.find(x => x.DOCUMENT_NO = this.data.DOCUMENT_NO)
                    findData.IS_SAVE = 'Y'
                    this.isSave = true
                  }else{
                    this.modal.error("Found error please contact support team",this.viewref);
                  }
            },err=>{
                this.modal.error("Found error please contact support team",this.viewref);
            })
        }
    }

    public BackToGrid(){
        this.showSearch = true;
    }

    public ShowDetail(event){
        this.http.post("K9","SNPE051_GetDetailReceive",event)
        .subscribe(res =>{
            this.data = event;
            this.tableDetail = res.Table
            this.showSearch = false;
            this.isSave = false;
        })
    }

}