import { Component, ElementRef, OnInit, ViewChild, ViewContainerRef } from "@angular/core";
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';
import { ActivatedRoute } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { SelectionModel } from "@angular/cdk/collections";
import * as moment from "moment";
import { DateAdapter, MAT_DATE_FORMATS, MAT_DATE_LOCALE } from "@angular/material/core";
import { MAT_MOMENT_DATE_ADAPTER_OPTIONS, MomentDateAdapter } from "@angular/material-moment-adapter";

export const MY_FORMATS = {
  parse: {
    dateInput: ['MM-YYYY', 'MM/YYYY', 'MMYYYY', 'MMM-YY', 'MMM-YYYY'],
  },
  display: {
    dateInput: 'MMM-YYYY',
    monthYearLabel: 'MMM YYYY',
    dateA11yLabel: 'LL',
    monthYearA11yLabel: 'MMMM YYYY',
  },
};


@Component({
  selector: 'snpp205',
  templateUrl: './snpp205.component.html',
  styleUrls: ['./snpp205.component.css'],
  providers: [
    {
      provide: DateAdapter,
      useClass: MomentDateAdapter,
      deps: [MAT_DATE_LOCALE, MAT_MOMENT_DATE_ADAPTER_OPTIONS],
    },

    { provide: MAT_DATE_FORMATS, useValue: MY_FORMATS },
  ],
})
export class SNPP205Component implements OnInit {

  constructor(
    private http: HttpService,
    public modal: ModalService,
    public viewref: ViewContainerRef,
    private route: ActivatedRoute,
    private global: Globals
  ) {}

  public LookupVendorConfig: any = {
    ColName: "LOOKUP_VENDOR_NAME",
    PlaceholderText: "Select Vendor Code",
    SourceController: "wPMS",
    SourceMethodName: "GetVendorCode",
    NoOfShowRecords: 50,
    UpperCase: true
  }
  public param : any = {}
  public tableData: any = [];
  public tableDataStock: any = [];
  public tablePO: any = [];
  public selection = new SelectionModel<any>(true, []);
  @ViewChild("dialogView",{static: false}) dialogView : any;
  @ViewChild("fileInput") fileInput: ElementRef;
  @ViewChild("dialogUpload", { static: false }) dialogUpload: any;
  @ViewChild("dialogPO",{static: false}) dialogPO : any;

  public tableDataUpload: any = [];
  public correctData: any = [];
  private file: any;
  public fileNameInput: string = "";
  ngOnInit() {
    this.param.FROM_DATE = moment().subtract(1,'month');
    this.param.TO_DATE = moment();
    this.param.PIC = this.global.GetTokenDetail("ssUserName");
    //this.Search();
   }

  

  public Search(){
    this.http.post("K9","SNPP205_GetData",this.param)
    .subscribe(res => {
      this.tableData = res.Table;
      console.log(this.tableData)
    })


  }

  public Save(){
    
    if(this.selection.isEmpty()){
      this.modal.warning("Please select some PO befire confirm",this.viewref)
      return
    }

    let find = this.selection.selected.some(x => x.ACCEPT_QTY < 1)
    if(find){
      this.modal.warning("Accept Qty must more than 0",this.viewref)
      return;
    }

    let findRemark = this.selection.selected.some(x => x.ACCEPT_QTY != x.ORDER_QTY && !x.REMARKS)
    if(findRemark){
      this.modal.warning("In case of edit accpet qty. Pleas input remarks",this.viewref)
      return;
    }

    this.modal.confirm("Do you want to create new PO",this.viewref,() => ConfirmSave())

    let ConfirmSave = () =>{
      this.http.post("K9","SNPP205_CreatePO",this.selection.selected)
      .subscribe(res =>{
        if(res.STATUS == "DONE"){
          
          this.modal.info("Create new PO complete <br> PO No = " + res.FROM_PO + " - " + res.TO_PO,this.viewref,this.GetDataPO);
          this.selection.clear()
          this.Search();
          this.param.CREATE_ID = res.CREATE_ID
          

        }else{
          this.modal.error("Found error please contact support team",this.viewref);
        }
      }, err =>{
        this.modal.error("Found error please contact support team",this.viewref);
      })
    }
  }

  public GetDataPO = () => {
    
    this.http.post("K9","SNPP205_GetDataPO",this.param)
    .subscribe(res => {
      this.tablePO = res.Table;
      this.param.CREATE_ID =  null;
      this.dialogPO.OpenDialog();
    })
  }

  public DownloadPO(){
    this.http.Download("K9","SNPP205_DownloadPO",{Table : this.tablePO})
    .subscribe(res => {
      this.WriteContents(res,"SNPP205_PO_DATA");
      this.dialogPO.Close();
    })
  }

  public DownLoad(){
    if(this.tableData.length == 0){
      return false;
    }
    this.http.Download("K9","SNPP205_DownloadRaw",{Table : this.tableData})
    .subscribe(res => {
      this.WriteContents(res,"SNPP205_RAW_DATA");
    })
  }

  private WriteContents(content,filename) {
    const a = document.createElement('a');
    const file = new Blob([content], { type: content.type });
    a.href = URL.createObjectURL(file);
    a.download = filename + ".xlsx";
    a.click();
    //this.modal.info("Generate data complete",this.viewref)
  }

  public StockInfo(){
    this.http.get("K9","SNPP205_GetStockInfo")
    .subscribe(res =>{
      this.tableDataStock = res.Table
      this.dialogView.OpenDialog();
    })
  }

  public SelectVendor(event) {
    this.param.VENDOR_NAME = event.LOOKUP_VENDOR_NAME;
    this.param.VENDOR_CODE = event.VENDOR_CODE;
  }

  public isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.tableData.length;
    return numSelected === numRows;
  }

  public SelectMonthAndYearFrom(event: any, datepicker: any) {
    this.param.FROM_DATE = event;
    datepicker.close();

  }

  public SelectMonthAndYearTo(event: any, datepicker: any) {
    this.param.TO_DATE = event;
    datepicker.close();

  }


  public Toggle() {
    this.isAllSelected() ?
      this.selection.clear() :
      this.tableData.forEach(row =>this.selection.select(row));
  }

  public OpendialogUpload() {
    this.dialogUpload.OpenDialog();
    this.fileNameInput = "";
    //this.fileInput.nativeElement.value = '';
    this.tableDataUpload = []
    this.correctData = []
  }

  public OpenFileBrowser() {
    this.fileNameInput = "";
    this.fileInput.nativeElement.value = '';
    this.fileInput.nativeElement.click();
  }
  public SelectFile(evt) {
    let Files: Array<File> = evt.target.files;
    if (Files.length > 0) {
      //let File: File = Files[0];
      this.file = Files[0];
      this.fileNameInput = this.file.name;
    }
  }

  public PreView() {
    if (!this.fileInput) {
      this.modal.warning("Please Open File First...", this.viewref)
      return;
    }
    let formData = new FormData();
    formData.append('file', this.file);
    this.tableDataUpload = []

    this.http.postFile("K9", "SNPP205_UploadFile", formData)
    .subscribe(result => {
      this.tableDataUpload = result.Table;
    }, err => {
      this.modal.error('Found an error, please contract support team.', this.viewref);
    })
    
  }
  
  public ConfirmProcess(){

    this.modal.confirm("Do you want to start process",this.viewref,() => Confirm())

    let Confirm = () => {
      this.http.get("K9","SNPP205_Process")
      .subscribe(res =>{
        if(res == "DONE"){
          this.modal.info("Process complete",this.viewref);
        }else{
          this.modal.warning("Process not complete, please contact support team",this.viewref)
        }
      },err =>{
        this.modal.warning("Process not complete, please contact support team",this.viewref)
      })
    }
   
  }
}
