import { Component, ElementRef, OnInit, ViewChild, ViewContainerRef } from "@angular/core";
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';
import { ActivatedRoute } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { SelectionModel } from "@angular/cdk/collections";

@Component({
  selector: 'SNPP209',
  templateUrl: './SNPP209.component.html',
  styleUrls: ['./SNPP209.component.css']
})
export class SNPP209Component implements OnInit {

  constructor(
    private http: HttpService,
    public modal: ModalService,
    public viewref: ViewContainerRef,
    private route: ActivatedRoute,
    private global: Globals
  ) {}


  public ConfigVin: any = {
    ColName: "VIN",
    ColValue: "VIN",
    PlaceholderText: "Select Vin.",
    SourceController: "K9",
    SourceMethodName: "SNPP209_GetVin",
    NoOfShowRecords: 60,
    MinLengthSearch: 4
  }

  public ConfigEndItem: any = {
    ColName: "END_ITEM_18",
    ColValue: "END_ITEM_18",
    PlaceholderText: "Select End ITem 18",
    SourceController: "K9",
    SourceMethodName: "SNPP209_GetEndItem18",
    NoOfShowRecords: 60,
    MinLengthSearch: 3,
  }

  public paramSearch : any = {}
  public param : any = {}
  public tableData: any = [];
  public selection = new SelectionModel<any>(true, []);

  ngOnInit(): void {
   
  }

  public Search(){
   
    this.http.post("K9","SNPP209_GetData",this.paramSearch)
    .subscribe(res => {
      console.log(res)
      this.selection.clear()
      this.tableData = res.Table
    })
    
  }

  public SelectedEndItem(event){
    this.paramSearch.END_ITEM_18 = event
  }


  public Save(){
    
    this.modal.confirm("Do you want to Confirm Process",this.viewref,() => ConfirmSave())

    let ConfirmSave = () =>{
      this.http.post("K9","SNPP209_Process",this.selection.selected)
      .subscribe(res =>{
        if(res.STATUS == "DONE"){
          this.modal.info("Process complete",this.viewref);
          this.tableData = []
          this.selection.clear();
          this.Search();
        }else{
          this.modal.error("Found error please contact support team",this.viewref);
        }
      }, err =>{
        this.modal.error("Found error please contact support team",this.viewref);
      })
    }
  }

  public isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.tableData.length;
    return numSelected === numRows;
  }

  public Toggle() {
    this.isAllSelected() ?
      this.selection.clear() :
      this.tableData.forEach(row => this.selection.select(row));
  }
}
