import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';

@Component({
  selector: 'SKCUMUSER_HH',
  templateUrl: 'SKCUMUSER_HH.component.html',
  styleUrls: ['SKCUMUSER_HH.component.css']
})

export class SKCUMUSER_HHComponent implements OnInit {
  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef,
  ) { }

  @ViewChild("dialogAdd", { static: false }) dialogAdd: any;
  @ViewChild("dialogEdit", { static: false }) dialogEdit: any;

  public params: any = {};
  public tableData: any = [];

  public data: any = {};
  public dataRef: any = {};
  public showpwd: boolean = false;
  public dialog: any = "";

  public lookupUserIDConfig: any = {
    ColName: "LOOKUP_USER_ID",
    PlaceholderText: "Select User ID",
    SourceController: "System",
    SourceMethodName: "SKCUMUSER_HH_GetUserID",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: false
  }

  public SetSelectedUserID(value: any) {
    this.params.SK_USER_ID = value.SK_USER_ID;
    this.params.ENAME = value.ENAME;
    this.params.TNAME = value.TNAME;
    this.Search();
  }

  public dialogLookupSystemIDConfig: any = {
    ColName: "LOOKUP_SYSTEM_ID",
    PlaceholderText: "Select System ID",
    SourceController: "System",
    SourceMethodName: "SKCUMUSER_HH_GetSystemID",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedDialogSystemID(value: any) {
    if (value) {
      this.data.SK_SYSTEM_ID = value.SK_SYSTEM_ID;
      this.data.SYSTEM_DESC = value.ENAME;
    } else {
      this.data.SK_SYSTEM_ID = null;
      this.data.SYSTEM_DESC = null;
    }
  }

  public dialogLookupGroupIDConfig: any = {
    ColName: "LOOKUP_GRP_USER_ID",
    PlaceholderText: "Select Group User ID",
    SourceController: "System",
    SourceMethodName: "SKCUMUSER_HH_GetUserGroup",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedDialogGroupID(value: any) {
    if (value) {
      this.data.SK_GRP_USER_ID = value.SK_GRP_USER_ID;
      this.data.GROUP_DESC = value.GROUP_NAME;
    } else {
      this.data.SK_GRP_USER_ID = null;
      this.data.GROUP_DESC = null;
    }
  }

  ngOnInit() {
    this.Search()
  }

  public Search() {
    this.http.post('System', 'SKCUMUSER_HH_GetData', this.params)
      .subscribe(res => {
        this.tableData = res.Table;
      })
  }

  public EditClick(row) {
    this.dialog = 'edit'
    this.data = JSON.parse(JSON.stringify(row));
    this.dataRef = JSON.parse(JSON.stringify(row));
    this.dialogEdit.OpenDialog();
  }

  public ConfirmSaveEdit() {
    let notchange = (JSON.stringify(this.data) == JSON.stringify(this.dataRef))
    if (notchange) {
      this.modal.warning('There is no data change.', this.viewref)
    }
    else {
      if (this.data.LIMIT_FLAG == 'T' && (!this.data.ST_DATE || !this.data.EX_DATE)) {
        this.modal.warning('Please set start date and expire date!!', this.viewref)
        return
      }
      if (!this.data.SK_USER_ID || !this.data.SK_SYSTEM_ID || !this.data.SK_GRP_USER_ID) {
        this.modal.warning("Please fill all required(*) fields.", this.viewref);
        return
      }
      this.modal.confirm('Do you want to save changed you have made?', this.viewref, this.Save)
    }
  }

  Save = () => {
    if(this.data.ENAME){
      var nameEN = this.data.ENAME.split(" ", 2);
      this.data.FIRST_NAME_EN = nameEN[0];
      this.data.LAST_NAME_EN = nameEN[1];
    }
    if(this.data.TNAME){
      var nameTH = this.data.TNAME.split(" ", 2);
      this.data.FIRST_NAME_TH = nameTH[0];
      this.data.LAST_NAME_TH = nameTH[1];
    }

    this.http.post('System', 'SKCUMUSER_HH_Save', this.data)
      .subscribe(res => {
        if (res.STATUS == 'DONE') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          if (this.dialog == 'edit') {
            this.dialogEdit.Close();
          } else {
            this.dialogAdd.Close();
          }
          this.Search();
        }
        else {
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contract support team", this.viewref);
      })
  }

  public CloseDialogEdit() {
    this.dialogEdit.Close();
  }

  public ResetFailure() {
    this.data.LOGIN_FAILURE = 0;
  }

  public CheckHistory(event) {
    if (event.checked) {
      this.data.HISTORY = 'Y'
    } else {
      this.data.HISTORY = 'N'
    }
  }

  public ChangeToggle(event) {
    if (event.checked) {
      this.data.SET_TOGGLE = 'Y'
    } else {
      this.data.SET_TOGGLE = 'N'
    }
  }

  public CreateClick() {
    this.dialog = 'add'
    this.data = {};
    this.dataRef = {};
    this.data.ACTIVE = 'Y';
    this.data.LANGUAGE = 'E';
    this.data.LIMIT_FLAG = 'P';
    this.data.TITLE = '1';
    this.data.SET_TOGGLE = 'Y';
    this.data.HISTORY = 'Y';
    this.dialogAdd.OpenDialog();
  }

  public CloseDialogAdd() {
    this.dialogAdd.Close();
  }
  
  public CheckDupUser() {
    this.http.post('System', 'SKCUMUSER_HH_CheckUser', this.data)
      .subscribe(res => {
        console.log(res)
        if (res.Table.length > 0) {
          this.modal.warning("This user is duplicated!", this.viewref);
          this.data.SK_USER_ID = null;
        }
      })
  }
}
