import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from '../../../core/modal.service';

@Component({
  selector: 'skcumuser_m',
  templateUrl: './SKCUMUSER_M.component.html',
  styleUrls: ['./SKCUMUSER_M.component.css']
})

export class SKCUMUSER_MComponent implements OnInit {

  public params: any = {};
  public tableData: any = [];

  public Data: any = {};
  public DataRef: any = {};
  public showpwd: boolean = false;
  public dialog: any = null;

  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef,
  ) { }

  @ViewChild("dialogAdd", { static: false }) dialogAdd: any;
  @ViewChild("dialogEdit", { static: false }) dialogEdit: any;

  public LookupUserIDConfig: any = {
    ColName: "LOOKUP_USER_ID",
    PlaceholderText: "Select User ID",
    SourceController: "System",
    SourceMethodName: "SKCUMUSER_GetUserID",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: false
  }

  public SetSelectedUserID(value: any) {
    this.params.SK_USER_ID = value.SK_USER_ID;
    this.params.ENAME = value.ENAME;
    this.params.TNAME = value.TNAME;
    this.Search();
  }

  public dialogLookupSystemIDConfig: any = {
    ColName: "LOOKUP_SYSTEM_ID",
    PlaceholderText: "Select System ID",
    SourceController: "System",
    SourceMethodName: "SKCUMUSER_GetSystemID",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedDialogSystemID(value: any) {
    if (value) {
      this.Data.SK_SYSTEM_ID = value.SK_SYSTEM_ID;
      this.Data.SYSTEM_DESC = value.ENAME;
    } else {
      this.Data.SK_SYSTEM_ID = null;
      this.Data.SYSTEM_DESC = null;
    }
  }

  public dialogLookupGroupIDConfig: any = {
    ColName: "LOOKUP_GRP_USER_ID",
    PlaceholderText: "Select Group User ID",
    SourceController: "System",
    SourceMethodName: "SKCUMUSER_GetUserGroup",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedDialogGroupID(value: any) {
    if (value) {
      this.Data.SK_GRP_USER_ID = value.SK_GRP_USER_ID;
      this.Data.GROUP_DESC = value.GROUP_NAME;
    } else {
      this.Data.SK_GRP_USER_ID = null;
      this.Data.GROUP_DESC = null;
    }
  }

  ngOnInit() {
    this.Search()
  }

  public Search() {
    this.http.post('System', 'SKCUMUSER_GetData', this.params)
      .subscribe(res => {
        this.tableData = res.Table;
      })
  }

  public EditClick(row) {
    this.Data = JSON.parse(JSON.stringify(row));
    this.DataRef = JSON.parse(JSON.stringify(row));
    this.dialogEdit.OpenDialog();
    this.dialog = 'edit'
  }

  public ConfirmSaveEdit() {
    let notchange = (JSON.stringify(this.Data) == JSON.stringify(this.DataRef))
    if (notchange) {
      this.modal.warning('There is no data change.', this.viewref)
    }
    else {
      if (this.Data.LIMIT_FLAG == 'T' && (!this.Data.ST_DATE || !this.Data.EX_DATE)) {
        this.modal.warning('Please set start date and expire date!!', this.viewref)
        return
      }
      if (!this.Data.SK_USER_ID || !this.Data.SK_SYSTEM_ID || !this.Data.SK_GRP_USER_ID) {
        this.modal.warning("Please fill all required(*) fields.", this.viewref);
        return
      }
      this.modal.confirm('Do you want to save changed you have made?', this.viewref, this.Save)
    }
  }

  Save = () => {
    var nameEN = this.Data.ENAME.split(" ", 2);
    var nameTH = this.Data.TNAME.split(" ", 2);
    this.Data.FIRST_NAME_EN = nameEN[0];
    this.Data.LAST_NAME_EN = nameEN[1];
    this.Data.FIRST_NAME_TH = nameTH[0];
    this.Data.LAST_NAME_TH = nameTH[1];
    this.http.post('System', 'SKCUMUSER_Save', this.Data)
      .subscribe(res => {
        if (res.STATUS == 'DONE') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          if (this.dialog == 'edit') {
            this.dialogEdit.Close();
          } else {
            this.dialogAdd.Close();
          }
          this.Search();
        }
        else {
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contract support team", this.viewref);
      })
  }

  public CloseDialogEdit() {
    this.dialogEdit.Close();
  }

  public ResetFailure() {
    this.Data.LOGIN_FAILURE = 0;
  }

  public CheckHistory(event) {
    if (event.checked) {
      this.Data.HISTORY = 'Y'
    } else {
      this.Data.HISTORY = 'N'
    }
  }

  public ChangeToggle(event) {
    if (event.checked) {
      this.Data.SET_TOGGLE = 'Y'
    } else {
      this.Data.SET_TOGGLE = 'N'
    }
  }

  public CreateClick() {
    this.Data = {};
    this.DataRef = {};

    this.Data.ACTIVE = 'Y';
    this.Data.LANGUAGE = 'E';
    this.Data.LIMIT_FLAG = 'P';
    this.Data.TITLE = '1';
    this.Data.SET_TOGGLE = 'Y';
    this.Data.HISTORY = 'Y';

    this.dialogAdd.OpenDialog();
    this.dialog = 'add'
  }

  public CloseDialogAdd() {
    this.dialogAdd.Close();
  }
  public CheckDupUser() {
    this.http.post('System', 'SKCUMUSER_CheckUser', this.Data)
      .subscribe(res => {
        console.log(res)
        if (res.Table.length > 0) {
          this.modal.warning("This user is duplicated!", this.viewref);
          this.Data.SK_USER_ID = null;
        }
      })
  }
}
