import { Component, OnInit } from '@angular/core';
import { Title } from '@angular/platform-browser';
import * as moment from 'moment';
import { HttpService } from 'src/app/core/http.service';

@Component({
  selector: 'batch',
  templateUrl: './batch.component.html',
  styleUrls: ['./batch.component.scss']
})
export class BatchComponent implements OnInit {
  constructor(private http: HttpService) { }

  public currentDate: moment.Moment;
  public batchList: any[];
  public displayedColumns: string[] = ['BATCH_ID', 'JOB_ID', 'JOB_NAME', 'PROCESS_CODE', 'JOB_STATUS', 'START_STATUS', 'END_STATUS'];

  ngOnInit(): void {
    this.GetCurrentSystemDate()
    this.GetBatchStatus()
  }

  private GetCurrentSystemDate() {
    this.http.GetSystemDate()
      .subscribe(res => {
        this.currentDate = res
      })
  }

  private GetBatchStatus() {
    this.batchList = [];
    this.http.get("System", "GetBatchStatus")
      .subscribe(res => {
        this.batchList = res.Table || [];
      })
  }

  public CheckDateControl(): boolean {
    const curDate: string = moment().format('YYYYMMDD');
    const sysDate: string = moment(this.currentDate).format('YYYYMMDD');

    return curDate === sysDate
  }

  public CheckStartDone(elem: any): boolean {
    const curDate: string = moment().format('YYYYMMDD');
    const elemDate: string = moment(elem.START_DATE).format('YYYYMMDD');
    
    return elem.START_STATUS === 'Y' && curDate === elemDate;
  }

  public CheckEndDone(elem: any): boolean {
    const curDate: string = moment().format('YYYYMMDD');
    const elemDate: string = moment(elem.END_DATE).format('YYYYMMDD');

    return elem.END_STATUS === 'Y' && curDate === elemDate;
  }
}
