import { Component, OnInit, ViewChild, ViewContainerRef } from "@angular/core";
import { HttpService } from 'src/app/core/http.service';
import { MatDialog } from '@angular/material/dialog';
import { DialogComponent } from '../../../components/shared/dialog/dialog.component';
import { ModalService } from '../../../core/modal.service';
import * as cloneDeep from 'lodash/cloneDeep';
import { Globals } from 'src/app/core/global';
import { ActivatedRoute } from '@angular/router';

@Component({
  selector: 'snm083',
  templateUrl: './snm083.component.html',
  styleUrls: ['./snm083.component.css']
})

export class SNM083Component implements OnInit {

  constructor(
    private http: HttpService,
    public dialog: MatDialog,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private global: Globals,
    private route: ActivatedRoute
  ) {
  }

  @ViewChild("dialogEdit") dialogEdit: any
  @ViewChild("dialogAdd") dialogAdd: any
  public dataList: any = [];
  public tariffList: any = [];
  public MTtariffList: any = [];
  public formData: any = { PART_NO: '' };
  public index: any;
  public DutyLate: any;
  public data: any = {};
  public UpdateBy: string;
  public UpdateDate: any;
  public dataDetail: any;
  public PART_NO: any;

  //  public lookupConfigTariff: any = {
  //      ColName: "TARIFF_TEXT",
  //      ColValue: "TARIFF_CODE",
  //      PlaceholderText: "Select Tariff Code",
  //      SourceController: "IC",
  //      SourceMethodName: "SNM042P_GetTariffCode",
  //      NoOfShowRecords: 50,
  //      MinLengthSearch: 2
  //}

  public lookupConfig: any = {
    ColName: "LOOKUP_PART_VALUE",
    PlaceholderText: "Select Part",
    SourceController: "IC",
    SourceMethodName: "SNSQ005_GetPart",
    NoOfShowRecords: 50,
    UpperCase: true
  }

  ngOnInit() {
    this.GetData();
  }


  public SetSelectedPart(value: any) {
    this.data.PART_NO = value.PART_NO;
    this.data.PART_NAME_EN = value.PART_NAME_EN;
    this.data.PART_NAME_TH = value.PART_NAME_TH;
  }


  private GetData() {
    this.dataList = [];
    this.http.post("wPMS", "SNM083_GetExcise", JSON.stringify(this.formData))
      .subscribe((result: any) => {
        this.dataList = result.Table;
      })
  }

  keyDownFunction(event) {
    if (event.keyCode == 13) {
      this.GetData();
    }
  }

  SetTariffLookup(v) {
    this.formData.TariffCode = v;
  }

  public AddData() {
    this.data = {};
    this.dialogAdd.OpenDialog();
  }

  public SaveDataAdd() {

    if (this.data.PART_NO == '' || this.data.PART_NO == undefined) {
      this.modal.warning("Please input the Part no.", this.viewref);
      return false;
    }

    if (this.data.CALCULATE_TYPE == '' || this.data.CALCULATE_TYPE == undefined) {
      this.modal.warning("Please input the Calcualte type", this.viewref);
      return false;
    }

    if (this.data.CALCULATE_TYPE == 'Retail Price' && (this.data.EXCISE_RATE == '' || this.data.EXCISE_RATE == undefined)) {
      this.modal.warning("Please input the Excise rate", this.viewref);
      return false;
    }

    if (this.data.CALCULATE_TYPE == 'Capacity' && (this.data.CAPACITY == '' || this.data.CAPACITY == undefined)) {
      this.modal.warning("Please input the Capacity", this.viewref);
      return false;
    }

    if (this.data.CALCULATE_TYPE == 'Capacity' && (this.data.CAPACITY_RATE == '' || this.data.CAPACITY_RATE == undefined)) {
      this.modal.warning("Please input the Capacity rate", this.viewref);
      return;
    }

    if (this.data.CALCULATE_TYPE == 'Capacity' && (this.data.UNIT_TYPE == '' || this.data.UNIT_TYPE == undefined)) {
      this.modal.warning("Please input the Unit type", this.viewref);
      return;
    }

    if ((this.data.CAPACITY == '' || this.data.CAPACITY == undefined)) {
      this.data.CAPACITY = 0;
    }

    if (this.data.EFFECTIVE_DATE == '' || this.data.EFFECTIVE_DATE == undefined) {
      console.log('this.data.EFFECTIVE_DATE :', this.data.EFFECTIVE_DATE);
      this.modal.warning("Please input the Effective date", this.viewref);
      return false;
    }


    if (this.data.DISABLED_DATE == '' || this.data.DISABLED_DATE == undefined) {
      this.modal.warning("Please input the Expire date", this.viewref);
      return false;
    }

    if (this.data.EFFECTIVE_DATE > this.data.DISABLED_DATE) {
      this.modal.warning("Please select the Effective date less than the Expire date", this.viewref);
      return false;
    }

    this.http.post("wPMS", "SNM083_ValidateAddExcise", this.data)
      .subscribe((result: any) => {
        if (result != undefined) {
          if (result.Table.length != 0) {
            this.modal.warning("This part no has overlap the Effect date and Expire date", this.viewref);
            return false;
          } else {
            this.modal.confirm("Do you want to save change you have made?", this.viewref,
              () => {

                this.http.post('wPMS', 'SNM083_AddExcise', this.data)
                  .subscribe(res => {
                    if (res === "DONE") {
                      this.modal.info('Transaction complete: applied and saved.', this.viewref)
                      this.GetData();
                      this.dialogAdd.Close();
                    } else {
                      console.log(res, 'err')
                      this.modal.warning("Found an error, please contract support team", this.viewref);
                    }
                  }, (err) => {
                    console.log(err, 'err')
                  })

              }, () => { })
          }

        } else {
          this.modal.warning("Found an error, please contract support team", this.viewref);
          return false;
        }

      })


  }

  editRow(row: any, index: any) {

    this.dataDetail = cloneDeep(row);
    this.dialogEdit.OpenDialog();
  }

  public SaveDataEdit() {

    if (this.dataDetail.CALCULATE_TYPE == '' || this.dataDetail.CALCULATE_TYPE == undefined) {
      this.modal.warning("Please input the Calcualte type", this.viewref);
      return;
    }

    if (this.dataDetail.CALCULATE_TYPE == 'Retail Price' && (this.dataDetail.EXCISE_RATE == '' || this.dataDetail.EXCISE_RATE == undefined)) {
      this.modal.warning("Please input the Excise rate", this.viewref);
      return;
    }

    if (this.dataDetail.CALCULATE_TYPE == 'Capacity' && (this.dataDetail.CAPACITY == '' || this.dataDetail.CAPACITY == undefined)) {
      this.modal.warning("Please input the Capacity", this.viewref);
      return;
    }

    if (this.dataDetail.CALCULATE_TYPE == 'Capacity' && (this.dataDetail.CAPACITY_RATE == '' || this.dataDetail.CAPACITY_RATE == undefined)) {
      this.modal.warning("Please input the Capacity rate", this.viewref);
      return;
    }

    if (this.dataDetail.CALCULATE_TYPE == 'Capacity' && (this.dataDetail.UNIT_TYPE == '' || this.dataDetail.UNIT_TYPE == undefined)) {
      this.modal.warning("Please input the Unit type", this.viewref);
      return;
    }

    this.modal.confirm("Do you want to save change you have made?", this.viewref,
      () => {
        this.http.post('wPMS', 'SNM083_UpdateExcise', this.dataDetail)
          .subscribe(res => {
            if (res === "DONE") {
              this.modal.info('Transaction complete: applied and saved.', this.viewref)
              this.GetData();
              this.dialogEdit.Close();
            } else {
              console.log(res, 'err')
              this.modal.warning("Found an error, please contract support team", this.viewref);
            }
          }, (err) => {
            console.log(err, 'err')
          })
      }, () => { })
  }

  SelectCalculateType(data) {
    data.UNIT_TYPE = null;
    data.CAPACITY = null;
    data.UNIT_TYPE = null;
    if (data.CALCULATE_TYPE == 'Capacity') {
      data.UNIT_TYPE = 'Ltr.'
    }
  }

  Download() {
    this.http.Download('wPMS', 'SNM083_Download',{})
      .subscribe(res => {
        if (res) {
          this.WriteContents(res)
        } else {
          this.modal.error('Export file not complete', this.viewref)
        }
      },err => {
        this.modal.error('Export file not complete', this.viewref)
      })
  }

  WriteContents(content) {
    const a = document.createElement('a');
    const file = new Blob([content], { type: content.type });
    a.href = URL.createObjectURL(file);
    a.download = "PartExciseInfo.xlsx";
    a.click();
  }
}
