import { Component, OnInit, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';
import * as moment from 'moment';

enum PageAction {
  Search = 0,
  Detail,
  Retrive
}


@Component({
  selector: 'snm122p',
  templateUrl: 'SNM122P.component.html',
  styleUrls: ['SNM122P.component.css']
})

export class SNM122PComponent implements OnInit {

  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  public params: any = {}
  public tableData: any = [];
  public tableData_Ref: any = [];
  public currentDate: moment.Moment = moment();
  public PageAction: number;

  public ConfigSearchDiscountGroup: any = {
    ColName: "LOOKUP_DISCOUNT_GROUP",
    PlaceholderText: "Select Discount Group",
    SourceController: "TI",
    SourceMethodName: "SNM122P_SearchDiscountGroup",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSearchDiscountGroup(values: any) {
    this.params.DISCOUNT_GROUP = values.DISCOUNT_GROUP;
    this.params.DISCOUNT_NAME = values.DISCOUNT_NAME;
  }

  public ConfigSearchSalesChannel: any = {
    ColName: "LOOKUP_SALES_CHANNEL",
    PlaceholderText: "Select Sales Channel",
    SourceController: "TI",
    SourceMethodName: "SNM122P_SearchSalesChannel",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSearchSalesChannel(values: any) {
    this.params.SALES_CHANNEL = values.SALES_CHANNEL;
    this.params.CHANNEL_NAME = values.CHANNEL_NAME
  }

  public ConfigSearchOrderClass: any = {
    ColName: "LOOKUP_ORDER_CLASS",
    PlaceholderText: "Select Order Class",
    SourceController: "TI",
    SourceMethodName: "SNM122P_SearchOrderClass",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: false
  }

  public SetSearchOrderClass(values: any) {
    this.params.ORDER_CLASS = values.ORDER_CLASS;
    this.params.ORDER_DESCRIPT = values.ORDER_DESCRIPT;
  }

  public ConfigSearchFamilyCode: any = {
    ColName: "LOOKUP_FAMILY_CODE",
    PlaceholderText: "Select Family Code",
    SourceController: "TI",
    SourceMethodName: "SNM122P_SearchFamilyCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true,
  }

  public SetSearchFamilyCode(values: any) {
    this.params.DISCOUNT_FAMILY = values.FAMILY_CODE;
    this.params.FAMILY_NAME = values.FAMILY_NAME;
  }

  ngOnInit() {
    this.params.DISCOUNT_STATUS = "";
  }

  public Search() {
    this.tableData = [];
    this.tableData_Ref = [];
    this.http.post('TI', 'SNM122P_GetData', this.params)
      .subscribe(res => {
        this.tableData = res.Table;
        if (this.tableData.length > 0) {
          this.tableData.forEach((e, index) => {
            e.ROW_NUMBER = index + 1;
            e.DSP_EFFECTIVE_DATE = new Date(e.DSP_EFFECTIVE_DATE)
          });
        }
        this.tableData.push({
          'EDIT': 'ADD'
        });
        this.tableData = this.tableData.slice();
        this.PageAction = PageAction.Retrive;

        this.tableData_Ref = JSON.parse(JSON.stringify(this.tableData));

      }, (err) => {
        console.log(err, 'err');
        this.modal.warning("Found an error, please contract support team", this.viewref);
      });
  }

  public Save() {
    let notchange = (JSON.stringify(this.tableData_Ref) == JSON.stringify(this.tableData))
    if (notchange) {
      this.modal.warning('There is no data change.', this.viewref)
      return;
    }

    let incom = this.tableData.filter(x => x.EDIT == 'DEL' && (!x.DISCOUNT_GROUP || !x.SALES_CHANNEL || !x.ORDER_CLASS || !x.DISCOUNT_FAMILY || !x.EFFECTIVE_DATE || !x.DISABLE_DATE))
    if (incom.length > 0) {
      this.modal.error("Please input all required fields, Please check!", this.viewref);
      return
    }

    let err = 0;
    this.tableData.forEach((e, index) => {

      let dup = this.tableData.some((data, index2) => index2 != index && data.EDIT == 'DEL'
        && data.DISCOUNT_GROUP == e.DISCOUNT_GROUP
        && data.SALES_CHANNEL == e.SALES_CHANNEL
        && data.ORDER_CLASS == e.ORDER_CLASS
        && data.DISCOUNT_FAMILY == e.DISCOUNT_FAMILY
        && data.DSP_EFFECTIVE_DATE.getTime() === e.DSP_EFFECTIVE_DATE.getTime())
      if (dup) {
        err = 1;
      }
    });
    if (err == 1) {
      this.modal.warning("Duplicate discount on the same effective date!", this.viewref)
      return;
    }
    this.modal.confirm("Do you want to save change you have made?", this.viewref, this.ConfirmSave)
  }

  private ConfirmSave = () => {
    let DataSaveList = [];
    this.tableData.forEach((i) => {
      if (i.EDIT == 'DEL' && i.DISCOUNT_GROUP && i.SALES_CHANNEL && i.ORDER_CLASS && i.DISCOUNT_FAMILY) {
        DataSaveList.push(i)
      }
      this.tableData_Ref.forEach((j) => {
        if (i.ROW_NUMBER === j.ROW_NUMBER && i.DISABLE_DATE != j.DISABLE_DATE) {
          DataSaveList.push(i)
        }
      });
    });
    if (DataSaveList.length > 0) {
      this.http.post("TI", "SNM122P_Save", DataSaveList)
        .subscribe(res => {
          console.log(res)
          if (res.Table[0].STATUS == 'DONE') {
            this.modal.info('Transaction complete: applied and saved.', this.viewref);
            this.Search();
          }
          else {
            this.modal.warning("Found an error, please contract support team", this.viewref);
          }
        }, (err) => {
          console.log(err, 'err');
          this.modal.warning("Found an error, please contract support team", this.viewref);
        });
    }
  }

  public AppendRow() {
    for (var i = 0; i < this.tableData.length; i++) {
      if (this.tableData[i].EDIT === "ADD") {
        this.tableData[i].EDIT = 'DEL';
        this.tableData[i].ROW_NUMBER = this.tableData.length;
        this.tableData[i].DISCOUNT_MODE = 'RTP';
        this.tableData[i].DISCOUNT_EFFECT = '-1';
        this.tableData[i].DISCOUNT_RATE1 = 0;
        this.tableData[i].DISCOUNT_RATE2 = 0;
        this.tableData[i].DISCOUNT_RATE3 = 0;
      }
    }
    this.tableData.push({
      'EDIT': 'ADD',
      'CAMPAIGN_ID': this.params.CAMPAIGN_ID,
      'ORDER_CLASS': null,
      'ORDER_PREFIX': null,
      'LAST_UPD_BY': null,
      'LAST_UPD_DATE': null,
      'CHECK': null
    });
    this.tableData = this.tableData.slice();
  }

  public DeleteRow(data) {
    if (this.PageAction == PageAction.Retrive) {
      let index = this.tableData.findIndex(x => x == data)
      this.tableData.splice(index, 1);
      if (this.tableData.find(e => e.EDIT === 'ADD') == undefined) {
        this.tableData.push({
          'EDIT': 'ADD'
        });
      }
      if (this.tableData.length > 0) {
        this.tableData.forEach((e, index) => {
          if (e.EDIT == 'DEL') {
            e.ROW_NUMBER = index + 1;
          }
        });
      }
      this.tableData = this.tableData.slice();
    }
  }

  public CheckDate(data) {
    var dToDate = moment().locale("en").startOf('day');
    if (data.EFFECTIVE_DATE && data.EFFECTIVE_DATE < dToDate) {
      this.modal.warning('Effective date should more than today!', this.viewref)
      data.EFFECTIVE_DATE = dToDate;
      return;
    }
    if (data.DISABLE_DATE && data.EFFECTIVE_DATE && data.DISABLE_DATE < data.EFFECTIVE_DATE) {
      this.modal.warning('Disable date should more than effective date!', this.viewref)
      data.DISABLE_DATE = data.EFFECTIVE_DATE;
      return;
    }
    if (data.DISABLE_DATE && data.DISABLE_DATE < dToDate) {
      this.modal.warning('Disable date should more than today!', this.viewref)
      data.DISABLE_DATE = dToDate;
      return;
    }
    if (data.EFFECTIVE_DATE) {
      data.DSP_EFFECTIVE_DATE = new Date(data.EFFECTIVE_DATE)
      data.DSP_EFFECTIVE_DATE.setHours(0);
    } else {
      data.DSP_EFFECTIVE_DATE = null;
    }
  }
}
