import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Globals } from 'src/app/core/global';
import { FormControl, Validators } from '@angular/forms';
import { ModalService } from 'src/app/core/modal.service';
import * as moment from 'moment';

@Component({
  selector: 'SNM134P',
  templateUrl: './SNM134P.component.html',
  styleUrls: ['./SNM134P.component.css']
})


export class SNM134PComponent implements OnInit {


  constructor(
    private http: HttpService,
    private global: Globals,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  @ViewChild("dialogAdd", { static: false }) dialogAdd: any;
  @ViewChild("dialogEdit", { static: false }) dialogEdit: any;

  public ParamSearch: any = {};
  public ParamEdit: any = {};
  public ParamEdit_Ex: any = {};
  public ParamAdd: any = {};
  public tabledata: any = [];
  public tabledataEdit: any = [];
  public iSupdate: boolean = false;
  public partData: any = {};
  public iSupdateEx: boolean = false;
  public currentDate: moment.Moment = moment();
  public formData: any = {};
  public hideCols: Array<string> = [];

  public partNumber: string;
  SetPartNoControl = new FormControl('', [Validators.required])
  SetPartTypeControl = new FormControl('', [Validators.required])

  public lookupConfig: any = {
    ColName: "LOOKUP_PART_NO_VALUE",
    PlaceholderText: "Select Part",
    SourceController: "SL",
    SourceMethodName: "SNM134P_GET_PART_NO",
    NoOfShowRecords: 50,
    UpperCase: true
  }
  public ngOnInit() {
    this.partNumber = '';
    this.partData.PART_NO = ''; //'40; //B
    this.Search();
    this.global.GetRoleDetail().CHG === "N" ? this.hideCols.push("EDIT") : null;
    this.global.GetRoleDetail().DEL === "N" ? this.hideCols.push("DELETE") : null;
  }

  public SetSelectedPART(value: any) {
    if (value.PART_NO) {
      this.partData.PART_NO = value.PART_NO;
      this.partNumber = value.PART_NO;
      this.ParamSearch.PART_NO = value.PART_NO;
    } else {
      this.ParamSearch.PART_NO = '';
    }
  }
  public SetSelectedPARTADD(value: any) {
    if (value.PART_NO) {
      this.ParamAdd.PART_NO = value.PART_NO;
    } else {
      this.ParamSearch.PART_NO = '';
    }
  }


  public Search() {
    this.tabledata = [];

    this.http.post("SL", "SNM134P_GET_DATA", this.ParamSearch)
      .subscribe(res => {
        this.tabledata = res.Table;
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contract support team", this.viewref);
      });
  }

  public Add() {
    this.ParamAdd = {}
    this.SetPartNoControl.reset();
    this.dialogAdd.OpenDialog();
  }

  public SaveAdd() {
    if (this.ParamAdd.PART_NO && this.ParamAdd.PART_TYPE) {
        this.modal.confirm("Do you want to save change you have made?", this.viewref, this.ConfirmSave);
      }
      else {
        this.modal.warning("Please Input fill Round No. and select Effective Date.", this.viewref);
      }
  }


  public ConfirmSave = () => {

    this.http.post('SL', 'SNM134P_INSERT', this.ParamAdd)
      .subscribe(res => {

        if (res.Table[0].STATUS == 'Done') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
          this.ParamAdd = this.global.ClearObject(this.ParamAdd);
          this.dialogAdd.Close();
        }
        else if (res.Table[0].STATUS == 'Duplicate') {
          this.modal.warning('No change to save. Found duplicate record.', this.viewref);
        }
        else {
          this.modal.error('No change to save. Something went wrong.', this.viewref);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contract support team", this.viewref);
      })
  }

  public CancelAdd() {
    this.dialogAdd.Close();
  }

  public EditRow(data) {

    this.ParamEdit = data;
    this.SetPartNoControl.reset();
    this.dialogEdit.OpenDialog();
    this.tabledataEdit = [];
  }

  public SaveEdit() {
    this.modal.confirm("Do you want to save changed you have made?", this.viewref, this.ConfirmEdit)
  }

  public ConfirmEdit = () => {

    this.ParamEdit_Ex.ModEdit = true;

    this.http.post('SL', 'SNM134P_UPDATE', this.ParamEdit)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'Done') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
          this.dialogEdit.Close();
        }
        else {
          this.modal.error('No change to save. Something went wrong.', this.viewref);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contract support team", this.viewref);
      });

    if (this.tabledataEdit.length > 0) {
      this.http.post('SL', 'SNM124_UPDATE_EXCHANGE_RATE', this.ParamEdit_Ex)
        .subscribe(res => {
        }, (err) => {
          console.log(err, 'err')
          this.modal.warning("Found an error, please contract support team", this.viewref);
        });
    }
  }

  public CancleEdit() {
    this.dialogEdit.Close();
  }


  public Delete(data) {
    this.modal.confirm("Do you want to delete record?", this.viewref, () => this.ConfirmDelete(data))
  }

  public ConfirmDelete = data => {
    this.http.post('SL', 'SNM134P_DELETE', data)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'Done') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
        }
        else {
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contract support team", this.viewref);
      })
  }
}

