import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Globals } from 'src/app/core/global';
import { FormControl, Validators } from '@angular/forms';
import { ModalService } from 'src/app/core/modal.service';
import * as moment from 'moment';

@Component({
  selector: 'SNM136P',
  templateUrl: './SNM136P.component.html',
  styleUrls: ['./SNM136P.component.css']
})


export class SNM136PComponent implements OnInit {


  constructor(
    private http: HttpService,
    private global: Globals,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  @ViewChild("dialogAdd", { static: false }) dialogAdd: any;
  @ViewChild("dialogEdit", { static: false }) dialogEdit: any;

  public ParamSearch: any = {};
  public ParamEdit: any = {};
  public ParamAdd: any = {};
  public tabledata: any = [];
  public currentDate: moment.Moment = moment();
  public status: string;

  public lookupConfig: any = {
    ColName: "LOOKUP_PACKAGE_NAME_VALUE",
    PlaceholderText: "Select Package Name",
    SourceController: "wPMS",
    SourceMethodName: "SNM136P_GET_PACKAGE",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: false
  }

  public ngOnInit() {
    this.status = '';
    this.Search();
  }

  public SetSelectedPack(value: any) {
    if (value.PACKAGE_NAME) {
      this.ParamSearch.PACKAGE_NAME = value.PACKAGE_NAME;
    } else {
      this.ParamSearch.PACKAGE_NAME = '';
    }
  }

  public SetSelectedPACKAGEADD(value: any) {
    if (value.PACKAGE_NAME) {
      this.ParamAdd.PACKAGE_NAME = value.PACKAGE_NAME;
    } else {
      this.ParamSearch.PACKAGE_NAME = '';
    }
  }

  public Search() {
    this.tabledata = [];
    this.ParamSearch.PACKAGE_STATUS = this.status;
    this.http.post("wPMS", "SNM136P_GET_DATA", this.ParamSearch)
      .subscribe(res => {
        this.tabledata = res.Table;
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contract support team", this.viewref);
      });
  }

  public Add() {
    this.ParamAdd = {}
    this.ParamAdd.PACKAGE_STATUS = 'Active';
    this.dialogAdd.OpenDialog();
  }

  public SaveAdd() {
    if (this.ParamAdd.PACKAGE_NAME && this.ParamAdd.PACKAGE_STATUS) {
      this.modal.confirm("Do you want to save change you have made?", this.viewref, this.ConfirmSave);
    } else {
      this.modal.warning("Please Input fill Round No.", this.viewref);
    }
  }

  public ConfirmSave = () => {
    this.http.post('wPMS', 'SNM136P_INSERT', this.ParamAdd)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'Done') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
          this.ParamAdd = {};
          this.dialogAdd.Close();
        }
        else if (res.Table[0].STATUS == 'Duplicate') {
          this.modal.warning('No change to save. Found duplicate record.', this.viewref);
        }
        else {
          this.modal.error('No change to save. Something went wrong.', this.viewref);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contract support team", this.viewref);
      })
  }

  public CancelAdd() {
    this.dialogAdd.Close();
  }

  public EditRow(data) {
    this.ParamEdit = {...data};
    this.dialogEdit.OpenDialog();
  }

  public SaveEdit() {
    if (this.ParamEdit.PACKAGE_NAME && this.ParamEdit.PACKAGE_STATUS) {
      this.modal.confirm("Do you want to save change you have made?", this.viewref, this.ConfirmEdit);
    } else {
      this.modal.warning("Please Input fill Round No.", this.viewref);
    }
  }

  public ConfirmEdit = () => {
    this.http.post('wPMS', 'SNM136P_UPDATE', this.ParamEdit)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'Done') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
          this.dialogEdit.Close();
        }
        else {
          this.modal.error("Can't inactive. Because Package name : '" + this.ParamEdit.PACKAGE_NAME + "' is use in Part Package.", this.viewref);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contract support team", this.viewref);
      });
  }

  public Delete(data) {
    this.modal.confirm("Do you want to delete record ?", this.viewref, () => this.ConfirmDelete(data))
  }

  public ConfirmDelete(data) {
    this.http.post('wPMS', 'SNM136P_Delete', data)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'Done') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
        }
        else {
          console.log(res)
          this.modal.error("Can't delete. Because Package name : '" + data.PACKAGE_NAME + "' is use in Part Package.", this.viewref);
        }
      },err => {
        this.modal.warning("Found an error, please contract support team", this.viewref);
      })
  }

  public CancleEdit() {
    this.dialogEdit.Close();
  }
}

