import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Globals } from 'src/app/core/global';
import { FormControl, Validators } from '@angular/forms';
import { ModalService } from 'src/app/core/modal.service';

@Component({
  selector: 'SNM138P',
  templateUrl: './SNM138P.component.html',
  styleUrls: ['./SNM138P.component.css']
})

export class SNM138PComponent implements OnInit {

  constructor(
    private http: HttpService,
    private global: Globals,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  @ViewChild("dialogAdd", { static: false }) dialogAdd: any;
  @ViewChild("dialogEdit", { static: false }) dialogEdit: any;
  @ViewChild("autoCompleteCountryCode", { static: false }) autoCompleteCountryCode: any;
  @ViewChild("autoCompleteRegionCode", { static: false }) autoCompleteRegionCode: any;

  public ParamSearch: any = {};
  public ParamEdit: any = {};
  public ParamAdd: any = {};
  public tabledata: any = [];

  SetCountryCodeControl = new FormControl('', [Validators.required])
  SetRegionCodeControl = new FormControl('', [Validators.required])

  public lookupCountryCodeConfig: any = {
    ColName: "LOOKUP_COUNTRY_CODE",
    PlaceholderText: "Select Country Code",
    SourceController: "SL",
    SourceMethodName: "SNM049P_GetCountryCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public lookupRegionCodeConfig: any = {
    ColName: "LOOKUP_REGION_CODE",
    PlaceholderText: "Select Region Code",
    SourceController: "wPMS",
    SourceMethodName: "SNM139P_GET_REGION",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true,
    SourceParams: {
      COUNTRY_CODE: '',
    }
  }
  public ngOnInit() {
    this.Search();
    //this.global.GetRoleDetail().CHG === "N" ? this.hideCols.push("EDIT") : null;
    //this.global.GetRoleDetail().DEL === "N" ? this.hideCols.push("DELETE") : null;
  }

  public SetSelectedCountryCode(value: any) {
    if (value) {
      this.ParamSearch.COUNTRY_CODE = value.COUNTRY_CODE;
      this.ParamSearch.COUNTRY_NAME = value.COUNTRY_NAME;      
      this.lookupRegionCodeConfig.SourceParams.COUNTRY_CODE = value.COUNTRY_CODE;
    } else {
      this.ParamSearch.COUNTRY_CODE = '';
    }
  }
  public SetSelectedRegionCode(value: any) {
    if (value) {
      this.ParamSearch.REGION_CODE = value.REGION_CODE;
      this.ParamSearch.REGION_NAME_EN = value.REGION_NAME;   
    } else {
      this.ParamSearch.REGION_CODE = '';
      this.ParamSearch.REGION_NAME_EN = ''; 
    }
  }
  public SetSelectedCountryCodeAdd(value: any) {
    if (value) {
      this.ParamAdd.COUNTRY_CODE = value.COUNTRY_CODE;
      this.ParamAdd.COUNTRY_NAME = value.COUNTRY_NAME;
    } else {
      this.ParamAdd.COUNTRY_CODE = '';
    }
  }
  public SetSelectedCountryCodeEdit(value: any) {
    if (value) {
      this.ParamEdit.COUNTRY_CODE = value.COUNTRY_CODE;
      this.ParamEdit.COUNTRY_NAME = value.COUNTRY_NAME;
    } else {
      this.ParamEdit.COUNTRY_CODE = '';
    }
  }


  public Search() {
    this.tabledata = [];

    this.http.post("wPMS", "SNM138P_GetData", this.ParamSearch)
      .subscribe(res => {
        this.tabledata = res.Table;
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contract support team", this.viewref);
      });
  }

  public Add() {
    this.ParamAdd = {}
    this.SetCountryCodeControl.reset();
    this.dialogAdd.OpenDialog();
  }

  public SaveAdd() {
    if (this.ParamAdd.COUNTRY_CODE && this.ParamAdd.REGION_NAME_EN && this.ParamAdd.REGION_NAME_TH) {
      this.modal.confirm("Do you want to save change you have made?", this.viewref, this.ConfirmSave);
    }
    else {
      this.modal.warning("Please Input fill", this.viewref);
    }
  }


  public ConfirmSave = () => {

    this.http.post('wPMS', 'SNM138P_INSERT', this.ParamAdd)
      .subscribe(res => {

        if (res.Table[0].STATUS == 'Done') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
          this.ParamAdd = this.global.ClearObject(this.ParamAdd);
          this.dialogAdd.Close();
        }
        else if (res.Table[0].STATUS == 'Duplicate') {
          this.modal.warning('No change to save. Found duplicate record.', this.viewref);
        }
        else {
          this.modal.error('No change to save. Something went wrong.', this.viewref);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contract support team", this.viewref);
      })
  }

  public CancelAdd() {
    this.dialogAdd.Close();
  }

  public EditRow(data) {
    this.ParamEdit = { ...data };
    this.dialogEdit.OpenDialog();

    //setTimeout((x) => {
    //  this.autoCompleteCountryCode.textInput = this.ParamEdit.COUNTRY_CODE
    //  this.autoCompleteCountryCode.query();
    //}, 200);
  }

  public SaveEdit() {
    this.modal.confirm("Do you want to save changed you have made?", this.viewref, this.ConfirmEdit)
  }

  public ConfirmEdit = () => {

    this.http.post('wPMS', 'SNM138P_UPDATE', this.ParamEdit)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'Done') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
          this.dialogEdit.Close();
        }
        else {
          this.modal.error('No change to save. Something went wrong.', this.viewref);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contract support team", this.viewref);
      });
  }

  public CancleEdit() {
    this.dialogEdit.Close();
  }

  public Delete(data) {
    this.modal.confirm("Do you want to delete record?", this.viewref, () => this.ConfirmDelete(data))
  }
  public ConfirmDelete(data) {
    this.http.post('wPMS', 'SNM138P_Delete', data)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
        }
        else if (res.Table[0].STATUS == 'BeingUsed') {
          this.modal.warning('No change to save. Found region code was being used.', this.viewref);
        }
        else {
          console.log(res)
          this.modal.error('No change to save. Something went wrong.', this.viewref);
        }
      })
  }

}

