import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Globals } from 'src/app/core/global';
import { FormControl, Validators } from '@angular/forms';
import { ModalService } from 'src/app/core/modal.service';
import * as moment from 'moment';

@Component({
  selector: 'SNM139P',
  templateUrl: './SNM139P.component.html',
  styleUrls: ['./SNM139P.component.css']
})


export class SNM139PComponent implements OnInit {


  constructor(
    private http: HttpService,
    private global: Globals,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  @ViewChild("dialogAdd", { static: false }) dialogAdd: any;
  @ViewChild("dialogEdit", { static: false }) dialogEdit: any;
  @ViewChild("autoCompleteCountryCode", { static: false }) autoCompleteCountryCode: any;
  @ViewChild("autoCompleteRegionCode", { static: false }) autoCompleteRegionCode: any;

  public ParamSearch: any = {};
  public ParamEdit: any = {};
  public ParamAdd: any = {};
  public tabledata: any = [];
  public temptable: any = [];

  SetCountryCodeControl = new FormControl('', [Validators.required])
  SetRegionCodeControl = new FormControl('', [Validators.required])
  SetZoneAreaCodeControl = new FormControl('', [Validators.required])
  SetSalesmanCodeControl = new FormControl('', [Validators.required])

  public lookupConfigZone: any = {
    ColName: "LOOKUP_ZONE_AREA_CODE_VALUE",
    PlaceholderText: "Select Zone",
    SourceController: "wPMS",
    SourceMethodName: "SNM139P_GET_ZONE_AREA",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      COUNTRY_CODE: '',
      REGION_CODE: '',
    }
  }

  public lookupCountryCodeConfig: any = {
    ColName: "LOOKUP_COUNTRY_CODE",
    PlaceholderText: "Select Country Code",
    SourceController: "SL",
    SourceMethodName: "SNM049P_GetCountryCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }
  public lookupConfigRegion: any = {
    ColName: "LOOKUP_REGION_CODE",
    PlaceholderText: "Select Region",
    SourceController: "wPMS",
    SourceMethodName: "SNM139P_GET_REGION",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true,
    SourceParams: {
      COUNTRY_CODE: '',
    }
  }

  public lookupConfigSalesman: any = {
    ColName: "LOOK_UP",
    PlaceholderText: "Select Salesman Name",
    SourceController: "wPMS",
    SourceMethodName: "SNM139P_GET_SALESMAN",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
  }

  public ngOnInit() {
    this.Search();
  }

  public SetSelectedCountryCode(value: any) {

      if (value) {
      this.ParamSearch.COUNTRY_CODE = value.COUNTRY_CODE;
      this.ParamSearch.COUNTRY_NAME = value.COUNTRY_NAME;
      this.lookupConfigRegion.SourceParams.COUNTRY_CODE = value.COUNTRY_CODE;
      this.lookupConfigZone.SourceParams.COUNTRY_CODE = value.COUNTRY_CODE;
      } else {
      this.ParamSearch.COUNTRY_CODE = '';
      }
    }

  public SetSelectedCountryCodeAdd(value: any) {
    if (value) {
      this.ParamAdd.COUNTRY_CODE = value.COUNTRY_CODE;
      this.ParamAdd.COUNTRY_NAME = value.COUNTRY_NAME;
      this.lookupConfigRegion.SourceParams.COUNTRY_CODE = value.COUNTRY_CODE;
      this.ParamAdd.REGION_CODE = '';
      this.ParamAdd.REGION_NAME_EN = '';
      this.ParamAdd.REGION_NAME_TH = '';
    } else {
      this.ParamAdd.COUNTRY_CODE = '';
      }
  }

  public SetSelectedCountryCodeEdit(value: any) {
    if (value) {
      this.ParamEdit.COUNTRY_CODE = value.COUNTRY_CODE;
      this.ParamEdit.COUNTRY_NAME = value.COUNTRY_NAME;
      this.lookupConfigRegion.SourceParams.COUNTRY_CODE = value.COUNTRY_CODE;
      this.ParamEdit.REGION_CODE = '';
      this.ParamEdit.REGION_NAME_EN = '';
      this.ParamEdit.REGION_NAME_TH = '';
          } else {
      this.ParamEdit.COUNTRY_CODE = '';
      this.ParamEdit.COUNTRY_NAME = '';
    }
  }

  public SetSelectedRegionCode(value: any) {

      if (value) {
      this.ParamSearch.REGION_CODE = value.REGION_CODE;
      this.ParamSearch.REGION_NAME_EN = value.REGION_NAME_EN;
      this.ParamSearch.REGION_NAME_TH = value.REGION_NAME_TH;
      this.lookupConfigZone.SourceParams.REGION_CODE = value.REGION_CODE;
      } else {
      this.ParamSearch.REGION_CODE = '';
      this.ParamSearch.REGION_NAME_EN = '';
      this.ParamSearch.REGION_NAME_TH = '';
      }
    }

  public SetSelectedRegionAdd(value: any) {
    if (value) {

      this.ParamAdd.REGION_CODE = value.REGION_CODE;
      this.ParamAdd.REGION_NAME_EN = value.REGION_NAME_EN;
      this.ParamAdd.REGION_NAME_TH = value.REGION_NAME_TH;
          } else {
      this.ParamAdd.REGION_CODE = '';
      this.ParamAdd.REGION_NAME_EN = '';
      this.ParamAdd.REGION_NAME_TH = '';
    }
  }

  public SetSelectedRegionEdit(value: any) {
      if (value) {
      this.ParamEdit.REGION_CODE = value.REGION_CODE;
      this.ParamEdit.REGION_NAME_EN = value.REGION_NAME_EN;
      this.ParamEdit.REGION_NAME_TH = value.REGION_NAME_TH;
      } else {
      this.ParamEdit.REGION_CODE = '';
      this.ParamEdit.REGION_NAME_EN = '';
      this.ParamEdit.REGION_NAME_TH = '';
      }
    }

  public SetSelectedZoneArea(value: any) {
    if (value) {
      this.ParamSearch.ZONE_AREA_CODE = value.ZONE_AREA_CODE;
      this.ParamSearch.ZONE_AREA_EN = value.ZONE_AREA_EN;
      this.ParamSearch.ZONE_AREA_TH = value.ZONE_AREA_TH;
          } else {
      this.ParamSearch.ZONE_AREA_CODE = '';
      this.ParamSearch.ZONE_AREA_EN = '';
      this.ParamSearch.ZONE_AREA_TH = '';
    }
  }

  public SetSelectedSALESMANAdd(value: any) {

      if (value) {
      this.ParamAdd.SALESMAN_CODE = value.SALESMAN_CODE;
      this.ParamAdd.SALESMAN_NAME = value.SALESMAN_NAME;
      } else {
      this.ParamAdd.SALESMAN_CODE = '';
      this.ParamAdd.SALESMAN_NAME = '';
      }
    }

  public SetSelectedSALESMANEdit(value: any) {
    if (value) {


      this.ParamEdit.SALESMAN_CODE = value.SALESMAN_CODE;
      this.ParamEdit.SALESMAN_NAME = value.SALESMAN_NAME;
          } else {
      this.ParamEdit.SALESMAN_CODE = '';
      this.ParamEdit.SALESMAN_NAME = '';
    }
  }

  public Search() {
    this.tabledata = [];
    this.http.post("wPMS", "SNM139P_GET_DATA", this.ParamSearch)
      .subscribe(res => {
        this.tabledata = res.Table;
        this.temptable = res.Table;
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contract support team", this.viewref);
      });
  }


  public Add() {
    this.ParamAdd = {}
    this.dialogAdd.OpenDialog();
  }

  public SaveAdd() {
      this.modal.confirm("Do you want to save change you have made?", this.viewref, this.ConfirmSave);
  }

  public ConfirmSave = () => {
    this.http.post('wPMS', 'SNM139P_INSERT', this.ParamAdd)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'Done') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
          this.ParamAdd = {};
          this.dialogAdd.Close();
        } else if (res.Table[0].STATUS == 'Duplicate') {
          this.modal.warning('No change to save. Found duplicate record.', this.viewref);
        } else {
          this.modal.error('No change to save. Something went wrong.', this.viewref);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contract support team", this.viewref);
      })
  }

  public CancelAdd() {
    this.dialogAdd.Close();
  }

  public EditRow(data) {
    this.ParamEdit = { ...data };
    this.dialogEdit.OpenDialog();
  }

  public SaveEdit() {
       this.modal.confirm("Do you want to save change you have made?", this.viewref, this.ConfirmEdit);
  }

  public ConfirmEdit = () => {
    this.http.post('wPMS', 'SNM139P_UPDATE', this.ParamEdit)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'Done') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
          this.dialogEdit.Close();
        }  else if (res.Table[0].STATUS == 'Duplicate') {
          this.modal.warning('No change to save. Found duplicate record.', this.viewref);
        } else {
          this.modal.error('No change to save. Something went wrong.', this.viewref);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contract support team", this.viewref);
      });
  }

  public Delete(data) {
    this.modal.confirm("Do you want to delete record?", this.viewref, () => this.ConfirmDelete(data))
  }
  public ConfirmDelete(data) {
    this.http.post('wPMS', 'SNM139P_Delete', data)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'Done') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
        } else if (res.Table[0].STATUS == 'Active') {
          this.modal.error("Can't delete. Because Zone Area Code: " + data.ZONE_AREA_CODE + " is use.", this.viewref);
        } else {
          this.modal.error('No change to save. Something went wrong.', this.viewref);
        }
      })
  }
  public CancleEdit() {
    this.dialogEdit.Close();
  }
}

