import { Component, ElementRef, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Globals } from 'src/app/core/global';
import { FormControl, Validators } from '@angular/forms';
import { ModalService } from 'src/app/core/modal.service';
import * as moment from 'moment';
import { SelectionModel } from '@angular/cdk/collections';

@Component({
  selector: 'SNM140P',
  templateUrl: './SNM140P.component.html',
  styleUrls: ['./SNM140P.component.css']
})


export class SNM140PComponent implements OnInit {


  constructor(
    private http: HttpService,
    private global: Globals,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  public ConfigPartAdd: any = {
    ColName: "LOOKUP",
    PlaceholderText: "Select Part",
    SourceController: "wPMS",
    SourceMethodName: "SNM140P_GetPartAdd",
    NoOfShowRecords: 50,
    MinLengthSearch: 3,
    UpperCase: true
  }

  public ConfigPartSearch: any = {
    ColName: "LOOKUP",
    PlaceholderText: "Select Part",
    SourceController: "wPMS",
    SourceMethodName: "SNM140P_GetPartSearch",
    NoOfShowRecords: 50,
    MinLengthSearch: 3,
    UpperCase: true
  }

  public ParamSearch: any = {};
  public Param: any = {};
  public tabledata: any = [];
  public temptable: any = [];
  public currentDate: moment.Moment = moment();
  public formData: any = {};
  public iSEdit : boolean = false;
  public FileName: string = "";
  private File : any;
  public tableUpload = []
  public selection = new SelectionModel<any>(true, []);
  public total_error :number = 0;
  public error_list = []

  @ViewChild("dialog", { static: false }) dialog: any;
  @ViewChild("dialogupload", { static: false }) dialogupload: any;
  @ViewChild("fileInput") fileInput: ElementRef;
  ngOnInit() {
    
  }

  public Search(){
    this.http.post("wPMS","SNM140P_GetData",this.ParamSearch)
    .subscribe(res =>{
      this.tabledata = res.Table;
    })
  }

  public Add(type : string){
    console.log(type)
    if(type == "Part")
    {
      this.iSEdit = false
      this.Param = {}
      this.Param.ISSUE_FLAG = "TF"
      this.dialog.title = "Add Part"
      this.dialog.OpenDialog()
    }
    else
    {
      this.selection.clear()
      this.total_error = 0
      this.FileName = "";
      this.error_list = []
      this.tableUpload = []
      this.dialogupload.title = "Add by upload"
      this.dialogupload.OpenDialog()
    }
  }

  public Cancel(){
    this.dialog.Close();
  }

  public Edit(data){
    this.iSEdit = true
    this.Param = data
    this.dialog.title = "Edit Part"
    this.dialog.OpenDialog();
  }

  public Save(){

    if(this.iSEdit)
    {
      this.modal.confirm("Do you want to save?",this.viewref,() => confirm())

      let confirm = () => {
        
        this.http.post('wPMS',"SNM140P_Update",this.Param)
        .subscribe(res =>{
          if(res.STATUS_MSG == "DONE")
          {
            this.modal.info("Save data complete",this.viewref)
            this.Search();
            this.dialog.Close();
          }
          else
          {
            this.modal.error("Found an error, please contact support team", this.viewref);
          }
        },err =>{
          this.modal.error("Found an error, please contact support team", this.viewref);
        })
      }
    }
    else
    {
      this.modal.confirm("Do you want to save?",this.viewref,() => confirm())

      let confirm = () => {
        this.http.post('wPMS',"SNM140P_Insert",this.Param)
        .subscribe(res =>{
          if(res.STATUS_MSG == 'DONE')
          {
            this.modal.info("Save data complete",this.viewref)
            this.dialog.Close();
          }
          else if(res.STATUS_MSG == "DUPPLICATE")
          {
            this.modal.info('No change to save. Found duplicate record.', this.viewref);
          }
          else
          {
            this.modal.error("Found an error, please contact support team", this.viewref);
          }
        },err =>{
          this.modal.error("Found an error, please contact support team", this.viewref);
        })
      }
    }

  }

 

  public Delete(data){
    this.modal.confirm("Do you want to delete record?",this.viewref,()=> confirm())

    let confirm = () =>{
      this.http.post("wPMS","SNM140P_Delete",data)
      .subscribe(res => {
        if(res.STATUS_MSG == "DONE")
        {
          this.modal.info("Delete data complete",this.viewref)
          this.Search();
        }
        else
        {
          this.modal.error("Found an error, please contact support team", this.viewref);
        }
      } ,err => {
        this.modal.error("Found an error, please contact support team", this.viewref);
      })
    }
  }

  public openFileBrowser() {
    this.FileName = "";
    this.fileInput.nativeElement.value = '';
    this.fileInput.nativeElement.click();
  }

  public selectFile(evt) {
    
    let Files: Array<File> = evt.target.files;

    if (Files.length > 0) {
      //let File: File = Files[0];
      this.File = Files[0];
      this.FileName = this.File.name;
    }
  }

  public PreView() {

    if (!this.FileName) {
      this.modal.warning("Please Open File First...", this.viewref)
      return;
    }
    
        let formData = new FormData();
        formData.append('file', this.File);
        this.tableUpload = []
        this.error_list = []
        this.http.postFile("wPMS", "SNM140P_UploadFile", formData)
            .subscribe(result => {
              
              this.modal.info("Upload complete",this.viewref);      
              this.tableUpload = result.filter(x => x.PART_NO)
              //this.total_error = this.tableUpload.filter(x => x.ERROR_FLAG == 'Y').length
              let countrow = 0;
              this.tableUpload.map((x,i) => {
                if(x.FLAG == 'Y'){
                   countrow += 1;
                    this.error_list.push({
                        Records : i + 1
                    })
                } 

                this.total_error = countrow;
          })
                
            }, err => {
              this.modal.error("Upload not complete", this.viewref);
            })
  }

  public SaveUpload(){
    this.modal.confirm("Do you want to save data?",this.viewref,()=> confirm())

    let confirm = () => {
      this.http.post("wPMS","SNM140P_SaveUpload",this.selection.selected)
      .subscribe(res =>{
        if(res.STATUS == "DONE")
        {
          this.modal.info("Save data complete",this.viewref)
        }
        else
        {
          this.modal.error("Found an error, please contact support team", this.viewref);
        }
      },err => {
        this.modal.error("Found an error, please contact support team", this.viewref);
      })
    }
  
  }


  isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.tableUpload.filter(x => x.FLAG == 'N').length;
    return numSelected === numRows;
  }

  Toggle() {
    this.isAllSelected() ?
      this.selection.clear() :
      this.tableUpload.forEach(row => {
        if (row.FLAG == 'N') {
          this.selection.select(row)
        }
      });
  }


  public DownloadTemplate(){
   
    let link = "assets/templates/SNM140P_Upload_Template.xlsx"
    window.open(link,'_blank')
  }

  
}

