import {
  Component,
  ElementRef,
  OnInit,
  ViewChild,
  ViewContainerRef,
} from "@angular/core";
import { HttpService } from "src/app/core/http.service";
import { Router } from "@angular/router";
import { ModalService } from "src/app/core/modal.service";

@Component({
  selector: "SNM143P",
  templateUrl: "./SNM143P.component.html",
  styleUrls: ["./SNM143P.component.css"],
})
export class SNM143PComponent implements OnInit {
  constructor(
    private http: HttpService,
    private router: Router,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) {}

  public ConfigPart: any = {
    ColName: "LOOKUP_PART_VALUE",
    PlaceholderText: "Select Part No.",
    SourceController: "IC",
    SourceMethodName: "SNSQ005_GetPart",
    NoOfShowRecords: 30,
  };

  @ViewChild("dialog", { static: false }) dialog: any;
  @ViewChild("dialogMultiPart", { static: false }) dialogMultiPart: any;

  public paramSearch: any = {};
  public params: any = {};
  public tableData: any = [];
  public isAdd: boolean = false;
  public tableDataMultipart: any = [];
  public tempData: any = [];
  public error_list: any = [];
  public total_error: number;
  public fileName: string = "";
  public fileNameMultipart: string = "";
  private file: any;

  @ViewChild("fileInput") fileInput: ElementRef;
  @ViewChild("fileInputMultipart") fileInputMultipart: ElementRef;

  ngOnInit() {
  }

  public Search() {
    if (this.paramSearch.PART_NO === undefined || this.paramSearch.PART_NO.length < 3 ) {
      this.modal.warning("Please input part number more than 3 characters.", this.viewref);
      return;
    } else {
    this.tableData = [];
    this.http
      .post("wPMS", "SNM143P_GetData", this.paramSearch)
      .subscribe((res) => {
        this.tableData = res.Table;
      });
    }
  }

  public DownloadTemplate(template: number) {
    let link = "";
    if (template == 1) {
      link = "assets/templates/Allocation_Multipart_Template.xlsx";
    }

    window.open(link, "_blank");
  }

  public Add() {
    this.params = {};
    this.isAdd = true;
    this.dialog.title = "Add New Allocation lot";
    this.dialog.height = "420px";
    this.dialog.width = "580px";

    this.dialog.OpenDialog();
  }

  public EditRow(dataRow) {
    this.params = { ...dataRow };
    this.isAdd = false;
    this.dialog.title = "Edit Allocation lot";
    this.dialog.height = "520px";
    this.dialog.width = "720px";

    this.dialog.OpenDialog();
  }

  public SetSelectPart(event) {
    if (event) {
      this.paramSearch.PART_NO = event.PART_NO;
      this.paramSearch.PART_NAME_EN = event.PART_NAME_EN;
      this.paramSearch.PART_NAME_TH = event.PART_NAME_TH;
    } else {
      this.paramSearch.PART_NO = '';
      this.paramSearch.PART_NAME_EN = '';
      this.paramSearch.PART_NAME_TH = '';
    }
  }

  public SetSelectPartEdit(event) {
    if (event) {
      this.params.PART_NO = event.PART_NO;
      this.params.PART_NAME_EN = event.PART_NAME_EN;
      this.params.PART_NAME_TH = event.PART_NAME_TH;
    } else {
      this.params.PART_NO = null;
      this.params.PART_NAME_EN = null;
      this.params.PART_NAME_TH = null;
    }
  }

  public CheckQty(event, data) {
    if (event.target.valueAsNumber < 1) {
      this.modal.warning("Lot quantity must not be less than 1", this.viewref);
      data.LOT_QTY = 1;
    }
  }

  public Delete(data) {
    this.modal.confirm(
      "Do you want to delete this record?",
      this.viewref,
      () => {
        this.http.post("TI", "SNM132P_Delete", data).subscribe((res) => {
          if (res.STATUS_MSG == "DONE") {
            this.modal.info(
              "Transaction complete: 1 record applied and deleted.",
              this.viewref
            );
            this.Search();
            this.dialog.Close();
          } else {
            this.modal.warning(
              "No change to save. Something went wrong.",
              this.viewref
            );
          }
        });
      }
    );
  }

  public Save() {
    if (this.params.LOT_QTY < 1 || !this.params.LOT_QTY) {
      this.modal.warning("Quantity must not be less than 1", this.viewref);
      return;
    }

    this.modal.confirm(
      "Do you want to save change you have made?",
      this.viewref,
      this.ConfirmSave
    );
  }

  private ConfirmSave = () => {
    if (this.isAdd) {
      this.http.post("wPMS", "SNM143P_Insert", this.params).subscribe(
        (res) => {
          if (res.Table[0].STATUS == "DONE") {
            this.modal.info(
              "Transaction complete: applied and saved.",
              this.viewref
            );
            if (this.tableData.length > 0) {
              this.Search();
            }
            this.dialog.Close();
          } else if (res.Table[0].STATUS == "Duplicate") {
            this.modal.info(
              "No change to save. Found duplicate record.",
              this.viewref
            );
          } else {
            this.modal.warning(
              "No change to save. Something went wrong.",
              this.viewref
            );
          }
        },
        (err) => {
          this.modal.warning(
            "No change to save. Something went wrong.",
            this.viewref
          );
        }
      );
    } else {
      this.http.post("wPMS", "SNM143P_Update", this.params).subscribe(
        (res) => {
          if (res.Table[0].STATUS == "DONE") {
            this.modal.info(
              "Transaction complete: applied and saved.",
              this.viewref
            );
            if (this.tableData.length > 0) {
              this.Search();
            }
            this.dialog.Close();
          } else {
            this.modal.warning(
              "No change to save. Something went wrong.",
              this.viewref
            );
          }
        },
        (err) => {
          this.modal.error(
            "No change to save. Something went wrong.",
            this.viewref
          );
        }
      );
    }
  };

  public Cancel() {
    this.dialog.Close();
  }

  public UploadMultipart() {
    this.tableDataMultipart = [];
    this.fileNameMultipart = "";
    this.dialogMultiPart.title = "Add New Allocation lot";

    this.dialogMultiPart.OpenDialog();
  }

  public SaveMultipart() {
    if (this.tableDataMultipart.some((x) => x.MSG)) {
      this.modal.warning(
        "This data have error, Please recheck data.",
        this.viewref
      );
      return;
    }

    this.modal.confirm(
      "Do you want to save changed you have made?",
      this.viewref,
      () => confirmSave()
    );

    let confirmSave = () => {
      this.http
        .post("wPMS", "SNM143P_SaveMultipart", this.tableDataMultipart)
        .subscribe(
          (res) => {
            if (res.STATUS_MSG == "DONE") {
              this.modal.info(
                "Transaction complete: applied and saved.",
                this.viewref
              );
              this.Search();
              this.dialogMultiPart.Close();
            } else {
              this.modal.error(
                "No change to save. Something went wrong.",
                this.viewref
              );
            }
          },
          (err) => {
            this.modal.error(
              "Found an error, please contract support team.",
              this.viewref
            );
          }
        );
    };
  }

  public OpenFileBrowserMultipart() {
    this.fileNameMultipart = "";
    this.fileInputMultipart.nativeElement.value = "";
    this.fileInputMultipart.nativeElement.click();
  }

  public SelectFileMultipart(evt) {
    let files: Array<File> = evt.target.files;

    if (files.length > 0) {
      //let File: File = Files[0];
      this.file = files[0];
      this.fileNameMultipart = this.file.name;
    }
  }

  public PreView() {
    if (!this.fileNameMultipart) {
      this.modal.warning(
        "Please upload file before preview data.",
        this.viewref
      );
      return;
    }

    let formData = new FormData();
    formData.append("file", this.file);
    this.tableDataMultipart = [];
    this.http.postFile("wPMS", "SNM143P_UploadMultiParts", formData).subscribe(
      (result) => {
        this.total_error = 0;
        this.tableDataMultipart = result.filter((x) => x.PART_NO);
        let countrow = 0;
        this.total_error = this.tableDataMultipart.filter((x, i) => {
          if (x.ERR_FLAG == "Y") {
            countrow += 1;
            this.error_list.push({
              Records: i + 1,
            });
          }
        });
        this.total_error = countrow;

        this.modal.info("Upload completed.", this.viewref);
      },
      (err) => {
        this.modal.error("Upload failed. Something went wrong.", this.viewref);
      }
    );
  }
}
