import { SelectionModel } from '@angular/cdk/collections';
import { Component, ElementRef, OnInit, ViewChild, ViewContainerRef } from "@angular/core";
import { Globals } from 'src/app/core/global';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';


@Component({
    selector: 'snm146p',
    templateUrl: './SNM146P.component.html',
    styleUrls: ['./SNM146P.component.css']
})

export class SNM146PComponent implements OnInit {

    constructor(
        private http: HttpService,
        private modal:ModalService,
        private viewref : ViewContainerRef,
        private global : Globals
    ) { }

    public tableData: any = [];
    public selection = new SelectionModel<any>(true, []);
    public checkInvoice : boolean = true;
    public checkBusinessplace : boolean = true;
    public files: any = [];
    public fileName: string = ""
    public total_error : number = 0
    @ViewChild("file") fileSelect: ElementRef;

    
    @ViewChild("dialog",{static: false}) dialog : any;
    ngOnInit() {
        this.CreateTable();
    }

    public DownLoadTemplate() {
        let link = "assets/templates/SNM146P_TEMPLATE.xlsx";
        window.open(link, "_blank");
    }

    public OpenFileBrowser() {
        this.fileSelect.nativeElement.value = "";
        this.fileSelect.nativeElement.click();
        //this.files = [];
        //this.fileName = "";
      }

    public FileChange(fileInput) {
        this.fileName = "";
        this.selection.clear();
        this.files = fileInput.target.files;
        this.fileName = this.files[0].name;
    
        if(this.fileName){
          this.UpLoad();
        }
        
    }

    private UpLoad() {
        let formData = new FormData();
        formData.append("file", this.files[0]);
    
        this.http.postFile("wPMS", "SNM146P_Upload", formData).subscribe(
          (res) => {
            this.tableData = res.filter((x) => x.INVOICE_NO);
            this.total_error = this.tableData.filter(x => x.MSG).length
            this.AppendRow()
          },
          (err) => {
            this.modal.error("Upload error", this.viewref);
          }
        );
    }



    public UpdateData(){
        this.modal.confirm("Do you want to update date",this.viewref,this.ConfirmUpdate)
    }

    private ConfirmUpdate = () => {
        let isInvoice = this.checkInvoice == true ? 'Y' : 'N';
        let isBusiness = this.checkBusinessplace == true ? 'Y' : 'N';

        let data = {
            IS_INVOICE : isInvoice,
            IS_BUSINESS_PLACE : isBusiness,
            DETAIL : this.tableData.filter(x => x.INVOICE_NO && !x.MSG)
        }

        this.http.post("wPMS","SNM146P_UPDATE",data)
        .subscribe(res => {
            if(res.STATUS_MSG == 'DONE'){
                this.modal.info('Update data complet', this.viewref);
                this.tableData = []
                this.CreateTable();
                //this.selection.clear();
            }else{
                this.modal.error('Update data fail, please contact support team', this.viewref);
            }
        },err =>{
            this.modal.error('Update data fail, please contact support team', this.viewref);
        })
    }

    public InvoiceChange(event) {
        if (this.tableData.length == 0) return;
        //this.CheckSelect();
    }

    public BusinessPlaceChange(event) {
        if (this.tableData.length == 0) return;
        //this.CheckSelect();
    }


    public CheckSelect() {

        if (!this.checkInvoice && !this.checkBusinessplace) {
          this.selection.clear()
        } else {
          if (this.selection.selected.length > 0) {
            this.tableData.forEach((row) => {
                this.selection.deselect(row)
            });
          }
        }
    }

    public CreateTable(){
        let i = 0;
        while(i < 4){
            this.tableData.push(
            { 'CHECK': 'DEL', 
            'INVOICE_NO': null ,
            'CORRECT_INVOICE' : null,
            'BUSINESS_PLACE' : null,
            'MSG':null
            });
            i++
        }

        this.tableData.push(
            { 'CHECK': 'ADD', 
            'INVOICE_NO': null ,
            'CORRECT_INVOICE' : null,
            'BUSINESS_PLACE' : null,
            'MSG':null
            });
    }

    public AppendRow() {
        for (var i = 0; i < this.tableData.length; i++) {
          if (this.tableData[i].CHECK === "ADD") {
            this.tableData[i].CHECK = 'DEL';
            // this.tableData[i].ITEM = this.tableData.length;
          }
        }
        this.tableData.push({ 'CHECK': 'ADD', 
        'INVOICE_NO': null ,
        'CORRECT_INVOICE' : null,
        'BUSINESS_PLACE' : null,
        'MSG':null
        });
  
        this.tableData = this.tableData.slice();
    }

    public DeleteRow(Item) {
    
        let index = this.tableData.findIndex(x => x == Item)
        this.tableData.splice(index, 1);
        this.tableData = this.tableData.slice();

    }

    public isAllSelected() {
        const numSelected = this.selection.selected.length;
        const numRows = this.tableData.length;
        return numSelected === numRows;
    }
    
    public Toggle() {
        this.isAllSelected() ?
          this.selection.clear() :
          this.tableData.forEach(row => {
              this.selection.select(row)
          });
    }


    public CheckDetail(){
        return this.tableData.filter(x => x.INVOICE_NO && !x.MSG).length
    }

}
