import { Component, OnInit, ViewChild, ViewContainerRef, ElementRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';
import { SelectionModel } from '@angular/cdk/collections';

@Component({
  selector: 'SNM163P',
  templateUrl: './SNM163P.component.html',
  styleUrls: ['./SNM163P.component.css']
})

export class SNM163PComponent implements OnInit {


  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  @ViewChild("dialogAdd", { static: false }) dialogAdd: any;
  @ViewChild("dialogEdit", { static: false }) dialogEdit: any;
  @ViewChild("fileUpload") fileUpload: ElementRef;


  public showScreen: any = 0;
  public params: any = {};
  public paramsDialog: any = {};
  public tableData: any = [];
  public tableTempData: any = [];
  public FileName: any;
  public file: any;
  public dataIsSelected: any = [];
  public selection = new SelectionModel<any>(true, []);
  public action: any;

  ngOnInit() {
    this.GetStatus();
    this.Search();
  }

  public lookupCustomerCodeConfig: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "SL",
    SourceMethodName: "SNM163P_GetCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedCustomerCode(value: any) {
    this.params.CUSTOMER_CODE = value.CUSTOMER_CODE;
    this.params.CUSTOMER_NAME = value.CUSTOMER_NAME;
    this.params.BRANCH_CODE = value.BRANCH_CODE;
    this.lookupBranchCodeConfig.SourceParams.CUSTOMER_CODE = value.CUSTOMER_CODE;
    this.Search();
  }

  public lookupBranchCodeConfig: any = {
    ColName: "LOOKUP_BRANCH_CODE",
    PlaceholderText: "Select Branch Code",
    SourceController: "SL",
    SourceMethodName: "SNM163P_GetBranchCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      CUSTOMER_CODE: ''
    },
    UpperCase: true
  }

  public SetSelectedBranchCode(value: any) {
    this.params.BRANCH_CODE = value.BRANCH_CODE;
    this.Search();
  }

  public lookupPartNoConfig: any = {
    ColName: "LOOKUP_PART_NO",
    PlaceholderText: "Select Part Code",
    SourceController: "SL",
    SourceMethodName: "SNM163P_GetPartNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedPartNo(value: any) {
    this.params.PART_NO = value.PART_NO;
    this.params.PART_NAME = value.PART_NAME;
    this.Search();
  }

  public lookupCustomerCodeAddConfig: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "SL",
    SourceMethodName: "SNM163P_GetCustomerCodeForAdd",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedCustomerCodeAdd(value: any) {
    this.paramsDialog.CUSTOMER_CODE = value.CUSTOMER_CODE;
    this.paramsDialog.CUSTOMER_NAME = value.CUSTOMER_NAME;
    this.lookupBranchCodeAddConfig.SourceParams.CUSTOMER_CODE = value.CUSTOMER_CODE;
  }

  public lookupBranchCodeAddConfig: any = {
    ColName: "LOOKUP_BRANCH_CODE",
    PlaceholderText: "Select Branch Code",
    SourceController: "SL",
    SourceMethodName: "SNM163P_GetBranchCodeForAdd",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      CUSTOMER_CODE: ''
    },
    UpperCase: true
  }

  public SetSelectedBranchCodeAdd(value: any) {
    this.paramsDialog.BRANCH_CODE = value.BRANCH_CODE;
    this.paramsDialog.BRANCH_NAME = value.BRANCH_NAME;
  }

  public lookupPartNoAddConfig: any = {
    ColName: "LOOKUP_PART_NO",
    PlaceholderText: "Select Part Code",
    SourceController: "SL",
    SourceMethodName: "SNM163P_GetPartNoForAdd",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedPartNoAdd(value: any) {
    this.paramsDialog.PART_NO = value.PART_NO;
    this.paramsDialog.PART_NAME = value.PART_NAME;
  }

  public Search() {
    this.tableData = [];
    this.http.post("SL", "SNM163P_GetData", this.params)
      .subscribe(res => {
        this.tableData = res.Table;
      }, (err) => {
        console.log(err, 'err');
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
  }

  public Add() {
    this.dataIsSelected = [];
    this.selection.clear();
    this.paramsDialog = {};
    this.action = 'ADD';
    this.dialogAdd.OpenDialog();
  }

  public CancelAdd() {
    this.action = null;
    this.dialogAdd.Close();
  }

  public EditRow(data) {
    this.dataIsSelected = [];
    this.selection.clear();
    this.paramsDialog = data;
    this.action = 'EDIT';
    this.dialogEdit.OpenDialog();
  }

  public CancelEdit() {
    this.action = null;
    this.dialogEdit.Close();
  }

  public Delete(data) {
    this.modal.confirm("Do you want to delete record?", this.viewref, () => this.ConfirmDelete(data));
  }

  public ConfirmDelete = data => {
    this.http.post('SL', 'SNM163P_Delete', data)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
        }
        else {
          console.log(res)
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      }, (err) => {
        console.log(err, 'err');
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
  }

  public GoToUpload() {
    this.tableTempData = [];
    this.FileName = null;
    this.showScreen = 1;
  }

  public SaveAdd() {
    if (this.paramsDialog.EFFECTIVE_DATE && this.paramsDialog.DISABLE_DATE && this.paramsDialog.CUSTOMER_CODE && this.paramsDialog.BRANCH_CODE && this.paramsDialog.PART_NO) {
      this.modal.confirm("Do you want to save change you have made?", this.viewref, this.ConfirmSave);
    }
    else {
      this.modal.warning('Please complete all request field!!', this.viewref)
    }
  }

  public ConfirmSave = () => {
    this.http.post('SL', 'SNM163P_Save', this.paramsDialog)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
          this.paramsDialog = {};
          if (this.action == 'ADD') {
            this.action = null;
            this.dialogAdd.Close();
          } else {
            this.action = null;
            this.dialogEdit.Close();
          }
        }
        else {
          this.modal.error('No change to save. Something went wrong.', this.viewref);
        }
      }, (err) => {
        console.log(err, 'err');
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
  }

  public SaveUpload() {
    let foundErr = this.tableTempData.some(x => x.MESSAGE)
    if (!foundErr) {
      this.modal.confirm("Do you want to save changed you have made?", this.viewref, this.ConfirmUpload)
    } else {
      this.modal.warning("Please check error message!!", this.viewref)
    }
  }

  public ConfirmUpload = () => {
    this.http.post('SL', 'SNM163P_SaveUpload', this.params)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.tableTempData = [];
          this.showScreen = 0;
          this.Search();
        }
        else {
          this.modal.error('No change to save. Something went wrong.', this.viewref);
        }
      }, (err) => {
        console.log(err, 'err');
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
  }

  public SelectFile(evt) {
    this.file = null;
    let Files: Array<File> = evt.target.files;

    if (Files.length > 0) {
      this.file = Files[0];
      this.FileName = this.file.name;
    }
  }

  public OpenFileBrowser() {
    this.FileName = "";
    this.fileUpload.nativeElement.value = '';
    this.fileUpload.nativeElement.click();
  }

  public DownloadTemplate() {
    let link = "assets/templates/PMS_ETA_Showing_Upload.xlsx"
    window.open(link, '_blank')
  }

  public Preview() {
    if (!this.FileName) {
      this.modal.error('Please Open xlsx File First...', this.viewref)
    } else {
      let formData = new FormData();
      formData.append('file', this.file);
      this.http.postFile("SL", "SNM163P_UploadExcel", formData)
        .subscribe(result => {
          this.http.get("SL", "SNM163P_GetTempData")
            .subscribe(result => {
              this.tableTempData = result.Table;
            })
        }, err => {
          console.log(err);
          this.modal.error("Found eror, please contact support team.", this.viewref);
        })
    }
  }

  public GotoMain() {
    this.showScreen = 0;
  }

  public GetStatus() {
    this.http.get('SL', 'SNM163P_GetStatus')
      .subscribe(res => {
        this.params = res.Table[0];
      }, (err) => {
        this.modal.warning("Found an error, please contract support team", this.viewref);
      });
  }

  public ConfirmSwitch() {
    this.modal.confirm('Do you want to change status?', this.viewref, this.SaveStatus)
  }

  SaveStatus = () => {
    this.http.post('SL', 'SNM163P_UpdateStatus', this.params)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info('Status Changed.', this.viewref);
          this.GetStatus();
        }
        else {
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      }, (err) => {
        this.modal.warning("Found an error, please contract support team", this.viewref);
      });
  }
}
