import { Component, OnInit, ElementRef, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from '../../../core/modal.service';
import { DateAdapter, MAT_DATE_FORMATS, MAT_DATE_LOCALE } from '@angular/material/core';
import { MAT_MOMENT_DATE_ADAPTER_OPTIONS, MomentDateAdapter } from '@angular/material-moment-adapter';

@Component({
  selector: 'SNM165',
  templateUrl: './SNM165.component.html',
  styleUrls: ['./SNM165.component.css'],
})


export class SNM165Component implements OnInit {


  @ViewChild("fileUpload") fileUpload: ElementRef;

  public filename: string = "";
  public extension: string = "";
  public file: any;

  public files: any = [];
  public tableUpload: any = []

  constructor(
    public http: HttpService,
    public modal: ModalService,
    public viewRef: ViewContainerRef
  ) { }

  public param: any = {};


  public tableData: any = [];
  public tableData2: any = [];
  public tableDataMultipart: any = [];
  public tableSuccess2: any = [];
  public params: any = {};

  public todayDate: Date = new Date();
  public showSuccess: Boolean;
  public showList: Boolean;
  public showListDetail: Boolean;
  public editMode: any;
  public isAdd: boolean = false;
  public tableDataDetail: any = [];
  public fileNameMultipart: string = "";
  public countMSG: number = 0;
  private File: any;
  @ViewChild("fileInput") fileInput: ElementRef;
  @ViewChild("fileInputMultipart") fileInputMultipart: ElementRef;

  @ViewChild("dialog", { static: false }) dialog: any;
  @ViewChild("dialogMultiPart", { static: false }) dialogMultiPart: any;
  ngOnInit(): void {
    this.showSuccess = false;
    this.showList = true
    this.showListDetail = false
  }

  public ConfigPart: any = {
    ColName: "LOOKUP",
    PlaceholderText: "Select Part No.",
    SourceController: "Report",
    SourceMethodName: "SNM165_GetPart",
    NoOfShowRecords: 30,
  };
  public CancelPart(event) {
    if (this.params.PART_NO) {
      this.http
        .get("Report", "SNM165_GetPart", this.params.PART_NO, "20")
        .subscribe((res) => {
          if (res.Table.length > 0) {
            this.params.PART_NO = res.Table[0].PART_NO;
            this.params.PART_NAME_EN = res.Table[0].PART_NAME_EN;
            this.params.PART_NAME_TH = res.Table[0].PART_NAME_TH;
          } else {
            this.params.PART_NO = null;
            this.params.PART_NAME_EN = null;
            this.params.PART_NAME_TH = null;
          }
        });
    } else {
      this.params.PART_KIT_NO = null;
      this.params.PART_NAME_EN = null;
      this.params.PART_NAME_TH = null;
    }
  }
  //#region Upload templates
  public DownloadTemplate(template: number) {
    let link = "";
    if (template == 1) {
      link = "assets/templates/SNM165_Upload_Template.xlsx";
    }
    window.open(link, "_blank");
  }

  public OpenFileBrowserMultipart() {
    this.fileNameMultipart = "";
    this.fileInputMultipart.nativeElement.value = "";
    this.fileInputMultipart.nativeElement.click();
  }

  public SelectFileMultipart(evt) {
    let Files: Array<File> = evt.target.files;

    if (Files.length > 0) {
      //let File: File = Files[0];
      this.File = Files[0];
      this.fileNameMultipart = this.File.name;
    }
  }

  public UploadScore() {
  
    this.http.post("Report", "SNM165_Save_Upload", this.tableUpload)
      .subscribe(res => {
        
        if (res.STATUS_MSG == 'DONE') {
          this.tableUpload = []
          this.filename = ""
          this.GetData_Upload();
        } else if (res.STATUS_MSG == 'FAIL') {
          this.modal.warning("Found an error, please contact support team", this.viewRef);
        }
        else {
          this.modal.warning("Found an error, please contact support team", this.viewRef);
        }
      }, err => {
        console.log(err, "err")
        this.modal.warning("Found an error, please contact support team", this.viewRef);
        return;
      })
  }

  public GetData_Upload() {
    this.showSuccess = true;
    this.tableDataMultipart = [];
    this.tableSuccess2 = [];
    this.http.post("Report", "SNM165_GetData_Upload", this.params)
      .subscribe(res => {
        this.tableDataMultipart = res.Table;
        this.tableSuccess2 = res.Table1;
        if (res.Table1.length > 0) {
          this.param.TOTAL_RECORD = this.tableSuccess2[0].TOTAL;
          this.param.COMPLETE = this.tableSuccess2[0].COMPLETE;
          this.param.REJECT = this.tableSuccess2[0].REJECT;
          this.param.UPLOAD_TIME = this.todayDate;

        }
      }, (err) => {
        console.log(err, "err")
        this.modal.warning("Found an error, please contact support team", this.viewRef);
      });
  }

  public PreView() {
    if (!this.fileNameMultipart) {
      this.modal.warning("Please Open File First...", this.viewRef);
      return;
    }

    let formData = new FormData();
    formData.append("file", this.File);
    this.tableDataMultipart = [];
    this.http.postFile("Report", "SNM165_Upload", formData).subscribe(
      (result) => {
        this.modal.info("Upload complete", this.viewRef);

        this.tableDataMultipart = result.filter((x) => x.PART_NO);
        this.countMSG = 0
        this.tableDataMultipart.map((data, index) => {
          let find = this.tableDataMultipart.some(
            (x, i) =>
              x.PART_NO == data.PART_NO && i != index
          );
          if (find) {
            this.countMSG += 1
            if (data.MSG) {
              data.MSG =
                data.MSG +
                " , " +
                data.PART_NO +
                " duplicate in file";
            } else {
              data.MSG = data.PART_NO + " duplicate in file";
            }
          }
        });
        console.log("this.countMSG",this.countMSG);
        
      },
      (err) => {
        this.modal.error("Upload not complete.", this.viewRef);
      }
    );
  }

  public ConfirmSaveUpload() {
    this.modal.confirm("Do you want to save?", this.viewRef, () => SaveUpload())
    let SaveUpload = () => {
      this.http.post("Report", "SNM165_Confirm_Upload", this.params)
        .subscribe(result => {
          if (result.Table[0].STATUS == "DONE") {
            this.modal.info("Save data complete", this.viewRef);
          } else if (result.status == "Fail") {
            this.modal.warning(result.message, this.viewRef);
            return;
          } else {
            this.modal.warning("Found an error, please contact support team", this.viewRef);
          }
        }, (err) => {
          console.log(err, "err")
          this.modal.warning("Found an error, please contact support team", this.viewRef);
        })
    }
  }

  public SaveMultipart() {
    if (this.tableDataMultipart.some((x) => x.MSG)) {
      this.modal.warning(
        "This data have error, Please recheck data",
        this.viewRef
      );
      return;
    }

    this.modal.confirm("Do you want to save", this.viewRef, () =>
      confirmSave()
    );

    let confirmSave = () => {
      this.http
        .post("Report", "SNM165_Confirm_Upload", this.tableDataMultipart)
        .subscribe(
          (res) => {
            console.log("res",res);
            
            if (res.Table[0].STATUS == "DONE") {
              this.modal.info(
                "Transaction complete: applied and saved.",
                this.viewRef
              );
              // this.Search();
              this.dialogMultiPart.Close();
            } else if (res.status == "Fail") {
              this.modal.warning(res.message, this.viewRef);
              return;
            } else {
              this.modal.error("No change to save. fail.1", this.viewRef);
            }
          },
          (err) => {
            this.modal.error("No change to save. fail.2", this.viewRef);
          }
        );
    };
  }



  public Search() {
    if(!this.param.PART_NO){
      this.modal.warning("Please input parts number",this.viewRef)
      return
    }
    const param = {
      PART_NO: this.param.PART_NO  ,
    }
    this.http.post("Report", "SNM165_GetData_Master", param)
      .subscribe(res => {
        
        this.tableData = res.Table;
      }, (err) => {
        console.log(err, "err")
        this.modal.warning("Found an error, please contact support team", this.viewRef);
        return;
      })
  }

  public ViewPart_No(data) {   
    this.showList = false;
    this.showListDetail = true;
    if (data.PART_NO){
      this.editMode = true
    }

    this.tableData2 = [];  
    const param = {
      PART_NO : data.PART_NO,
    } 
    this.http.post("Report", "SNM165_GetData_Part_No", param).subscribe(res => {
      this.tableData2 = res.Table;
      if (this.tableData2.length > 0) {
        this.params.COMPANY_CODE = this.tableData2[0].COMPANY_CODE
        this.params.PART_NO = this.tableData2[0].PART_NO
        this.params.PART_NAME_EN = this.tableData2[0].PART_NAME_EN,
        this.params.PART_NAME_TH = this.tableData2[0].PART_NAME_TH,
        this.params.PRODUCT_TYPE = this.tableData2[0].PRODUCT_TYPE
        this.params.USING_PURPOSE = this.tableData2[0].USING_PURPOSE
        this.params.USING_ADVICE = this.tableData2[0].USING_ADVICE
        this.params.USING_WARNING = this.tableData2[0].USING_WARNING
        this.params.LAST_UPDATE_USER = this.tableData2[0].LAST_UPDATE_USER
        this.params.LAST_UPD_DATE = this.tableData2[0].LAST_UPD_DATE
      } 
    }, (err) => { 
        console.log(err, "err")
        this.modal.warning("Found an error, please contact support team", this.viewRef); 
    });

    

    
    
  }
  public CancelEditModeSupplier() {
    this.params = {};
    this.editMode = false;
  }
  

  public SaveAdd() {
    if (!this.params.PART_NO ) {
      this.modal.warning('Please input parts number', this.viewRef);
      return;
    }

    this.modal.confirm('Do you want to save?', this.viewRef,
      () => {
        
          this.http.post("Report", "SNM165_Insert_PastNo", this.params)
            .subscribe(res => {
              if (res.Table[0].STATUS == 'DONE') {
                this.modal.info("Save data complete", this.viewRef);
                this.param.PART_NO = this.params.PART_NO;
                this.Search();
                this.dialog.Close();
              }
              else {
                console.log(res.Table[0].MESSAGE, "err")
                this.modal.warning("Found an error, please contact support team", this.viewRef);
              }
            }, (err) => {
              console.log(err, "err")
              this.modal.warning("Found an error, please contact support team", this.viewRef);
            });
      }
    )
  }

  public SaveUpdate() {
    if (!this.params.PART_NO ) {
      this.modal.warning('Please input parts number', this.viewRef);
      return;
    }
    
    this.modal.confirm('Do you want to save?', this.viewRef,
      () => {
          this.http.post("Report", "SNM165_Update_PastNo", this.params)
            .subscribe(res => {
              if (res.Table[0].STATUS == 'DONE') {
                this.modal.info("Save data complete", this.viewRef);
                this.param.PART_NO = this.params.PART_NO;
                this.Search();
                this.dialog.Close();
              }
              else {
                console.log(res.Table[0].MESSAGE, "err")
                this.modal.warning("Found an error, please contact support team", this.viewRef);
              }
            }, (err) => {
              console.log(err, "err")
              this.modal.warning("Found an error, please contact support team", this.viewRef);
            });
      }
    )
  }
  public BackToFirst() {
    this.showList = true;
    this.showListDetail = false;
    this.Search()
  }

  
  public Add() {
    this.params = {};
    this.isAdd = true;
    this.dialog.title = "Add New Part OCPB No.";

    this.dialog.OpenDialog();
  }

  
  public EditRow(datarow) {
    this.tableData2 = [];  
    this.http
      .post("Report", "SNM165_GetData_Part_No", { PART_NO: datarow.PART_NO })
      .subscribe((res) => {
        if (res.Table.length > 0) {
          this.params = res.Table[0];
          this.isAdd = false;
          // this.SearchDetail(this.params);
          this.dialog.title = "Edit Part OCPB No.";
          this.dialog.OpenDialog();
        } else {
          this.modal.warning("Part No not found.", this.viewRef);
        }
      });
  }
  public Cancel() {
    this.dialog.Close();
  }
  public SelectPart(event) {
    
    if (event) {
      this.params.PART_NO = event.PART_NO;
      this.params.PART_NAME_EN = event.PART_NAME_EN;
      this.params.PART_NAME_TH = event.PART_NAME_TH;
    } else {
      this.params.PART_NO = null;
      this.params.PART_NAME_EN = null;
      this.params.PART_NAME_TH = null;
    }
    if (this.isAdd == true){
      this.http.post("Report", "SNM165_Check_PastNo", this.params)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE' && res.Table[0].CHECKROW != 0) {
          this.modal.warning("Duplicate Part No!", this.viewRef);
          this.params.PART_NO = null;
          this.params.PART_NAME_EN = null;
          this.params.PART_NAME_TH = null;
         return;
        }
      }, (err) => {
        console.log(err, "err")
        this.modal.warning("Found an error, please contact support team", this.viewRef);
        return;
      })
      // this.modal.warning("Part No not found.", this.viewRef);
    }
  }

  public UploadMultipart() {
    this.tableDataMultipart = [];
    this.fileNameMultipart = "";
    this.dialogMultiPart.title = "Upload Parts OCPB Master";
    this.dialogMultiPart.OpenDialog();
  }
}

