import { Component, ElementRef, OnInit, QueryList, ViewChildren, ViewContainerRef, ViewChild} from "@angular/core";
import * as moment from "moment";
import { Subject } from "rxjs";
import { debounceTime, delay, map, take } from "rxjs/operators";
import { Globals } from "src/app/core/global";
import { HttpService } from "src/app/core/http.service";
import { ModalService } from "src/app/core/modal.service";
import { SignalrService } from "src/app/core/signalr.service";

@Component({
  selector: "SNWR016_M",
  templateUrl: "SNWR016_M.component.html",
})
export class SNWR016_MComponent implements OnInit {

  public params: any = {};

  constructor(
    private modal: ModalService,
    private viewRef: ViewContainerRef,
    private http: HttpService,
    private el: ElementRef,
    private global: Globals,
    private signalR: SignalrService
  ) {

    this.signalR.initiateSignalrConnection();
    this.signalR.proxy.on('pickticker', (data: any) => this.GetDataPickTicker(data));
    this.signalR.proxy.on('checkticker', (data: any) => this.GetDataCheckTicker(data));
    this.signalR.proxy.on('invoiceticker', (data: any) => this.GetDataInvoiceTicker(data));

    this.signalR.proxy.on('getdatapick', (data: any) => this.GetDataPick(data));
    this.signalR.proxy.on('getdatacheck', (data: any) => this.GetDataCheck(data));
    this.signalR.proxy.on('getdatainvoice', (data: any) => this.GetDataInvoice(data));
    this.signalR.connection.start().done((dataconnect: any) => {
      this.FirstGetData();
    }).fail((error: any) => {
      console.log('Could not connect ' + error);
    });

   }

  
  public tableDataPick: any = [];
  public tableDataCheck: any = [];
  public tableDataInvoice: any = [];
  public tableDataDetail: any = [];
  public IsSelectTab: number = 0;
  public tabIndex: number = 0;

  @ViewChild("dialogPickDetail", { static: false }) dialogPickDetail: any;

  ngOnInit() {
    this.params.SEARCH_TYPE = '1';
  }

  public lookupPickingListNoConfig: any = {
    ColName: "PICKING_LIST_NO",
    PlaceholderText: "Select Picking List No.",
    SourceController: "WH",
    SourceMethodName: "SNWR016_getPickListNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedPickingListNo(value: any) {
    this.params.PICKING_LIST_NO = value.PICKING_LIST_NO;
  }


  public Search() {
    // this.http.post('WH', 'SNWR016_GetDataPick', this.params)
    //   .subscribe(res => {
    //     this.tableDataPick = res.Table;
    //   }, (err) => {
    //     console.log(err, 'err')
    //     this.modal.warning("Found an error, please contract support team", this.viewRef);
    //   })

    // this.http.post('WH', 'SNWR016_GetDataCheck', this.params)
    //   .subscribe(res => {
    //     this.tableDataCheck = res.Table;
    //   }, (err) => {
    //     console.log(err, 'err')
    //     this.modal.warning("Found an error, please contract support team", this.viewRef);
    //   })


    // this.http.post('WH', 'SNWR016_GetDataInvoice', this.params)
    //   .subscribe(res => {
    //     this.tableDataInvoice = res.Table;
    //   }, (err) => {
    //     console.log(err, 'err')
    //     this.modal.warning("Found an error, please contract support team", this.viewRef);
    //   })

  }

  private FirstGetData(){
    this.signalR.proxy.invoke("GetDataPick",JSON.stringify(this.params));
    this.signalR.proxy.invoke("GetDataCheck",JSON.stringify(this.params))
    this.signalR.proxy.invoke("GetDataInvoice",JSON.stringify(this.params))
  }

  private GetDataPickTicker(data) {
    this.signalR.proxy.invoke("GetDataPick",JSON.stringify(this.params));
  }

  private GetDataCheckTicker(data){
    this.signalR.proxy.invoke("GetDataCheck",JSON.stringify(this.params))
  }

  private GetDataInvoiceTicker(data){
    this.signalR.proxy.invoke("GetDataInvoice",JSON.stringify(this.params))
  }

  private GetDataPick(data) {
    this.tableDataPick = data.Table;
  }

  private GetDataCheck(data){
    this.tableDataCheck = data.Table;
  }

  private GetDataInvoice(data){
    this.tableDataInvoice = data.Table;
  }

  public tabClick(tab: any) {
    if (tab != 0) {
      this.IsSelectTab = tab
    }
  }

  public ViewDetail(data: any) {
    this.params.DSP_PICKING_LIST_NO = data.PICKING_LIST_NO;
    this.tableDataDetail = [];
    this.http.post('WH', 'SNWR016_GetDataDetail', data)
      .subscribe(res => {
        this.tableDataDetail = res.Table;
        this.dialogPickDetail.OpenDialog();

      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contract support team", this.viewRef);
      })
  }

  Close() {
    this.dialogPickDetail.Close();
  }
}
