import { Component, OnInit, ViewChild, ViewContainerRef } from "@angular/core";
import { MatSelectionList, MatSelectionListChange } from "@angular/material/list";
import * as moment from "moment";
import { Globals } from "src/app/core/global";
import { HttpService } from "src/app/core/http.service";
import { ModalService } from "src/app/core/modal.service";

@Component({
  selector: "purchase-report",
  templateUrl: "PurchaseReport.component.html",
  styleUrls: ["PurchaseReport.component.css"],
})
export class PurchaseReportComponent implements OnInit {
  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewRef: ViewContainerRef,
    private global: Globals
  ) {}

  public currentDate: moment.Moment;
  public countRow: number;
  public reportList: Array<any> = [];
  
  @ViewChild("reportSelectList") reportSelectList: MatSelectionList;

  ngOnInit() {
    this.currentDate = moment();
    this.GetReportList();
    // this.GetCurrentDate();
  }

  GetReportList() {
    this.http.get("wPMS", "GetReportList", "PURCHASE").subscribe(
      (res) => {
        console.log(res)
        if (res.Table) {
          this.reportList = res.Table;
        }
      },
      (err) => {
        console.log(err, "err");
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewRef
        );
      }
    );
  }

  GetCurrentDate() {
    this.http.GetSystemDate().subscribe((d) => {
      this.currentDate = moment(d);
    });
  }

  RunReport(selectVal: MatSelectionListChange) {
    const reportName = selectVal.options[0].value;
    console.log(selectVal.options[0].value)

    this.global.GoToReport(
      reportName,
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      },
      true,
      true
    );

    this.reportSelectList.deselectAll();
  }
}
