import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router, ActivatedRoute } from '@angular/router';
import { FormControl } from '@angular/forms';
import * as moment from 'moment';

import { ModalService } from 'src/app/core/modal.service';
import { MatDialog, MatDialogRef, MAT_DIALOG_DATA } from '@angular/material/dialog';
import { DialogPoComponent } from '../../../components/shared/dialog-po/dialog-po.component';
import * as cloneDeep from 'lodash/cloneDeep';
import { Globals } from 'src/app/core/global';


@Component({
  selector: 'snm080p',
  templateUrl: './snm080p.component.html',
  styleUrls: ['./snm080p.component.css']
})


export class SNM080PComponent implements OnInit {

  constructor(
    private http: HttpService,
    private router: Router,
    private modal: ModalService,
    private viewRef: ViewContainerRef,
    public dialog: MatDialog,
    private global: Globals,
    private route: ActivatedRoute
  ) {

  }

  public formData: any = {};
  public dataList: any = [];
  public etdList: any = [];
  public mtStatusCode: any = [];
  public mtStatusAccount: any = [];
  public mtCurrencyCode: any = [];
  //private mtTariff: any = [];

  public dataDetail: any = {};
  public vendorData: any = {};
  public findPO: string;
  public findPODate: moment.Moment;
  public findInvoice: string;
  public findInvoiceDate: moment.Moment;
  public findShippedDate: moment.Moment;
  public OrderPartNo: string;
  public OrderPartName: string;
  public AcceptPartNo: string;
  public AcceptPartName: string;

  public qDisableUnitPrice: boolean;

  public section: any;
  //private pageMode: any;
  public actionMode: any;

  public lookupPOConfig: any = {
    ColName: "PO_NO",
    PlaceholderText: "Select PO No.",
    SourceController: "wPMS",
    SourceMethodName: "GetPONo",
    NoOfShowRecords: 50,
    MinLengthSearch: 3,
    UpperCase: true
  }

  public lookupInvoiceConfig: any = {
    ColName: "INVOICE_NO",
    PlaceholderText: "Select Invoice",
    SourceController: "IC",
    SourceMethodName: "SNM080P_GetInvoice",
    NoOfShowRecords: 50,
    MinLengthSearch: 3
  }

  public lookupConfig: any = {
    ColName: "LOOKUP_PART_NAME",
    PlaceholderText: "Select Part",
    SourceController: "wPMS",
    SourceMethodName: "GetPartNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 5
  }

  @ViewChild("EditETDDialog", { static: false }) EditETDDialog;

  ngOnInit() {
    this.initVariable();

    var userRole = this.global.GetTokenDetail("ssUserRole");
       
    console.log('userRole >', userRole);
    if (userRole == '1' || userRole =='25') {
      this.qDisableUnitPrice = false;
    } else {
      this.qDisableUnitPrice = true;
    }
    
    this.http.get("System", "QueryData", "SP_NP_MT_STATUS_CODE_LIST")
      .subscribe(result => {
        this.mtStatusCode = result.Table;

      })

    this.http.get("System", "QueryData", "SP_NP_MT_STATUS_ACCOUNT_LIST")
      .subscribe(result => {
        this.mtStatusAccount = result.Table;

      })

    this.http.get("System", "QueryData", "SP_NP_MT_CURRENTCY_LIST")
      .subscribe(result => {
        this.mtCurrencyCode = result.Table;

      })
  }

  initVariable() {
    this.findPO = '';
    this.dataDetail = {};
    this.dataDetail.INVOICE_DATE = null;
    this.section = 0;
    this.actionMode = 'Edit';
    this.EditETDDialog = null;
    this.formData = {};
    this.dataList = [];
  }

  openDialog(): void {
    const dialogRef = this.dialog.open(DialogPoComponent, {
      width: '750px',
      height: '500px',
      data: { data_type: 'PO_NO_INV', data_name: 'PO No.', finding_word: this.findPO }
    });

    dialogRef.afterClosed().subscribe(result => {
      this.findPO = result;

      this.Find();

    });
  }

  public Find() {

    this.section = 1;
    this.formData = {};
    this.formData.PO_DATE = '';
    this.dataList = [];
    this.http.get("IC", "GetIndentStatus",
      this.findPO || "null",
      this.global.ConvertDateToFormatSTD(this.findPODate) || "null",
      this.global.EscapeCharacter(this.findInvoice) || "null",
      this.global.ConvertDateToFormatSTD(this.findInvoiceDate) || "null",
      this.global.ConvertDateToFormatSTD(this.findShippedDate) || "null",
      this.OrderPartNo || "null",
      this.AcceptPartNo || "null"
    ).subscribe(result => {
      this.dataList = result.Table;
    })
  }

  public ViewItem(data) {
    this.actionMode = 'Edit';
    this.dataDetail = cloneDeep(data);

    this.http.get("IC", "GetETDList", data.PO_NO, data.ITEM_NO, data.SUB_ITEM_NO)
      .subscribe(result => {
        this.etdList = result.Table;
      })
    this.section = 2;
  }

  public QTY_Changed() {

    if (this.dataDetail.ACCEPT_QTY < 0) {
      this.dataDetail.ACCEPT_QTY = 0;
      this.modal.warning("The QTY must more that zero '0'", this.viewRef);
    }

    if (this.dataDetail.OVERSEA_FLAG_V = 'D') {
      this.dataDetail.EXCHANGE_RATE = 1;
      this.dataDetail.NET_AMT_B = this.dataDetail.UNIT_PRICE * this.dataDetail.ACCEPT_QTY;
      this.dataDetail.NET_AMT_C = this.dataDetail.UNIT_PRICE * this.dataDetail.ACCEPT_QTY;
    } else if (this.dataDetail.OVERSEA_FLAG_V = 'E') {


      if (this.dataDetail.EXCHANGE_UNIT == 0) {
        this.dataDetail.NET_AMT_B = 0;
      }
      else {
        this.dataDetail.NET_AMT_B = (this.dataDetail.UNIT_PRICE * this.dataDetail.ACCEPT_QTY) * this.dataDetail.EXCHANGE_RATE, 0 / (this.dataDetail.EXCHANGE_UNIT, 0);
      }

    } else {
      this.dataDetail.NET_AMT_C = this.dataDetail.UNIT_PRICE * this.dataDetail.ACCEPT_QTY;

    }

    //this.dataDetail.NET_AMT_B = this.dataDetail.ACCEPT_QTY * this.dataDetail.UNIT_PRICE;

  }


  public SaveData() {

    if (this.dataDetail.UNIT_PRICE == null || this.dataDetail.UNIT_PRICE == undefined) {
      
      this.modal.warning("Please input [Unit Price].", this.viewRef);
      return;
    }

    if (!this.dataDetail.ACCEPT_QTY || this.dataDetail.ACCEPT_QTY <= 0) {
      this.modal.warning("Accept QTY should > 0", this.viewRef);
      return;
    }

    this.modal.confirm("Are you sure to save this record?", this.viewRef,
      () => {

        this.SaveChangePart();
      }, () => { })

  }

  private SaveChangePart() {

    if (this.actionMode == 'Edit') {
      this.http.post("IC", "SNM080P_EditItem", JSON.stringify(this.dataDetail))
        .subscribe(result => {
          if (result.substring(0, 5) != "Error") {
            this.modal.info("Saved data successfully : ", this.viewRef);
            this.section = 1;
            this.Find();
          }
        }, (err) => {
          console.log(err, 'err')
        })
    } else {

      this.http.post("IC", "SNM080P_AddSubItem", JSON.stringify(this.dataDetail))
        .subscribe(result => {
          if (result.substring(0, 5) != "Error") {
            this.modal.info("Saved data successfully : ", this.viewRef);

            this.section = 1;
            this.Find();
            this.actionMode = 'Edit';
          } else {
            this.modal.warning(result.substring(), this.viewRef);
          }
        }, (err) => {
          console.log(err, 'err')
        })
    }
  }

  public AddSubItem() {
    this.actionMode = 'Add';

    this.http.get("wPMS", "GetNextPOSubItemNo", this.dataDetail.PO_NO, this.dataDetail.ITEM_NO)
      .subscribe(result => {
        this.dataDetail.OLD_SUB_ITEM_NO = this.dataDetail.SUB_ITEM_NO;
        this.dataDetail.SUB_ITEM_NO = result.SUB_ITEM_NO;
        this.dataDetail.STATUS_CODE = 'B';
        this.dataDetail.ACCEPT_QTY = this.dataDetail.REMAINING_QTY || 0;
        this.dataDetail.STATUS_ACCOUNT = '';
      })

  }

  public AddLineETD() {
    var iRow: number = 0;

    iRow = this.etdList.length;

    if (this.etdList.find(v => v.ACCEPT_QTY === 0 || !v.ETP_DATE)) {
      this.modal.error("Please fill empty line.", this.viewRef);
    } else {
      if (iRow == 0) {
        this.etdList = [];
        this.etdList[0] = {};
        this.vendorData = {};

      } else {
        this.etdList[iRow] = {};
      }

      this.etdList[iRow].ITEM_NO = this.dataDetail.ITEM_NO;
      this.etdList[iRow].SUB_ITEM_NO = this.padding2digit(iRow);

      this.etdList[iRow].ACCEPT_QTY = 0;
      this.etdList[iRow].ETD_DATE = null;
      this.etdList[iRow].ETP_DATE = null;
      this.etdList[iRow].ETA_EO_BKK_DATE = null;
      this.etdList[iRow].ETA_EO_UPC_DATE = null;
      this.etdList[iRow].ETA_RO_BKK_DATE = null;
      this.etdList[iRow].ETA_RO_UPC_DATE = null;
      this.etdList[iRow].LAST_UPD_PGM = 'SNM080P';

      this.etdList[iRow].PO_NO = this.dataDetail.PO_NO;
      this.etdList[iRow].ORDER_PART_NO = this.dataDetail.ORDER_PART_NO;
      this.etdList[iRow].ACCEPT_PART_NO = this.dataDetail.ACCEPT_PART_NO;
      this.etdList[iRow].ORDER_QTY = this.dataDetail.ORDER_QTY;

      this.etdList = this.etdList.slice();
    }

  }

  private padding2digit(pValue) {

    var gReturn: string;
    gReturn = pValue.toString(16);
    return ("00" + gReturn).slice(-2);

  }

  public GetExchangeRate() {

    var pParam: any = {};

    pParam.SHIPPED_DATE = this.dataDetail.SHIPPED_DATE;
    pParam.CURRENCY_CODE = this.dataDetail.CURRENCY_CODE;
    pParam.NET_AMT_C = this.dataDetail.NET_AMT_C;

    this.http.post("IC", "GetExchangeRate", JSON.stringify(pParam))
      .subscribe(result => {
        var dtResult = result.Table[0];

        this.dataDetail.EXCHANGE_RATE = dtResult.EXCHANGE_RATE;
        this.dataDetail.NET_AMT_B = dtResult.NET_AMT_B;

      }, (err) => {
        console.log(err, 'err');
      })

  }

  public GetEstimateDate(pType) {

    if (pType == 'ETD') {
      this.vendorData.CALC_DATE = this.vendorData.ETD_DATE;
      this.vendorData.CALC_TYPE = 'ETP';
    } else if (pType == 'ETP') {
      this.vendorData.CALC_DATE = this.vendorData.ETP_DATE;
      this.vendorData.CALC_TYPE = 'ETA';
    }

    this.vendorData.VENDOR_CODE = this.dataDetail.VENDOR_CODE;
    this.vendorData.VENDOR_TYPE = this.dataDetail.VENDOR_TYPE;
    this.vendorData.PO_CLASS = this.dataDetail.PO_CLASS;
    this.vendorData.JOB_TYPE = '2';


    this.http.post("IC", "GetEstimateDate", JSON.stringify(this.vendorData))
      .subscribe(result => {
        var dtResult = result.Table[0];

        if (pType == 'ETD') {
          this.vendorData.ETP_DATE = dtResult.ETP_DATE;
        }

        this.vendorData.ETA_EO_BKK_DATE = dtResult.ETA_EO_BKK_DATE;
        this.vendorData.ETA_EO_UPC_DATE = dtResult.ETA_EO_UPC_DATE;
        this.vendorData.ETA_RO_BKK_DATE = dtResult.ETA_RO_BKK_DATE;
        this.vendorData.ETA_RO_UPC_DATE = dtResult.ETA_RO_UPC_DATE;

      }, (err) => {
        console.log(err, 'err');
      })

  }

  public CancelEdit() {
    this.section = 1;
    // this.Find();
    this.actionMode = 'Edit';
  }

  public EditETD(data) {
    this.vendorData = cloneDeep(data);
  }

  public SaveETD() {

    if (this.vendorData.ACCEPT_QTY && this.vendorData.ACCEPT_QTY > 0
      && this.vendorData.ETD_DATE
      && this.vendorData.ETP_DATE
    ) {

      this.vendorData.H_SUB_ITEM_NO = this.dataDetail.SUB_ITEM_NO;

      this.modal.confirm("Are you sure to save this confirm ETD?", this.viewRef,
        () => {
          this.http.post("IC", "SNM080P_UpdateETD", JSON.stringify(this.vendorData))
            .subscribe(result => {
              if (result === "Done") {

                this.modal.info("Saved data successfully", this.viewRef);
                this.ViewItem(this.dataDetail);
                this.EditETDDialog.Close();
              } else {
                this.modal.error("Cannot saved data, please contract administrator", this.viewRef);

              }
            }, (err) => {
              console.log(err, 'err')
            })
        },
        () => { })
    } else {
      this.modal.warning("Accept QTY should > 0 <br>ETD Date and ETP Date should has a value.", this.viewRef)
    }
  }

  public SetSelectedOrderPart(value: any) {
    this.OrderPartNo = value.PART_NO;
    this.OrderPartName = value.PART_NAME;
  }
  public SetSelectedAcceptPart(value: any) {
    this.AcceptPartNo = value.PART_NO;
    this.AcceptPartName = value.PART_NAME;
  }

  public SetSelectedPONo(value: any) {
    this.findPO = value.PO_NO;
  }

  public SetSelectedInvoice(value: any) {
    this.findInvoice = value.INVOICE_NO;
  }

}
