import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import * as moment from 'moment';
import { Globals } from '../../../core/global';
import { ModalService } from 'src/app/core/modal.service';

@Component({
  selector: 'snpe010',
  templateUrl: './snpe010.component.html',
  styleUrls: ['./snpe010.component.css']
})



export class SNPE010Component implements OnInit {


  constructor(
    private http: HttpService,
    private global: Globals,
    private viewRef: ViewContainerRef,
    private modal: ModalService,
    private router: Router
  ) { }


  public formData: any = {};
  public dataList: any = [];
  public findInvoice: string;
  public findInvoiceDate: moment.Moment;
  public findVendorCode: string;
  public findVendorName: string;
  public isSearchCriteria: boolean = false;

  public lookupInvoiceConfig: any = {
    ColName: "INVOICE_NO",
    ColValue: "INVOICE_NO",
    PlaceholderText: "Select Invoice No.",
    SourceController: "wPMS",
    SourceMethodName: "GetInvoiceImport",
    NoOfShowRecords: 50,
    MinLengthSearch: 3
  }


  public lookupConfig: any = {
    ColName: "LOOKUP_VENDOR_NAME",
    PlaceholderText: "Select Vendor",
    SourceController: "wPMS",
    SourceMethodName: "GetVendorCode",
    NoOfShowRecords: 50,
    UpperCase: true
  }

  ngOnInit() {


    //this.http.get("System", "QueryData", "SP_NP_MT_CURRENTCY_LIST")
    //  .subscribe(result => {
    //    this.mtCurrencyCode = result.Table;

    //  })

  }

  public ViewItem(data) {

  }

  public SetSelectedInvoice(value: any) {
    this.findInvoice = value;
  }


  public SetVendorCodeLookup(value) {
    this.findVendorCode = value.VENDOR_CODE;
    this.findVendorName = value.LOOKUP_VENDOR_NAME;
  }

  public Find() {
    this.isSearchCriteria = false;
    this.formData = {};
    this.dataList = [];
    var invoiceDate;

    if (this.findInvoiceDate == null || this.findInvoiceDate == undefined) {
      invoiceDate = null;
    } else {
      invoiceDate = this.global.ConvertDateToFormatSTD(this.findInvoiceDate)
    }


    let data = {
      INVOICE_NO : this.findInvoice,
      INVOICE_DATE : invoiceDate,
      VENDOR_CODE : null
    }
    this.http.post("Ac", "SNPE0010_GetInvoiceInfo", data)
    .subscribe(result => {
      if (result != 'Error') {
        this.dataList = result.Table;

        if(result.Table.length > 0 && (this.findInvoice || this.findInvoiceDate)) {
          this.isSearchCriteria = true;
        }
      } else {
        this.modal.warning("Found an error, please contract support team", this.viewRef);
      }

    })
  }

  public Arrival_Change() {


  }


  public SaveData() {



    this.modal.confirm("Do you want to save changed you have made?", this.viewRef,
      () => {
        this.ConfirmSave();
      }, () => { })
  }

  public CheckArravalDate(event,value) {

    //console.log('value.ARRIVAL_DATE', value.ARRIVAL_DATE.toDate());

    //console.log('value.INVOICE_DATE', value.INVOICE_DATE);
    //if (value.ARRIVAL_DATE <= value.INVOICE_DATE) {
    //  this.modal.warning("The Arrival date less than Invoice date", this.viewRef);
    //}
    //if (value.ARRIVAL_DATE <= value.SHIPPED_DATE) {
    //  this.modal.warning("The Arrival date less than Shipping date", this.viewRef);
    //}

  }

  private ConfirmSave() {


    var sendData: any = [];
    var i: number = 0;
    var ii: number = 0;

    this.dataList.forEach((value) => {

      if (value.ARRIVAL_DATE && value.SHIPPED_DATE && value.C_FOUND_55_60 == 'N') {
        sendData[i] = {};
        sendData[i].INVOICE_NO = value.INVOICE_NO;
        sendData[i].INVOICE_DATE = value.INVOICE_DATE;
        sendData[i].ARRIVAL_DATE = this.global.ConvertDateToFormatSTD(value.ARRIVAL_DATE);
        sendData[i].VENDOR_CODE = value.VENDOR_CODE;
        sendData[i].LAST_UPD_PGM = 'SNPE010';
        //sendData[i].ARRIVAL_DATE_CHANGE = value.ARRIVAL_DATE != value.OLD_ARRIVAL_DATE ? 'Y' : 'N';
        //sendData[i].SHIPPED_DATE_CHANGE = value.SHIPPED_DATE != value.OLD_SHIPPED_DATE ? 'Y' : 'N';
        sendData[i].SHIPPED_DATE = this.global.ConvertDateToFormatSTD(value.SHIPPED_DATE);
        //sendData[i].OLD_SHIPPED_DATE = value.OLD_SHIPPED_DATE;
        i = i + 1;
      }

    });

    if (i == 0) {
      this.modal.info("No data for Save", this.viewRef)
      return;
    }

    this.http.post("Ac", "SNPE010_EditData", JSON.stringify(sendData))
      .subscribe(result => {
        if (result == "DONE") {
          this.Find();
          this.modal.info("Transaction complete: applied and saved.",this.viewRef);
        } else {
          this.modal.warning("Found an error, please contract support team", this.viewRef);
        }
      }, (err) => {
        this.modal.warning("Found an error, please contract support team", this.viewRef);
        console.log(err, 'err')
      })


  }

}


