import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router, ActivatedRoute } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { ModalService } from 'src/app/core/modal.service';

@Component({
  selector: 'snpp202',
  templateUrl: './snpp202.component.html',
  styleUrls: ['./snpp202.component.css']
})



export class SNPP202Component implements OnInit {

  public invConfig: any = {
    ColName: "INVOICE_NO",
    ColValue: "INVOICE_NO",
    PlaceholderText: "Select invoice",
    SourceController: "IC",
    SourceMethodName: "SNPP202_GetINV",
    NoOfShowRecords: 50
  }

  public invoiceFrom: string;
  public invoiceTo: string;
  public countRec: string;

  constructor(
    private http: HttpService,
    private router: Router,
    private global: Globals,
    private route: ActivatedRoute,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) {

  }

  public CustomerList: any = [];

  ngOnInit() {
  }

  StartProcess() {
    if (this.CheckInvoiceFrom() && this.CheckInvoiceTo()) {
      this.modal.confirm("Are you sure to run process for " + this.invoiceFrom + " - " + this.invoiceTo, this.viewref,
        () => {
          this.http.post('IC', ['SNPP202_StartProcess', this.global.EscapeCharacter(this.invoiceFrom), this.global.EscapeCharacter(this.invoiceTo)], {})
            .subscribe(result => {
              this.modal.info("Process Complete.", this.viewref);
              this.countRec = result.COUNT_REC
            })
        }, () => { })
    }
  }

  SetInvoiceFrom(val) {
    this.invoiceFrom = val;
  }

  SetInvoiceTo(val) {
    this.invoiceTo = val;
  }

  CheckInvoiceFrom() {
    if (!this.invoiceTo) {
      this.invoiceTo = this.invoiceFrom
    }

    if (!this.invoiceFrom) {
      this.modal.error("Please fill invoice.", this.viewref);
    }

    if (this.invoiceFrom && this.invoiceTo) {
      if (this.invoiceFrom > this.invoiceTo) {
        this.modal.error("First Value Not Larger Than Last Value", this.viewref)
      } else {
        return true;
      }
    }

    return false;
  }

  CheckInvoiceTo() {
    if (this.invoiceFrom && this.invoiceTo) {
      if (this.invoiceFrom > this.invoiceTo) {
        this.modal.error("First Value Not Larger Than Last Value", this.viewref)
      } else {
        return true;
      }
    } else {
      this.invoiceTo = "z";
    }

    return false;
  }

}

