import { Component, HostListener, OnInit } from "@angular/core";
import { ActivatedRoute } from "@angular/router";
import { HttpService } from "src/app/core/http.service";
import { DomSanitizer, SafeResourceUrl } from "@angular/platform-browser";
import { environment } from "./../../../environments/environment";
import { Globals } from "src/app/core/global";

@Component({
  selector: "report",
  templateUrl: "./report.component.html",
  styles: [
    `
      .report-container {
        width: 100vw;
        height: 100vh;
        overflow: hidden;
      }

      iframe {
        width: 100%;
        height: 100%;
        border: none;
      }

      .iframe-load-wrapper, .iframe-download-wrapper {
        width: 100vw;
        height: 100vh;
        background: rgba(255, 255, 255, 0.25);
        position: fixed;
      }
      .iframe-load-wrapper:after {
        content: "Please wait...";
        position: absolute;
        display: block;
        top: 50%;
        left: 50%;
        transform: translate(-50%, -50%);
        width: 15rem;
        height: 5rem;
        background: white;
        border: 1px solid #9e9e9e;
        box-shadow: 1px 1px 2px #9e9e9e;
        text-align: center;
        padding-top: 1.5rem;
      }
      .iframe-download-wrapper:after {
        content: "File ready to download";
        position: absolute;
        display: block;
        top: 50%;
        left: 50%;
        transform: translate(-50%, -50%);
        width: 15rem;
        height: 5rem;
        background: white;
        border: 1px solid #9e9e9e;
        box-shadow: 1px 1px 2px #9e9e9e;
        text-align: center;
        padding-top: 1.5rem;
      }
    `,
  ],
})
export class ReportComponent implements OnInit {
  public reportserver: string = environment.report.url;
  public showparameters: string = "false";
  public language: string = "en-us";
  public toolbar: string = "true";
  public parameters: any = [];
  private reportRootPath: string = environment.report.rootPath;

  private params: any;

  public reportName: string;

  public reportUrl: SafeResourceUrl;
  public reportUrlStr: string;
  public exportTo: string;
  public fileName: string;
  public showLoader: boolean = false;
  public showCompleteDownload: boolean = false;

  constructor(
    private route: ActivatedRoute,
    private http: HttpService,
    private sanitizer: DomSanitizer,
    private global: Globals
  ) {
    route.data.subscribe((d) => {
      if (d?.showParam) {
        this.showparameters = "true";
      }
    });

    route.params.subscribe((p) => {
      this.reportName = p.reportName;
      this.exportTo = p.exportTo;
      this.fileName = p.fileName || p.reportName;
    });

    this.parameters = route.snapshot.queryParams;
  }

  ngOnInit() {
    this.params = this.global.buildParameterString(this.parameters);

    if (this.exportTo == "pdf" || this.exportTo == "EXCELOPENXML") {
      this.reportUrlStr = this.reportserver.concat(
        "?",
        "/",
        this.reportRootPath,
        "/",
        this.reportName,
        // "&rs:Embed=true",
        "&rs:Format=" + this.exportTo,
        "&rs:FileName=" + this.fileName,
        "&rc:Parameters=",
        this.showparameters,
        this.params,
        // "&rs:ParameterLanguage=",
        // this.language,
        // "&rc:Toolbar=",
        // this.toolbar,
        // "&rs:ClearSession=true"
      );

      window.location.href = this.reportUrlStr;
        
    } else {
      this.showLoader = true;

      this.reportUrlStr = this.reportserver.concat(
        "?",
        "/",
        this.reportRootPath,
        "/",
        this.reportName,
        // "&rs:Embed=true",
        "&rc:Parameters=",
        this.showparameters,
        this.params,
        // "&rs:ParameterLanguage=",
        // this.language,
        // "&rc:Toolbar=",
        // this.toolbar,
        // "&rs:ClearSession=true"
      );
      this.reportUrl = this.sanitizer.bypassSecurityTrustResourceUrl(
        this.reportUrlStr
      );
      // window.location.href = this.reportUrlStr;

    }
  }

  ReportLoaded() {
    if (this.reportUrl) {
      this.showLoader = false;
    }
  }
}
