import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Globals } from 'src/app/core/global';
import { FormControl, Validators } from '@angular/forms';
import { ModalService } from 'src/app/core/modal.service';

@Component({
  selector: 'SNM125P',
  templateUrl: './SNM125P.component.html',
  styleUrls: ['../saleorder.component.css']
})


export class SNM125PComponent implements OnInit {


  constructor(
    private http: HttpService,
    private global: Globals,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  @ViewChild("dialogAdd", { static: false }) dialogAdd: any;
  @ViewChild("dialogEdit", { static: false }) dialogEdit: any;

  public ParamSearch: any = {};
  public Params: any = {};
  public ParamEdit: any = {};
  public ParamAdd: any = {};
  public tabledata: any = [];
  public dangerousCodeList

  public ConfigPartNo: any = {
    ColName: "LOOKUP_PART_NO",
    PlaceholderText: "Select Part No",
    SourceController: "SL",
    SourceMethodName: "SNM125P_GET_PART_NO",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public ConfigPartCode: any = {
    ColName: "LOOKUP_PART_CODE",
    PlaceholderText: "Select Part Code",
    SourceController: "SL",
    SourceMethodName: "SNM125P_GET_PART_CODE",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public PartNoAddConfig: any = {
    ColName: "LOOKUP_PART",
    PlaceholderText: "Select Part No",
    SourceController: "SL",
    SourceMethodName: "SNM125P_GET_PART_CODE_ADD",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetPartNoAdd(value: any) {
    this.ParamAdd.PART_NO = value.PART_NO;
    this.ParamAdd.PART_CODE = value.PART_CODE;
    this.ParamAdd.PART_NAME_TH = value.PART_NAME_TH;
  }

  public SetSelectedDescriptCode(value: any) {
    this.ParamSearch.DESCRIPT_CODE = value.DESCRIPT_CODE;
    this.ParamSearch.DESCRIPT_NAME = value.DESCRIPT_NAME;
  }

  public hideCols: Array<string> = [];
  ExpensiveCodeControl = new FormControl('', [Validators.required])

  public ngOnInit() {
    this.GetDangerousCode();
    this.global.GetRoleDetail().CHG === "N" ? this.hideCols.push("EDIT") : null;
    this.global.GetRoleDetail().DEL === "N" ? this.hideCols.push("DELETE") : null;
  }

  public GetDangerousCode() {
    this.http.get('SL', 'SNM125P_GetDangerousCode')
      .subscribe(res => {
        if (res.Table.length > 0) {
          this.dangerousCodeList = res.Table;
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contract support team", this.viewref);
      })
  }

  public Search() {
    this.tabledata = [];
    this.http.post("SL", "SNM125P_GET_DATA", this.ParamSearch)
      .subscribe(res => {
        this.tabledata = res.Table;
      })
  }

  public Add() {
    this.ParamAdd = {}
    this.ExpensiveCodeControl.reset();
    this.dialogAdd.OpenDialog();
  }

  public SaveAdd() {
    if (this.ParamAdd.PART_NO) {
      if (this.ParamAdd.EXPENSIVE_CODE) {
        this.modal.confirm("Do you want to save change you have made?", this.viewref, this.ConfirmSave);
      }
      else {
        this.modal.warning("Please Input fill Expensive Code", this.viewref);
      }
    }
    else {
      this.modal.warning("Please Input fill Part No", this.viewref);
    }
  }


  public ConfirmSave = () => {
    this.http.post('SL', 'SNM125P_INSERT', this.ParamAdd)
      .subscribe(res => {

        if (res.Table[0].STATUS == 'Done') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
          this.ParamAdd = this.global.ClearObject(this.ParamAdd);
          this.dialogAdd.Close();
        }
        else if (res.Table[0].STATUS == 'Duplicate') {
          this.modal.warning('No change to save. Found duplicate record.', this.viewref);
        }
        else {
          this.modal.error('No change to save. Something went wrong.', this.viewref);
        }
      })
  }

  public CancelAdd() {
    this.dialogAdd.Close();
  }

  public EditRow(data) {
    this.ExpensiveCodeControl.reset();
    this.ParamEdit = data;
    this.dialogEdit.OpenDialog();
  }

  public SaveEdit() {
    this.modal.confirm("Do you want to save changed you have made?", this.viewref, this.ConfirmEdit)
  }

  public ConfirmEdit = () => {
    this.http.post('SL', 'SNM125P_Update', this.ParamEdit)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'Done') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
          this.dialogEdit.Close();
        }
        else {
          this.modal.error('No change to save. Something went wrong.', this.viewref);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contract support team", this.viewref);
      })
  }

  public CancleEdit() {
    this.dialogEdit.Close();
  }

  public Delete(data) {
    this.modal.confirm("Do you want to delete record?", this.viewref, () => this.ConfirmDelete(data))
  }

  public ConfirmDelete = data => {
    this.http.post('SL', 'SNM125P_DELETE', data)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'Done') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
        }
        else {
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contract support team", this.viewref);
      })
  }
}
