import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Globals } from 'src/app/core/global';
import { ModalService } from 'src/app/core/modal.service';
import { SelectionModel } from '@angular/cdk/collections';

@Component({
  selector: 'snse010',
  templateUrl: './SNSE010.component.html',
  styleUrls: ['./SNSE010.component.css']
})



export class SNSE010Component implements OnInit {

  public params: any = {};
  public TOTAL_QUANTITY: number = 0;
  public TOTAL_AMOUNT: number = 0;
  public IsSearch: boolean = true;

  public orderHeader: any = {};
  public orderList: any = [];
  public orderStatus: any = [];

  constructor(
    private Http: HttpService,
    private global: Globals,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  @ViewChild("dialogReport", { static: false }) dialogReport: any;


  public tableData: any = [];
  public DataIsSelected: any = [];
  public selection = new SelectionModel<any>(true, []);

  public filteredData: any = [];


  ngOnInit() { }

  public InitData() {
    this.params.ORDER_NO = null;
    this.params.BRANCH_NAME = null;
    this.params.ORDER_CLASS = null;
    this.params.ORDER_DATE = null;
    this.params.BO_FLAG = null;

    this.TOTAL_QUANTITY = 0
    this.TOTAL_AMOUNT = 0
  }

  public lookupCustomerCodeConfig: any = {
    ColName: "LOOKUP_CUSTOMER_NAME",
    PlaceholderText: "Select Customer Code",
    SourceController: "SL",
    SourceMethodName: "SNSE010_GetCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }


  public BranchLookupConfig: any = {
    ColName: "BRANCH",
    PlaceholderText: "Select Branch Code",
    SourceController: "SL",
    SourceMethodName: "SNSE011_GetSearchBranch",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public lookupOrderNoConfig: any = {
    ColName: "LOOKUP_ORDER_NO",
    PlaceholderText: "Select Order No",
    SourceController: "SL",
    SourceMethodName: "SNSE010_GetOrderNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public lookupOrderNoRptConfig: any = {
    ColName: "ORDER_NO",
    PlaceholderText: "Select Order No",
    SourceController: "SL",
    SourceMethodName: "SNSE010_getOrderNoRpt",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public SetCustomerCode(values: any) {
    this.params.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.params.CUSTOMER_NAME = values.CUST_NAME;
    this.params.BRANCH_CODE = values.BRANCH_CODE;
    this.params.BRANCH_NAME_TH = values.BRANCH_NAME;

    this.params.CUSTOMER_CODE_FROM = values.CUSTOMER_CODE;
    this.params.CUSTOMER_CODE_TO = values.CUSTOMER_CODE;
  }

  public SetBranchLookup(values: any) {
    this.params.BRANCH_CODE = values.BRANCH_CODE;
    this.params.BRANCH_NAME_TH = values.BRANCH_NAME_TH;

  }

  public SetSelectedOrderNo(values: any) {
    this.params.ORDER_NO = values.ORDER_NO;
    this.params.ORDER_DATE = values.ORDER_DATE;
    this.params.ORDER_CLASS_TEXT = values.ORDER_CLASS_TEXT;
    this.params.ORDER_CLASS = values.ORDER_CLASS;
    this.params.BO_FLAG = values.BO_FLAG;
    this.params.LAST_UPD_NAME = values.LAST_UPD_NAME;
    this.params.LAST_UPD_DATE = values.LAST_UPD_DATE;
    //this.Search();

    this.params.ORDER_NO_FROM = values.ORDER_NO;
    this.params.ORDER_NO_TO = values.ORDER_NO;
  }
 
  public Search = () => {
    this.orderList = [];
    this.Http.post("SL", "SNSE010_GetOrderList", this.params)
      .subscribe(res => {
        this.orderList = res.Table;
      }, (err) => {
        console.log(err)
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
  }

  public ViewOrder(orderHeader) {
    this.orderHeader = orderHeader;
    this.selection.clear();
    this.DataIsSelected = [];
    this.TOTAL_AMOUNT = 0;
    this.TOTAL_QUANTITY = 0;
    this.orderStatus = [];
    this.IsSearch = false;

    if (this.orderHeader.ORDER_CLASS == '1') {
      this.orderHeader.ORDER_CLASS_SH = this.orderHeader.ORDER_CLASS + ' : Hot Line';
    }
    else if (this.orderHeader.ORDER_CLASS == '2') {
      this.orderHeader.ORDER_CLASS_SH = this.orderHeader.ORDER_CLASS + ' : Emergency Order';
    }
    else if (this.orderHeader.ORDER_CLASS == '3') {
      this.orderHeader.ORDER_CLASS_SH = this.orderHeader.ORDER_CLASS + ' : New Model';
    }
    else if (this.orderHeader.ORDER_CLASS == '4') {
      this.orderHeader.ORDER_CLASS_SH = this.orderHeader.ORDER_CLASS + ' : Regular Order';
    }
    else if (this.orderHeader.ORDER_CLASS == '5') {
      this.orderHeader.ORDER_CLASS_SH = this.orderHeader.ORDER_CLASS + ' : Conditional Order';
    }
    else if (this.orderHeader.ORDER_CLASS == '7') {
      this.orderHeader.ORDER_CLASS_SH = this.orderHeader.ORDER_CLASS + ' : OIL';
    }

    this.Http.post('SL', 'SNSE010_getData', orderHeader)
      .subscribe(res => {
        this.orderStatus = res.Table;
      }, (err) => {
        console.log(err)
        this.modal.warning("Found an error, please contact support team", this.viewref); 
      });
  }

  public isAllSelected() {
    const unmatched = this.filteredData.map((data) => this.selection.selected.find((item) => data.ITEM_NO === item.ITEM_NO))
                        .filter(isMatched => !isMatched);
    // const numSelected = this.selection.selected.length;
    // const numRows = this.orderStatus.length;
    return unmatched.length === 0;  //numSelected === numRows;
  }

  public Toggle() {
    if (this.isAllSelected()) {
      this.selection.clear()
      
      this.DataIsSelected = [];
      this.TOTAL_AMOUNT = 0
      this.TOTAL_QUANTITY = 0
    } else {

      this.DataIsSelected = [];
      this.TOTAL_AMOUNT = 0
      this.TOTAL_QUANTITY = 0

      this.filteredData.forEach(row => {
        this.selection.select(row)
        this.DataIsSelected.push(row);
        this.TOTAL_AMOUNT += row.NET_AMT_B
        this.TOTAL_QUANTITY += row.ORDER_QTY
      })
    }
  }

  public CheckBoxChanged(event, data) {
    if (event.checked) {
      this.TOTAL_AMOUNT += data.NET_AMT_B
      this.TOTAL_QUANTITY += data.ORDER_QTY
      this.DataIsSelected.push(data);
    }
    else {
      this.TOTAL_AMOUNT -= data.NET_AMT_B
      this.TOTAL_QUANTITY -= data.ORDER_QTY
      this.DataIsSelected.splice(this.DataIsSelected.indexOf(data), 1);

      if (this.TOTAL_AMOUNT < 0) { this.TOTAL_AMOUNT = 0 }
      if (this.TOTAL_QUANTITY < 0) { this.TOTAL_QUANTITY = 0 }
    }
  }

  public ConfirmSave() {
    const partList = this.DataIsSelected.map((data) => `- ${data.ORDER_PART_NO}`).join('<br/>')
    this.modal.confirm(`Do you want to cancel the selected items?<br/>${partList}`, this.viewref, this.Update, () => {}, {height: "max-content"})
  }

  public Update = () => {
    this.Http.post('SL', 'SNSE010_UpdateOrder', this.DataIsSelected)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info("Cancel selected items Completed.", this.viewref);
          this.IsSearch = true;
          this.Search();
          
        }
        else {
          this.modal.warning("Cancel selected items Failed!", this.viewref);
        }
      })
  }

  public OpenReport() {
    this.dialogReport.OpenDialog();
  }

  public CloseReport() {
    this.dialogReport.Close();
  }

  public GoToReport() {
    if (this.params.CUSTOMER_CODE_FROM && this.params.CUSTOMER_CODE_TO && this.params.ORDER_NO_FROM && this.params.ORDER_NO_TO) {
      this.global.GoToReport("PMS_RPT_SALES_SNSE010R", {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_CUST_CODE_FROM: this.params.CUSTOMER_CODE_FROM,
        P_CUST_CODE_TO: this.params.CUSTOMER_CODE_TO,
        P_ORDER_NO_FROM: this.params.ORDER_NO_FROM,
        P_ORDER_NO_TO: this.params.ORDER_NO_TO

      })
    }
    else {
      this.modal.warning("Please fill Customer Code Or Order No.", this.viewref);
    }
  }

  public BackToGrid() {
    this.IsSearch = true;
  }

  public SelectedCustomerFrom(values: any) {
    this.params.CUSTOMER_CODE_FROM = values.CUSTOMER_CODE;
    this.params.ORDER_NO_FROM = null;
    this.params.ORDER_NO_TO = null;
  }

  public SelectedCustomerTo(values: any) {
    this.params.CUSTOMER_CODE_TO = values.CUSTOMER_CODE;
    this.params.ORDER_NO_FROM = null;
    this.params.ORDER_NO_TO = null;
  }

  public SelectedOrderNoFrom(values: any) {
    this.params.ORDER_NO_FROM = values.ORDER_NO;
  }

  public SelectedOrderNoTo(values: any) {
    this.params.ORDER_NO_TO = values.ORDER_NO;
  }
}
