import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Globals } from 'src/app/core/global';
import { ModalService } from 'src/app/core/modal.service';
import { SelectionModel } from '@angular/cdk/collections';


@Component({
  selector: 'snse015',
  templateUrl: './SNSE015.component.html',
  styleUrls: ['./SNSE015.component.css']
})



export class SNSE015Component implements OnInit {

  constructor(
    private Http: HttpService,
    private global: Globals,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  @ViewChild("dialogReport", { static: false }) dialogReport: any;

  public params: any = {};
  public params2: any = {};
  public paramsByPart: any = {};

  public TableData: any = [];
  public TableDataByPart: any = [];
  public DataIsSelected: any = [];
  public DataIsSelectedByPart: any = [];
  public selection = new SelectionModel<any>(true, []);
  public selectionByPart = new SelectionModel<any>(true, []);

  ngOnInit() {
  }

  //-------------For Report---------------

  public SelectedCustomerFrom(event) {
    this.params2.CUSTOMER_CODE_FROM = event.CUSTOMER_CODE
    this.params2.ORDER_NO_FROM = null;
  }

  public SelectedCustomerTo(event) {
    this.params2.CUSTOMER_CODE_TO = event.CUSTOMER_CODE
    this.params2.ORDER_NO_TO = null;
  }

  public SelectedOrderNoFrom(event) {
    this.params2.ORDER_NO_FROM = event.ORDER_NO;
  }

  public SelectedOrderNoTo(event) {
    this.params2.ORDER_NO_TO = event.ORDER_NO;
  }

  //--------------------------------------

  public lookupCustomerCodeConfig: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "SL",
    SourceMethodName: "SNSE015_GetCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedCustomerCode(values: any) {
    this.params.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.params.CUSTOMER_NAME = values.CUSTOMER_NAME;
  

      this.params2.CUSTOMER_CODE_FROM = values.CUSTOMER_CODE;
      this.params2.CUSTOMER_CODE_TO = values.CUSTOMER_CODE;

      this.Search();
  }

  public SetSelectedCustomerCodeByPart(values: any) {
    this.paramsByPart.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.paramsByPart.CUSTOMER_NAME = values.CUSTOMER_NAME;
    this.paramsByPart.CUSTOMER_CODE_FROM = values.CUSTOMER_CODE;
    this.paramsByPart.CUSTOMER_CODE_TO = values.CUSTOMER_CODE;
    this.SearchByPart();
  }

  public lookupOrderNoConfig: any = {
    ColName: "ORDER_NO_TEXT",
    PlaceholderText: "Select Order No",
    SourceController: "SL",
    SourceMethodName: "SNSE015_GetOrderNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public SetSelectedOrderNo(values: any) {
    this.params.ORDER_NO = values.ORDER_NO;
    this.params.ORDER_CLASS = values.ORDER_CLASS;
    this.params.DSP_ORDER_CLASS = values.DSP_ORDER_CLASS;
    this.params.ORDER_DATE = values.ORDER_DATE;
    this.params.BO_FLAG = values.BO_FLAG;
    this.params.LOCK_CUSTOMER = values.LOCK_CUSTOMER;
    this.params.LAST_UPD_DATE = values.LAST_UPD_DATE;
    this.params.LAST_UPD_NAME = values.LAST_UPD_NAME;

    this.params2.ORDER_NO_FROM = values.ORDER_NO;
    this.params2.ORDER_NO_TO = values.ORDER_NO;

    this.Search();
  }

  public lookupOrderNoByPartConfig: any = {
    ColName: "ORDER_NO_TEXT",
    PlaceholderText: "Select Order No",
    SourceController: "SL",
    SourceMethodName: "SNSE015_GetOrderNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.paramsByPart
    },
    UpperCase: true
  }

  public SetSelectedOrderNoByPart(values: any) {
    this.paramsByPart.ORDER_NO = values.ORDER_NO;
    this.paramsByPart.ORDER_CLASS = values.ORDER_CLASS;
    this.paramsByPart.DSP_ORDER_CLASS = values.DSP_ORDER_CLASS;
    this.paramsByPart.ORDER_DATE = values.ORDER_DATE;
    this.paramsByPart.BO_FLAG = values.BO_FLAG;
    this.paramsByPart.LOCK_CUSTOMER = values.LOCK_CUSTOMER;
    this.paramsByPart.LAST_UPD_DATE = values.LAST_UPD_DATE;
    this.paramsByPart.LAST_UPD_NAME = values.LAST_UPD_NAME;
    this.paramsByPart.FIRST_ALLOCATE = values.FIRST_ALLOCATE;
    this.paramsByPart.FIRST_ALLOCATE_FLAG = values.FIRST_ALLOCATE_FLAG;
    this.params2.ORDER_NO_FROM = values.ORDER_NO;
    this.params2.ORDER_NO_TO = values.ORDER_NO;
    this.SearchByPart();
    if(this.paramsByPart.FIRST_ALLOCATE_FLAG == "N"){
      this.modal.warning("ออเดอร์นี้ไม่สามารถ allocate by part ได้เนื่องจากไม่พบการรัน first allocate", this.viewref);
    }
  }

  public lookupOrderNoRptConfig: any = {
    ColName: "ORDER_NO_TEXT",
    PlaceholderText: "Select Order No",
    SourceController: "SL",
    SourceMethodName: "SNSE015_GetOrderNoRpt",
    NoOfShowRecords: 100,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  Search = () => {
    this.TableData = [];
    this.Http.post('SL', 'SNSE015_getData', this.params)
      .subscribe(res => {
        this.TableData = res.Table;
      })
  }

  SearchByPart = () => {
    this.selectionByPart.clear();
    this.DataIsSelectedByPart = [];
    this.TableDataByPart = [];
    this.Http.post('SL', 'SNSE015_getData', this.paramsByPart)
      .subscribe(res => {
        this.TableDataByPart = res.Table;
      })
  }

  isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.TableData.length;
    return numSelected === numRows;
  }

  isAllSelectedByPart() {
    const numSelected = this.selectionByPart.selected.length;
    const numRows = this.TableDataByPart.length;
    return numSelected === numRows;
  }

  Toggle() {
    if (this.isAllSelected()) {
      this.selection.clear()
      this.TableData.map(x => {
        this.DataIsSelected = [];
      })
    } else {
      this.TableData.forEach(row => this.selection.select(row));
      this.DataIsSelected = [];
      this.TableData.map(x => {
        this.DataIsSelected.push(x);
      })
    }
  }

  ToggleByPart() {
    if (this.isAllSelectedByPart()) {
      this.selectionByPart.clear()
      this.TableDataByPart.map(x => {
        this.DataIsSelectedByPart = [];
      })
    } else {
      this.TableDataByPart.forEach(row => this.selectionByPart.select(row));
      this.DataIsSelectedByPart = [];
      this.TableDataByPart.map(x => {
        this.DataIsSelectedByPart.push(x);
      })
    }
  }

  CheckboxChange(event, data) {
    if (event.checked) {
      this.DataIsSelected.push(data);
    }
    else {
      this.DataIsSelected.splice(this.DataIsSelected.indexOf(data), 1);
    }
  }

  CheckboxChangeByPart(event, data) {
    if (event.checked) {
      this.DataIsSelectedByPart.push(data);
    }
    else {
      this.DataIsSelectedByPart.splice(this.DataIsSelectedByPart.indexOf(data), 1);
    }
  }


  ConfirmAllowcate() {
    this.modal.confirm('Do you want to allocate this order?', this.viewref, this.Allocate)
  }

  Allocate = () => {
    this.Http.post('SL', 'SNSE015_AllocateOrder', this.params)
      .subscribe(
        (res) => {
        if (res.STATUS == 'DONE') {
          this.modal.info("Allocate Order Completed.", this.viewref);
          this.Search();
          this.SearchByPart();
        } else {
          this.modal.warning(res.MESSAGE, this.viewref);
        }
      },
      (err) => {
        console.log(err, 'err');
        this.modal.warning("พบปัญหาการใช้งาน กรุณาแจ้งผู้ดูแลระบบ", this.viewref);
      });
  }


  ConfirmAllowcateByPart() {
    this.modal.confirm('Do you want to allocate by part that you have selected?', this.viewref, this.AllocateByPart)
  }

  AllocateByPart = () => {
    this.paramsByPart.PartsSelected = this.DataIsSelectedByPart;
    this.Http.post('SL', 'SNSE015_AllocateOrderByPart', this.paramsByPart)
      .subscribe(
        (res) => {
        if (res.STATUS == 'DONE') {
          this.modal.info("Allocate Order Completed.", this.viewref);
          this.Search();
          this.SearchByPart();
        } else {
          this.modal.warning(res.MESSAGE, this.viewref);
        }
      },
      (err) => {
        console.log(err, 'err');
        this.modal.warning("พบปัญหาการใช้งาน กรุณาแจ้งผู้ดูแลระบบ", this.viewref);
      });
  }


  openReport() {
    this.dialogReport.OpenDialog();
  }

  CloseReport() {
    this.dialogReport.Close();
  }

  public GoToReport() {
    if (this.params2.CUSTOMER_CODE_FROM && this.params2.CUSTOMER_CODE_TO && this.params2.ORDER_NO_FROM && this.params2.ORDER_NO_TO) {
      this.global.GoToReport("PMS_RPT_SALES_SNSE015R", {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_CUST_CODE_FROM: this.params2.CUSTOMER_CODE_FROM,
        P_CUST_CODE_TO: this.params2.CUSTOMER_CODE_TO,
        P_ORDER_NO_FROM: this.params2.ORDER_NO_FROM,
        P_ORDER_NO_TO: this.params2.ORDER_NO_TO
      })
    }
    else {
      this.modal.warning("Please fill Customer Code Or Order No.", this.viewref);
    }
  }

}
