import { Component, OnInit, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Globals } from 'src/app/core/global';
import { ModalService } from 'src/app/core/modal.service';
import { MatDatepicker } from '@angular/material/datepicker';
import { SelectionModel } from '@angular/cdk/collections';


@Component({
  selector: 'snse026M',
  templateUrl: './SNSE026M.component.html',
  styleUrls: ['./SNSE026M.component.css']
})

export class SNSE026MComponent implements OnInit {

  constructor(
    private Http: HttpService,
    private global: Globals,
    private modal: ModalService,
    private viewRef: ViewContainerRef
  ) { }

  public params: any = {}
  public tableData: any = [];
  public dataIsSelected: any = [];
  public selection = new SelectionModel<any>(true, []);

  public isProcessed: boolean = false;
  public isPrinted: boolean = false;

  ngOnInit() {
    this.GetFromDate();
    this.GetToDate();
    this.params.CNT_REC = 0;
    this.params.PICK_LOT_DATE = new Date();
    this.params.CNT_SEL = 0;
    this.params.PICK_LOT_SEQ = 0;
    this.params.LOCATION = "0";
    this.params.AUTO_PRINT = "0";
    this.params.ORDER_CLASS = "1";
    this.params.PRINTER_NAME = "0";
    this.params.PRINTER = "3";
    this.params.LOCATION_FROM = "1A";
    this.params.LOCATION_TO = "1B";
    this.GetPickLotSeq();
    this.params.PRINTER = 'PRINTER'
    this.params.AUTO_PRINT = 'Y'
  }

  public lookupFromAllocateDateConfig: any = {
    ColName: "DIS_ALLOCATE_DATE",
    PlaceholderText: "Select Allocate Date",
    SourceController: "SL",
    SourceMethodName: "SNSE026M_getAllocateFromDate",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public SetSelectedFromAllocateDate(values: any) {
    this.params.FROM_DATE = values.DIS_ALLOCATE_DATE;
    this.params.ALLOCATE_DATE_FROM = values.ALLOCATE_DATE;
  }

  public lookupToAllocateDateConfig: any = {
    ColName: "DIS_ALLOCATE_DATE",
    PlaceholderText: "Select Allocate Date",
    SourceController: "SL",
    SourceMethodName: "SNSE026M_getAllocateToDate",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public SetSelectedToAllocateDate(values: any) {
    this.params.TO_DATE = values.DIS_ALLOCATE_DATE;
    this.params.ALLOCATE_DATE_TO = values.ALLOCATE_DATE;
  }

  public lookupCustomerCodeConfig: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "SL",
    SourceMethodName: "SNSE026M_getCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public SetSelectedCustomerCode(values: any) {
    this.params.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.params.CUSTOMER_NAME = values.CUSTOMER_NAME;
  }

  public lookupOrderNoConfig: any = {
    ColName: "LOOKUP_ORDER_NO",
    PlaceholderText: "Select Order No",
    SourceController: "SL",
    SourceMethodName: "SNSE026M_GetOrderNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public SetSelectedOrderNo(value: any) {
    this.params.ORDER_NO = value.ORDER_NO;
  }

  public lookupAcceptPartNoConfig: any = {
    ColName: "LOOKUP_ACCEPT_PART_NO",
    PlaceholderText: "Select Accept Part No",
    SourceController: "SL",
    SourceMethodName: "SNSE026M_GetAcceptPartNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public SetSelectedAcceptPartNo(value: any) {
    this.params.ACCEPT_PART_NO = value.ACCEPT_PART_NO;
  }

  private GetPickLotSeq() {
    this.Http.get('SL', 'SNSE026M_GetPickLotSeq')
      .subscribe(res => {
        if (res.Table[0].PICK_LOT_SEQ) {
          this.params.PICK_LOT_SEQ = res.Table[0].PICK_LOT_SEQ
        }
        else {
          this.params.PICK_LOT_SEQ = 1;
        }
      });
  }

  private GetToDate() {
    this.params.ALLOCATE_DATE = 'TO'
    this.Http.post('SL', 'SNSE026M_FirstLast_Date', this.params)
      .subscribe(res => {
        this.params.TO_DATE = res.Table[0].DIS_ALLOCATE_DATE
        this.params.ALLOCATE_DATE_TO = res.Table[0].ALLOCATE_DATE;
      });
  }

  private GetFromDate() {
    this.params.ALLOCATE_DATE = 'FROM'
    this.Http.post('SL', 'SNSE026M_FirstLast_Date', this.params)
      .subscribe(res => {
        this.params.FROM_DATE = res.Table[0].DIS_ALLOCATE_DATE
        this.params.ALLOCATE_DATE_FROM = res.Table[0].ALLOCATE_DATE;
      });
  }

  public Search = () => {
    if (this.params.CUSTOMER_CODE) {
      this.params.PICKING_LIST_NO = null;
      this.params.PICK_LOT_SEQ = null;
      this.params.CNT_SEL = 0;
      this.tableData = []
      this.dataIsSelected = []
      this.selection.clear() 
      this.Http.post('SL', 'SNSE026M_getData', this.params)
        .subscribe(res => {
          this.tableData = res.Table;
          this.params.CNT_REC = this.tableData.length;
          this.isPrinted = false;
          this.GetPickLotSeq();
        });
    }
    else {
      this.modal.warning("Please input Customer Code.", this.viewRef);
    }
  }


  public CustomerChange() {
    if (!this.params.CUSTOMER_CODE) {
      this.params.ORDER_NO = '';
      this.params.ACCEPT_PART_NO = '';
    }
  }

  public isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.tableData.length;
    return numSelected === numRows;
  }

  public Toggle() {
    if (this.isAllSelected()) {
      this.selection.clear()
      this.tableData.map(x => {
        this.dataIsSelected = [];
      })
    } else {
      this.tableData.forEach(row => this.selection.select(row));
      this.dataIsSelected = [];
      this.params.LOCATION = '0';
      this.tableData.map(x => {
        x.PICK_LOT_DATE = this.params.PICK_LOT_DATE
        x.PICK_LOT_SEQ = this.params.PICK_LOT_SEQ
        this.dataIsSelected.push(x);
      })
    }
    //console.log(this.dataIsSelected)
    this.params.CNT_SEL = this.dataIsSelected.length;
  }

  public CheckboxChange(event, data) {
    if (event.checked) {
      //data.PICK_LOT_DATE = this.params.PICK_LOT_DATE
      //data.PICK_LOT_SEQ = this.params.PICK_LOT_SEQ
      //data.PICKING_LIST_NO = this.params.PICKING_LIST_NO_2
      this.dataIsSelected.push(data);
    }
    else {
      this.dataIsSelected.splice(this.dataIsSelected.indexOf(data), 1);
    }
    this.params.CNT_SEL = this.dataIsSelected.length;
  }

  public SetFromTo() {
    if (this.params.LOCATION == "1") {
      this.selection.clear();
      this.dataIsSelected = [];
      this.tableData.forEach((row) => {
        if (row.LOCATION_NO) {
          if (row.LOCATION_NO.substring(0, 2).toUpperCase() >= this.params.LOCATION_FROM.substring(0, 2).toUpperCase() && row.LOCATION_NO.substring(0, 2).toUpperCase() <= this.params.LOCATION_TO.substring(0, 2).toUpperCase()) {
            this.dataIsSelected.push(row);
            this.selection.select(row);
          }
          this.params.CNT_SEL = this.dataIsSelected.length;
        }
      });
      this.modal.info("Selected from-to completed", this.viewRef);

    } else {
      this.selection.clear();
      this.dataIsSelected = [];
      this.tableData.forEach((row) => {          
          this.dataIsSelected.push(row);
          this.selection.select(row)
          this.params.CNT_SEL = this.dataIsSelected.length;        
      });
    }
  }

  public ConfirmProcess() {
    
    if (this.dataIsSelected.length > 0) {
      this.modal.confirm('Do you want to process and print picking cards? ' +'[Selected : ' + this.params.CNT_SEL + ' Items]', this.viewRef, this.Process)
    }
    else {
      this.modal.warning("No data selected.", this.viewRef);
    }
  }

  private Process = async () => {
    if (this.dataIsSelected.length > 0) {
      this.Http.get('SL', 'SNSE026M_GetPickLotSeq')
        .subscribe(res => {
          if (res.Table[0].PICK_LOT_SEQ) {
            this.params.PICK_LOT_SEQ = res.Table[0].PICK_LOT_SEQ
          }
          else {
            this.params.PICK_LOT_SEQ = 1;
          }

          this.Http.get('SL', 'SNSE026M_GetPickingNo')
            .subscribe(res => {
              this.params.PICKING_LIST_NO = res.Table[0].PICKING_LIST_NO

              this.dataIsSelected[0].PICK_LOT_DATE = this.params.PICK_LOT_DATE
              this.dataIsSelected[0].PICKING_LIST_NO = this.params.PICKING_LIST_NO;
              this.dataIsSelected[0].PICK_LOT_SEQ = this.params.PICK_LOT_SEQ;

              this.Http.post('SL', 'SNSE026M_Process', this.dataIsSelected)
                .subscribe(res => {
                  //console.log(res)
                  if (res.status == "fail") {
                    this.modal.error(res.message, this.viewRef)
                  }
                  else {
                    this.isProcessed = true;
                    if (this.params.AUTO_PRINT == 'Y') {
                      this.OpenReport()
                    } else {
                      this.modal.info("Generate picking card completed!", this.viewRef);
                    }
                  }
                }, (err) => {
                  console.log(err, 'err')
                  this.modal.warning("Found an error, please contract support team", this.viewRef);
                })

            });

        });

    }
    else {
      this.modal.warning("No selected data.", this.viewRef);
    }
  };

  public OpenReport() {
    this.Http.post('SL', 'SNSE026M_UpdateStatus', this.params)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.global.GoToReport("PMS_RPT_SALES_SNSE052R3_N",
            {
              P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
              P_CUST_CODE: this.params.CUSTOMER_CODE,
             // P_ORDER_NO: this.params.ORDER_NO,
              P_ALLOCATE_DATE_S: this.global.ConvertDateToFormatSTD(this.params.PICK_LOT_DATE), //-- Use this param instead of
              P_PICK_LIST_NO_S: this.params.PICK_LOT_SEQ, //-- Use this param instead of
              P_CREATE_BY: this.global.GetTokenDetail("ssUserName"),  
              P_IP: this.global.GetTokenDetail("ssIPAddress"),
              P_TYPE: "REQUEST"
            });
    
          this.isProcessed = false;
          this.isPrinted = true;
        }
        else {
          this.modal.warning("Update Status Fail!", this.viewRef);
        }
      })
  }

  public CheckAutoPrint(event) {
    if (event.checked) {
      this.params.AUTO_PRINT = 'Y';
    }
    else {
      this.params.AUTO_PRINT = 'N';
    }
  }

  public OpendateFromPopup(datepicker: MatDatepicker<any>) {
    datepicker.open();
  }

  public OpendateToPopup(datepicker: MatDatepicker<any>) {
    datepicker.open();
  }
}
