import { Component, OnInit, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Globals } from 'src/app/core/global';
import { ModalService } from 'src/app/core/modal.service';
import { SelectionModel } from '@angular/cdk/collections';


@Component({
  selector: 'SNSE038_W',
  templateUrl: './SNSE038_W.component.html',
  styleUrls: ['./SNSE038_W.component.css']
})



export class SNSE038_WComponent implements OnInit {

  constructor(
    private http: HttpService,
    private global: Globals,
    private modal: ModalService,
    private viewRef: ViewContainerRef
  ) { }

  public params: any = {}
  public tableData: any = [];
  public dataIsSelected: any = [];
  public selection = new SelectionModel<any>(true, []);

  public tblFooter: any = [
    {
      fieldName: "PART_NO",
      value: "Total",
      show: true
    },
    {
      fieldName: "ACCEPT_QTY",

      show: true
    },
    {
      fieldName: "NET_AMT_B",

      show: true
    }

  ]


  ngOnInit() {
    this.params.PICK_LOT_DATE = new Date();
    this.GetPickLotSeq();
    this.params.AUTO_PRINT = 'Y'
  }

  public lookupCustomerCodeConfig: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "SL",
    SourceMethodName: "SNSE038_W_GetCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedCustomerCode(values: any) {
    this.params.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.params.CUSTOMER_NAME = values.CUSTOMER_NAME;
    this.params.ORDER_NO = null;
    this.params.ORDER_CLASS = null;
    this.params.ORDER_DATE = null;
    this.params.BO_FLAG = null;
    this.params.LOCK_CUSTOMER = null;
    this.params.LAST_UPD_DATE = null;
    this.params.LAST_UPD_NAME = null;
  }

  public lookupOrderNoConfig: any = {
    ColName: "ORDER_NO_TEXT",
    PlaceholderText: "Select Order No",
    SourceController: "SL",
    SourceMethodName: "SNSE038_W_GetOrderNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public SetSelectedOrderNo(values: any) {
    this.params.ORDER_NO = values.ORDER_NO;
    this.params.ORDER_NO_TO = values.ORDER_NO;
  }

  public SetSelectedOrderNoTo(values: any) {
    this.params.ORDER_NO_TO = values.ORDER_NO;
  }

  public ClearFilter() {
    location.reload();
  }

  public Search() {
    this.tableData = [];
    this.dataIsSelected = [];
    this.selection.clear();

    this.http.post('SL', 'SNSE038_W_GetData', this.params)
      .subscribe(res => {
        this.tableData = res.Table;
        if (this.tableData.length > 0) {
          this.params.ROW_FROM = 1;
          this.params.ROW_TO = this.tableData.length;
        }
      })
  }

  public isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.tableData.length;
    return numSelected === numRows;
  }

  public Toggle() {
    if (this.isAllSelected()) {
      this.selection.clear()
      this.tableData.map(x => {
        this.dataIsSelected = [];
      })
    } else {
      this.tableData.forEach(row => this.selection.select(row));
      this.dataIsSelected = [];
      this.tableData.map(x => {
        this.dataIsSelected.push(x);
      })
    }
  }

  public CheckboxChange(event, data) {
    if (event.checked) {
      this.dataIsSelected.push(data);
    }
    else {
      this.dataIsSelected.splice(this.dataIsSelected.indexOf(data), 1);
    }
  }

  public SelectRow() {
    this.dataIsSelected = [];
    this.selection.clear();
    for (var i = 0; i < this.tableData.length; i++) {
      if (this.params.ROW_FROM <= i + 1 && this.params.ROW_TO >= i + 1) {
        this.dataIsSelected.push(this.tableData[i]);
        this.selection.select(this.tableData[i]);
      }
    };
  }

  public TotalAmount(){
    var amount = 0;
  this.dataIsSelected.forEach((e) => {
    amount = amount + e.NET_AMT_B ;
  });

    return amount;
}

  public ConfirmProcess() {
    if (this.dataIsSelected.length > 0) {
      this.modal.confirm('Do you want to process and print picking cards? ' + '[Selected : ' + this.dataIsSelected.length + ' Items]', this.viewRef, this.Process)
    }
    else {
      this.modal.warning("No data selected.", this.viewRef);
    }
  }

  private Process = () => {
    this.dataIsSelected.forEach((e) => {
      e.PICK_LOT_DATE = this.params.PICK_LOT_DATE;
    });
    this.http.post('SL', 'SNSE038_W_Process', this.dataIsSelected)
      .subscribe(result => {
        if (result.substring(0, 4) == "DONE") {

          this.modal.info("Generate picking card completed. <BR> Pick lot seq : " + this.params.PICK_LOT_SEQ, this.viewRef);
          this.Search();
      
          this.dataIsSelected = [];
          this.selection.clear();
          this.GetPickLotSeq();
          //if (this.params.AUTO_PRINT == 'Y') {
          //  this.OpenReport()
          //}

        } else {
          this.modal.warning("Found an error, please contact support team", this.viewRef);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewRef);
      })
  }

  private GetPickLotSeq() {
    this.http.get('SL', 'SNSE038_W_GetPickLotSeq')
      .subscribe(res => {
        if (res.Table[0].PICK_LOT_SEQ) {
          this.params.PICK_LOT_SEQ = res.Table[0].PICK_LOT_SEQ
        }
        else {
          this.params.PICK_LOT_SEQ = 1;
        }
      });
  }

  public OpenReport() {
    this.global.GoToReport("PMS_RPT_SALES_SNSE038R",
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_IPADD: this.global.GetTokenDetail("ssIPAddress")
      });
  }

  public CheckAutoPrint(event) {
    if (event.checked) {
      this.params.AUTO_PRINT = 'Y';
    }
    else {
      this.params.AUTO_PRINT = 'N';
    }
  }

  public SelectPartNo() {
    this.dataIsSelected = [];
    this.selection.clear();

    var acceptQTY = 0;
    var amount = 0;
    var totalAmount = 0;

    this.tableData.forEach((e) => {
      if (e.ACCEPT_PART_NO == this.params.ACCEPT_PART_NO) {
        this.dataIsSelected.push(e);
        this.selection.select(e);
        acceptQTY = acceptQTY + e.ACCEPT_QTY;
        amount = amount + e.NET_AMT_B;
        totalAmount = totalAmount + e.ACCEPT_QTY * e.NET_AMT_B;
      }
    });

    if (this.dataIsSelected.length > 0) {
      this.modal.info("Accept Qty : " + acceptQTY + "  Amont : " + amount + "  Total Amount : " + totalAmount, this.viewRef);
    }
  }
}
