import { Component, OnInit, ViewContainerRef } from '@angular/core';
import { ModalService } from 'src/app/core/modal.service';
import { HttpService } from 'src/app/core/http.service';
import { Globals } from 'src/app/core/global';

@Component({
  selector: 'snse042NA4',
  templateUrl: './SNSE042NA4.component.html',
  styleUrls: ['./SNSE042NA4.component.css']
})


export class SNSE042NA4Component implements OnInit {

  constructor(
    private Http: HttpService,
    private modal: ModalService,
    private viewRef: ViewContainerRef,
    private global: Globals,

  ) { }


  public params: any = {};

  ngOnInit() {
/*    this.InitData()*/
  }

  public ConfigPickLotSeq: any = {
    ColName: "INVOICE_SEQ_DSP",
    PlaceholderText: "Select Invoice Seq",
    SourceController: "SL",
    SourceMethodName: "SNSE042NA4_GetPickLotSeq",
    SourceParams: {
      DATA: this.params
    },
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true

  }


  public SetPickLotSeq(values: any) {
    this.params.PICK_LOT_SEQ = values.PICK_LOT_SEQ;
    this.params.BEGIN_INVOICE_NO = values.BEGIN_INVOICE_NO;
    this.params.END_INVOICE_NO = values.END_INVOICE_NO;

  }

  private GoToReport() {
    this.global.GoToReport("PMS_RPT_SALES_SNSE039R_3_A4", {
      P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      P_INVOICE_NO_FROM: this.params.BEGIN_INVOICE_NO,
      P_INVOICE_NO_TO: this.params.END_INVOICE_NO
    });
  }

  public CheckDataPreview() {
    if (this.params.BEGIN_INVOICE_NO && this.params.END_INVOICE_NO) {
      this.Http.post('SL', 'SNSE042NA4_CheckDataReport', this.params)
        .subscribe(res => {
          if (res.Table.length > 0) {
            this.GoToReport()
          } else {
            this.modal.warning("No Data Found!", this.viewRef);
          }
        }, (err) => {
          console.log(err, 'err')
          this.modal.warning("Found an error, please contract support team", this.viewRef);
        })
    }
    else {
      this.modal.warning('Please fill all data for print report!!', this.viewRef)
    }
  }

  public CheckDataReport() {
    if (this.params.BEGIN_INVOICE_NO && this.params.END_INVOICE_NO) {

      this.Http.post('SL', 'SNSE042NA4_SetPrintData', this.params)
      .subscribe(res => {
        if(res === "Exists") {
          this.modal.info("Please wait for printing.", this.viewRef);
        } else {
          this.modal.info("Not found data for printing.", this.viewRef);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contract support team", this.viewRef);
      })
      
    }
    else {
      this.modal.warning('Please fill all data for print report!!', this.viewRef)
    }
  }

  public InitData() {
    this.Http.get('SL', 'SNSE042NA4_GetInitData')
      .subscribe(res => {
        console.log(res.Table[0])
        let detail = res.Table[0]
        this.params.PICK_LOT_DATE = detail.PICK_LOT_DATE
        this.params.PICK_LOT_SEQ = detail.PICK_LOT_SEQ
        this.params.BEGIN_INVOICE_NO = detail.S_INVOICE_NO
        this.params.END_INVOICE_NO = detail.E_INVOICE_NO
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contract support team", this.viewRef);
      })
  }

}
