import { Component, OnInit, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Globals } from 'src/app/core/global';
import { ModalService } from 'src/app/core/modal.service';
import { MatDatepicker } from '@angular/material/datepicker';

@Component({
  selector: 'snse043N',
  templateUrl: './SNSE043N.component.html',
  styleUrls: ['./SNSE043N.component.css']
})

export class SNSE043NComponent implements OnInit {



  constructor(
    private Http: HttpService,
    private global: Globals,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  public params: any = {};
  public tableData: any;
  public ExportData: any;

  public lookupCustomerCodeConfig: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "SL",
    SourceMethodName: "SNSE043N_getCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public lookupInvoiceDateConfig: any = {
    ColName: "INVOICE_DATE",
    PlaceholderText: "Select Invoice Date",
    SourceController: "SL",
    SourceMethodName: "SNSE043N_getInvoiceDate",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public lookupDocNoConfig: any = {
    ColName: "LOOKUP_DOC_NO",
    PlaceholderText: "Select Doc No.",
    SourceController: "SL",
    SourceMethodName: "SNSE043N_getDocNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  clearInput() {
    this.params.INVOICE_DATE_FROM = null;
    this.params.INVOICE_DATE_TO = null;
    this.params.DOC_NO_FROM = null;
    this.params.DOC_NO_TO = null;

  }

  public SetSelectedCustomerCodeFrom(values: any) {
    this.params.DSP_CUSTOMER_CODE_FROM = values.CUSTOMER_CODE
    this.params.CUSTOMER_CODE_FROM = values.CUSTOMER_CODE;

    if (!this.params.CUSTOMER_CODE_TO) {
      this.params.DSP_CUSTOMER_CODE_TO = values.CUSTOMER_CODE
      this.params.CUSTOMER_CODE_TO = values.CUSTOMER_CODE;
    }
    this.clearInput()

  }
  public SetSelectedCustomerCodeTo(values: any) {
    this.params.DSP_CUSTOMER_CODE_TO = values.CUSTOMER_CODE
    this.params.CUSTOMER_CODE_TO = values.CUSTOMER_CODE;
    this.clearInput()
  }

  //public SetSelectedInvoiceDateFrom(values: any) {
  //  this.params.INVOICE_DATE_FROM = values.INVOICE_DATE;
  //}
  //public SetSelectedInvoiceDateTo(values: any) {
  //  this.params.INVOICE_DATE_TO = values.INVOICE_DATE;
  //}

  public SetSelectedDocNoFrom(values: any) {
    this.params.DOC_NO_FROM = values.DOC_NO;

    if (!this.params.DOC_NO_TO) {
      this.params.DOC_NO_TO = values.DOC_NO;
    }
  }
  public SetSelectedDocNoTo(values: any) {
    this.params.DOC_NO_TO = values.DOC_NO;
  }

  ngOnInit() {
    this.params.SENT_BY = 'A'
  }

  //public getData() {
  //   this.tableData = [];
  //   this.Http.post('SL', 'SNSE43N_getData', this.params)
  //     .subscribe(res => {
  //       this.tableData = res.Table;
  //       if (res.Table.length > 0) {
  //         this.ExportExcel()
  //       }
  //     });
  // }

  //private ExportExcel() {
  //   this.ExportData = this.tableData;

  //   var hash = Object.create(null);
  //   var result = this.ExportData.map(function (a) {
  //     if (!a.CASE_NO || hash[a.CASE_NO]) {
  //       a.CASE_NO = '';
  //       a.SUB_CASE_NO = '';
  //       a.GROSS_MM = '';
  //       a.GROSS_WEIGHT = '';
  //       return a;
  //     }
  //     hash[a.CASE_NO] = true;
  //     return a;
  //   });

  //   this.Http.Download('SL', "SNSE043N_ExportExcel", JSON.stringify(result))
  //     .subscribe(res => {
  //       if (res) {
  //         this.WriteContents(res)
  //       } else {
  //         this.modal.error('Download not complete', this.viewref)
  //       }
  //     })
  // }

  //private WriteContents(content) {
  //   const a = document.createElement('a');
  //   const file = new Blob([content], { type: content.type });
  //   a.href = URL.createObjectURL(file);
  //   a.download = "SNSE043N" + ".csv";
  //   a.click();
  // }


  public OpenReport() {
    //if (this.params.CUSTOMER_CODE_FROM && this.params.CUSTOMER_CODE_TO && this.params.DOC_NO_FROM && this.params.DOC_NO_TO && this.params.INVOICE_DATE_FROM && this.params.INVOICE_DATE_TO) {
    this.global.GoToReport("PMS_RPT_SALES_SNSE032R_N", {
      P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      P_CUST_S: this.params.CUSTOMER_CODE_FROM,
      P_CUST_E: this.params.CUSTOMER_CODE_TO,
      P_PINV_NO_START: this.params.DOC_NO_FROM,
      P_PINV_NO_END: this.params.DOC_NO_TO,
      P_PINV_DATE_S: this.global.ConvertDateToFormatSTD(this.params.INVOICE_DATE_FROM),
      P_PINV_DATE_E: this.global.ConvertDateToFormatSTD(this.params.INVOICE_DATE_TO),
      P_SENT_BY: this.params.SENT_BY
    })

  }

  public ExportReport() {
    //if (this.params.CUSTOMER_CODE_FROM && this.params.CUSTOMER_CODE_TO && this.params.DOC_NO_FROM && this.params.DOC_NO_TO && this.params.INVOICE_DATE_FROM && this.params.INVOICE_DATE_TO) {
    this.global.GoToExport("PMS_RPT_SALES_SNSE032R_N_Raw", {
      P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      P_CUST_S: this.params.CUSTOMER_CODE_FROM,
      P_CUST_E: this.params.CUSTOMER_CODE_TO,
      P_PINV_NO_START: this.params.DOC_NO_FROM,
      P_PINV_NO_END: this.params.DOC_NO_TO,
      P_PINV_DATE_S: this.global.ConvertDateToFormatSTD(this.params.INVOICE_DATE_FROM),
      P_PINV_DATE_E: this.global.ConvertDateToFormatSTD(this.params.INVOICE_DATE_TO),
      P_SENT_BY: this.params.SENT_BY
    } , true, "EXCELOPENXML"
    ); 
   
  }

  public SentByChange() {
    this.params.DSP_CUSTOMER_CODE_FROM = null;
    this.params.CUSTOMER_CODE_FROM = null;
    this.params.DSP_CUSTOMER_CODE_TO = null;
    this.params.CUSTOMER_CODE_TO = null;
    this.clearInput();
  }

  public OpendateFromPopup(datepicker: MatDatepicker<any>) {
    datepicker.open();
  }

  public OpendateToPopup(datepicker: MatDatepicker<any>) {
    datepicker.open();
  }

  public DateChange(date) {
    if (!this.params.INVOICE_DATE_TO) {
      this.params.INVOICE_DATE_TO = date;
    }
  }
}
