import { Component, OnInit, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';
import { SelectionModel } from '@angular/cdk/collections';


@Component({
  selector: 'SNSE212',
  templateUrl: './SNSE212.component.html',
  styleUrls: ['./SNSE212.component.css']
})



export class SNSE212Component implements OnInit {

  constructor(
    private Http: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  public params: any = {}

  public TableData: any = [];
  public DataIsSelected: any = [];

  public selection = new SelectionModel<any>(true, []);

  ngOnInit() {
  }

  public lookupCustomerCodeConfig: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "SL",
    SourceMethodName: "SNSE212GetCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedCustomerCode(values: any) {
    this.params.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.params.CUSTOMER_NAME = values.CUSTOMER_NAME;
    this.params.ORDER_NO = null;
    this.params.ORDER_CLASS = null;
    this.params.DSP_ORDER_CLASS = null;
    this.params.ORDER_DATE = null;
    this.params.BO_FLAG = null;
    this.params.LOCK_CUSTOMER = null;
    this.params.LAST_UPD_DATE = null;
    this.params.LAST_UPD_NAME = null;
  }

  public lookupOrderNoConfig: any = {
    ColName: "ORDER_NO_TEXT",
    PlaceholderText: "Select Order No",
    SourceController: "SL",
    SourceMethodName: "SNSE212GetOrderNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    }
  }

  public SetSelectedOrderNo(values: any) {
    this.params.ORDER_NO = values.ORDER_NO;
    this.params.ORDER_CLASS = values.ORDER_CLASS;
    this.params.DSP_ORDER_CLASS = values.DSP_ORDER_CLASS;
    this.params.ORDER_DATE = values.ORDER_DATE;
    this.params.BO_FLAG = values.BO_FLAG;
    this.params.LOCK_CUSTOMER = values.LOCK_CUSTOMER;
    this.params.LAST_UPD_DATE = values.LAST_UPD_DATE;
    this.params.LAST_UPD_NAME = values.LAST_UPD_NAME;

    this.Search();
  }

  private Search() {
    this.DataIsSelected = []
    this.selection.clear();
    this.TableData = [];
    this.Http.post('SL', 'SNSE212getData', this.params)
      .subscribe(res => {
        this.TableData = res.Table;
      })
  }

  public isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.TableData.length;
    return numSelected === numRows;
  }

  public Toggle() {
    if (this.isAllSelected()) {
      this.selection.clear()
      this.TableData.map(x => {
        this.DataIsSelected = [];
      })
    } else {
      this.TableData.forEach(row => this.selection.select(row));
      this.DataIsSelected = [];
      this.TableData.map(x => {
        this.DataIsSelected.push(x);
      })
    }
  }

  public CheckboxChange(event, data) {
    if (event.checked) {
      this.DataIsSelected.push(data);
      data.STATUS_CONFIRM = 'Y';
    }
    else {
      this.DataIsSelected.splice(this.DataIsSelected.indexOf(data), 1);
      data.STATUS_CONFIRM = 'N';
    }
  }

  public ConfirmAllowcate() {
    this.modal.confirm('Do you want to unlock this order part?', this.viewref, this.Allocate)
  }

  private Allocate = () => {
    this.Http.post('SL', 'SNSE212AllocateOrder', this.DataIsSelected)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info("Unlock Order Part Completed.", this.viewref);
          this.Search();
          this.selection.clear();
        }
        else {
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contract support team", this.viewref);
      })
  }
}
