import { Component, OnInit, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router, ActivatedRoute } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { ModalService } from 'src/app/core/modal.service';
import { NgForm } from '@angular/forms';

@Component({
  selector: 'snsp005m',
  templateUrl: './SNSP005_M.component.html',
  styleUrls: ['./SNSP005_M.component.css']
})


export class SNSP005MComponent implements OnInit {

  constructor(
    private http: HttpService,
    private router: Router,
    public global: Globals,
    private modal: ModalService,
    private viewRef: ViewContainerRef,
    private route: ActivatedRoute
  ) { 

  }

  public PartNo: string;
  public PartName: string;
  public dataList: any = [];
  public detailList: any = [];
  public selectedPO: any = {};
  public disabledAddLineBtn: boolean = true;
  public FormSNSP005: NgForm;

  public lookupConfig: any = {
    ColName: "LOOKUP_PART_NAME",
    PlaceholderText: "Select part",
    SourceController: "wPMS",
    SourceMethodName: "GetPartNo",
    NoOfShowRecords: 50,
    UpperCase: true
  }

  ngOnInit() {
  }

  GetData() {
    this.dataList = [];
    this.detailList = [];
    this.selectedPO = {};
    this.disabledAddLineBtn = true;
    this.http.get("IC", "SNSP005_M_Query", this.PartNo)
      .subscribe(result => {
        this.dataList = result.Table;
      })
  }

  GetDetail(selectedItem: any) {
    this.detailList = [];
    this.disabledAddLineBtn = true;
    this.http.get("IC", "SNSP005_M_GetDetail", selectedItem.PO_NO, selectedItem.ITEM_NO)
      .subscribe(result => {
        this.detailList = result.Table;
        this.disabledAddLineBtn = false;
      })
  }

  MainRowClick(data: any) {
    if (this.selectedPO.PO_NO !== data.PO_NO || this.selectedPO.ITEM_NO !== data.ITEM_NO) {
      this.selectedPO = data;

      this.GetDetail(this.selectedPO)
    }
  }

  AddConfirmLine(selectedPO: any, detailList: Array<any>) {

    if (selectedPO && selectedPO !== {}) {
      let maxSubItemNo: number = 0;
      let list = detailList.slice().sort((a, b) => {
        if (a.SUB_ITEM_NO > b.SUB_ITEM_NO) {
          return -1;
        } else if (a.SUB_ITEM_NO < b.SUB_ITEM_NO) {
          return 1;
        } else {
          return 0;
        }
      })

      if (list.length > 0) {
        maxSubItemNo = parseInt(list[0].SUB_ITEM_NO) + 1;
      }

      let addData = {
        ACCEPT_PART_NO: selectedPO.ACCEPT_PART_NO,
        ACCEPT_QTY: 1,
        ACCEPT_QTY_OLD: 1,
        COMPANY_CODE: selectedPO.COMPANY_CODE,
        CONFIRM_DATE: new Date(),
        CONFIRM_FLAG: "Y",
        CREATE_TYPE: selectedPO.CREATE_TYPE,
        ETA_EO_BKK_DATE: null,
        ETA_EO_UPC_DATE: null,
        ETA_RO_BKK_DATE: null,
        ETA_RO_UPC_DATE: null,
        ETD_DATE: null,
        ETP_DATE: null,
        ITEM_NO: selectedPO.ITEM_NO,
        ORDER_PART_NO: selectedPO.ORDER_PART_NO,
        ORDER_QTY: selectedPO.ORDER_QTY,
        PO_DATE: selectedPO.PO_DATE,
        PO_NO: selectedPO.PO_NO,
        SUB_ITEM_NO: ('00' + maxSubItemNo.toString()).substr(-2),
        VENDOR_CODE: selectedPO.VENDOR_CODE,
        TYPE: 'New'
        // OLD_ETD_DATE: ,
        // OLD_ETP_DATE: ,
      };

      if (this.ValidateDetailACCEPT_QTY(addData, true)) {
        detailList.push(addData);

        this.detailList = detailList.slice();
      }

    }
  }

  SaveData() {
    if (this.CheckSaveable()) {
      this.modal.confirm("Do you want to save changed you have made?", this.viewRef
        , () => {
          this.SaveMain()
            .subscribe(() => {
              this.SaveDetail()
                .subscribe(() => {
                  this.modal.info("Saved successfully.", this.viewRef)
                  this.GetDetail(this.selectedPO);
                }, (err) => {
                  this.modal.error(err.message, this.viewRef);
                });
            }, (err) => {
              this.modal.error(err.message, this.viewRef);
            });
        }, () => { return; })
    }
  }

  SaveMain() {
    let saveableList = this.dataList.filter(v => {
      if ((v.ACCEPT_QTY !== v.ACCEPT_QTY_OLD
        || v.STATUS_CODE !== v.STATUS_CODE_OLD
        || !this.global.CompareDate(v.ETD_DATE, v.ETD_DATE_OLD)
        || !this.global.CompareDate(v.ETP_DATE, v.ETP_DATE_OLD))
        && this.EditableMain(v)) {

        return true;
      }
      return false;
    });

    return this.http.post("IC", "SNSP005_M_SaveIndent", saveableList);
  }

  SaveDetail() {
    let saveableList = this.detailList.filter(v => {
      if (((v.ACCEPT_QTY !== v.ACCEPT_QTY_OLD && v.ACCEPT_QTY > 0)
        || !this.global.CompareDate(v.ETD_DATE, v.ETD_DATE_OLD)
        || !this.global.CompareDate(v.ETP_DATE, v.ETP_DATE_OLD))
        && this.EditableDetail()) {
        return true;
      }
      return false;
    });

    return this.http.post("IC", "SNSP005_M_SaveETDConfirm", saveableList);
  }

  CheckSaveable() {
    let modifiedMain = this.dataList.filter(v =>
      ((v.ACCEPT_QTY !== v.ACCEPT_QTY_OLD
        || v.STATUS_CODE !== v.STATUS_CODE_OLD
        || !this.global.CompareDate(v.ETD_DATE, v.ETD_DATE_OLD)
        || !this.global.CompareDate(v.ETP_DATE, v.ETP_DATE_OLD))
        && this.EditableMain(v))
    );

    let modifiedDetail = this.detailList.filter(v =>
      (((v.ACCEPT_QTY !== v.ACCEPT_QTY_OLD && v.ACCEPT_QTY > 0)
        || !this.global.CompareDate(v.ETD_DATE, v.ETD_DATE_OLD)
        || !this.global.CompareDate(v.ETP_DATE, v.ETP_DATE_OLD))
        && this.EditableDetail())
    );

    if (modifiedMain.length > 0 || modifiedDetail.length > 0) {
      return true;
    } else {
      this.modal.error("No row are modified", this.viewRef);
      return false;
    }
  }

  DeleteMain(data: any) {
    this.modal.confirm("Are you sure to delete this record?", this.viewRef,
      () => {
        this.http.post("IC", ["SNSP005_M_DeleteIndent", data.PO_NO, data.ITEM_NO, data.SUB_ITEM_NO], {})
          .subscribe(result => {
            this.modal.info("Saved successfully", this.viewRef)
            this.GetData();
          }, err => {
            console.log(err.message);
          })
      }, () => { })
  }

  DeleteDetail(data: any) {
    this.modal.confirm("Are you sure to delete this record?", this.viewRef,
      () => {
        if (data.TYPE === 'Old') {
          this.http.post("IC", ["SNSP005_M_DeleteConfirm", data.PO_NO, data.ITEM_NO, data.SUB_ITEM_NO], {})
            .subscribe(result => {
              this.modal.info("Saved successfully", this.viewRef)
            }, err => {
              console.log(err.message);
            })
        }

        let detailList = this.detailList.slice();
        let detailIdx = detailList.indexOf(data);

        detailList.splice(detailIdx, 1);

        this.detailList = detailList.slice();
      }, () => { })
  }

  /**
   * For Main fields
   */


  DateMainChange(data: any, fieldName: string) {
    this.ValidateField(data, fieldName);
  }

  CheckEditableField(data: any, fieldName: string) {
    let returnBool: boolean = true;
    switch (fieldName) {
      case 'ACCEPT_QTY': returnBool = this.EditableMain(data);
        break;
      case 'STATUS_CODE': returnBool = this.EditableMain(data);
        break;
      case 'ETD_DATE': returnBool = this.EditableMain(data);
        break;
      case 'ETP_DATE': returnBool = this.EditableMain(data);
        break;
      default: break;
    }

    return returnBool;
  }

  TitleField(data: any, fieldName: string) {
    let returnMsg: string = "";
    switch (fieldName) {
      case 'ACCEPT_QTY': if (!this.EditableMain(data)) {
        returnMsg = "Cannot change Accept qty of this @TPM_INDENT_STATUS";
      };
        break;
      case 'STATUS_CODE': if (!this.EditableMain(data)) {
        returnMsg = "Cannot change Status code of this @TPM_INDENT_STATUS";
      };
        break;
      case 'ETD_DATE': if (!this.EditableMain(data)) {
        returnMsg = "Cannot change ETD date of this @TPM_INDENT_STATUS";
      };
        break;
      case 'ETP_DATE': if (!this.EditableMain(data)) {
        returnMsg = "Cannot change ETP date of this @TPM_INDENT_STATUS";
      };
        break;
      default: break;
    }

    return returnMsg;
  }

  ValidateField(data: any, fieldName: string) {
    switch (fieldName) {
      case 'ACCEPT_QTY': return this.ValidateACCEPT_QTY(data);
        break;
      case 'ETD_DATE': return this.ValidateETD_DATE(data);
        break;
      case 'ETP_DATE': return this.ValidateETP_DATE(data);
        break;

      default: break;
    }
  }

  public EditableMain(data: any) {
    return data && data.STATUS_CODE_OLD
      && data.STATUS_CODE_OLD !== 'C'
      && data.STATUS_CODE_OLD !== '53'
      && data.STATUS_CODE_OLD !== '54'
      && data.STATUS_CODE_OLD !== '55'
      && data.STATUS_CODE_OLD !== '60'
      && data.STATUS_CODE_OLD !== 'D1';
  }


  ValidateACCEPT_QTY(data: any) {

    if (!data.ACCEPT_QTY || data.ACCEPT_QTY <= 0) {
      this.modal.error("Accept QTY must be more than 0.", this.viewRef);
      data.ACCEPT_QTY = data.ACCEPT_QTY_OLD;

      return false;
    }
    if (data.ACCEPT_QTY > data.ORDER_QTY) {
      this.modal.error("Accept QTY cannot over Order QTY.", this.viewRef);
      data.ACCEPT_QTY = data.ACCEPT_QTY_OLD;

      return false;
    }

    return true;
  }

  private ValidateETD_DATE(data: any) {
    this.http.post("IC", "SNSP005_M_CalETD", data)
      .subscribe(result => {
        data = Object.assign(data, result);
      })
  }

  private ValidateETP_DATE(data: any) {
    this.http.post("IC", "SNSP005_M_CalETP", data)
      .subscribe(result => {
        data = Object.assign(data, result);
      })
  }


  /**
   * For Detail fields
   */

  DateDetailChange(data: any, fieldName: string) {
    data.VENDOR_TYPE = this.selectedPO.VENDOR_TYPE;
    data.PO_CLASS = this.selectedPO.PO_CLASS;

    this.ValidateField(data, fieldName);
  }

  CheckEditableDetailField(data: any, fieldName: string) {
    let returnBool: boolean = true;
    switch (fieldName) {
      case 'ACCEPT_QTY': returnBool = this.EditableDetail();
        break;
      case 'ETD_DATE': returnBool = this.EditableDetail();
        break;
      case 'ETP_DATE': returnBool = this.EditableDetail();
        break;
      default: break;
    }

    return returnBool;
  }

  TitleDetailField(data: any, fieldName: string) {
    let returnMsg: string = "";
    switch (fieldName) {
      case 'ACCEPT_QTY': if (!this.EditableDetail()) {
        returnMsg = "Cannot change Accept qty.";
      };
        break;
      case 'ETD_DATE': if (!this.EditableDetail()) {
        returnMsg = "Cannot change ETD date.";
      };
        break;
      case 'ETP_DATE': if (!this.EditableDetail()) {
        returnMsg = "Cannot change ETP date.";
      };
        break;
      default: break;
    }

    return returnMsg;
  }

  public EditableDetail() {

    return this.selectedPO && this.selectedPO.STATUS_CODE_OLD
      && this.selectedPO.STATUS_CODE_OLD !== 'C'
      && this.selectedPO.STATUS_CODE_OLD !== '60'
      && this.selectedPO.STATUS_CODE_OLD !== 'D1';
  }


  ValidateDetailField(data: any, fieldName: string) {
    switch (fieldName) {
      case 'ACCEPT_QTY': return this.ValidateDetailACCEPT_QTY(data);
        break;

      default: break;
    }
  }

  ValidateDetailACCEPT_QTY(data: any, isNewItem: boolean = false) {
    let confirm_qty: number = isNewItem ? data.ACCEPT_QTY : 0;
    this.detailList.forEach(d => {
      confirm_qty += d.ACCEPT_QTY;
    });

    if (!data.ACCEPT_QTY || data.ACCEPT_QTY <= 0) {
      this.modal.error("Accept QTY must be more than 0.", this.viewRef);
      data.ACCEPT_QTY = data.ACCEPT_QTY_OLD;

      return false;
    }
    if (confirm_qty > this.selectedPO.ORDER_QTY) {
      this.modal.error("Accept QTY cannot over than Order QTY.", this.viewRef);
      data.ACCEPT_QTY = data.ACCEPT_QTY_OLD;

      return false;
    }

    return true;
  }

  SetPartNo(part) {
    this.PartNo = part.PART_NO;
    this.PartName = part.PART_NAME;
    this.GetData();
  }

}
