import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { SelectionModel } from '@angular/cdk/collections';
import { ModalService } from 'src/app/core/modal.service';
import * as moment from 'moment';

@Component({
  selector: 'snsq033',
  templateUrl: './snsq033.component.html',
  styleUrls: ['./snsq033.component.css']
})



export class SNSQ033Component implements OnInit {


  constructor(
    private http: HttpService,
    private router: Router,
    private modal : ModalService,
    private viewref : ViewContainerRef
  ) { }

  public ConfigVendor: any = {
    ColName: "LOOKUP",
    ColValue: "",
    PlaceholderText: "Select Supplier Code",
    SourceController: "SL",
    SourceMethodName: "SNSQ033_GetVendor",
    NoOfShowRecords: 30,
    MinLengthSearch: 1,
    UpperCase: false
  }

  public ConfigPart: any = {
    ColName: "LOOKUP",
    ColValue: "",
    TextSelect: "Select Part No.",
    SourceController: "SL",
    SourceMethodName: "SNSQ033_GetPart",
    NoOfShowRecords: 30,
    MinLengthSearch: 3,
    UpperCase: false,
    SourceParams: {
      FROM_DATE: null,
      TO_DATE : null,
      VENDOR_CODE : null
    },
  }

  public tableData: any = [];
  public selection = new SelectionModel<any>(true, []);
  public paramSearch : any = {}
  public logList : any = [];
  public startDate : any;
  @ViewChild("dialog",{static: false}) dialog : any;
  ngOnInit() {

    var date = new Date();
    var firstDay = new Date(date.getFullYear(), date.getMonth() , 2);
    var lastDay = new Date(date.getFullYear(), date.getMonth() + 1, 1);

    this.paramSearch.FROM_DATE = firstDay;
    this.paramSearch.TO_DATE = lastDay;
    this.paramSearch.CHECK_MIGRATION = true
    this.ConfigPart.SourceParams.FROM_DATE = firstDay
    this.ConfigPart.SourceParams.TO_DATE = lastDay
    this.paramSearch.BASE_PRICE = 'ALL';
  }

  public Search(){

    this.paramSearch.MIGRATION = this.paramSearch.CHECK_MIGRATION ? 'Y' : 'N';
    
    this.http.post("SL","SNSQ033_Search",this.paramSearch)
    .subscribe(res =>{
      this.tableData = res.Table;
      this.CreateLog([]);
    },err =>{
      this.modal.error("Found eror, please contact support team.", this.viewref);
      console.log('error',err)
    })
  }


  private GetProcessLog(){
    this.http.get("SL","SNSQ033_GetProcessLog")
    .subscribe(res => {
      this.CreateLog(res.Table)
    })
  }

  private CreateLog(array : Array<any>){

    if(array.length > 0){
      this.logList.push({
        LOG_DESCRIPTION : null
      })

      array.forEach(x =>{
        this.logList.push({
          LOG_DESCRIPTION : x.LOG_DESCRIPTION
        })
      })

    }else{
    

      if(this.logList.length > 0){
        this.logList.push({
          LOG_DESCRIPTION : null
        })
      }
  
      this.logList.push(
      {
        LOG_DESCRIPTION : 'Loading TPM_PARTS_MASTER... '+ this.tableData.length+' records... loaded...' 
      }
     )
    }
  }


  ExportDat() {

    if(this.selection.selected.length == 0){
      this.modal.warning("Please select at least 1 record",this.viewref);
      return
    }

    this.http.Download('SL', 'SNSQ033_Export_DAT',this.selection.selected)
      .subscribe(res => {
        if (res) {

          let filename = "GTTCSVAS" + moment(new Date()).format("YYYYMMDDHHmmss") + ".DAT";
          this.WriteContents(res,filename)
          this.GetProcessLog()
          
        } else {
          //console.log('errrr')
          this.modal.error('EXPORT NOT COMPLETE', this.viewref)
        }

      },err => {
        this.modal.error("Found error con not export file",this.viewref)
        console.log('errr',err)
      })
  }

  ExportDatCSV(){
    if(this.tableData.length == 0){
      this.modal.warning("No data for export file",this.viewref)
      return
    }
    this.http.Download("SL","SNSQ033_Export_CSV",this.tableData)
    .subscribe(res =>{
        let filename = "SNSQ033_" + moment(new Date()).format("YYYYMMDDHHmmss") + ".CSV";
        this.WriteContents(res,filename)
    },err =>{
      this.modal.error("Found error con not export file",this.viewref)
    })
}

  WriteContents(content,filename) {
    const a = document.createElement('a');
    const file = new Blob([content], { type: content.type });
    a.href = URL.createObjectURL(file);
    a.download = filename;
    a.click();
  }
 
  public isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.tableData.length;
    return numSelected === numRows;
  }

  public Toggle() {

    this.isAllSelected() ?
      this.selection.clear() :
      this.tableData.forEach(row => this.selection.select(row));

  }

  
  public ShowLog(){
    this.dialog.OpenDialog();
  }



}
