import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { FormControl, Validators } from '@angular/forms';
import { ModalService } from 'src/app/core/modal.service';

@Component({
  selector: 'snm041p',
  templateUrl: './SNM041P.component.html',
  styleUrls: ['./SNM041P.component.css']
})



export class SNM041PComponent implements OnInit {


  constructor(
    private http: HttpService,
    private router: Router,
    private modal : ModalService,
    private viewref : ViewContainerRef
  ) { }
  @ViewChild("dialog",{static: false}) dialog : any;
  public ParamSearch :any ={};
  public Params :any ={};
  public categoryList: any = [];
  public tabledata : any = [];
  public isAdd : boolean = false;
  public CategoryControl = new FormControl('',[Validators.required])

  public ConfigJobtype: any = {
    ColName: "LOOKUP",
    ColValue: "",
    PlaceholderText: "Select Job Type",
    SourceController: "TI",
    SourceMethodName: "SNM041P_JobType",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: false
  }

  public ConfigOrderclass: any = {
    ColName: "INV_LOOKUP",
    PlaceholderText: "Select Order Class",
    SourceController: "TI",
    SourceMethodName: "SNM041P_OrderClass",
    NoOfShowRecords: 30,
    MinLengthSearch: 0,
    UpperCase: false,
    SourceParams: {
      JOB_TYPE: null
    }
  }


  ngOnInit() {

  }

  Search(){
    this.tabledata = []
    this.http.post("TI","SNM041P_OrderList",this.ParamSearch)
    .subscribe(res =>{
          this.tabledata = res.Table
    })

  }

  Add(){
    this.Params = {}
    this.isAdd = true
    this.dialog.title = "Add Order Class"
    this.dialog.OpenDialog();
  }

  EditRow(data){

    this.http.post("TI","SNM041P_OrderList",data)
    .subscribe(res =>{
      if(res.Table.length > 0){
        this.isAdd = false;
        this.Params = res.Table[0];
        this.dialog.title = "Edit Order Class"
        this.dialog.OpenDialog();
      }else{
        this.modal.warning("Order Class not found",this.viewref)
      }
    })
  }

  Delete(data){
    this.modal.confirm("Do you want to delete racord?",this.viewref,() =>{
      this.http.get("TI","SNM041P_DELETE",data.JOB_TYPE,data.ORDER_CLASS)
      .subscribe(res =>{
        if (res.Table[0].STATUS == 'Done') {
          this.modal.info('Transaction complete: 1 record applied and deleted.', this.viewref);
          this.Search();
          this.dialog.Close();
            
        } else {
            this.modal.warning('Delete fail.', this.viewref);
        }
      })
    })
  }


  Save(){
    this.modal.confirm("Do you want to save change you have made?",this.viewref,this.ConfirmSave)
  }

  ConfirmSave = () =>{

    if(this.isAdd){
      this.http.post("TI","SNM041P_Insert",this.Params)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'Done') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          if(this.tabledata.length > 0){
            this.Search();
          }
          this.dialog.Close();                                 
        } else if (res.Table[0].STATUS == 'Duplicate') {
            this.modal.info('No change to save. Found duplicate record.', this.viewref);
        }
        else {
            this.modal.warning('No change to save. Add fail.', this.viewref);
        }
      },(err)=>{
        this.modal.warning('No change to save. Add fail.', this.viewref);
      })
    }else{
      this.http.post("TI","SNM041P_UPDATE",this.Params)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'Done') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
          this.dialog.Close();
            
        } else {
            this.modal.warning('No change to save. Update fail.', this.viewref);
        }
      })
    }

  }
  Cancel(){
    this.dialog.Close();
  }

}
