import { Component, ElementRef, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { FormControl, Validators } from '@angular/forms';
import { ModalService } from 'src/app/core/modal.service';

@Component({
  selector: 'snm132p',
  templateUrl: './SNM132P.component.html',
  styleUrls: ['./SNM132P.component.css']
})



export class SNM132PComponent implements OnInit {


  constructor(
    private http: HttpService,
    private router: Router,
    private modal : ModalService,
    private viewref : ViewContainerRef
  ) { }

  public ConfigPart: any = {
    ColName: "LOOKUP",
    PlaceholderText: "Select Part No.",
    SourceController: "TI",
    SourceMethodName: "SNM132P_GetPArt",
    NoOfShowRecords: 30
  }

  public ConfigPartKIT: any = {
    ColName: "LOOKUP",
    PlaceholderText: "Select Part No.",
    SourceController: "TI",
    SourceMethodName: "SNM132P_GetPArtKit",
    NoOfShowRecords: 30
  }

  public ConfigSpps: any = {
    ColName: "SPPS_CODE",
    ColValue: "",
    PlaceholderText: "Select Spps Code",
    SourceController: "TI",
    SourceMethodName: "SNM130P_Spps_Code",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: false
  }

  @ViewChild("dialog",{static: false}) dialog : any;
  @ViewChild("dialogMultiPart",{static: false}) dialogMultiPart : any;
  public ParamSearch :any ={};
  public Params :any ={};
  public categoryList: any = [];
  public tabledata : any = [];
  public isAdd : boolean = false;
  public CategoryControl = new FormControl('',[Validators.required])
  public tableDataDetail : any = [];
  public tableDataMultipart : any = [];
  public tempData : any = [];
  public FileName: string = "";
  public FileNameMultipart: string = "";
  private File : any;
  @ViewChild("fileInput") fileInput: ElementRef;
  @ViewChild("fileInputMultipart") fileInputMultipart: ElementRef;

  ngOnInit() {

  }

  public Search(){
    this.tabledata = []
    this.http.post("TI","SNM132P_SearchHeader",this.ParamSearch)
    .subscribe(res =>{
      //console.log(res)
          this.tabledata = res.Table
    })

  }

  public Download() {

    if(!this.Params.FILE_NAME){
      this.modal.warning("File not found!",this.viewref)
      return
    }
    
    this.http.Download('TI', 'SNM130P_Download',{filename : this.Params.FILE_NAME})
        .subscribe(res => {
            if (res) {
              this.writeContents(res,this.Params.FILE_NAME)     
            }              
        })
  }

  private writeContents(content,filename) {
    
    const a = document.createElement('a');
    const file = new Blob([content], { type: content.type });
    a.href = URL.createObjectURL(file);
    a.download = filename;
    a.click();
  }

  public DownloadTemplate(template : number){

    let link = ''
    if(template == 1){
       link = "assets/templates/Kitbom_Upload_template.xlsx"
    }else{
      link = "assets/templates/Kitbom_Multipart_Template.xlsx"
    }
    
    window.open(link,'_blank')
  }


  public openFileBrowser() {
    this.FileName = "";
    this.fileInput.nativeElement.value = '';
    this.fileInput.nativeElement.click();
  }

  public selectFile(evt) {
    
    let Files: Array<File> = evt.target.files;

    if (Files.length > 0) {
        let File: File = Files[0];
        this.FileName = File.name;

        let formData = new FormData();
        formData.append('file', File);

        this.http.postFile("TI", "SNM132P_UploadFile", formData)
            .subscribe(result => {
              
              this.modal.info("Upload complete",this.viewref);           

              if(this.tableDataDetail.filter(x => x.PART_COMPONENT_NO).length > 0){
                let newobject = [];
                this.tableDataDetail = this.tableDataDetail.filter(x => x.PART_COMPONENT_NO)

                result.forEach(x =>{
                  let find = this.tableDataDetail.find(n => n.PART_COMPONENT_NO == x.PART_COMPONENT_NO)
                  
                  if(find == undefined){
                    if(x.MSG == "OK"){
                      this.tableDataDetail.push(x)
                      this.tempData.push(x)
                    }                   
                  }
                })
                //Array.prototype.push.apply(this.tableDataDetail,newobject); 

                this.tableDataDetail.push({ 'EDIT': 'ADD', 
                                            'PART_COMPONENT_NO': null,
                                            'COMPONENT_NAME_EN' : null,
                                            'COMPONENT_NAME_TH' : null,                                     
                                            });

               
              }else{
                result = result.filter(x => x.MSG == 'OK');
                this.tableDataDetail = result;
                result.forEach(x =>{
                  this.tempData.push(x)
                })
                this.tableDataDetail.push({ 'EDIT': 'ADD', 
                                            'PART_COMPONENT_NO': null,
                                            'COMPONENT_NAME_EN' : null,
                                            'COMPONENT_NAME_TH' : null,                                     
                                            });
              }
                
            }, err => {
              this.modal.error("Upload not complete", this.viewref);
            })

    }
  }


 
  

  

  public Add(){
    this.tableDataDetail = []
    this.Params = {}
    this.isAdd = true
    this.dialog.title = "Add New Kit Bom"

    this.tableDataDetail.push({ 'EDIT': 'ADD', 
    'PART_COMPONENT_NO': null,
    'COMPONENT_NAME_EN' : null,
    'COMPONENT_NAME_TH' : null,                                     
    });


    this.dialog.OpenDialog();
  }

  public EditRow(datarow){
    
    this.http.post("TI","SNM132P_SearchHeader",{PART_NO : datarow.PART_KIT_NO})
    .subscribe(res =>{
      if(res.Table.length > 0){
        this.isAdd = false;
        this.Params = res.Table[0];
        this.SearchDetail(this.Params)
        this.dialog.title = "Edit Kit Bom"
        this.dialog.OpenDialog();
      }else{
        this.modal.warning("Kit Bom not found",this.viewref)
      }
    })

  }

  public SearchDetail(data){
    this.tableDataDetail = [];
    this.http.post("TI","SNM132P_SearchDetail",data)
    .subscribe(res =>{
          this.tableDataDetail = res.Table
          this.tableDataDetail.push({ 'EDIT': 'ADD', 
                                      'PART_COMPONENT_NO': null,
                                      'COMPONENT_NAME_EN' : null,
                                      'COMPONENT_NAME_TH' : null,                                     
                                      });
    })

  }


  public SelectPart(event){

    if(event){
      this.Params.PART_KIT_NO = event.PART_NO
      this.Params.PART_NAME_EN = event.PART_NAME_EN
      this.Params.PART_NAME_TH = event.PART_NAME_TH
    }else{
      this.Params.PART_KIT_NO = null  
      this.Params.PART_NAME_EN = null 
      this.Params.PART_NAME_TH = null 
    
    }
  }
  
  public CancelPart(event){

    if(this.Params.PART_KIT_NO){

      this.http.get("TI","SNM132P_GetPArt",this.Params.PART_KIT_NO,'20')
      .subscribe(res => {
        if(res.Table.length > 0){
          this.Params.PART_KIT_NO = res.Table[0].PART_NO
          this.Params.PART_NAME_EN = res.Table[0].PART_NAME_EN
          this.Params.PART_NAME_TH = res.Table[0].PART_NAME_TH
        }else{
          this.Params.PART_KIT_NO = null  
          this.Params.PART_NAME_EN = null 
          this.Params.PART_NAME_TH = null 
        }
        
      })
    }else{
      this.Params.PART_KIT_NO = null  
      this.Params.PART_NAME_EN = null 
      this.Params.PART_NAME_TH = null 
    }

  }

  public SelectSPPS(event){
    if(event){
      this.Params.SPPS_CODE = event.SPPS_CODE;
      this.Params.FILE_NAME = event.FILE_NAME
    }else{
      this.Params.SPPS_CODE = null;
      this.Params.FILE_NAME = null
    }
    
  }

  public CancelSPPS(event){

    if(this.Params.SPPS_CODE){

      this.http.get("TI","SNM130P_Spps_Code",this.Params.SPPS_CODE,'20')
      .subscribe(res => {
        if(res.Table.length > 0){
          this.Params.SPPS_CODE = res.Table[0].SPPS_CODE
          this.Params.FILE_NAME = res.Table[0].FILE_NAME         
        }else{
          this.Params.SPPS_CODE = null;
          this.Params.FILE_NAME = null
        }       
      })
    }else{
      this.Params.SPPS_CODE = null;
      this.Params.FILE_NAME = null
    }
  }



  public SelectKitPart(event,data,index){
  
    if(event){

    if(event.PART_NO == this.Params.PART_KIT_NO){
        this.modal.warning("Component part can not be like Kit part",this.viewref);
        data.PART_COMPONENT_NO = null
        data.COMPONENT_NAME_EN = null
        data.COMPONENT_NAME_TH = null
        data.ITEM_QTY = null
        data.REMARKS = null
        return
    }

    let duppart = this.tableDataDetail.filter((x,i) => x.PART_COMPONENT_NO == event.PART_NO && i != index);
    if(duppart.length > 0){
      this.modal.warning("Part No" + ' - ' + event.PART_NO + ' is dupplicate',this.viewref)
      data.PART_COMPONENT_NO = null
      data.COMPONENT_NAME_EN = null
      data.COMPONENT_NAME_TH = null
      data.ITEM_QTY = null
      data.REMARKS = null
      return

    }

      data.PART_COMPONENT_NO = event.PART_NO
      data.COMPONENT_NAME_EN = event.PART_NAME_EN
      data.COMPONENT_NAME_TH = event.PART_NAME_TH
  
      if(!this.isAdd){
  
        let ind = this.tempData.findIndex(x => x.PART_COMPONENT_NO == data.PART_COMPONENT_NO && data.FLAG == 'D')
        if(ind > -1){
          this.tempData.splice(ind, 1);
        }
  
        data.FLAG = 'A'
        this.tempData.push(data)
      }
    }
    else{

      data.PART_COMPONENT_NO = data.PART_COMPONENT_NO.toUpperCase()
    let duppart = this.tableDataDetail.filter((x,i) => x.PART_COMPONENT_NO == event.PART_NO && i != index);
    if(duppart.length > 0){
      this.modal.warning("Part No" + ' - ' + event.PART_NO + ' is dupplicate',this.viewref)
      data.PART_COMPONENT_NO = null
      data.COMPONENT_NAME_EN = null
      data.COMPONENT_NAME_TH = null
      data.ITEM_QTY = null
      data.REMARKS = null
      return
    }
      if(!this.isAdd){
  
        let ind = this.tempData.findIndex(x => x.PART_COMPONENT_NO == data.PART_COMPONENT_NO && data.FLAG == 'D')
        if(ind > -1){
          this.tempData.splice(ind, 1);
        }
  
        data.FLAG = 'A'
        this.tempData.push(data)
      }
      // data.PART_COMPONENT_NO = null
      // data.COMPONENT_NAME_EN = null
      // data.COMPONENT_NAME_TH = null
      // data.ITEM_QTY = null
      // data.REMARKS = null
    }
    
  }

  public CancelCallback(event,data,index){

            data.PART_COMPONENT_NO = null
            data.COMPONENT_NAME_EN = null
            data.COMPONENT_NAME_TH = null
            data.ITEM_QTY = null
            data.REMARKS = null

      // if(data.PART_COMPONENT_NO){
      //   this.http.post("TI","SNM132P_FIndPartsMaster",{PART_NO : data.PART_COMPONENT_NO})
      //   .subscribe(res =>{          
      //     if(res.Table.lenght > 0){
      //       data.PART_COMPONENT_NO = res.Table[0].PART_NO
      //       data.COMPONENT_NAME_EN = res.Table[0].PART_NAME_EN
      //       data.COMPONENT_NAME_TH = res.Table[0].PART_NAME_TH
      //     }else{
      //       this.modal.warning("Part no not found in data base",this.viewref)
      //       data.PART_COMPONENT_NO = null
      //       data.COMPONENT_NAME_EN = null
      //       data.COMPONENT_NAME_TH = null
      //       data.ITEM_QTY = null
      //       data.REMARKS = null
      //     }
      //   })
      //}
      // console.log('event',event)
      // console.log('data',data)
  }

  public CheckQty(event,data){
    if(event.target.valueAsNumber < 1){
      this.modal.warning("Quantity must not be less than 1",this.viewref)
      data.ITEM_QTY = 1;
    }
    //console.log(event.target.valueAsNumber)
  }


  public CheckRowData(){
    let filter = this.tableDataDetail.filter(x => x.PART_COMPONENT_NO) 
    let valid = filter.length > 0 ? true : false

    // let valid = this.tableDataDetail.some(x => x.PART_NO)
    return valid
  }


  public Delete(data){
    this.modal.confirm("Do you want to delete racord?",this.viewref,() =>{
      this.http.post("TI","SNM132P_Delete",data)
      .subscribe(res =>{
       
        if (res.STATUS_MSG == 'DONE') {
          this.modal.info('Transaction complete: 1 record applied and deleted.', this.viewref);
          this.Search();
          this.dialog.Close();
            
        } else {
            this.modal.warning('Delete fail.', this.viewref);
        }
      })
    })
  }


  public Save(){

    console.log(this.tableDataDetail)

    if(this.tableDataDetail.some(x => x.PART_COMPONENT_NO == this.Params.PART_KIT_NO)){
        this.modal.warning("Component part can not be like Kit part",this.viewref);
        return
    }

    if(this.tableDataDetail.some(x => x.PART_COMPONENT_NO && (x.ITEM_QTY < 1 || !x.ITEM_QTY))){
      this.modal.warning("Quantity must not be less than 1",this.viewref)
      return
    }

    console.log('this.tableDataDetail',this.tableDataDetail)

    if(this.tableDataDetail.some(x => x.PART_COMPONENT_NO && !x.COMPONENT_NAME_EN && !x.REMARKS)){
      this.modal.warning("Please write remarks for parts is not register in parts master",this.viewref)
      return
    }


    this.modal.confirm("Do you want to save change you have made?",this.viewref,this.ConfirmSave)
  }

  private ConfirmSave = () =>{

    if(this.isAdd){

      this.Params.Detail = this.tableDataDetail.filter(x => x.PART_COMPONENT_NO && x.ITEM_QTY)

      // if(this.Params.Detail.length == 0){
      //   this.modal.warning("No data for save or data not complete",this.viewref)
      //   return;
      // }

      this.http.post("TI","SNM132P_Insert",this.Params)
      .subscribe(res => {
        
        if (res.STATUS_MSG == 'DONE') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          if(this.tabledata.length > 0){
            this.Search();
          }
          this.dialog.Close();                                 
        } else if (res.STATUS_MSG == 'DUPLICATE') {
            this.modal.info('No change to save. Found duplicate record.', this.viewref);
        }
        else {
            this.modal.warning('No change to save. Add fail.', this.viewref);
        }
      },(err)=>{
        this.modal.warning('No change to save. Add fail.', this.viewref);
      })
    }else{

      
      // if(this.tableDataDetail.some(x => (x.FLAG == 'U' || x.FLAG == 'A') && x.PART_COMPONENT_NO && x.ITEM_QTY < 1)){
      //   this.modal.warning("Quantity must not be less than 1",this.viewref)
      //   return
      // }

      this.tableDataDetail.map(x => {
        if(x.FLAG == 'U'){
          this.tempData.push(x)
        }
      })

      //console.log('dddddd',this.tempData)
      this.Params.Detail = this.tempData

      // if(this.Params.Detail.length == 0){
      //   this.modal.warning("No detail data",this.viewref)
      //   return;
      // }
      
      this.http.post("TI","SNM132P_Update",this.Params)
      .subscribe(res => {
        if (res.STATUS_MSG == 'DONE') {
          this.tempData = [];
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
          this.dialog.Close();
            
        } else {
            this.modal.error('No change to save. Update fail.', this.viewref);
        }
      },err =>{
        this.modal.error('No change to save. Update fail.', this.viewref);
      })
    }

  }
  public Cancel(){
    this.dialog.Close();
  }

  public AppendRow() {
    for (var i = 0; i < this.tableDataDetail.length; i++) {
      if (this.tableDataDetail[i].EDIT === "ADD") {
        this.tableDataDetail[i].EDIT = 'DEL';
      }
    }
    this.tableDataDetail.push({ 'EDIT': 'ADD', 
    'PART_COMPONENT_NO': null,
    'COMPONENT_NAME_EN' : null,
    'COMPONENT_NAME_TH' : null,                                     
    });

    this.tableDataDetail = this.tableDataDetail.slice();

    
  }
  public DeleteRow(index,data) {

    if(!this.isAdd){
      let ind = this.tempData.findIndex(x => x.PART_KIT_NO == data.PART_KIT_NO && data.FLAG == 'A')
      if(ind > -1){
        this.tempData.splice(ind, 1);
      }
      data.FLAG = 'D'
      this.tempData.push(data)
    }

      //let index = this.tableDataDetail.findIndex(x => x == Item)
      this.tableDataDetail.splice(index, 1);
      this.tableDataDetail = this.tableDataDetail.slice();
 
  }

  public UploadMultipart(){
    this.tableDataMultipart = []
    this.FileNameMultipart = "";
    this.dialogMultiPart.title = "Add New Kit Bom"
    this.dialogMultiPart.OpenDialog()
  }

  public SaveMultipart(){

    if(this.tableDataMultipart.some(x => x.MSG)){
      this.modal.warning("This data have error,please recheck data",this.viewref)
      return
    }


    this.modal.confirm("Do you want to save",this.viewref,() => confirmSave())

    let confirmSave = () =>{
        this.http.post("TI","SNM132P_SaveMultipart",this.tableDataMultipart)
          .subscribe(res =>{
            if (res.STATUS_MSG == 'DONE') {              
              this.modal.info('Transaction complete: applied and saved.', this.viewref);
              this.Search();
              this.dialogMultiPart.Close();
                
            } else {
                this.modal.error('No change to save. fail.', this.viewref);
            }
          },err =>{
            this.modal.error('No change to save. fail.', this.viewref);
          })
    }
  }


  public OpenFileBrowserMultipart() {
    this.FileNameMultipart = "";
    this.fileInputMultipart.nativeElement.value = '';
    this.fileInputMultipart.nativeElement.click();
  }

  public SelectFileMultipart(evt) {
    let Files: Array<File> = evt.target.files;

    if (Files.length > 0) {
      //let File: File = Files[0];
      this.File = Files[0];
      this.FileNameMultipart = this.File.name;
    }
  }

  public PreView() {

    if (!this.FileNameMultipart) {
      this.modal.warning("Please Open File First...", this.viewref)
      return;
    }
    
        let formData = new FormData();
        formData.append('file', this.File);
        this.tableDataMultipart = []
        this.http.postFile("TI", "SNM132P_UploadMultiParts", formData)
            .subscribe(result => {
              
              this.modal.info("Upload complete",this.viewref);      
               
              this.tableDataMultipart = result.filter(x => x.PART_KIT_NO)

              this.tableDataMultipart.map((data, index) => {

                let find = this.tableDataMultipart.some((x, i) => x.PART_KIT_NO == data.PART_KIT_NO && x.PART_COMPONENT_NO == data.PART_COMPONENT_NO && i != index)
                if (find) {
                  if (data.MSG) {
                    data.MSG = data.MSG + ' , ' + data.PART_COMPONENT_NO + ' duplicate in file'
                  } else {
                    data.MSG = data.PART_COMPONENT_NO + ' duplicate in file'
                  }
                }
      
              })
                
            }, err => {
              this.modal.error("Upload not complete", this.viewref);
            })

    
  }
}

