import {
  Component,
  ElementRef,
  OnInit,
  ViewChild,
  ViewContainerRef,
} from "@angular/core";
import { HttpService } from "src/app/core/http.service";
import { Router } from "@angular/router";
import { FormControl, Validators } from "@angular/forms";
import { ModalService } from "src/app/core/modal.service";
import { Globals } from 'src/app/core/global';

@Component({
  selector: "SNM172P",
  templateUrl: "./SNM172P.component.html",
  styleUrls: ["./SNM172P.component.css"],
})
export class SNM172PComponent implements OnInit {
  constructor(
    private http: HttpService,
    private router: Router,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private global: Globals
  ) {}

  public ConfigPart: any = {
    ColName: "LOOKUP",
    PlaceholderText: "Select Part No.",
    SourceController: "TI",
    SourceMethodName: "SNM172P_GetPart",
    NoOfShowRecords: 30,
  };

  public SelectPart(event) {
    if (event) {
      if(event.EXISTS_FOUND == 'Y'){
        this.modal.warning(
          "Found this P/N: " + event.PART_NO + " already in Transfer Indent Part.",
          this.viewref
        );
      }
      this.params.PART_TRANSFER_NO = event.PART_NO;
      this.params.PART_NAME_EN = event.PART_NAME_EN;
      this.params.PART_NAME_TH = event.PART_NAME_TH;
      this.params.VENDOR = event.VENDOR;
      this.params.PIC = event.PIC;
    } else {
      this.params.PART_TRANSFER_NO = null;
      this.params.PART_NAME_EN = null;
      this.params.PART_NAME_TH = null;
      this.params.VENDOR = null;
      this.params.PIC = null;
    }
  }

  public CancelPart(event) {
    if (this.params.PART_TRANSFER_NO) {
      this.http
        .get("TI", "SNM172P_GetPart", this.params.PART_TRANSFER_NO, "20")
        .subscribe((res) => {
          if (res.Table.length > 0) {
            if(res.Table[0].EXISTS_FOUND == 'Y'){
              this.modal.warning(
                "Found this P/N: " + res.Table[0].PART_NO + " already in Transfer Indent Part.",
                this.viewref
              );
            }
            this.params.PART_TRANSFER_NO = res.Table[0].PART_NO;
            this.params.PART_NAME_EN = res.Table[0].PART_NAME_EN;
            this.params.PART_NAME_TH = res.Table[0].PART_NAME_TH;
            this.params.PART_NAME_TH = res.Table[0].VENDOR;
            this.params.PART_NAME_TH = res.Table[0].PIC;
          } else {
            this.params.PART_TRANSFER_NO = null;
            this.params.PART_NAME_EN = null;
            this.params.PART_NAME_TH = null;
            this.params.VENDOR = null;
            this.params.PIC = null;
          }
        });
    } else {
      this.params.PART_TRANSFER_NO = null;
      this.params.PART_NAME_EN = null;
      this.params.PART_NAME_TH = null;
      this.params.VENDOR = null;
      this.params.PIC = null;
    }
  }

  public ConfigPartKIT: any = {
    ColName: "LOOKUP",
    PlaceholderText: "Select Part No.",
    SourceController: "TI",
    SourceMethodName: "SNM172P_GetPartTransfer",
    NoOfShowRecords: 30,
  };

  public SelectKitPart(event, data, index) {
    if (event) {
      if (event.PART_NO == this.params.PART_TRANSFER_NO) {
        this.modal.warning(
          "Component part can not be like Kit part",
          this.viewref
        );
        data.PART_COMPONENT_NO = null;
        data.COMPONENT_NAME_EN = null;
        data.COMPONENT_NAME_TH = null;
        data.ITEM_QTY = null;
        data.STOCK_TYPE = null;
        data.REMARKS = null;
        return;
      }

      let duppart = this.tableDataDetail.filter(
        (x, i) => x.PART_COMPONENT_NO == event.PART_NO && i != index
      );
      if (duppart.length > 0) {
        this.modal.warning(
          "Part No" + " - " + event.PART_NO + " is dupplicate.",
          this.viewref
        );
        data.PART_COMPONENT_NO = null;
        data.COMPONENT_NAME_EN = null;
        data.COMPONENT_NAME_TH = null;
        data.ITEM_QTY = null;
        data.STOCK_TYPE = null;
        data.REMARKS = null;
        return;
      }

      data.PART_COMPONENT_NO = event.PART_NO;
      data.COMPONENT_NAME_EN = event.PART_NAME_EN;
      data.COMPONENT_NAME_TH = event.PART_NAME_TH;

      if (!this.isAdd) {
        let ind = this.tempData.findIndex(
          (x) =>
            x.PART_COMPONENT_NO == data.PART_COMPONENT_NO && data.FLAG == "D"
        );
        if (ind > -1) {
          this.tempData.splice(ind, 1);
        }

        data.FLAG = "A";
        this.tempData.push(data);
      }
    } else {
      data.PART_COMPONENT_NO = data.PART_COMPONENT_NO.toUpperCase();
      let duppart = this.tableDataDetail.filter(
        (x, i) => x.PART_COMPONENT_NO == event.PART_NO && i != index
      );
      if (duppart.length > 0) {
        this.modal.warning(
          "Part No" + " - " + event.PART_NO + " is dupplicate",
          this.viewref
        );
        data.PART_COMPONENT_NO = null;
        data.COMPONENT_NAME_EN = null;
        data.COMPONENT_NAME_TH = null;
        data.ITEM_QTY = null;
        data.STOCK_TYPE = null;
        data.REMARKS = null;
        return;
      }
      if (!this.isAdd) {
        let ind = this.tempData.findIndex(
          (x) =>
            x.PART_COMPONENT_NO == data.PART_COMPONENT_NO && data.FLAG == "D"
        );
        if (ind > -1) {
          this.tempData.splice(ind, 1);
        }

        data.FLAG = "A";
        this.tempData.push(data);
      }
    }
  }

  public CancelKitPart(event, data, index) {
    data.PART_COMPONENT_NO = null;
    data.COMPONENT_NAME_EN = null;
    data.COMPONENT_NAME_TH = null;
    data.ITEM_QTY = null;
    data.STOCK_TYPE = null;
    data.REMARKS = null;
  }

  @ViewChild("dialog", { static: false }) dialog: any;
  @ViewChild("dialogMultiPart", { static: false }) dialogMultiPart: any;
  public paramSearch: any = {};
  public params: any = {};
  public categoryList: any = [];
  public isAdd: boolean = false;
  public tableDataHeader: any = [];
  public tableDataDetail: any = [];
  public tableDataMultipart: any = [];
  public tempData: any = [];
  public paramDataMultipart: any = {};
  public fileName: string = "";
  public fileNameMultipart: string = "";
  private File: any;
  @ViewChild("fileInputMultipart") fileInputMultipart: ElementRef;

  ngOnInit() {
    this.paramSearch.PIC = this.global.GetTokenDetail("ssUserName");
    this.Search();
  }

  public Search() {
    this.tableDataHeader = [];
    this.http.post("TI", "SNM172P_SearchHeader", this.paramSearch)
      .subscribe((res) => {
        //console.log(res)
        this.tableDataHeader = res.Table;
      }, err => {
        console.log(err, 'err');
        this.modal.error("Found error please contact support team",this.viewref);
      })
  }

  public SearchDetail(data) {
    this.tableDataDetail = [];
    this.http.post("TI", "SNM172P_SearchDetail", data)
      .subscribe((res) => {
        this.tableDataDetail = res.Table;
        this.tableDataDetail.push({
          EDIT: "ADD",
          PART_COMPONENT_NO: null,
          COMPONENT_NAME_EN: null,
          COMPONENT_NAME_TH: null,
        });
    }, err => {
      console.log(err, 'err');
      this.modal.error("Found error please contact support team",this.viewref);
    });
  }

  public ExportExcel() {
    this.global.GoToExport("PMS_RPT_TI_SNM172P_DATA",
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_PART_NO: this.paramSearch.PART_NO,
        P_PIC: this.paramSearch.PIC,
      }, true, "EXCELOPENXML");
  }

  public Delete(data) {
    this.modal.confirm("Do you want to delete record?", this.viewref, () => {
      this.http.post("TI", "SNM172P_Delete", data)
      .subscribe(
        (res) => {
          if (res.STATUS == "DONE") {
            this.modal.info(
              "Transaction complete: 1 record applied and deleted.",
              this.viewref
            );
            this.Search();
            this.dialog.Close();
          } else if (res.STATUS == "FAIL") { 
            this.modal.warning(res.MSG, this.viewref);
          } else {
            this.modal.warning("Delete fail.", this.viewref);
          }
        },
        (err) => {
          console.log('err', err);
          this.modal.warning("Found an error, please contact support team", this.viewref);
      });
    });
  }

  public Add() {
    this.tableDataDetail = [];
    this.params = {};
    this.isAdd = true;
    this.dialog.title = "Add New Transfer Indent Part";

    this.tableDataDetail.push({
      EDIT: "ADD",
      PART_COMPONENT_NO: null,
      COMPONENT_NAME_EN: null,
      COMPONENT_NAME_TH: null,
    });

    this.dialog.OpenDialog();
  }

  public Edit(datarow) {
    this.http
      .post("TI", "SNM172P_SearchHeader", { PART_NO: datarow.PART_TRANSFER_NO })
      .subscribe((res) => {
        if (res.Table.length > 0) {
          this.isAdd = false;
          this.params = res.Table[0];
          this.SearchDetail(this.params);
          this.dialog.title = "Edit Transfer Indent Part";
          this.dialog.OpenDialog();
        } else {
          this.modal.warning("Transfer Indent Part not found.", this.viewref);
        }
      },(err) => {
        console.log('err', err);
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
  }

  public CheckQty(event, data) {
    if (event.target.valueAsNumber < 1) {
      this.modal.warning("Quantity must not be less than 1", this.viewref);
      data.ITEM_QTY = 1;
    }
    //console.log(event.target.valueAsNumber)
  }

  public Save() {
    if (this.tableDataDetail.some((x) => x.PART_COMPONENT_NO == this.params.PART_TRANSFER_NO)) {
      this.modal.warning(
        "Component part can not be like TF part.",
        this.viewref
      );
      return;
    }

    if (this.tableDataDetail.some((x) => x.PART_COMPONENT_NO && (x.ITEM_QTY < 1 || !x.ITEM_QTY))) {
      this.modal.warning("Quantity must not be less than 1 digit.", this.viewref);
      return;
    }

    if (this.tableDataDetail.some((x) => x.PART_COMPONENT_NO && (!x.STOCK_TYPE || x.STOCK_TYPE === null || x.STOCK_TYPE.match(/^ *$/) !== null))) {
      this.modal.warning("Stock type must not be null.", this.viewref);
      return;
    }

    if (this.tableDataDetail.some((x) => x.PART_COMPONENT_NO && !x.COMPONENT_NAME_EN && !x.REMARKS)) {
      this.modal.warning(
        "Please write remarks for parts is not register in parts master.",
        this.viewref
      );
      return;
    }

    this.modal.confirm(
      "Do you want to save change you have made?",
      this.viewref,
      this.ConfirmSave
    );
  }

  private ConfirmSave = () => {
    if (this.isAdd) {
      this.params.Detail = this.tableDataDetail.filter(
        (x) => x.PART_COMPONENT_NO && x.ITEM_QTY
      );

      this.http.post("TI", "SNM172P_Insert", this.params).subscribe(
        (res) => {
          if (res.STATUS_MSG == "DONE") {
            this.modal.info(
              "Transaction complete: applied and saved.",
              this.viewref
            );
            if (this.tableDataHeader.length > 0) {
              this.Search();
            }
            this.dialog.Close();
          } else if (res.STATUS_MSG == "DUPLICATE") {
            this.modal.info(
              "No change to save. Found duplicate record.",
              this.viewref
            );
          } else {
            this.modal.warning("No change to save. Add fail.", this.viewref);
          }
        },
        (err) => {
          console.log('err', err)
          this.modal.warning("No change to save. Add fail.", this.viewref);
        }
      );
    } else {
      this.tableDataDetail.map((x) => {
        if (x.FLAG == "U") {
          this.tempData.push(x);
        }
      });
      this.params.Detail = this.tempData;
      this.http.post("TI", "SNM172P_Update", this.params).subscribe(
        (res) => {
          if (res.STATUS_MSG == "DONE") {
            this.tempData = [];
            this.modal.info(
              "Transaction complete: applied and saved.",
              this.viewref
            );
            this.Search();
            this.dialog.Close();
          } else {
            this.modal.error("No change to save. Update fail.", this.viewref);
          }
        },
        (err) => {
          console.log('err', err)
          this.modal.error("No change to save. Update fail.", this.viewref);
        }
      );
    }
  };

  public AppendRow() {
    for (var i = 0; i < this.tableDataDetail.length; i++) {
      if (this.tableDataDetail[i].EDIT === "ADD") {
        this.tableDataDetail[i].EDIT = "DEL";
      }
    }
    this.tableDataDetail.push({
      EDIT: "ADD",
      PART_COMPONENT_NO: null,
      COMPONENT_NAME_EN: null,
      COMPONENT_NAME_TH: null,
    });

    this.tableDataDetail = this.tableDataDetail.slice();
  }

  public DeleteRow(index, data) {
    if (!this.isAdd) {
      let ind = this.tempData.findIndex(
        (x) => x.PART_TRANSFER_NO == data.PART_TRANSFER_NO && data.FLAG == "A"
      );
      if (ind > -1) {
        this.tempData.splice(ind, 1);
      }
      data.FLAG = "D";
      this.tempData.push(data);
    }

    //let index = this.tableDataDetail.findIndex(x => x == Item)
    this.tableDataDetail.splice(index, 1);
    this.tableDataDetail = this.tableDataDetail.slice();
  }

  public UploadMultipart() {
    this.paramDataMultipart = {};
    this.paramDataMultipart.errorList = [];
    this.paramDataMultipart.errorCount = 0;
    this.tableDataMultipart = [];
    this.fileNameMultipart = "";
    this.dialogMultiPart.title = "Add Transfer Indent Part";
    this.dialogMultiPart.OpenDialog();
  }

  public DownloadTemplate(template: number) {
    let link = "";
    if (template == 1) {
      link = "assets/templates/Transfer_Multipart_Template.xlsx";
    }
    window.open(link, "_blank");
  }

  public OpenFileBrowserMultipart() {
    this.fileNameMultipart = "";
    this.fileInputMultipart.nativeElement.value = "";
    this.fileInputMultipart.nativeElement.click();
  }

  public SelectFileMultipart(evt) {
    let Files: Array<File> = evt.target.files;

    if (Files.length > 0) {
      //let File: File = Files[0];
      this.File = Files[0];
      this.fileNameMultipart = this.File.name;
    }
  }

  public PreView() {
    if (!this.fileNameMultipart) {
      this.modal.warning("Please Open File First...", this.viewref);
      return;
    }

    let formData = new FormData();
    formData.append("file", this.File);
    this.tableDataMultipart = [];
    this.http.postFile("TI", "SNM172P_UploadMultiParts", formData).subscribe(
      (res) => {
        //this.modal.info("Upload complete", this.viewref);
        this.tableDataMultipart = res.set.Table;
        let countrow = 0;
        this.tableDataMultipart.map((x,i) => {
          if(x.ERR_FLAG == 'Y'){
              countrow += 1;
              this.paramDataMultipart.errorList.push({
                  record : x.SEQ,
                  message : x.ERR_MSG
              })
          } 
          this.paramDataMultipart.errorCount = countrow;
        })
      },
      (err) => {
        console.log('err', err)
        this.modal.error("Upload not complete.", this.viewref);
      }
    );
  }

  public SaveMultipart() {
    if (this.tableDataMultipart.some((x) => x.MSG)) {
      this.modal.warning(
        "This data have error, Please recheck data",
        this.viewref
      );
      return;
    }

    this.modal.confirm("Do you want to save", this.viewref, () =>
      confirmSave()
    );

    let confirmSave = () => {
      this.http
        .post("TI", "SNM172P_SaveMultipart", this.tableDataMultipart)
        .subscribe(
          (res) => {
            if (res.STATUS_MSG == "DONE") {
              this.modal.info(
                "Transaction complete: applied and saved.",
                this.viewref
              );
              this.Search();
              this.dialogMultiPart.Close();
            } else {
              this.modal.error("No change to save. fail.", this.viewref);
            }
          },
          (err) => {
            console.log('err', err)
            this.modal.error("No change to save. fail.", this.viewref);
          }
        );
    };
  }
}
