import { Component, OnInit, ViewContainerRef, ElementRef, ViewChild } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from 'src/app/core/global';

@Component({
    selector: 'SNSE143_F2',
    templateUrl: 'SNSE143_F2.component.html',
    styleUrls: ['SNSE143_F2.component.css']
})

export class SNSE143F2Component implements OnInit {
    constructor(
        private http: HttpService,
        private modal: ModalService,
        private viewref: ViewContainerRef,
        private el: ElementRef,
        private global: Globals
    ) { }

    public FileName: string = "";
    public FileNameReturn: string;
    public DataUploadList: Array<any> = [];
    public FileList: Array<any> = [];
    @ViewChild("fileInput") fileInput: ElementRef;

    ngOnInit() { }

    openFileBrowser() {
        this.FileName = "";
        this.fileInput.nativeElement.value = '';
        this.fileInput.nativeElement.click();
    }

    getFileList() {
        this.http.get("TI", "SNSE143_F2_GetFileList")
            .subscribe(result => {
                this.FileList = result.Table;
            }, err => {
                console.error(err);
            })
    }

    getData(FileName) {
        this.http.get("TI", "SNSE143_F2_GetDetailByFileName", FileName)
            .subscribe(result => {
                this.DataUploadList = result.Table;
            }, err => {
                console.error(err);
            })
    }

    TransferData() {
        this.http.post("TI", ["SNSE143_F2_TransferData", this.FileNameReturn], {})
            .subscribe(result => {
                this.modal.info("Transfer data completed.", this.viewref);
                this.DataUploadList = [];
                this.FileNameReturn = null;
                this.FileName = null;
                this.fileInput.nativeElement.value = '';
            }, err => {
                this.modal.error("Unable to Transfer data.", this.viewref);
                console.error(err);
            })
    }

    selectFile(evt) {
        let Files: Array<File> = evt.target.files;

        if (Files.length > 0) {
            let File: File = Files[0];
            this.FileName = File.name;

            let formData = new FormData();
            formData.append('file', File);

            this.http.postFile("TI", "SNSE143_F2_UploadFile", formData)
                .subscribe(result => {
                      if(result == "DUPLICATE"){
                        this.modal.warning("This file is duplicate please rename before upload",this.viewref)
                      }else{
                        this.FileNameReturn = result;
                        this.getData(this.FileNameReturn);
                        this.modal.info("Upload " + this.FileName + " completed.", this.viewref);   
                      }
                 
                }, err => {
                    console.error(err);
                    this.modal.error("Found eror, please contact support team.", this.viewref);
                })

        }
    }

    GetPassRecord() {
        let passRec = this.DataUploadList.filter(v => v.PRC_STATUS == 'OK').length;

        return passRec;
    }
    GetFailRecord() {
        let failRec = this.DataUploadList.filter(v => v.PRC_STATUS == 'NG').length;

        return failRec;
    }
}