import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewContainerRef, ElementRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Globals } from 'src/app/core/global';
import { SelectionModel } from '@angular/cdk/collections';
import { ModalService } from 'src/app/core/modal.service';


@Component({
  selector: 'snse144',
  templateUrl: './snse144.component.html',
  styleUrls: ['./snse144.component.css']
})



export class SNSE144Component implements OnInit {


  constructor(
    private http: HttpService,
    private global: Globals,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  public ConfigMainModel: any = {
    ColName: "LOOKUP",
    ColValue: "",
    PlaceholderText: "Select Main Model",
    SourceController: "TI",
    SourceMethodName: "SNSE_144_MAIN_MODEL",
    NoOfShowRecords: 30,
    MinLengthSearch: 1,
    UpperCase: false
  }

  public ConfigPart: any = {
    ColName: "LOOKUP",
    ColValue: "",
    TextSelect: "Select Part No.",
    SourceController: "TI",
    SourceMethodName: "SNSE144_PART_NO",
    NoOfShowRecords: 30,
    MinLengthSearch: 3,
    UpperCase: false,
    SourceParams: {
      MAIN_MODEL: null
    },
  }

  public ConfigVendor: any = {
    ColName: "LOOKUP",
    ColValue: "",
    TextSelect: "Select Vendor Code.",
    SourceController: "TI",
    SourceMethodName: "SNSE144_VENDOR_CODE",
    NoOfShowRecords: 30,
    MinLengthSearch: 0,
    UpperCase: false,
    SourceParams: {
      UPDATE_STATUS: null
    },
  }

  public ConfigSourcing: any = {
    ColName: "LOOKUP",
    ColValue: "",
    PlaceholderText: "Select Sourcing Code",
    SourceController: "TI",
    SourceMethodName: "SNSE144_SOURCING_CODE",
    NoOfShowRecords: 30,
    MinLengthSearch: 0,
    UpperCase: false
  }

  public ConfigVendorLocal: any = {
    ColName: "LOOKUP",
    ColValue: "",
    TextSelect: "Select Vendor Code.",
    SourceController: "TI",
    SourceMethodName: "SNSE144_VENDOR_CODE_LOCAL",
    NoOfShowRecords: 30,
    MinLengthSearch: 0,
    UpperCase: false,
    SourceParams: {
      SUPPLIER_CODE: null
    },
  }

  public ConfigGSC: any = {
    ColName: "VENDOR_GLOBAL_CODE",
    ColValue: "",
    TextSelect: "Select GSC",
    SourceController: "TI",
    SourceMethodName: "SNSE144_GSC",
    NoOfShowRecords: 30,
    MinLengthSearch: 0,
    UpperCase: false,

  }


  public ConfigFilename: any = {
    ColName: "FILE_NAME",
    ColValue: "",
    TextSelect: "Select File Name",
    SourceController: "TI",
    SourceMethodName: "SNSE144_GET_FILE_NAME",
    NoOfShowRecords: 30,
    MinLengthSearch: 2,
    UpperCase: false,
    SourceParams: {
      FROM_TABLE: null
    },
  }
  


  public tableData: any = [];

  public paramSearch: any = {};
  public selection = new SelectionModel<any>(true, []);

  public activeButtonUpdateData: boolean = false;
  public activeButtonTranfer: boolean = false;
  public LabelButtonTranfer: string = "Register New Part";
  public activeButtonUpdateCancel: boolean = false;
  public activeCheckbox: boolean = false;
  public SourcingList: any = [];
  public Msg_error: string = null;
  public iSnewPart: boolean = false;
  public LogData: any = [];
  public iSsearch: boolean = false;
  public FileList: Array<any> = [];
  public FileName: string = "";
  @ViewChild("fileInput") fileInput: ElementRef;
  @ViewChild("dialog", { static: false }) dialog: any;
  @ViewChild("dialogmaster", { static: false }) dialogmaster: any;

  ngOnInit() {

    this.paramSearch.COMPLETE_STATUS = 'ALL'
    this.paramSearch.UPDATE_STATUS = 'N'
    this.paramSearch.FROM_TABLE = 'ALL'

    this.paramSearch.SOURCING_TYPE = 'S'
    this.ConfigVendor.SourceParams.UPDATE_STATUS = this.paramSearch.UPDATE_STATUS
    this.ConfigFilename.SourceParams.FROM_TABLE = this.paramSearch.FROM_TABLE 
    let reader = new FileReader();
  }

  openFileBrowser() {
    this.FileName = "";
    this.fileInput.nativeElement.value = '';
    this.fileInput.nativeElement.click();
  }

  SelectFile(evt) {

    let Files: Array<File> = evt.target.files;

    if (Files.length > 0) {
      let File: File = Files[0];
      this.FileName = File.name;

      let formData = new FormData();
      formData.append('file', File);

      this.http.postFile("TI", "SNSE144_UploadExcel", formData)
        .subscribe(result => {
          this.modal.info("Upload complete", this.viewref);
          console.log('ressss', result)
          this.tableData = result
          this.tableData = this.tableData.slice();
        }, err => {
          this.modal.error("Upload not complete", this.viewref);
        })

    }
  }

  Search() {
    this.Msg_error = null
    this.SourcingList = []
    this.tableData = []
    this.iSsearch = true;
    this.iSnewPart = false;

    this.http.post("TI", "SNSE144_getSearch", this.paramSearch)
      .subscribe(res => {
        //console.log('resssssss',res)
        this.tableData = res.Table
        this.SourcingList = res.Table1
        this.CheckActiveButton();
        this.GetLog();
      })
  }

  UpdateData() {

    if (this.selection.selected.length == 0) {
      this.modal.warning("Please select data for updata", this.viewref);
      return;
    }

    this.modal.confirm("Do you want to update data?", this.viewref, () => ConfirmUpdate())


    let ConfirmUpdate = () => {
      this.paramSearch.List = this.selection.selected
      this.http.post("TI", "SNSE144_UpdateData", this.paramSearch)
        .subscribe(res => {
          this.iSnewPart = false;
          this.iSsearch = false;
          this.selection.clear();
          this.Search()
          this.modal.info("Process complete", this.viewref)
        }, err => {
          this.modal.error("Found eror, please contact support team.", this.viewref);
        })
    }
  }

  RegisterNewPart() {

    if (this.selection.selected.length == 0) {
      this.modal.warning("Please select data for Register", this.viewref)
      return;
    }


    this.modal.confirm("Do you want to save change you have made?", this.viewref, () => ConfirmRegister())


    let ConfirmRegister = () => {
      this.http.post("TI", "SNSE144_Register", this.selection.selected)
        .subscribe(res => {
          this.modal.info("Process complete", this.viewref)
          this.iSnewPart = true;
          this.selection.clear();
          this.iSsearch = false;
          this.Search();

        }, err => {
          this.modal.error("Found eror, please contact support team.", this.viewref);
        })
    }
  }


  CancelUpdate() {
    if (this.selection.selected.length == 0) {
      this.modal.warning("Please select data for Cancel", this.viewref)
      return;
    }

    this.modal.confirm("DO you want to save change you have made?", this.viewref, () => ConfirmCancel())


    let ConfirmCancel = () => {
      this.http.post("TI", "SNSE144_CancelUpdate", this.selection.selected)
        .subscribe(res => {
          this.modal.info("Process complete", this.viewref)
          this.iSnewPart = true;
          this.iSsearch = false;
          this.Search();

        }, err => {
          this.modal.error("Found eror, please contact support team.", this.viewref);
        })
    }
  }

  GetLog() {
    this.LogData = []


    if (this.iSsearch) {
      this.LogData.push({
        ERROR_DESCRIPTION: "Loading TPM_PFPM_PO..."
      },
        {
          ERROR_DESCRIPTION: this.tableData.length + " record loaded..."
        })

      return;
    }


    this.http.get("TI", "SNSE144_GetLog")
      .subscribe(res => {
        this.LogData = res.Table;

        if (this.iSnewPart) {
          this.LogData.push({
            ERROR_DESCRIPTION: this.tableData.length + " record loaded..."
          })
        }

      })
  }

  OpenLog() {
    this.dialog.OpenDialog();
  }

  UpdateStatusChange() {
    this.ConfigVendor.SourceParams.UPDATE_STATUS = this.paramSearch.UPDATE_STATUS
  }

  CheckDiableVendor(data) {
    let isdisable = true;

    if (!data.SUPPLIER_CODE && data.UPDATE_STATUS == 'N') {
      let find = this.SourcingList.find(x => x.SOURCING_CODE == data.SOURCING_CODE)
      if (find) isdisable = false
    }

    return isdisable;

  }

  FromTableChange(event){   
    this.ConfigFilename.SourceParams.FROM_TABLE = event
  }


  CheckActiveButton() {
    this.activeCheckbox = false;
    this.activeButtonTranfer = false;
    this.activeButtonUpdateCancel = false;
    this.activeButtonUpdateData = false;
    this.LabelButtonTranfer = "Register New Part";

    if (this.paramSearch.COMPLETE_STATUS == 'Y') {
      if (this.paramSearch.UPDATE_STATUS == 'N') {
        this.activeCheckbox = true;
        this.activeButtonTranfer = true;
        this.LabelButtonTranfer = "Register New Part";
        this.activeButtonUpdateCancel = false;
        this.activeButtonUpdateData = true;
      }
      else if (this.paramSearch.UPDATE_STATUS == 'P') {
        this.activeCheckbox = true;
        this.activeButtonTranfer = true;
        this.LabelButtonTranfer = "Update Part Master";
        this.activeButtonUpdateCancel = true;
      }
    }
    else if (this.paramSearch.COMPLETE_STATUS == 'N') {
      if (this.paramSearch.UPDATE_STATUS == 'N') {
        this.activeButtonUpdateData = true;
        this.activeCheckbox = true;
      }
      else if (this.paramSearch.UPDATE_STATUS == 'P') {
        this.activeCheckbox = true;
        this.activeButtonUpdateData = true;
        this.activeButtonUpdateCancel = true;
      }
    }
  }


  GenerateReport() {
    let filename = "";
    switch(this.paramSearch.UPDATE_STATUS)
    {
      case 'ALL' :
        filename = "SNSE144_ALL_Status.xlsx"
        break;
      case 'N'  :
        filename = "SNSE144_Not Register.xlsx"
        break;
      case 'D'  :
        filename = "SNSE144_Duplicate.xlsx"
        break;
      case 'P'  :
        filename = "SNSE144_Dup-Dif.xlsx"
        break;
      case 'U'  :
        filename = "SNSE144_Dup-Dif Updated.xlsx"
        break;
      case 'C'  :
        filename = "SNSE144_Dup-Dif Cancelled.xlsx"
        break;
      default   :
        filename = "SNSE144_ALL_Status.xlsx"
    }

    let reportParams = {
      P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      P_MAIN_MODEL: this.paramSearch.MAIN_MODEL ? this.paramSearch.MAIN_MODEL : 'ALL',
      P_PART_NUMBER: this.paramSearch.PART_NUMBER ? this.paramSearch.PART_NUMBER : 'ALL',
      P_COMPLETE_STATUS: this.paramSearch.COMPLETE_STATUS ? this.paramSearch.COMPLETE_STATUS : 'ALL',
      P_VENDOR_CODE: this.paramSearch.VENDOR_CODE ? this.paramSearch.VENDOR_CODE : 'ALL',
      P_FROM_TABLE: this.paramSearch.FROM_TABLE ? this.paramSearch.FROM_TABLE : 'ALL',
      P_UPDATE_STATUS: this.paramSearch.UPDATE_STATUS ? this.paramSearch.UPDATE_STATUS : 'ALL',
      P_SOURCING_CODE: this.paramSearch.SOURCING_CODE ? this.paramSearch.SOURCING_CODE : 'ALL',
      P_SOURCING_TYPE: this.paramSearch.SOURCING_TYPE ? this.paramSearch.SOURCING_TYPE : 'ALL',
      P_USER: this.global.GetTokenDetail("ssUserName"),
      P_FORM: "SNSE144",
      P_FILE_NAME: this.paramSearch.FILE_NAME ? this.paramSearch.FILE_NAME : 'ALL'
    }

    this.http.getParams("TI", ["SNSE144_GenerateReport", "PMS_RPT_TI_SNSE144",filename], reportParams)
      .subscribe(result => {
        this.DownloadExcel(filename)
      })
  }

  DownloadExcel(filenames) {
    this.http.Download('TI', 'SNSE144_DownloadExcel', { filename: filenames })
      .subscribe(res => {
        if (res) {
          this.WriteContentsExcel(res,filenames)
        }
      })
  }

  WriteContentsExcel(content,filenames) {
    const a = document.createElement('a');
    const file = new Blob([content], { type: content.type });
    a.href = URL.createObjectURL(file);
    a.download = filenames;
    a.click();
  }


  Download() {
    this.http.Download('TI', 'SNSE144_Download', this.tableData)
      .subscribe(res => {
        if (res) {
          this.writeContents(res)
        }
      })
  }

  writeContents(content) {
    const a = document.createElement('a');
    const file = new Blob([content], { type: content.type });
    a.href = URL.createObjectURL(file);
    a.download = "SNSE144" + '_' + this.global.CurrentDate() + '' + ".csv";
    a.click();
  }


  RowClick(event) {
    this.Msg_error = event.MSG_ERROR
  }

  isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.tableData.length;
    return numSelected === numRows;
  }

  Toggle() {

    this.isAllSelected() ?
      this.selection.clear() :
      this.tableData.forEach(row => this.selection.select(row));

  }


  Openmaster() {
    this.dialogmaster.OpenDialog();
  }

  SetSourceVendor(data) {
    console.log('dddddd', data)
    this.ConfigVendorLocal.SourceParams.SUPPLIER_CODE = data.SUPPLIER_CODE
  }

}

