import { Component, OnInit, ViewChild, ViewContainerRef, ElementRef, ViewChildren  } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Globals } from 'src/app/core/global';
import { ModalService } from 'src/app/core/modal.service';
import { DomSanitizer } from '@angular/platform-browser';
import { SelectionModel } from '@angular/cdk/collections';
import * as moment from 'moment';
import { MatDatepickerInputEvent } from '@angular/material/datepicker';

@Component({
  selector: 'snjf003_W',
  templateUrl: './SNJF003_W.component.html',
  styleUrls: ['./SNJF003_W.component.css'],
})



export class SNJF003_WComponent implements OnInit {

  constructor(
    private Http: HttpService,
    private global: Globals,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    public domsanitizer: DomSanitizer
  ) { }

  @ViewChild('myDiv', { read: ElementRef }) myDiv: ElementRef;
  @ViewChildren("input") Inputs: any;

  @ViewChild("dialogPrint", { static: false }) dialogPrint: any;

  public fileUrlPDF;
  public tableData: any = [];
  public tableDataDetail: any = [];
  public headerUrl: string;
  public data: string[] = [];
  public detailUrl: string;
  public btnDRG: HTMLElement;
  public dataDetail: any = {};
  public params: any = {};
  public showPage: any;
  public DataIsSelected: any = [];
  public headerIsEdit: boolean = false;

  public selection = new SelectionModel<any>(true, []);
  public currentDate: moment.Moment = moment();

  ngOnInit() {
    this.params.ATTACH_SHEET = 'N';
    this.params.TOTAL_REC = 0;
    this.showPage = 0;
  }

  ngAfterViewInit() {
    this.btnDRG = this.myDiv.nativeElement;
  }

  public tblFooter: any = [
    {
      fieldName: "CONTAINER_NO",
      value: "Total",
      show: true
    },
    {
      fieldName: "GROSS_MM",
      show: true
    },
    {
      fieldName: "GROSS_WEIGHT",
      show: true
    },
    {
      fieldName: "QTY",
      show: true
    },
    {
      fieldName: "AMOUNT",
      show: true
    }]

  public tblFooterDetail: any = [
    {
      fieldName: "SUB_ITEM_NO",
      value: "Total",
      show: true
    },
    {
      fieldName: "PACK_QTY",
      show: true
    }]

  public lookupCustomerCodeConfig: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "WH",
    SourceMethodName: "SNJF003_W_GetCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public lookupInvoiceNoConfig: any = {
    ColName: "LOOKUP_INVOICE_NO",
    PlaceholderText: "Select Invoice No",
    SourceController: "WH",
    SourceMethodName: "SNJF003_W_getInvoiceNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public SetSelectedCustomerCode(values: any) {
    this.params.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.params.CUSTOMER_NAME = values.CUSTOMER_NAME;

    this.params.BRANCH_CODE = values.BRANCH_CODE;
    this.params.BRANCH_NAME = values.BRANCH_NAME;

    this.params.COUNTRY_CODE = values.COUNTRY;
    this.params.CURRENCY_CODE = values.CURRENCY_CODE;
    this.params.PAYMENT_TERM = values.PAYMENT_TERM;
    this.params.PRICE_TERM_CODE = values.PRICE_TERM_CODE;
    this.params.EXCHANGE_RATE = values.EXCHANGE_RATE;

  }

  public SetSelectedInvoiceNo(values: any) {
    this.params.INVOICE_NO = values.INVOICE_NO;
    this.params.INVOICE_DATE = values.INVOICE_DATE;
    this.params.DOCUMENT_TYPE = values.DOCUMENT_TYPE;

    this.params.SENT_BY = values.SENT_BY;

    this.params.BL_AWB_DATE = values.BL_AWB_DATE;
    this.params.BL_AWB_NO = values.BL_AWB_NO;
    this.params.VESSEL_FLIGHT_N = values.VESSEL_FLIGHT_N;
    this.params.FWD_CHARGE_C = values.FWD_CHARGE_C;
    this.params.FREIGH_CHARGE_C = values.FREIGH_CHARGE_C;
    this.params.INSURANCE_C = values.INSURANCE_C;

    this.params.OLD_BL_AWB_DATE = values.BL_AWB_DATE;
    this.params.OLD_BL_AWB_NO = values.BL_AWB_NO;
    this.params.OLD_VESSEL_FLIGHT_N = values.VESSEL_FLIGHT_N;
    this.params.OLD_FWD_CHARGE_C = values.FWD_CHARGE_C;
    this.params.OLD_FREIGH_CHARGE_C = values.FREIGH_CHARGE_C;
    this.params.OLD_INSURANCE_C = values.INSURANCE_C;
    this.headerIsEdit = false;
    this.SetSelectedCustomerCode(values);
    if(values?.INVOICE_NO){
      this.GetPreInvoice();
      this.Search();
    }
    else{
      this.params.PINVOICE_NO = "";
      this.params.PINVOICE_DATE = "";
      this.params.TOTAL_REC = "";
      this.tableData = [];
    }
  }

  public rowClick(row: any) {
    this.dataDetail = {}
    this.dataDetail = row
    this.Http.post('WH', 'SNJF003_W_getDataDetail', this.dataDetail)
      .subscribe(res => {
        this.tableDataDetail = res.Table;
      }, err => {
        console.log(err, 'err');
        this.modal.warning("Found an error, please contact support team", this.viewref);
      })
    this.showPage = 1;
  }

  public clickBack() {
    this.showPage = 0;
  }

  public ConfirmUTDDetail() {
    this.modal.confirm('Do you want to update on this data?', this.viewref, this.UpdateInvoice)
  }

  private UpdateInvoice = () => {
    var chk = 0;

    if (this.DataIsSelected.length == 0) {
      this.modal.warning("Please select data..", this.viewref);
      return;
    }
    else if (!this.params.VESSEL_FLIGHT_N) {
      this.modal.warning("Flight No. is not input..", this.viewref);
      return;
    }
    else if (!this.params.BL_AWB_NO) {
      this.modal.warning("AWB No. is not input..", this.viewref);
      return;
    }
    else if (!this.params.BL_AWB_DATE) {
      this.modal.warning("AWB Date. is not input..", this.viewref);
      return;
    }
    else if (this.params.EXCHANGE_RATE == 0) {
      this.modal.warning("Exchange Rate Invalid.", this.viewref);
      return;
    }
    else {
      this.DataIsSelected.forEach((e) => {
        if (!e.CONTAINER_NO) {
          chk = + 1;
        }
      });
    }

    if (chk == 0) {
      this.Http.post('WH', 'SNJF003_W_UpdateInvoiceDetail', this.DataIsSelected)
        .subscribe(res => {
          if (res.Table[0].STATUS == 'DONE') {
            this.Search();
            this.selection.clear();
            this.DataIsSelected = []

            this.modal.info(
              "Update Invoice Successful."
            , this.viewref
            , () => {
              if (this.params.ATTACH_SHEET == 'Y') {
                this.OpenReport();
              }
            });


          }
        }, err => {
          console.log(err, 'err');
          this.modal.warning("Found an error, please contact support team", this.viewref);
        });
    } else {
      this.modal.warning("Container No. Invalid.", this.viewref);
    }
  }

  public ConfirmUTDHeader() {
    this.modal.confirm('Do you want to update on this data?', this.viewref, this.UpdateHeader)
  }

  private UpdateHeader = () => {
    if (!this.params.INVOICE_NO) {
      this.modal.warning("Invoice is not input..", this.viewref);
      return;
    }
    else if (!this.params.VESSEL_FLIGHT_N) {
      this.modal.warning("Flight No. is not input..", this.viewref);
      return;
    }
    else if (!this.params.BL_AWB_NO) {
      this.modal.warning("AWB No. is not input..", this.viewref);
      return;
    }
    else if (!this.params.BL_AWB_DATE) {
      this.modal.warning("AWB Date. is not input..", this.viewref);
      return;
    }
    else {
      this.Http.post('WH', 'SNJF003_W_UpdateInvoiceHeader', this.params)
        .subscribe(res => {
          if (res.Table[0].STATUS == 'DONE') {
            this.modal.info("Update Invoice Header Successful.", this.viewref);
            this.params.OLD_BL_AWB_DATE = this.params.BL_AWB_DATE;
            this.params.OLD_BL_AWB_NO = this.params.BL_AWB_NO;
            this.params.OLD_VESSEL_FLIGHT_N = this.params.VESSEL_FLIGHT_N;
            this.params.OLD_FWD_CHARGE_C = this.params.FWD_CHARGE_C;
            this.params.OLD_FREIGH_CHARGE_C = this.params.FREIGH_CHARGE_C;
            this.params.OLD_INSURANCE_C = this.params.INSURANCE_C;
            this.headerIsEdit = false;
            this.Search()
          }
        }, err => {
          console.log(err, 'err');
          this.modal.warning("Found an error, please contact support team", this.viewref);
        });
    }
  }

  public GetPreInvoice() {
    this.Http.post('WH', 'SNJF003_W_getPreInvoice', this.params)
      .subscribe(res => {
        this.params.PINVOICE_NO = res.Table[0].PINVOICE_NO;
        this.params.PINVOICE_DATE = res.Table[0].PINVOICE_DATE;
      }, err => {
        console.log(err, 'err');
        this.modal.warning("Found an error, please contact support team", this.viewref);
      })
  }

  public Search() {
    this.tableData = [];
    this.Http.post('WH', 'SNJF003_W_getData', this.params)
      .subscribe(res => {
        this.tableData = res.Table;
        if (this.tableData.length > 0) {
          this.params.TOTAL_REC = this.tableData.length
        }
      }, err => {
        console.log(err, 'err');
        this.modal.warning("Found an error, please contact support team", this.viewref);
      })
  }

  public CheckboxChange(event, data) {
    if (event.checked) {
      this.DataIsSelected.push(data);
    }
    else {
      this.DataIsSelected.splice(this.DataIsSelected.indexOf(data), 1);
    }
  }

  public isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.tableData.length;
    return numSelected === numRows;
  }

  public Toggle() {
    if (this.isAllSelected()) {
      this.selection.clear()
      this.tableData.map(x => {
        this.DataIsSelected = [];
      })
    } else {
      this.tableData.forEach(row => this.selection.select(row));
      this.DataIsSelected = [];
      this.tableData.map(x => {
        this.DataIsSelected.push(x);
      })
    }
  }

  private OpenReport() {
    // this.global.GoToReport("PMS_RPT_SALES_SNSE033R_N", {
    //   P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
    //   P_DOC_TYPE: this.params.DOCUMENT_TYPE,
    //   P_DOC_NO: this.params.INVOICE_NO
    // })
    this.dialogPrint.OpenDialog();
    this.fileUrlPDF = null;
    this.Http
      .Download("WH", "SNJF003_W_PDF_INVOICE", {
        ReportPrefix: "PMS_RPT_SALES_SNJF003_W",
        ReportSuffix: ".PDF",
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_DOC_TYPE: this.params.DOCUMENT_TYPE,
        P_DOC_NO: this.params.INVOICE_NO
      })
      .subscribe((res) => {
        if (res) {
          this.SetIFrameContent(res);
        }
      }, (err) => {
        console.log(err, 'err');
        this.modal.warning("Found an error, please contract support team", this.viewref);
      });
  }

  private SetIFrameContent(content: any) {
    const file = new Blob([content], { type: content.type });
    const fileUrlPDF = URL.createObjectURL(file);
    this.fileUrlPDF = fileUrlPDF;
  }

  public CheckPrintChange(value) {
    if (value.checked == true) {
      this.params.ATTACH_SHEET = 'Y'
    }
    else {
      this.params.ATTACH_SHEET = 'N'
    }
  }

  public CheckEditHeader() {

    if (this.params.BL_AWB_NO != this.params.OLD_BL_AWB_NO ||
      this.params.VESSEL_FLIGHT_N != this.params.OLD_VESSEL_FLIGHT_N ||
      this.params.FWD_CHARGE_C != this.params.OLD_FWD_CHARGE_C ||
      this.params.FREIGH_CHARGE_C != this.params.OLD_FREIGH_CHARGE_C ||
      this.params.INSURANCE_C != this.params.OLD_INSURANCE_C) {
      this.headerIsEdit = true;
    } else {
      this.headerIsEdit = false;
    }
  }

  public CheckEditHeaderDate(data: MatDatepickerInputEvent<Date>) {

    this.params.BL_AWB_DATE = data.value;

    if (this.params.BL_AWB_DATE != this.params.OLD_BL_AWB_DATE) {
      this.headerIsEdit = true;
    } else {
      this.headerIsEdit = false;
    }
  }

  public GenDragon() {
    var chk_data: boolean = false;
    if (!this.params.INVOICE_NO) {
      this.modal.error('Invoice is not input..', this.viewref)
      chk_data = false;
    }
    else if (!this.params.VESSEL_FLIGHT_N) {
      this.modal.error('Flight No. is not input..', this.viewref)
      chk_data = false;
    }
    else if (!this.params.BL_AWB_NO) {
      this.modal.error('AWB No. is not input..', this.viewref)
      chk_data = false;
    }
    else if (!this.params.BL_AWB_DATE) {
      this.modal.error('AWB Date.is not input..', this.viewref)
      chk_data = false;
    }
    else {
      chk_data = true;
    }
    if (chk_data) {
      this.detailUrl = null;
      this.Http.post('WH', 'SNJF003_W_Dragon_Generate', this.params)
        .subscribe(async res => {
          if (res) {
            this.params.FILE_NAME = res.Detail.filename;
            this.detailUrl = "data:text/plain;charset=utf-8;base64," + res.Detail.file;
            function delay(ms: number) {
              return new Promise(resolve => setTimeout(resolve, ms));
            }
            await delay(2000);
            this.btnDRG.click();
          } else {
            this.modal.error('Download not complete', this.viewref)
          }
        }, async err => {
          console.log(err, 'err');
          this.modal.warning("Found an error, please contact support team", this.viewref);
        });
    }
  }
  public focusInput(rowIdx: number) {
    let inputEls = this.Inputs.toArray();
    inputEls[rowIdx].nativeElement.focus();
  }
  public shiftFocusDown(rowIdx: number) {
    rowIdx = Math.min(rowIdx + 1, this.tableData.length - 1);
    this.focusInput(rowIdx);
  }
  public shiftFocusUp(rowIdx: number) {
    rowIdx = Math.max(0, rowIdx - 1);
    this.focusInput(rowIdx);
  }
}
