import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { ModalService } from '../../../core/modal.service';
import { FormControl, Validators } from '@angular/forms';
import { Globals } from 'src/app/core/global';

@Component({
  selector: 'SNM007P',
  templateUrl: './SNM007P.component.html',
  styleUrls: ['./SNM007P.component.css']
})



export class SNM007PComponent implements OnInit {


  constructor(
    private http: HttpService,
    private router: Router,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private global: Globals

  ) { }
  @ViewChild("dialog", { static: false }) dialog: any;
  @ViewChild("dialog2", { static: false }) dialog2: any;
  public data: any = [];
  public opened: boolean;

  public Param: any = {}

  public ConfigTransport: any = {
    ColName: "LOOK_UP",
    ColValue: "",
    PlaceholderText: "Select Transport",
    SourceController: "WH",
    SourceMethodName: "SNM007P_GetTransport",
    NoOfShowRecords: 30,
    MinLengthSearch: 1,
    UpperCase: false
  }

  public paramsAdd: any = {
    TRANSPORT_CODE: null,
    TRANS_NAME_EN: null,
    TRANS_NAME_TH: null,
    TRANS_ADDR1: null,
    TRANS_ADDR2: null,
    TRANS_ADDR3: null,
    TRANS_ADDR4: null,
    TRANS_CONTACT: null
  }

  public paramsEdit: any = {
    TRANSPORT_CODE: null,
    TRANS_NAME_EN: null,
    TRANS_NAME_TH: null,
    TRANS_ADDR1: null,
    TRANS_ADDR2: null,
    TRANS_ADDR3: null,
    TRANS_ADDR4: null,
    TRANS_CONTACT: null,
    UPDATE_BY_NAME: null,
    LAST_UPD_DATE: null
  }

  public valid: boolean = false;
  public CategoryList: any = [];
  public TransportCodeControl = new FormControl('', [Validators.required])

  ngOnInit() {

  }

  openDialog() {
    this.dialog.OpenDialog()
  }



  Search() {
    this.data = []
    this.http.post("WH", "SNM007P_GetTransportDetail", { TRANSPORT: this.Param.TRANSPORT_CODE })
      .subscribe(res => {
        this.data = res.Table;
      })

  }


  SaveAdd() {

    this.modal.confirm('Do you want to save changed you have made?', this.viewref, this.ConfirmSaveAdd)

  }

  ConfirmSaveAdd = () => {

    this.http.post('WH', 'SNM007P_Insert', this.paramsAdd)
      .subscribe(res => {

        console.log(res)
        if (res.Table[0].STATUS == 'Done') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          if (this.data.length > 0) {
            this.Search();
          }

          this.paramsAdd = this.global.ClearObject(this.paramsAdd);
          this.paramsAdd.TRANSPORT_CODE = null;
          this.dialog.Close();
        } else if (res.Table[0].STATUS == 'Duplicate') {
          this.modal.info('No change to save. Found duplicate record.', this.viewref);
        }
        else {
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      })
  }

  CancelAdd() {

    this.dialog.Close();
    //this.ClearData();

  }

  EditRow(data) {

    this.paramsEdit = data
    this.dialog2.OpenDialog();
  }

  SaveEdit() {

    this.modal.confirm('Do you want to save changed you have made?', this.viewref, this.ConfirmSaveEdit)

  }

  ConfirmSaveEdit = () => {

    this.http.post('WH', 'SNM007P_Update', this.paramsEdit)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'Done') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
          this.dialog2.Close();

        } else {
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      })
  }

  Delete(data) {

    this.modal.confirm('Do you want to delete record?', this.viewref, () => this.ConfirmDelete(data))
  }

  ConfirmDelete = (data) => {

    this.http.post('WH', 'SNM007P_Delete', data)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'Done') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
        } else {
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      })

  }


  CancelEdit() {
    this.dialog2.Close();
  }


  TransportCodeErrorMessage() {

    return this.TransportCodeControl.hasError('required') ? 'Field must be entered' : ''

  }




}

