import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { ModalService } from 'src/app/core/modal.service';

enum Response {
  No = 1,
  Yes,
}


@Component({
  selector: 'SNM033',
  templateUrl: './SNM033.component.html',
  styleUrls: ['./SNM033.component.css'],
})


export class SNM033Component implements OnInit {

  constructor(
    private http: HttpService,
    private router: Router,
    private global: Globals,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  @ViewChild("dialogEdit", { static: false }) dialogEdit;
  @ViewChild("dialogEditPart", { static: false }) dialogEditPart;

  public opened: boolean;
  public tableData: any = [];
  public tableData2: any = [];
  public tableData3: any = [];
  public tableName: string;
  public show: boolean = true;
  public categoryList: any = [];
  public params: any = {};
  public editData: any = {};
  public editDataPart: any = {};

  public ConfigLocation: any = {
    ColName: "LOCATION_NO",
    ColValue: "LOCATION_NO",
    PlaceholderText: "Select Location",
    SourceController: "wPMS",
    SourceMethodName: "GetLocation",
    NoOfShowRecords: 30,
    MinLengthSearch: 3,
    UpperCase: true
  }

  public ConfigRackCode: any = {
    ColName: "RACK_CODE",
    ColValue: "RACK_CODE",
    PlaceholderText: "Select Rack Code",
    SourceController: "wPMS",
    SourceMethodName: "GetRackCode",
    NoOfShowRecords: 30,
    MinLengthSearch: 1,
  }

  public ConfigRackGroupCode: any = {
    ColName: "RACK_GROUP_CODE",
    ColValue: "RACK_GROUP_CODE",
    PlaceholderText: "Select Rack Group Code",
    SourceController: "wPMS",
    SourceMethodName: "GetRackGroupCode",
    NoOfShowRecords: 30,
    MinLengthSearch: 0
  }

  public PartNoLookupConfig: any = {
    ColName: "LOOKUP_PART_NAME",
    PlaceholderText: "Select Part No.",
    SourceController: "wPMS",
    SourceMethodName: "GetPartNo",
    NoOfShowRecords: 30

  }

  public ConfigLockLocation: any = {
    ColName: "LOCK_LOCATION",
    ColValue: "LOCK_LOCATION",
    PlaceholderText: "Select Lock Location",
    SourceController: "WH",
    SourceMethodName: "GetLockLocation",
    NoOfShowRecords: 30,
    MinLengthSearch: 0
  }

  ngOnInit() {
    this.GetCat();
  }

  public GetCat() {
    this.http.get('WH', 'SNM026P_GetPartCategory')
      .subscribe(res => {
        this.categoryList = res.Table
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
  }

  public CheckChanged() {
    //alert(this.params.EMPTY_LOCATION);
    //if (this.params.EMPTY_LOCATION) {
    //  this.modal.warning("Check", this.viewref);
    //} else {
    //  this.modal.warning("Un-check", this.viewref);
    //}
  }

  public SetPartNo(value: any) {
    this.editData.PART_NO = value.PART_NO;
    this.editData.PART_NAME_EN = value.PART_NAME_EN;
    this.editData.PART_NAME_TH = value.PART_NAME_TH;
  }

  public Search() {
    this.tableData = [];

    if (this.params.EMPTY_LOCATION) {
      this.http.post("WH", "SNM033_GetEmptyLocation", this.params)
        .subscribe(res => {
          this.tableData = res.Table
        })
    }
    else {
      if (!this.params.LOCATION_NO && !this.params.PART_NO && !this.params.RACK_CODE && !this.params.RACK_GROUP_CODE) {
        this.modal.warning("Please fill the criteria", this.viewref);
        return;
      }
      else {

      }

      if (this.params.LOCATION_NO) {
        this.params.LOCATION_NO = this.params.LOCATION_NO.toUpperCase();
      }
      if (this.params.PART_NO) {
        this.params.PART_NO = this.params.PART_NO.toUpperCase();
      }

      this.http.post("WH", "SNM033_GetData", this.params)
        .subscribe(res => {
          this.tableData = res.Table
        }, (err) => {
          console.log(err, 'err');
          this.modal.warning("Found an error, please contact support team", this.viewref);
        });
    }
  }

  public Edit(data) {
    // this.editData = data;
    // this.editData = this.editData.slice;

    this.editData.LOCATION_NO = data.LOCATION_NO;
    this.editData.PART_NO = data.PART_NO;
    this.editData.PART_CATEGORY = data.PART_CATEGORY;
    this.editData.PART_NAME_TH = data.PART_NAME_TH
    this.editData.PART_NAME_EN = data.PART_NAME_EN

    this.editData.CAPACITY_QTY = data.CAPACITY_QTY;
    this.editData.SHELVE_QTY = data.SHELVE_QTY;
    this.editData.OH_QTY = data.OH_QTY;
    this.editData.INDENT_QTY = data.INDENT_QTY;
    this.editData.MAX_WEIGHT = data.MAX_WEIGHT;
    this.editData.FLOOR_NO = data.FLOOR_NO;

    this.editData.DIMENSION_MAX = data.DIMENSION_MAX;
    this.editData.DIMENSION_MID = data.DIMENSION_MID;
    this.editData.DIMENSION_MIN = data.DIMENSION_MIN;
    this.editData.RACK_CODE = data.RACK_CODE;
    this.editData.RACK_GROUP_CODE = data.RACK_GROUP_CODE;
    this.editData.SEQUENCE_NO = data.SEQUENCE_NO;
    this.editData.LOCK_LOCATION = data.LOCK_LOCATION;
    this.editData.LAST_UPD_BY_NAME = data.LAST_UPD_BY_NAME;
    this.editData.LAST_UPD_DATE = data.LAST_UPD_DATE;
    this.dialogEdit.colors = "#c3002f"
    this.dialogEdit.title = "Location No :" + ' ' + data.LOCATION_NO
    this.dialogEdit.OpenDialog();
  }

  public SaveEdit() {
    this.modal.confirm("Do you want to save changed you have made?", this.viewref, this.ConfirmSave)
  } 

  private ConfirmSave = () => {
   

    this.http.post('WH', 'SNM033_Save', this.editData)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'Done') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.dialogEdit.Close();
          this.Search();
        } else {
          this.modal.error('No change to save. Something went wrong.', this.viewref);
        }
      }, (err) => {
        console.log(err, 'err');
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
  }

  public CancelEdit() {
    this.dialogEdit.Close();
  }

  public ClickRow(event) {
    this.editData.PART_NO = event.PART_NO;
    this.editData.LOCATION_NO = event.LOCATION_NO;
  }

  public SelectedTab(event) {
    if (this.editData.PART_NO && event.index == 1) {
      this.GetPartDetail();
    }
    if (this.editData.LOCATION_NO && event.index == 2) {
      this.GetControlSystem();
    }
  }

  private GetPartDetail() {
    //this.tableData3 = [];
    this.http.get("WH", "SNM033_GetPartDetail", this.editData.PART_NO)
      .subscribe(res => {
        this.tableData3 = res.Table
      }, (err) => {
        console.log(err, 'err');
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
  }

  private GetControlSystem() {
    this.http.get("WH", "SNM033_GetControlSystem", this.editData.LOCATION_NO)
      .subscribe(res => {
        this.tableData2 = res.Table
      }, (err) => {
        console.log(err, 'err');
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
  }




  public EditPart(data) {

    this.editDataPart.PART_NO = data.PART_NO
    this.editDataPart.PART_NAME_TH = data.PART_NAME_TH
    this.editDataPart.PART_NAME_EN = data.PART_NAME_EN
    this.editDataPart.LOCATION_NO = data.LOCATION_NO
    this.editDataPart.DIMENSION_MAX = data.DIMENSION_MAX
    this.editDataPart.DIMENSION_MID = data.DIMENSION_MID
    this.editDataPart.DIMENSION_MIN = data.DIMENSION_MIN
    this.editDataPart.LAST_UPD_BY_NAME = data.LAST_UPD_BY_NAME
    this.editDataPart.LAST_UPD_DATE = data.LAST_UPD_DATE

    //this.editDataPart = data;
    //this.editDataPart = this.editDataPart.slice;

    this.dialogEditPart.title = "Edit Part";
    this.dialogEditPart.OpenDialog();
  }


  public SaveEditPart() {
    this.modal.confirm("Do you want to save changed you have made?", this.viewref, this.ConfirmSavePart)
  }

  private ConfirmSavePart = () => {
    this.http.post("WH", "SNM033_SavePart", this.editDataPart)
      .subscribe(res => {
        if (res.Table[0].STATUS == "Done") {
          this.modal.info("Transaction complete: applied and saved.", this.viewref)
          this.GetPartDetail();
          this.dialogEditPart.Close();
        } else {
          this.modal.warning("No change to save. Something went wrong.", this.viewref)
        }
      }, (err) => {
        console.log(err, 'err');
        this.modal.warning("Found an error, please contact support team", this.viewref);
      });
  }

  public CancelEditPart() {
    this.dialogEditPart.Close();
  }


}
