import { Component, ElementRef, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { FormControl, Validators } from '@angular/forms';
import { ModalService } from 'src/app/core/modal.service';

@Component({
  selector: 'SNM170',
  templateUrl: './SNM170.component.html',
  styleUrls: ['./SNM170.component.css']
})



export class SNM170Component implements OnInit {


  constructor(
    private http: HttpService,
    private router: Router,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  public ConfigPart: any = {
    ColName: "LOOKUP",
    PlaceholderText: "Select Part No.",
    SourceController: "TI",
    SourceMethodName: "SNM132P_GetPArt",
    NoOfShowRecords: 30
  }

  @ViewChild("dialogEditScenario", { static: false }) dialogEditScenario: any;
  @ViewChild("dialogUploadScenario", { static: false }) dialogUploadScenario: any;
  public ParamSearch: any = {};
  public Params: any = {};
  public tabledata: any = [];
  public isAdd: boolean = false;
  public tableUploadScenario: any = [];
  public FileNameScenario: string = "";
  private File: any;
  @ViewChild("fileInputScenario") fileInputScenario: ElementRef;

  ngOnInit() {

  }

  public SearchScenario() {
    this.tabledata = []
    this.http.post("WH", "SNM170_GetData", this.ParamSearch)
      .subscribe(res => {
        this.tabledata = res.Table
      })

  }

  public TabChange(event) {
  }


  public DownloadTemplate(template: number) {

    let link = ''
    if (template == 1) {
      link = "assets/templates/PART_SCENARIO_TEMPLATE.xlsx"
    } else {
      link = "assets/templates/PART_PERCENT_TEMPLATE.xlsx"
    }

    window.open(link, '_blank')
  }

  public AddScenario() {
    this.Params = {}
    this.isAdd = true
    this.dialogEditScenario.title = "New Part Scenario"
    this.dialogEditScenario.OpenDialog();
  }

  public EditRowScenario(datarow) {

    this.isAdd = false;
    this.Params = datarow;
    this.dialogEditScenario.title = "Edit Part Scenario"
    this.dialogEditScenario.OpenDialog();

  }


  public DeleteScenario(data) {
    this.modal.confirm("Do you want to delete racord?", this.viewref, () => {
      this.http.post("WH", "SNM170_DeleteScenario", data)
        .subscribe(res => {

          if (res.STATUS_MSG == 'DONE') {
            this.modal.info('Transaction complete: 1 record applied and deleted.', this.viewref);
            this.SearchScenario();
            this.dialogEditScenario.Close();

          } else {
            this.modal.warning('Delete fail.', this.viewref);
          }
        })
    })
  }


  public SaveScenario() {

    this.modal.confirm("Do you want to save change you have made?", this.viewref, () => ConfirmSave())

    let ConfirmSave = () => {

      if (this.isAdd) {

        this.http.post("WH", "SNM170_InsertScenario", this.Params)
          .subscribe(res => {

            if (res.STATUS_MSG == 'DONE') {
              this.modal.info('Transaction complete: applied and saved.', this.viewref);
              if (this.tabledata.length > 0) {
                this.SearchScenario();
              }
              this.dialogEditScenario.Close();
            } else if (res.STATUS_MSG == 'DUPLICATE') {
              this.modal.info('No change to save. Found duplicate record.', this.viewref);
            }
            else {
              this.modal.warning('No change to save. Add fail.', this.viewref);
            }
          }, (err) => {
            this.modal.warning('No change to save. Add fail.', this.viewref);
          })
      } else {


        this.http.post("WH", "SNM170_UpdateScenario", this.Params)
          .subscribe(res => {
            if (res.STATUS_MSG == 'DONE') {
              this.modal.info('Transaction complete: applied and saved.', this.viewref);
              this.SearchScenario();
              this.dialogEditScenario.Close();
            } else {
              this.modal.error('No change to save. Update fail.', this.viewref);
            }
          }, err => {
            this.modal.error('No change to save. Update fail.', this.viewref);
          })
      }

    }
  }

  public CancelScenario() {
    this.dialogEditScenario.Close();
  }

  public UploadScenario() {
    this.tableUploadScenario = []
    this.FileNameScenario = "";
    this.dialogUploadScenario.title = "Upload Part Scenario"
    this.dialogUploadScenario.OpenDialog()
  }

  public SaveUploadScenario() {

    this.modal.confirm("Do you want to save", this.viewref, () => confirmSave())

    let confirmSave = () => {
      const data = this.tableUploadScenario.filter(x => !x.MSG)
      this.http.post("WH", "SNM170_SaveUploadScenario", data)
        .subscribe(res => {
          if (res.STATUS_MSG == 'DONE') {
            this.modal.info('Transaction complete: applied and saved.', this.viewref);
            this.SearchScenario();
            this.dialogUploadScenario.Close();

          } else {
            this.modal.error('No change to save. fail.', this.viewref);
          }
        }, err => {
          this.modal.error('No change to save. fail.', this.viewref);
        })
    }
  }


  public OpenFileBrowserScenario() {
    this.FileNameScenario = "";
    this.fileInputScenario.nativeElement.value = '';
    this.fileInputScenario.nativeElement.click();
  }

  public SelectFileScenario(evt) {
    let Files: Array<File> = evt.target.files;

    if (Files.length > 0) {
      //let File: File = Files[0];
      this.File = Files[0];
      this.FileNameScenario = this.File.name;
    }
  }

  public PreViewScenario() {

    if (!this.FileNameScenario) {
      this.modal.warning("Please Open File First...", this.viewref)
      return;
    }

    let formData = new FormData();
    formData.append('file', this.File);
    this.tableUploadScenario = []
    this.http.postFile("WH", "SNM170_UploadScenario", formData)
      .subscribe(result => {
        this.tableUploadScenario = result.filter(x => x.PART_NO)
        //this.tableUploadScenario.map(x => x.SCENARIO = x["SCENARIO(1 or 2)"])
      }, err => {
        this.modal.error("Upload not complete", this.viewref);
      })
  }




  //-------------------------------- Percent ---------------------------------------------------------//

  @ViewChild("dialogEditPercent", { static: false }) dialogEditPercent: any;
  @ViewChild("dialogUploadPercent", { static: false }) dialogUploadPercent: any;
  public tableUploadPercent: any = [];
  public FileNamePercent: string = "";
  public ParamSearchPercent: any = {};
  public ParamPercent : any = {};
  public tabledataPercent: any = [];
  public FilePercent : any;
  @ViewChild("fileInputPercent") fileInputPercent: ElementRef;



  public SearchPercent() {
    this.tabledataPercent = []
    this.http.post("WH", "SNM170_GetDataPercent", this.ParamSearchPercent)
      .subscribe(res => {
        this.tabledataPercent = res.Table
      })

  }

  public AddPercent() {
    this.ParamPercent = {}
    this.isAdd = true
    this.dialogEditPercent.title = "New Part Percent"
    this.dialogEditPercent.OpenDialog();
  }

  public EditRowPercent(datarow) {

    this.isAdd = false;
    this.ParamPercent = datarow;
    this.dialogEditPercent.title = "Edit Part Percent"
    this.dialogEditPercent.OpenDialog();

  }


  public DeletePercent(data) {
    this.modal.confirm("Do you want to delete racord?", this.viewref, () => {
      this.http.post("WH", "SNM170_DeletePercent", data)
        .subscribe(res => {

          if (res.STATUS_MSG == 'DONE') {
            this.modal.info('Transaction complete: 1 record applied and deleted.', this.viewref);
            this.SearchPercent();
            this.dialogEditScenario.Close();

          } else {
            this.modal.warning('Delete fail.', this.viewref);
          }
        })
    })
  }


  public SavePercent() {

    this.modal.confirm("Do you want to save change you have made?", this.viewref, () => ConfirmSave())

    let ConfirmSave = () => {

      if (this.isAdd) {

        this.http.post("WH", "SNM170_InsertPercent", this.ParamPercent)
          .subscribe(res => {

            if (res.STATUS_MSG == 'DONE') {
              this.modal.info('Transaction complete: applied and saved.', this.viewref);
              if (this.tabledata.length > 0) {
                this.SearchPercent();
              }
              this.dialogEditPercent.Close();
            } else if (res.STATUS_MSG == 'DUPLICATE') {
              this.modal.info('No change to save. Found duplicate record.', this.viewref);
            }
            else {
              this.modal.warning('No change to save. Add fail.', this.viewref);
            }
          }, (err) => {
            this.modal.warning('No change to save. Add fail.', this.viewref);
          })
      } else {


        this.http.post("WH", "SNM170_UpdatePercent", this.ParamPercent)
          .subscribe(res => {
            if (res.STATUS_MSG == 'DONE') {
              this.modal.info('Transaction complete: applied and saved.', this.viewref);
              this.SearchPercent();
              this.dialogEditPercent.Close();
            } else {
              this.modal.error('No change to save. Update fail.', this.viewref);
            }
          }, err => {
            this.modal.error('No change to save. Update fail.', this.viewref);
          })
      }

    }
  }

  public CancelPercent() {
    this.dialogEditPercent.Close();
  }

  public UploadPercent() {
    this.tableUploadPercent = []
    this.FileNamePercent = "";
    this.dialogUploadPercent.title = "Upload Part Percent"
    this.dialogUploadPercent.OpenDialog()
  }

  public SaveUploadPercent() {

    this.modal.confirm("Do you want to save", this.viewref, () => confirmSave())

    let confirmSave = () => {
      const data = this.tableUploadPercent.filter(x => !x.MSG)
      this.http.post("WH", "SNM170_SaveUploadPercent", data)
        .subscribe(res => {
          if (res.STATUS_MSG == 'DONE') {
            this.modal.info('Transaction complete: applied and saved.', this.viewref);
            this.SearchPercent();
            this.dialogUploadPercent.Close();

          } else {
            this.modal.error('No change to save. fail.', this.viewref);
          }
        }, err => {
          this.modal.error('No change to save. fail.', this.viewref);
        })
    }
  }


  public OpenFileBrowserPercent() {
    this.FileNamePercent = "";
    this.fileInputPercent.nativeElement.value = '';
    this.fileInputPercent.nativeElement.click();
  }

  public SelectFilePercent(evt) {
    let Files: Array<File> = evt.target.files;

    if (Files.length > 0) {
      //let File: File = Files[0];
      this.FilePercent = Files[0];
      this.FileNamePercent = this.FilePercent.name;
    }
  }

  public PreViewPercent() {

    if (!this.FileNamePercent) {
      this.modal.warning("Please Open File First...", this.viewref)
      return;
    }

    let formData = new FormData();
    formData.append('file', this.FilePercent);
    this.tableUploadPercent = []
    this.http.postFile("WH", "SNM170_UploadPercent", formData)
      .subscribe(result => {
        this.tableUploadPercent = result.filter(x => x.PART_NO)
        //this.tableUploadScenario.map(x => x.SCENARIO = x["SCENARIO(1 or 2)"])
      }, err => {
        this.modal.error("Upload not complete", this.viewref);
      })
  }









}

