import { Component, OnInit, ViewContainerRef, ViewChild } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from 'src/app/core/global';

@Component({
    selector: 'SNPE013',
    templateUrl: './SNPE013.component.html',
    styleUrls: ['./SNPE013.component.css']
})

export class SNPE013Component implements OnInit {
    constructor(
        private http: HttpService,
        private modal: ModalService,
        private viewref: ViewContainerRef,
        private global: Globals
    ) { }

    public vendor: string;
    public vendorCode: string;
    public invoiceNo: string;
    public invoice: any = {};
    public tableData: Array<any> = [];
    public tableDataOld: Array<any> = [];

    public updateBy: string;
    public updateDate: Date;

    @ViewChild("autoCompleteInvoice", { static: true }) autoCompleteInvoice: any;

    public lookupConfig: any = {
        ColName: "LOOKUP_VENDOR_NAME",
        PlaceholderText: "Select Vendor",
        SourceController: "wPMS",
        SourceMethodName: "GetVendorCode",
        NoOfShowRecords: 50,
        UpperCase: true
    }

    public lookupInvoiceConfig: any = {
        ColName: "INVOICE_NO",
        PlaceholderText: "Select Invoice",
        SourceController: "WH",
        SourceMethodName: "SNPE013_GetInvoice",
        NoOfShowRecords: 50,
        MinLengthSearch: 1
    }

    public tblFooter: any = [
        {
            fieldName: "PO_NO",
            value: "Total",
            show: true
        },
        {
            fieldName: "ACCEPT_QTY",
            show: true
        }
    ]

    ngOnInit() { 
        this.lookupInvoiceConfig.SourceParams.vendorCode = this.vendorCode;
    }

    SearchInvoice() {
        this.tableData = [];

        let invoiceDate: Date = new Date(this.invoice.INVOICE_DATE);
        this.http.get("WH", "SNPE013_GetData", this.vendorCode, this.global.EscapeCharacter(this.invoice.INVOICE_NO), invoiceDate.toDateString())
            .subscribe(result => {
                this.tableData = result.Table;
                this.tableDataOld = JSON.parse(JSON.stringify(this.tableData));
            })
    }

    SaveToShelve(status: string) {
        let changeRecords: Array<any> = this.tableData.filter(v => v.STATUS_CODE === 'B'); //Save only B

        if (changeRecords.length > 0) {
            // this.modal.confirm("Are you sure to confirm these changes?", this.viewref
            //     , () => {
            this.http.post("WH", ["SNPE013_SavetoShelve", this.vendorCode, this.global.EscapeCharacter(this.invoiceNo), status], changeRecords)
                .subscribe(result => {
                    if (result === "Done") {
                        this.modal.info("Saved successfully", this.viewref);
                        this.autoCompleteInvoice.query();
                        // this.SearchInvoice();
                    }
                }, err => {
                    console.log(err);
                    this.modal.error(err.message, this.viewref);
                })
            // }, () => { })
        } else {
            this.modal.warning("No record to process.", this.viewref);
        }
    }

    SetVendorCodeLookup(value) {
        this.vendor = value.LOOKUP_VENDOR_NAME;
        this.vendorCode = value.VENDOR_CODE;

        this.lookupInvoiceConfig.SourceParams.vendorCode = this.vendorCode;

        //Reset invoice
        this.invoiceNo = null;
        this.invoice = {};
        this.tableData.length > 0 ? this.tableData = [] : null;
    }

    SetInvoiceLookup(value) {
        this.invoiceNo = value.INVOICE_NO;
        this.invoice = value;

        this.updateBy = value.LAST_UPD_BY;
        this.updateDate = value.LAST_UPD_DATE;

        this.SearchInvoice();
    }

    CheckDataStatus(data) {
        let dataCount = data.length;
        let checkedCount = data.filter(v => v.STATUS_CODE === '55').length;

        if (checkedCount > 0 && dataCount !== checkedCount) {
            return -1;
        } else if (checkedCount === 0) {
            return 0;
        } else if (checkedCount > 0 && dataCount === checkedCount) {
            return 1;
        }
    }

    CheckboxAllChange(evt) {
        if (evt.checked) {
            this.tableData.forEach(v => {
                v.STATUS_CODE = '55';
            })

        } else {
            this.tableData.forEach(v => {
                v.STATUS_CODE = 'X';
            })
        }

        this.tableData = this.tableData.slice();
    }

    CheckboxChange(evt, data) {
        if (evt.checked) {
            data.STATUS_CODE = '55';
        } else {
            data.STATUS_CODE = 'X';
        }
    }

    // AddToShelve() {
    //     this.modal.confirm("Are you sure to add to shelve?", this.viewref
    //         , () => {
    //             this.tableData.forEach(v => {
    //                 if (v.STATUS_CODE === 'B') {
    //                     v.STATUS_CODE = '55';
    //                 }
    //             })

    //             this.tableData = [...this.tableData];
    //             this.SaveToShelve();
    //         }, () => { })
    // }

    CancelToShelve() {
        this.modal.confirm("Are you sure to cancel to shelve?", this.viewref
            , () => {
                //Convert all 55 to B
                this.tableData.forEach(v => {
                    if (v.STATUS_CODE === '55') {
                        v.STATUS_CODE = 'B';
                    }
                })

                this.tableData = [...this.tableData];
                this.SaveToShelve('C');
            }, () => { })
    }

    TotalQuantity() {
        return this.tableData.reduce((a, b) => a + (b.ACCEPT_QTY || 0), 0)
    }

    HasChange() {
        return this.tableData.length > 0 && JSON.stringify(this.tableData) !== JSON.stringify(this.tableDataOld);
    }
}