import {
  Component,
  OnInit,
  ViewChild,
  ViewContainerRef,
  ElementRef,
} from "@angular/core";
import { HttpService } from "src/app/core/http.service";
import { ModalService } from "src/app/core/modal.service";
import { debounceTime, take, tap } from "rxjs/operators";
import { Globals } from "src/app/core/global";
import * as moment from "moment";
import { Subject } from "rxjs";

@Component({
  selector: "snpe046_P",
  templateUrl: "./SNPE046_P.component.html",
  styleUrls: ["./SNPE046_P.component.css", "../warehouse.component.css"],
})
export class SNPE046_PComponent implements OnInit {
  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewRef: ViewContainerRef,
    private el: ElementRef,
    private global: Globals
  ) {}

  @ViewChild("dialog", { static: true }) dialog: any;
  @ViewChild("qtyConfirmDialog", { static: true }) qtyConfirmDialog: any;

  public blockPreReceive: boolean = false;
  public confirmedInvoiceQty: number;
  private currentDate: moment.Moment = moment();
  private matchedPO: any[] = [];
  private duplicateCheck: Subject<boolean> = new Subject<boolean>();
  public invoiceHeader: any = {};
  public invoiceDetail: any[] = [];
  public paramsSearch: any = {};
  public invoiceList: any[] = [];
  public ShowList: boolean = false;
  //public invoiceType: string;
  public hideColumnDetail: string[] = [];
  public mtPoClass: any = [];

  public tblFooter: any = [
    {
      fieldName: "PART_NAME",
      value: "Total",
      show: true,
    },

    {
      fieldName: "STICKER_UNIT",

      show: true,
    },
    {
      fieldName: "ORDER_QTY",

      show: true,
    },
    {
      fieldName: "QTY",

      show: true,
    },
  ];

  public vendorLookupConfig: any = {
    ColName: "LOOKUP_VENDOR_NAME",
    PlaceholderText: "Select Vendor",
    SourceController: "WH",
    SourceMethodName: "SNPE015_P_GetVendorCode",
    NoOfShowRecords: 50,
    UpperCase: true,
    MinLengthSearch: 1,
    SourceParams: {
      INV_TYPE: "I_PO",
    },
  };

  public PartNoLookupConfig: any = {
    ColName: "LOOKUP_PART_NAME",
    PlaceholderText: "Select Part No.",
    SourceController: "wPMS",
    SourceMethodName: "GetPartNo",
    NoOfShowRecords: 20,
  };

  public ConfigInvoiceNo: any = {
    ColName: "INVOICE_NO",
    PlaceholderText: "Select Document No.",
    SourceController: "WH",
    SourceMethodName: "SNPE046_P_GetInvList",
    NoOfShowRecords: 50,
    MinLengthSearch: 2,
    UpperCase: true,
    SourceParams: {
      INVOICE_STATUS: "P",
    },
  };

  public ConfigInvoiceP: any = {
    ColName: "INVOICE_TEXT",
    PlaceholderText: "Select Invoice",
    SourceController: "WH",
    SourceMethodName: "SNPE046_P_GetExistInvoice",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true,
    SourceParams: {
      VENDOR_CODE: "",
    },
  };

  ngOnInit() {
    this.InitAdd();
    this.GetPOClass();

    this.duplicateCheck
      .pipe(take(0), debounceTime(500))
      .subscribe(
        (v) =>
          this.invoiceHeader.VENDOR_CODE &&
          this.invoiceHeader.INVOICE_NO &&
          this.CheckDuplicate()
      );
  }

  private InitAdd(invType?: string) {
    invType = invType || "I_PO";
    this.blockPreReceive = false; 

    this.invoiceHeader = {
      VENDOR_CODE: null,
      INVOICE_NO: null,
      INVOICE_DATE: this.currentDate,
      INVOICE_STATUS: "N",
      INVOICE_STATUS_DESC: "New",
      INVOICE_TYPE: invType,
      ATTRIBUTE1: new Date(),
    };

    this.invoiceDetail = [];
    this.matchedPO = [];
    //this.CreateDetailRow(0);

    this.invoiceHeader.INVOICE_TYPE = invType;
    this.vendorLookupConfig.SourceParams.INV_TYPE = invType;

    this.SetHideColumns(invType);
  }

  private GetPOClass() {
    this.http
      .get("System", "QueryData", "SP_NP_MT_PO_CLASS_LIST")
      .subscribe((result) => {
        this.mtPoClass = result.Table;
      });
  }

  public Search() {
    this.invoiceList = [];
    this.http.post("WH", "SNPE046_P_GetData", this.paramsSearch).subscribe(
      (res) => {
        this.invoiceList = res.Table;
      },
      (err) => {
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewRef
        );
      }
    );
  }

  public ViewDetail(invoiceData) {
    this.invoiceHeader = {};

    this.invoiceDetail = [];

    this.ShowList = false;
    this.http.post("WH", "SNPE015_P_GetInvoiceDetail", invoiceData).subscribe(
      (res) => {
        this.invoiceHeader = res.Table[0];
        this.invoiceDetail = res.Table1;

        if (this.invoiceHeader.INVOICE_NO) {
          this.invoiceHeader.VENDOR = this.invoiceHeader.VENDOR_CODE;
          //this.invoiceHeader.INVOICE_TYPE = this.invoiceHeader.INVOICE_TYPE;
          this.SetHideColumns(this.invoiceHeader.INVOICE_TYPE, ["CHECK"]);

          //if(this.invoiceType.substr(-2) == 'WO') {
          //  this.invoiceHeader.ORDER_CLASS = this.invoiceDetail[0].ORDER_CLASS;
          //  this.invoiceHeader.ORDER_TYPE = this.invoiceDetail[0].ORDER_TYPE;
          //}
        }

        this.invoiceDetail.forEach((v) => {
          v.ACCEPT_PART_NO = v.PART_NO;
          v._PART_NO = v.PART_NO;
        });
      },
      (err) => {
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewRef
        );
      }
    );
  }

  public Add() {
    this.ShowList = false;
    this.InitAdd();
  }

  private Save() {
    var data = Object.assign({}, this.invoiceHeader);
    data.PART_LIST = this.invoiceDetail.slice().filter((v) => v.ACCEPT_PART_NO);

    this.modal.confirm(
      "Are you sure to confirm pre-receive",
      this.viewRef,
      () => {
        this.http.post("WH", "SNPE015_P_Save", data).subscribe(
          (res) => {
            if (res.Result == "Done") {
              //this.invoiceHeader.DOCUMENT_NO = res.DocNo;
              this.modal.info(
                "Transaction complete: applied and saved.",
                this.viewRef
              );
              this.ViewDetail(this.invoiceHeader);
            } else if (res.Result == "Duplicate invoice") {
              this.modal.warning(
                "Duplicate invoice : " + this.invoiceHeader.INVOICE_NO,
                this.viewRef
              );
            } else {
              this.modal.warning(
                "Found an error, please contact support team.",
                this.viewRef
              );
            }
          },
          (err) => {
            this.modal.warning(
              "Found an error, please contact support team",
              this.viewRef
            );
          }
        );
      },
      () => {}
    );
  }

  public CheckDuplicate() {
    this.http
      .post("WH", "SNPE015_P_CheckDuplicateInvoice", {
        VENDOR_CODE: this.invoiceHeader.VENDOR_CODE,
        INVOICE_NO: this.invoiceHeader.INVOICE_NO,
        INVOICE_DATE: this.invoiceHeader.INVOICE_DATE,
      })
      .subscribe((res) => {
        if (res.Result !== "Done") {
          this.modal.warning(res.Message, this.viewRef);
        }
      });
  }

  public InvoiceDateChange() {
    this.duplicateCheck.next(true);
  }

  public CheckValidSave() {
    var validItems = this.invoiceDetail.filter((d, i) =>
      this.CheckRequiredFields(i, false)
    );
    var filledItems = this.invoiceDetail.filter((v) => v.ACCEPT_PART_NO);
    return (
      this.invoiceHeader.INVOICE_STATUS === "N" &&
      validItems.length === filledItems.length &&
      validItems.length > 0
    );
  }

  public CheckRequiredFields(tblIndex, allowUnChange: boolean = true) {
    let valid: boolean =
      this.invoiceHeader.VENDOR_CODE &&
      this.invoiceHeader.INVOICE_NO &&
      this.invoiceHeader.INVOICE_DATE
        ? true
        : false;

    if (valid) {
      let thisRow = this.invoiceDetail[tblIndex];
      let countChangeItems: number = 0;

      if (thisRow.ACCEPT_PART_NO) countChangeItems++;
      if (thisRow.QTY) countChangeItems++;
      if (thisRow.ACCEPT_PART_NO) countChangeItems++;

      valid =
        (countChangeItems > 0 &&
          thisRow.ACCEPT_PART_NO &&
          thisRow.QTY &&
          thisRow.LOCATION_NO) ||
        (allowUnChange && countChangeItems === 0)
          ? true
          : false;
    }

    return valid;
  }

  public CheckActiveRow(tblIndex) {
    let valid: boolean =
      this.invoiceHeader.VENDOR_CODE &&
      this.invoiceHeader.INVOICE_NO &&
      this.invoiceHeader.INVOICE_DATE
        ? true
        : false;

    if (valid) {
      valid =
        !this.invoiceHeader.INVOICE_STATUS ||
        this.invoiceHeader.INVOICE_STATUS === "N";
    }

    if (valid && tblIndex > 0) {
      let prevRow = this.invoiceDetail[tblIndex - 1];

      valid =
        prevRow.ACCEPT_PART_NO && prevRow.QTY //&& prevRow.UNIT_PRICE_B
          ? true
          : false;
    }

    //if (valid) {
    //  this.CreateDetailRow(tblIndex);
    //}

    return valid;
  }

  //public CreateDetailRow(tblIndex) {
  //  //let currentMaxRow: number = this.invoiceDetail.length || 0;
  //  //let nextMaxRow: number = (Math.floor(currentMaxRow / 10) + 1) * 10;

  //  //if (currentMaxRow - tblIndex <= 2) {
  //  //  for (let i = currentMaxRow; i < nextMaxRow; i++) {
  //  //    this.invoiceDetail.push({});
  //  //  }

  //  //  this.invoiceDetail = this.invoiceDetail.slice();
  //  //}
  //}

  public DeleteRow(index) {
    this.modal.confirm(
      "Are you sure to remove this row?",
      this.viewRef,
      () => {
        this.invoiceDetail.splice(index, 1);
        this.invoiceDetail = [...this.invoiceDetail];
      },
      () => {}
    );
  }

  public CheckPO(event, elemID, index, data) {
    let currentElement = this.el.nativeElement.querySelector("#" + elemID);

    //With P/O
    if (this.invoiceHeader.INVOICE_TYPE.substr(-2) === "PO") {
      this.http
        .post("WH", "SNPE015_P_CheckPOByPartNo", {
          VENDOR_CODE: this.invoiceHeader.VENDOR_CODE,
          INVOICE_NO: this.invoiceHeader.INVOICE_NO,
          PART_NO: event.PART_NO,
        })
        .subscribe(
          (res) => {
            this.matchedPO = res.Table.filter(
              (v) =>
                v.ORDER_CLASS == "2" ||
                moment(v.PO_DATE) < this.invoiceHeader.INVOICE_DATE //Order class 2 or
            );

            if (this.matchedPO.length === 1) {
              this.SetPOMatchOne(
                data,
                index,
                this.matchedPO[0],
                currentElement
              );
            } else if (this.matchedPO.length > 1) {
              this.matchedPO.forEach((d) => (d.CHECK = this.CheckIfExists(d)));
              this.dialog.OpenDialog();
            } else {
              data.ACCEPT_PART_NO = null;
              currentElement.focus();
              this.modal.error("Unable to find matched PO.", this.viewRef);
            }
          },
          (err) => {
            this.modal.error(err.message, this.viewRef);
          }
        );
    } else {
      this.http
        .post("WH", "SNPE015_P_CheckWOPartNo", {
          VENDOR_CODE: this.invoiceHeader.VENDOR_CODE,
          PART_NO: event.PART_NO,
        })
        .subscribe(
          (res) => {
            this.matchedPO = res.Table;

            if (this.matchedPO.length === 1) {
              data = Object.assign(
                data,
                this.SetPartRow(data, this.matchedPO[0])
              );
            } else {
              data.ACCEPT_PART_NO = null;
              currentElement.focus();
              this.modal.error("Unable to find part no.", this.viewRef);
            }
          },
          (err) => {
            this.modal.error(err.message, this.viewRef);
          }
        );
    }
  }

  public AcceptSelectedPO() {
    let thisPartNo = this.matchedPO[0].ACCEPT_PART_NO;

    let ActiveRow = this.invoiceDetail.filter((d, i) =>
      this.CheckRequiredFields(i, false)
    );
    let SelectedRow = this.matchedPO.filter((d) => {
      //Add checking exists row for do not concat
      const found = ActiveRow.find(
        (v) =>
          v.ACCEPT_PART_NO === d.ACCEPT_PART_NO &&
          v.PO_NO === d.PO_NO &&
          v.ITEM_NO === d.ITEM_NO &&
          v.SUB_ITEM_NO === d.SUB_ITEM_NO
      );

      return d.CHECK && !found;
    });

    SelectedRow = SelectedRow.map((d) => this.SetPartRow({}, d));

    this.invoiceDetail = ActiveRow.concat(SelectedRow);

    this.invoiceDetail = this.invoiceDetail.slice();
    this.dialog.Close();
  }

  public SetPOMatchOne(
    data: any,
    index: number,
    result: any,
    currentElement: any
  ) {
    let foundDuplicate = this.invoiceDetail.find((d, i) => {
      return (
        index !== i &&
        result.ACCEPT_PART_NO === this.invoiceDetail[i].ACCEPT_PART_NO &&
        result.PO_NO === this.invoiceDetail[i].PO_NO &&
        result.ITEM_NO === this.invoiceDetail[i].ITEM_NO &&
        result.SUB_ITEM_NO === this.invoiceDetail[i].SUB_ITEM_NO
      );
    });

    if (foundDuplicate) {
      data.ACCEPT_PART_NO = null;
      currentElement.focus();
      this.modal.error("Unable to insert duplicated record.", this.viewRef);
      return;
    }

    // data.CHECK = true;
    data = Object.assign(data, this.SetPartRow(data, result));
  }

  private SetPartRow(row: any, data: any) {
    row = data;
    row._PART_NO = data.ACCEPT_PART_NO;
    return row;
  }

  //------------------------------------- Add mode ------------------------------------------------------

  public SetVendorCodeSearch(value) {
    this.paramsSearch.VENDOR_CODE = value.VENDOR_CODE;
  }

  public SetVendorCodeLookup(value) {
    if (value.VENDOR_CODE) {
      this.invoiceHeader.VENDOR = value.VENDOR_CODE;
      this.invoiceHeader.VENDOR_CODE = value.VENDOR_CODE;
      this.invoiceHeader.VENDOR_NAME = value.VENDOR_NAME_EN;

      //this.vendorLookupConfig.SourceParams.INV_TYPE = invType;
      this.ConfigInvoiceP.SourceParams.VENDOR_CODE = value.VENDOR_CODE;

      // this.duplicateCheck.next(true)
    } else {
      this.invoiceHeader.VENDOR = null;
      this.invoiceHeader.VENDOR_CODE = null;
      this.el.nativeElement.querySelector("#vendorcode").focus();
      this.modal.error("Unable to find vendor.", this.viewRef);
    }
  }

  public SetInvoiceLookup(value) {
    if (value.INVOICE_NO) {
      this.invoiceHeader.INVOICE_NO = value.INVOICE_NO;
      this.invoiceHeader.INVOICE_DATE = value.INVOICE_DATE;

      this.http
        .post("WH", "SNPE046_P_ValidateInvoice", this.invoiceHeader)
        .subscribe(
          (res) => {
            console.log("STATUS " + res.STATUS);
            console.log("MESSAGE" + res.MESSAGE);
            if (res.STATUS === "DONE") {
              this.http
                .post("WH", "SNPE046_P_GetInvoiceDetail", this.invoiceHeader)
                .subscribe(
                  (res) => {
                    this.invoiceDetail = res.Table1;
                    if (
                      this.invoiceDetail.find(
                        (v) => !v.LOCATION_NO || v.LOCATION_NO.length === 0
                      )
                    ) {
                      this.modal.error(
                        "Location hasn't configured on some part.",
                        this.viewRef
                      );
                    }
                    this.invoiceDetail.forEach((v) => {
                      v.ACCEPT_PART_NO = v.PART_NO;
                      v._PART_NO = v.PART_NO;
                    });
                  },
                  (err) => {
                    this.modal.warning(
                      "Found an error, please contact support team",
                      this.viewRef
                    );
                  }
                );
            } else {
              this.modal.warning(res.MESSAGE, this.viewRef);
            }
          },
          (err) => {
            this.modal.warning(
              "Found an error, please contact support team",
              this.viewRef
            );
          }
        );
    } else {
      this.invoiceHeader.INVOICE_NO = null;
      this.invoiceHeader.INVOICE_DATE = null;
    }
  }

  public QuantityChange(data) {
    if (data.QTY > data.ACCEPT_QTY) {
      data.QTY = data.ACCEPT_QTY;
    }
    if (data.QTY % data.RECEIVE_PACKAGE > 0) {
      this.modal.warning(
        "Receive QTY not matched by Receive package.",
        this.viewRef
      );
    }

    data.STICKER_UNIT = Math.ceil(data.QTY / data.RECEIVE_PACKAGE);
  }

  public CheckIfExists(data) {
    return this.invoiceDetail.find((d) => {
      return (
        d.ACCEPT_PART_NO === data.ACCEPT_PART_NO &&
        d.PO_NO === data.PO_NO &&
        d.ITEM_NO === data.ITEM_NO &&
        d.SUB_ITEM_NO === data.SUB_ITEM_NO
      );
    });
  }

  public CancelPartNo(data: any) {
    data._PART_NO = data.ACCEPT_PART_NO;
  }

  public TotalQty() {
    return this.invoiceDetail.reduce((a, b) => a + (b.QTY || 0), 0);
  }

  public TotalItem() {
    return this.invoiceDetail.reduce(
      (a, b) => a + ((b.QTY || 0) / b.RECEIVE_PACKAGE || 0),
      0
    );
  }

  public GetMatchedPO() {
    return this.matchedPO;
  }

  public BackToSearch() {
    this.ShowList = true;
    this.Search();
  }

  public OpenReport_Pre() {
    //this.global.GoToReport("PMS_RPT_WMS_SNPE046",
    //  {
    //    P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
    //    P_DOCUMENT_NO: this.invoiceHeader.DOCUMENT_NO
    //  }
    //);
    this.global.GoToReport("PMS_RPT_WMS_SNPR020_v3", {
      P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      P_DOCUMENT_NO: this.invoiceHeader.DOCUMENT_NO,
    });
  }

  public OpenReport_PreNew() {
    this.global.GoToReport("PMS_RPT_WMS_SNPE046", {
      P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      P_DOCUMENT_NO: this.invoiceHeader.DOCUMENT_NO,
    });
  }

  private SetHideColumns(invType: string, fixCols?: string[]) {
    let hideCols = [];
    if (invType.substr(-2) === "WO") {
      hideCols = ["PO_NO", "PO_DATE", "ITEM_NO_SHOW", "ORDER_QTY"];
    }
    this.hideColumnDetail = hideCols.concat(fixCols || []);
  }

  public OrderClassChanged(selected) {
    switch (parseInt(selected.value)) {
      case 1:
      case 2:
        this.invoiceHeader.ORDER_TYPE = "1";
        break;
      case 3:
      case 4:
        this.invoiceHeader.ORDER_TYPE = "3";
        break;
      case 5:
        this.invoiceHeader.ORDER_TYPE = "4";
        break;
      case 7:
        this.invoiceHeader.ORDER_TYPE = "6";
        break;
    }
  }

  public CancelPreReceive() {
    this.modal.confirm(
      "Are you sure to cancel pre-receive?",
      this.viewRef,
      () => {
        this.http.post("WH", "SNPE015_P_Cancel", this.invoiceHeader).subscribe(
          (res) => {
            this.modal.info(
              "Transaction complete: applied and saved.",
              this.viewRef
            );
          },
          (err) => {
            this.modal.warning(
              "Found an error, please contact support team",
              this.viewRef
            );
          }
        );
      },
      () => {}
    );
  }

  public OpenConfirmQtyDialog() {
    this.confirmedInvoiceQty = null;
    this.qtyConfirmDialog.OpenDialog();
  }

  public ConfirmInvoiceQty() {
    const systemInvoiceQty = this.TotalQty();

    if (this.confirmedInvoiceQty === systemInvoiceQty) {
      this.blockPreReceive = false;
      this.Save();
    } else {
      this.blockPreReceive = true;
      this.modal.warning(
        `Please contact to IC team to check invoice ${this.invoiceHeader.INVOICE_NO}:<br/>Incorrect Qty`,
        this.viewRef
      );
    }
    this.qtyConfirmDialog.Close();
  }
}
