import { Component, OnInit, ViewChild, ViewContainerRef, ElementRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';
import { tap } from 'rxjs/operators';
import { Globals } from 'src/app/core/global';
import { AutoCompleteQueryComponent } from 'src/app/components/shared/auto-complete-query/auto-complete-query.component';
import * as moment from 'moment';

@Component({
  selector: 'snpe046_r',
  templateUrl: './SNPE046_R.component.html',
  styleUrls: ['../warehouse.component.css']
})

export class SNPE046_RComponent implements OnInit {
  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewRef: ViewContainerRef,
    private el: ElementRef,
    private global: Globals
  ) { }

  @ViewChild("dialog", { static: true }) dialog: any;
  @ViewChild("autoCompleteVendor", { static: true }) autoCompleteVendor: AutoCompleteQueryComponent;

  private currentDate: moment.Moment = moment();
 

  public invoiceHeader: any = {};
  public invoiceDetail: any[] = [];
  public invoiceItem: any[] = [];
  public invoiceData: any = {};


  public paramsSearch: any = {};
  public ShowList: boolean = true;
  public docList: Array<any> = [];
  public tempData: any = {};
  public iSCancel: boolean = false;

  public rowSave: any = [];


  public tblFooter: any = [
    {
      fieldName: "ACCEPT_PART_NO",
      value: "Total",
      show: true
    },
    {
      fieldName: "ORDER_QTY",
      show: true
    },
    {
      fieldName: "QTY",

      show: true
    },  
    {
      fieldName: "AMOUNT",

      show: true
    }]


  public vendorLookupConfig: any = {
    ColName: "LOOKUP_VENDOR_NAME",
    PlaceholderText: "Select Vendor",
    SourceController: "WH",
    SourceMethodName: "SNPE015_P_GetVendorCode",
    NoOfShowRecords: 50,
    UpperCase: true,
    MinLengthSearch: 1,
    SourceParams: {
      INV_TYPE: "I_PO"
    }
  }

  public PartNoLookupConfig: any = {
    ColName: "LOOKUP_PART_NAME",
    PlaceholderText: "Select Part No.",
    SourceController: "wPMS",
    SourceMethodName: "GetPartNo",
    NoOfShowRecords: 20
  }

  public ConfigDocNo: any = {
    ColName: "PRE_RECEIVE_TEXT",
    PlaceholderText: "Select Pre Receiving No.",
    SourceController: "WH",
    SourceMethodName: "SNPE046_R_GetPre_ReceivingList",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true,
    SourceParams: {
      INVOICE_STATUS: "P"
    }
  }

  public ConfigInvoiceNo: any = {
    ColName: "INVOICE_NO",
    PlaceholderText: "Select Document No.",
    SourceController: "WH",
    SourceMethodName: "SNPE046_P_GetInvList",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true,
    SourceParams: {
      INVOICE_STATUS: "P"
    }
  }

  ngOnInit() {
    this.paramsSearch.DOCUMENT_DATE_FROM = moment();
    this.paramsSearch.DOCUMENT_DATE_TO = moment();
  }


  public SetVendorCodeSearch(value) {
    this.paramsSearch.VENDOR_CODE = value.VENDOR_CODE;
  }


  public Search() {
    this.http.post("WH", "SNPE046_R_GetData_Import",
      {
        DOCUMENT_DATE_FROM: this.global.ConvertDateToFormatSTD(this.paramsSearch.DOCUMENT_DATE_FROM),
        DOCUMENT_DATE_TO: this.global.ConvertDateToFormatSTD(this.paramsSearch.DOCUMENT_DATE_TO),
        PRE_RECEIVE_DOC_NO: this.paramsSearch.PRE_RECEIVE_DOC_NO,
        VENDOR_CODE: this.paramsSearch.VENDOR_CODE,
        INVOICE_NO: this.paramsSearch.INVOICE_NO
      })
      .subscribe(result => {
        this.docList = result.Table;
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewRef);
      });
  }


  public ViewDetail(invoiceData) {

    this.invoiceHeader = {};

    this.invoiceDetail = [];

    this.invoiceData = invoiceData;
    this.ShowList = false;
    this.http.post("WH", "SNPE015_R_WEB_GetInvoiceDetail", invoiceData).subscribe(
      (res) => {
        this.invoiceHeader = res.Table[0];
        this.invoiceDetail = res.Table1;
        this.invoiceItem = res.Table2;        

      },
      (err) => {
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewRef
        );
      }
    );
  }


  QuantityChange(data) {
    if (data.QTY > data.ACCEPT_QTY) {
      data.QTY = data.ACCEPT_QTY
    }
  }

  SetNewPartNo(part: any, data: any) {
    this.tempData.Part = part;
    data.ACCEPT_PART_NO = part.PART_NO;
  }


  public TotalQty() {
    return this.invoiceDetail.reduce((a, b) => a + (b.QTY || 0), 0);
  }

  public TotalAmount() {
    return this.invoiceDetail.reduce((a, b) => a + ((b.QTY || 0) * (b.UNIT_PRICE_B || 0)), 0);
  }

  public TotalItem() {
    return this.invoiceDetail.reduce(
      (a, b) => a + (((b.QTY || 0) / b.RECEIVE_PACKAGE) || 0),
      0
    );
  }

  public BackToGrid() {
    this.Search();
    this.iSCancel = false;
    this.ShowList = true;
  }

  public ConfirmSaveDocument() {
    
    if (this.invoiceDetail.length > 0) {

      this.invoiceHeader.PART_LIST = this.invoiceItem;

      this.modal.confirm("Are you sure to confirm?", this.viewRef
        , () => {
          this.http.post("WH", "SNPE015_R_SaveDocument", this.invoiceHeader)
            .subscribe(result => {
              if (result.Result == 'Done') {
              this.ViewDetail(this.invoiceData);
              this.modal.info("The document has been confirmed to receive", this.viewRef)
              } else {
                this.modal.error(result.Message, this.viewRef);
              }

            }, err => {
              this.modal.error(err.message, this.viewRef);
            })
        }, () => { })
    } else {
      this.modal.error("No data to process.", this.viewRef);
    }
  }

 
  public OpenReport() {
    this.global.GoToReport("PMS_RPT_WH_SNPR028",
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_DOCUMENT_NO: this.invoiceHeader.RECEIVE_DOC_NO,
        P_DOCUMENT_DATE: this.global.ConvertDateToFormatSTD(this.invoiceHeader.CREATE_DATE),
        P_VENDOR_CODE: this.invoiceHeader.VENDOR,
        P_INVOICE_NO: this.invoiceHeader.INVOICE_NO,
        P_INVOICE_DATE: this.global.ConvertDateToFormatSTD(this.invoiceHeader.INVOICE_DATE),
      }
    );
  }

}

