import { Component, OnInit, ViewChild, ViewContainerRef, ElementRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';
import { tap } from 'rxjs/operators';
import { Globals } from 'src/app/core/global';
import { AutoCompleteQueryComponent } from 'src/app/components/shared/auto-complete-query/auto-complete-query.component';
import * as moment from 'moment';
import { SelectionModel } from '@angular/cdk/collections';

@Component({
  selector: 'snpe046_s',
  templateUrl: './SNPE046_S.component.html',
  styleUrls: ['../warehouse.component.css']
})

export class SNPE046_SComponent implements OnInit {
  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewRef: ViewContainerRef,
    private el: ElementRef,
    private global: Globals
  ) { }

  @ViewChild("dialog", { static: true }) dialog: any;
  @ViewChild("autoCompleteVendor", { static: true }) autoCompleteVendor: AutoCompleteQueryComponent;

  private currentDate: moment.Moment = moment();
 

  public invoiceHeader: any = {};
  public invoiceDetail: any[] = [];
  public invoiceItem: any[] = [];
  public invoiceData: any = {};


  public paramsSearch: any = {};
  public ShowList: boolean = true;
  public docList: Array<any> = [];
  public tempData: any = {};
  public iSCancel: boolean = false;

  public rowSave: any = [];
  public selection = new SelectionModel<any>(true, []);
  public dataSelected: any[] = [];


  public tblFooter: any = [
    {
      fieldName: "ACCEPT_PART_NO",
      value: "Total",
      show: true
    },
    {
      fieldName: "ORDER_QTY",
      show: true
    },
    {
      fieldName: "QTY",

      show: true
    },  
    {
      fieldName: "AMOUNT",

      show: true
    }]


  public vendorLookupConfig: any = {
    ColName: "LOOKUP_VENDOR_NAME",
    PlaceholderText: "Select Vendor",
    SourceController: "WH",
    SourceMethodName: "SNPE015_P_GetVendorCode",
    NoOfShowRecords: 50,
    UpperCase: true,
    MinLengthSearch: 1,
    SourceParams: {
      INV_TYPE: "I_PO"
    }
  }

  public PartNoLookupConfig: any = {
    ColName: "LOOKUP_PART_NAME",
    PlaceholderText: "Select Part No.",
    SourceController: "wPMS",
    SourceMethodName: "GetPartNo",
    NoOfShowRecords: 20
  }

  public ConfigDocNo: any = {
    ColName: "PRE_RECEIVE_TEXT",
    PlaceholderText: "Select Pre Receiving No.",
    SourceController: "WH",
    SourceMethodName: "SNPE046_P_GetPre_ReceivingList",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true,
      SourceParams: {
      INVOICE_STATUS: "R"
    }
  }

  public ConfigInvoiceNo: any = {
    ColName: "INVOICE_NO",
    PlaceholderText: "Select Document No.",
    SourceController: "WH",
    SourceMethodName: "SNPE046_P_GetInvList",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true,
    SourceParams: {
      INVOICE_STATUS: "R"
    }
  }

  ngOnInit() {
    this.paramsSearch.DOCUMENT_DATE_FROM = moment();
    this.paramsSearch.DOCUMENT_DATE_TO = moment();
  }


  public SetVendorCodeSearch(value) {
    this.paramsSearch.VENDOR_CODE = value.VENDOR_CODE;
  }


  public Search() {
    this.http.post("WH", "SNPE046_S_GetData",
      {
        DOCUMENT_DATE_FROM: this.global.ConvertDateToFormatSTD(this.paramsSearch.DOCUMENT_DATE_FROM),
        DOCUMENT_DATE_TO: this.global.ConvertDateToFormatSTD(this.paramsSearch.DOCUMENT_DATE_TO),
        PRE_RECEIVING_NO: this.paramsSearch.PRE_RECEIVING_NO,
        VENDOR_CODE: this.paramsSearch.VENDOR_CODE,        
        INVOICE_NO: this.paramsSearch.INVOICE_NO
      })
      .subscribe(result => {
        this.docList = result.Table;
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewRef);
      });
  }


  public ViewDetail(invoiceData) {
    this.invoiceHeader = {};
    this.invoiceDetail = [];
    this.dataSelected = [];
    this.selection.clear();

    this.invoiceData = invoiceData;
    this.ShowList = false;
    this.http.post("WH", "SNPE015_R_WEB_GetInvoiceDetail", invoiceData).subscribe(
      (res) => {
        this.invoiceHeader = res.Table[0];
        this.invoiceDetail = res.Table1;
        this.invoiceItem = res.Table2;

      },
      (err) => {
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewRef
        );
      }
    );
  }

  QuantityChange(data) {
    if (data.QTY > data.ACCEPT_QTY) {
      data.QTY = data.ACCEPT_QTY
    }

    let invoiceQty = this.GetInvoiceItemsByPO(data).length
    let shelvedQty = this.ShelvedQty(data);
    if (data.QTY > invoiceQty) {
      this.modal.warning("Shelve QTY cannot more than Invoice QTY.",this.viewRef);
      data.QTY = invoiceQty;
      return;
    } 

    this.UpdateSelectedItem();
  }

  SetNewPartNo(part: any, data: any) {
    this.tempData.Part = part;
    data.ACCEPT_PART_NO = part.PART_NO;
  }


  public TotalQty() {
    return this.invoiceDetail.reduce((a, b) => a + (b.QTY || 0), 0);
  }

  public TotalAmount() {
    return this.invoiceDetail.reduce((a, b) => a + ((b.QTY || 0) * (b.UNIT_PRICE_B || 0)), 0);
  }

  public TotalItem() {
    return this.invoiceDetail.reduce(
      (a, b) => a + (((b.QTY || 0) / b.RECEIVE_PACKAGE) || 0),
      0
    );
  }

  public BackToGrid() {
    this.Search();
    this.iSCancel = false;
    this.ShowList = true;
  }

  /**Save section */
  public SaveInvoice() {
    if(this.dataSelected.length > 0) {
      this.modal.confirm("Are you sure to save?", this.viewRef
        , () => {
          try {
            this.Save(false); //Call save
          } catch (e) {
            this.modal.warning(
              'Found an error, please contact support team',
              this.viewRef
            );
          }
        }
        , () => { })
    } else {
      this.modal.error("No data to process.", this.viewRef);
    }
  }


  private async Save(isConfirmCall: boolean) {
    let data = Object.assign({}, this.invoiceHeader); //New object ref.
    let partList = this.dataSelected
                      .slice() //New object ref.
                      .map(v => {
                        v.SHELVE_FLAG = 'Y';  //Set shelve to Y
                        return v;
                      });
    data.PART_LIST = partList

    await this.http.post("WH", "SNPE015_S_SaveDocument", data)
      .toPromise() //awaitable
      .then(res => {
        if(res.Result === "Done" && !isConfirmCall) {
          this.modal.info("Save shelve item completed.", this.viewRef)
          this.ViewDetail(this.invoiceData);
        } else if(res.Result === "Fail"){
          this.modal.warning(res.Message, this.viewRef);
        }
      })
      .catch((e) => {
        throw(e);
      });
  }

  public OpenReport_Pre() {
    this.global.GoToReport("PMS_RPT_WH_SNPR028",
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_DOCUMENT_NO: this.invoiceHeader.RECEIVE_DOC_NO,
        P_DOCUMENT_DATE: this.global.ConvertDateToFormatSTD(this.invoiceHeader.CREATE_DATE),
        P_VENDOR_CODE: this.invoiceHeader.VENDOR,
        P_INVOICE_NO: this.invoiceHeader.INVOICE_NO,
        P_INVOICE_DATE: this.global.ConvertDateToFormatSTD(this.invoiceHeader.INVOICE_DATE),
      }
    );
  }

  public OpenReport() {
    this.global.GoToReport("PMS_RPT_WH_SNPR028",
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_DOCUMENT_NO: this.invoiceHeader.RECEIVE_DOC_NO,
        P_DOCUMENT_DATE: this.global.ConvertDateToFormatSTD(this.invoiceHeader.CREATE_DATE),
        P_VENDOR_CODE: this.invoiceHeader.VENDOR,
        P_INVOICE_NO: this.invoiceHeader.INVOICE_NO,
        P_INVOICE_DATE: this.global.ConvertDateToFormatSTD(this.invoiceHeader.INVOICE_DATE),
      }
    );
  }

  public ShelvedQty(data) {
    return this.GetInvoiceItemsByPO(data).filter(d => d.SHELVE_FLAG === 'Y').length;
  }

  /**Checkbox section */
  public isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.invoiceDetail.length;
    return numSelected === numRows;
  }

  public Toggle() {
    if (this.isAllSelected()) {
      this.selection.clear()
    } else {
      this.invoiceDetail.forEach(row => {
        if(this.IsShelvedChecked(row) !== 1) {
          this.selection.select(row);
        }
      });
    }

    this.UpdateSelectedItem();
  }

  private GetInvoiceItemsByPO(data) {
    return this.invoiceItem
              .filter(d => data.PO_NO === d.ORDER_NO && data.ITEM_NO === d.ORDER_ITEM_NO && data.SUB_ITEM_NO === d.ORDER_SUB_ITEM_NO);
  }

  public UpdateSelectedItem() {
    this.dataSelected = [];
    this.selection.selected.forEach(v => {
      let invoiceItems: any[] = this.GetInvoiceItemsByPO(v).filter(d => d.SHELVE_FLAG === 'N' && d.SEQ === v.SEQ).slice();
      this.dataSelected.push.apply(this.dataSelected, invoiceItems);
    })
  }

  public IsShelvedChecked(data) {
    let allInvoiceItems: number = this.GetInvoiceItemsByPO(data).length;
    let shelvedInvoiceItems: number = this.GetInvoiceItemsByPO(data).filter(d => d.SHELVE_FLAG === 'Y').length;

    if(allInvoiceItems === shelvedInvoiceItems) {
      return 1; //Checked
    } else if (shelvedInvoiceItems > 0 && allInvoiceItems !== shelvedInvoiceItems) {
      return 2; //Indeterminate
    } else {
      return 0; //Unchecked
    }
  }

  /** */

}

