import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core'
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';
import * as moment from 'moment';
import { Globals } from 'src/app/core/global';
import { SelectionModel } from '@angular/cdk/collections';

@Component({
  selector: 'snse033_w',
  templateUrl: './SNSE033_W.component.html',
  styleUrls: ['./SNSE033_W.component.css']
})

export class SNSE033_WComponent implements OnInit {

  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewRef: ViewContainerRef,
    private global: Globals
  ) { }

  @ViewChild("dialogPrint", { static: false }) dialogPrint: any;

  public fileUrlPDF;
  public tableDataAir: any = [];
  public tableDataSea: any = [];

  public paramAir: any = {};
  public paramSea: any = {};
  public paramReport: any = {};

  public dataAir: any = {};
  public dataSea: any = {};
  public dataSet: any = {};

  public currentDate: moment.Moment = moment();

  public selection = new SelectionModel<any>(true, []);

  public selection2 = new SelectionModel<any>(true, []);

  public DataIsSelectedAir: any = [];

  public DataIsSelectedSea: any = [];

  public params: any = {}

  public tblFooter: any = [
    {
      fieldName: "PACK_BY",
      value: "Total",
      show: true
    },
    {
      fieldName: "GROSS_WEIGHT",
      show: true
    },
    {
      fieldName: "GROSS_MM",
      show: true
    },
    {
      fieldName: "PACK_QTY",
      show: true
    },
    {
      fieldName: "AMOUNT",
      show: true
    }

  ]

  public lookupCustomerCodeAir: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "WH",
    SourceMethodName: "SNSE033_W_GetCustomerCodeAir",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public lookupPreInvoiceAir: any = {
    ColName: "PINVOICE_TEXT",
    PlaceholderText: "Select Pre-invoice no.",
    SourceController: "WH",
    SourceMethodName: "SNSE033_W_GetPreInvoiceAir",
    NoOfShowRecords: 20,
    MinLengthSearch: 0,
    UpperCase: true,
    SourceParams: {
      CUSTOMER_CODE: "",
      BRANCH_CODE: "01"
    }
  }

  public lookupCustomerCodeSea: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "WH",
    SourceMethodName: "SNSE033_W_GetCustomerCodeSea",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public lookupPreInvoiceSea: any = {
    ColName: "PINVOICE_TEXT",
    PlaceholderText: "Select Pre-invoice no.",
    SourceController: "WH",
    SourceMethodName: "SNSE033_W_GetPreInvoiceSea",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true,
    SourceParams: {
      CUSTOMER_CODE: "",
      BRANCH_CODE: ""
    }
  }

  ngOnInit() {
    this.paramAir.ATTACH_SHEET = 'Y';
    this.paramSea.ATTACH_SHEET = 'Y';
  }

  public SetSelectedCustomerCode(values: any, pSendBy: any) {
    if (pSendBy == 'A') {
      this.paramAir.CUSTOMER_CODE = values.CUSTOMER_CODE;
      this.paramAir.CUSTOMER_NAME = values.CUSTOMER_NAME;
      this.paramAir.BRANCH_CODE = values.BRANCH_CODE;
      this.paramAir.BRANCH_NAME = values.BRANCH_NAME;
      this.dataAir.INVOICE_NO = '';
      this.lookupPreInvoiceAir.SourceParams.CUSTOMER_CODE = values.CUSTOMER_CODE;
      this.lookupPreInvoiceAir.SourceParams.BRANCH_CODE = values.BRANCH_CODE;
      this.paramAir.PINVOICE_NO = '';
      this.paramAir.PINVOICE_DATE = '';
      this.tableDataAir = [];
    } else {
      this.paramSea.CUSTOMER_CODE = values.CUSTOMER_CODE;
      this.paramSea.CUSTOMER_NAME = values.CUSTOMER_NAME;
      this.paramSea.BRANCH_CODE = values.BRANCH_CODE;
      this.paramSea.BRANCH_NAME = values.BRANCH_NAME;
      this.dataSea.INVOICE_NO = '';
      this.lookupPreInvoiceSea.SourceParams.CUSTOMER_CODE = values.CUSTOMER_CODE;
      this.lookupPreInvoiceSea.SourceParams.BRANCH_CODE = values.BRANCH_CODE;
      this.paramSea.PINVOICE_NO = '';
      this.paramSea.PINVOICE_DATE = '';
      this.tableDataSea = [];
    }

  }

  public SelectPreInvoice(values: any, pSendBy: any) {
    if (pSendBy == 'A') {
      //this.paramAir.CUSTOMER_CODE = values.CUSTOMER_CODE;
      //this.paramAir.CUSTOMER_NAME = values.CUSTOMER_NAME;
      //this.paramAir.BRANCH_CODE = values.BRANCH_CODE;
      //this.paramAir.BRANCH_NAME = values.BRANCH_NAME;
      //this.dataAir.INVOICE_NO = '';
      this.paramAir.PINVOICE_NO = values.PINVOICE_NO;
      this.paramAir.PINVOICE_DATE = values.PINVOICE_DATE;
      this.paramAir.DOC_TYPE = values.DOC_TYPE;
    } else {
      //this.paramSea.CUSTOMER_CODE = values.CUSTOMER_CODE;
      //this.paramSea.CUSTOMER_NAME = values.CUSTOMER_NAME;
      //this.paramSea.BRANCH_CODE = values.BRANCH_CODE;
      //this.paramSea.BRANCH_NAME = values.BRANCH_NAME;
      //this.dataSea.INVOICE_NO = '';
      this.paramSea.PINVOICE_NO = values.PINVOICE_NO;
      this.paramSea.PINVOICE_DATE = values.PINVOICE_DATE;
      this.paramSea.DOC_TYPE = values.DOC_TYPE;
    }
    this.GetData(pSendBy);
  }

  private GetData(pSendBy: any) {
    if (pSendBy == 'A') {
      this.tableDataAir = [];
      this.selection.clear();
      this.DataIsSelectedAir = [];
      this.http.post('WH', 'SNSE033_W_GetDataAir', this.paramAir)
        .subscribe(res => {
          this.tableDataAir = res.Table1;
        })
    } else {
      this.tableDataSea = [];
      this.selection2.clear();
      this.DataIsSelectedSea = [];
      this.http.post('WH', 'SNSE033_W_GetDataSea', this.paramSea)
        .subscribe(res => {
          this.tableDataSea = res.Table1;
        })
    }
  }

  public Confirm_Click(pSendBy: any) {
    var msg: any = '';
    if (pSendBy == 'A') {
      if (this.paramAir.EXCHANGE_RATE == '') {
        msg = "Exchange Rate Invalid." + '<br/>';
      }
      if (this.dataAir.FLIGHT_NO == '' || this.dataAir.FLIGHT_NO == undefined) {
        msg = msg + "Flight No. is not input.." + "<br/>";
      }
      if (this.dataAir.AWB_NO == '' || this.dataAir.AWB_NO == undefined) {
        msg = msg + "AWB No. is not input.." + "<br/>";
      }
      var dToDate = moment().locale("en").startOf('day');
      if (this.dataAir.AWB_DATE == '' || this.dataAir.AWB_DATE == undefined) {
        msg = msg + "AWB Date. is not input.." + "<br/>";
      } else if (this.dataAir.AWB_DATE <= dToDate) {
        msg = msg + "AWB Date. is lower than current date" + "<br/>";
      }
      var thai = /[\u0E01-\u0E5B]/;
      if (thai.test(this.dataAir.FLIGHT_NO)) {
        msg = msg + "Flight No. is cannot input thai language " + "<br/>";
        this.dataAir.FLIGHT_NO = '';
      }
      if (thai.test(this.dataAir.AWB_NO)) {
        msg = msg + "AWB No. is cannot input thai language " + "<br/>";
        this.dataAir.AWB_NO = '';
      }
      if (msg != '') {
        this.modal.warning(msg, this.viewRef);
        return;
      }

      var nCT = 0;
      var QtyEmpty = 0;
      this.DataIsSelectedAir = this.tableDataAir
      if (this.DataIsSelectedAir.length == 0) {
        this.modal.warning('No "Case No." to be selected. Please check', this.viewRef);
        return;
      }
      this.DataIsSelectedAir.forEach((value) => {
        if (value.CONTAINER_NO == '') {
          nCT = nCT + 1;
        }
        if (value.PACK_QTY <= 0) {
          QtyEmpty = QtyEmpty + 1;
        }
      });
      if (nCT != 0) {
        this.modal.warning('Container No. Invalid.', this.viewRef);
        return;
      }
      if (QtyEmpty != 0) {
        this.modal.warning('Pack qty cannot be 0. Please check', this.viewRef);
        return;
      }
      this.DataIsSelectedAir[0].AWB_NO = this.dataAir.AWB_NO;
      this.DataIsSelectedAir[0].AWB_DATE = this.dataAir.AWB_DATE;
      this.DataIsSelectedAir[0].FRC = this.dataAir.FRC;
      this.DataIsSelectedAir[0].FWC = this.dataAir.FWC;
      this.DataIsSelectedAir[0].INS = this.dataAir.INS;
      this.DataIsSelectedAir[0].FLIGHT_NO = this.dataAir.FLIGHT_NO;
      this.DataIsSelectedAir[0].TOTAL_CASE = this.DataIsSelectedAir.length;
      //console.log('dataSelected[0] : ', dataSelected[0]);
      this.http.post('SL', 'CheckIssueInvoiceRunning', this.DataIsSelectedAir[0])
        .subscribe(res => {
          if (res.status == 'fail') {
            this.modal.warning(res.massage, this.viewRef);
          }
          else {
            this.modal.confirm("Are you sure to confirm this invoice?", this.viewRef, () => {
              this.http.post('WH', 'SNSE033_W_ConfirmAir', this.DataIsSelectedAir)
                .subscribe(result => {
                  if (result.substring(0, 4) == "DONE") {
                    this.GetData(pSendBy);
                    this.dataAir.INVOICE_NO = result.substring(5, 20);
                    this.modal.info("Confirm successfully [Invoice no.] : " + result.substring(5, 20), this.viewRef);

                    this.dataAir.AWB_NO = '';
                    this.dataAir.AWB_DATE = '';
                    this.dataAir.FRC = '';
                    this.dataAir.FWC = '';
                    this.dataAir.INS = '';
                    this.dataAir.FLIGHT_NO = '';

                    if (this.paramAir.ATTACH_SHEET == 'Y') {
                      this.OpenReport('FA', result.substring(5, 20))
                    }
                  } else {
                    console.log(result.substring(result.indexOf(":")), 'err');
                    this.GetData(pSendBy);
                    this.modal.warning("Found an error, please contact support team", this.viewRef);
                  }
                }, (err) => {
                  console.log(err, 'err')
                  this.GetData(pSendBy);
                  this.modal.warning("Found an error, please contact support team", this.viewRef);
                })
            });
          }
        }, (err) => {
          console.log(err, 'err')
          this.modal.warning("Found an error, please contact support team", this.viewRef);
        })
    }
    else { //------------- Sea
      msg = '';
      if (!this.dataSea.VESSEL) {
        msg = msg + "Vessel is not input.." + "<br/>";
      }
      if (!this.dataSea.BL_NO) {
        msg = msg + "B/L No. is not input.." + "<br/>";
      }
      if (!this.dataSea.BL_DATE) {
        msg = msg + "B/L Date is not input.." + "<br/>";
      }
      //---- Compare date
      var dToDate = moment().locale("en").startOf('day');
      if (this.dataSea.BL_DATE <= dToDate) {
        msg = msg + "B/L Date is lower than current date" + "<br/>";
      }

      var thai = /[\u0E01-\u0E5B]/;
      if (thai.test(this.dataSea.VESSEL)) {
        msg = msg + "Vessel is cannot input thai language " + "<br/>";
        this.dataSea.VESSEL = '';
      }
      if (thai.test(this.dataSea.BL_NO)) {
        msg = msg + "B/L No. is cannot input thai language " + "<br/>";
        this.dataSea.BL_NO = '';
      }
      if (msg != '') {
        this.modal.warning(msg, this.viewRef);
        return;
      }

      //var dataSelected = this.tableDataSea.filter(v => v.SELECT_CONFIRM == true);
      var nCT = 0;
      var QtyEmpty = 0;
      this.DataIsSelectedSea = this.tableDataSea
      if (this.DataIsSelectedSea.length == 0) {
        this.modal.warning('No "Case No." to be selected. Please check', this.viewRef);
        return;
      }

      this.DataIsSelectedSea.forEach((value) => {
        if (value.CONTAINER_NO == '') {
          nCT = nCT + 1;
        }
        if (value.PACK_QTY <= 0) {
          QtyEmpty = QtyEmpty + 1;
        }
      });

      if (nCT != 0) {
        this.modal.warning('Container No. Invalid.', this.viewRef);
        return;
      }
      if (QtyEmpty != 0) {
        this.modal.warning('Pack qty cannot be 0. Please check', this.viewRef);
        return;
      }
      this.DataIsSelectedSea[0].BL_NO = this.dataSea.BL_NO;
      this.DataIsSelectedSea[0].BL_DATE = this.dataSea.BL_DATE;

      this.DataIsSelectedSea[0].FRC = this.dataSea.FRC;
      this.DataIsSelectedSea[0].FWC = this.dataSea.FWC;
      this.DataIsSelectedSea[0].INS = this.dataSea.INS;
      this.DataIsSelectedSea[0].VESSEL = this.dataSea.VESSEL;
      this.DataIsSelectedSea[0].TOTAL_CASE = this.DataIsSelectedSea.length;

      this.http.post('SL', 'CheckIssueInvoiceRunning', this.DataIsSelectedSea[0])
        .subscribe(res => {
          if (res.status == 'fail') {
            this.modal.warning(res.massage, this.viewRef);
          }
          else {
            this.modal.confirm("Are you sure to confirm this invoice?", this.viewRef, () => {

              this.http.post('WH', 'SNSE033_W_ConfirmSea', this.DataIsSelectedSea)
                .subscribe(result => {
                  if (result.substring(0, 4) == "DONE") {
                    this.GetData(pSendBy);
                    this.dataSea.INVOICE_NO = result.substring(5, 20);
                    this.modal.info("Confirm successfully [Invoice no.] : " + result.substring(5, 20), this.viewRef);
                    this.dataSea.BL_NO = '';
                    this.dataSea.BL_DATE = '';
                    this.dataSea.FRC = '';
                    this.dataSea.FWC = '';
                    this.dataSea.INS = '';
                    this.dataSea.VESSEL = '';
                    if (this.paramSea.ATTACH_SHEET == 'Y') {
                      this.OpenReport('FS', result.substring(5, 20))
                    }
                  } else {
                    console.log(result.substring(result.indexOf(":")), 'err');
                    this.GetData(pSendBy);
                    this.modal.warning("Found an error, please contact support team", this.viewRef);
                  }
                }, (err) => {
                  console.log(err, 'err');
                  this.GetData(pSendBy);
                  this.modal.warning("Found an error, please contact support team", this.viewRef);
                })
            });
          }
        }, (err) => {
          console.log(err, 'err');
          this.modal.warning("Found an error, please contact support team", this.viewRef);
        })
    }
  }

  public CheckPrintChangeAir(value) {
    if (value.checked == true) {
      this.paramAir.ATTACH_SHEET = 'Y'
    }
    else {
      this.paramAir.ATTACH_SHEET = 'N'
    }
  }

  public CheckPrintChangeSea(value) {
    if (value.checked == true) {
      this.paramSea.ATTACH_SHEET = 'Y'
    }
    else {
      this.paramSea.ATTACH_SHEET = 'N'
    }
  }

  private OpenReport(docType, docNo) {

    

    // this.global.GoToExportName("PMS_RPT_SALES_SNSE033_W",
    //   {
    //     P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
    //     P_DOC_TYPE: docType,
    //     P_DOC_NO: docNo,
    //   }
    //   , docNo, 'PDF'
    // );


    setTimeout(() => {
      this.paramReport.DOC_TYPE = docType;
      this.paramReport.DOC_NO = docNo;
      if(docType == "FS"){
        const cus = this.paramSea.CUSTOMER_CODE.substring(0, 1) + "-" + this.paramSea.CUSTOMER_CODE.substring(1, 4) + "-"  + this.paramSea.CUSTOMER_CODE.substring(4, 6);
        this.Print({DOCUMENT_TYPE : docType,INVOICE_NO : docNo,CUSTOMER_CODE : cus,ORDER_TYPE : "S"})
      }else{
        const cus = this.paramAir.CUSTOMER_CODE.substring(0, 1) + "-" + this.paramAir.CUSTOMER_CODE.substring(1, 4) + "-"  + this.paramAir.CUSTOMER_CODE.substring(4, 6);
        this.Print({DOCUMENT_TYPE : docType,INVOICE_NO : docNo,CUSTOMER_CODE : cus,ORDER_TYPE : "A"})
      }
    }, 1500);
    
    

    // this.dialogPrint.OpenDialog();
    // this.fileUrlPDF = null;
    // this.http
    //   .Download("WH", "SNSE033_W_PDF_INVOICE", {
    //     ReportPrefix: "PMS_RPT_SALES_SNSE033_W",
    //     ReportSuffix: ".PDF",
    //     P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
    //     P_DOC_TYPE: docType,
    //     P_DOC_NO: docNo,
    //   })
    //   .subscribe((res) => {
    //     if (res) {
    //       this.SetIFrameContent(res);
    //     }
    //   }, (err) => {
    //     console.log(err, 'err');
    //     this.modal.warning("Found an error, please contact support team", this.viewRef);
    //   });
  }

  private SetIFrameContent(content: any) {
    const file = new Blob([content], { type: content.type });
    const fileUrlPDF = URL.createObjectURL(file);
    this.fileUrlPDF = fileUrlPDF;
  }

  isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.tableDataAir.length;
    return numSelected === numRows;
  }

  Toggle() {
    if (this.isAllSelected()) {
      this.selection.clear()
      this.tableDataAir.map(x => {
        this.DataIsSelectedAir = [];
      })
    } else {
      this.tableDataAir.forEach(row => this.selection.select(row));
      this.DataIsSelectedAir = [];
      this.tableDataAir.map(x => {
        this.DataIsSelectedAir.push(x);
      })
    }
  }

  CheckboxChange(event, data) {
    if (event.checked) {
      this.DataIsSelectedAir.push(data);
    }
    else {
      this.DataIsSelectedAir.splice(this.DataIsSelectedAir.indexOf(data), 1);

    }
  }





  isAllSelected2() {
    const numSelected = this.selection2.selected.length;
    const numRows = this.tableDataSea.length;
    return numSelected === numRows;
  }

  Toggle2() {
    if (this.isAllSelected2()) {
      this.selection2.clear()
      this.tableDataSea.map(x => {
        this.DataIsSelectedSea = [];
      })
    } else {
      this.tableDataSea.forEach(row => this.selection2.select(row));
      this.DataIsSelectedSea = [];
      this.tableDataSea.map(x => {
        this.DataIsSelectedSea.push(x);
      })
    }
  }

  CheckboxChange2(event, data) {
    if (event.checked) {
      this.DataIsSelectedSea.push(data);
    }
    else {
      this.DataIsSelectedSea.splice(this.DataIsSelectedSea.indexOf(data), 1);
    }
  }


  public async Print(data) {

    this.params = data
    this.http.post("SL", "SNSE225_GetData_Master_Customer_Group", data)
      .subscribe(async res => {
        this.params.New = 'Y'
        this.SetSearchInvoiceMasterNew(res.Table[0].CUSTOMER_GROUP_CODE)

      }, (err) => {
        console.log(err, "err")
        this.modal.warning("Found an error, please contact support team", this.viewRef);
        return;
      })
  }

  public async SetSearchInvoiceMasterNew(values: any) {

    this.params.CUSTOMER_GROUP_CODE = values;
    await this.http.post("SL", "SNSE225_GetData_Master", this.params)
      .subscribe(res => {
        if (res.Table[0]) {
          this.params.COMPANY_CODE = res.Table[0].COMPANY_CODE;
          this.params.CUSTOMER_GROUP_CODE = res.Table[0].CUSTOMER_GROUP_CODE;
          this.params.CUSTOMER_GROUP_NAME = res.Table[0].CUSTOMER_GROUP_NAME;
          this.params.SHIPPER1 = res.Table[0].SHIPPER1;
          this.params.SHIPPER2 = res.Table[0].SHIPPER2;
          this.params.SHIPPER3 = res.Table[0].SHIPPER3;
          this.params.SHIPPER4 = res.Table[0].SHIPPER4;
          this.params.SHIPPER_TAX_ID = res.Table[0].SHIPPER_TAX_ID;
          this.params.CONSIGNED_MESSRS1 = res.Table[0].CONSIGNED_MESSRS1;
          this.params.CONSIGNED_MESSRS2 = res.Table[0].CONSIGNED_MESSRS2;
          this.params.CONSIGNED_MESSRS3 = res.Table[0].CONSIGNED_MESSRS3;
          this.params.CONSIGNED_MESSRS4 = res.Table[0].CONSIGNED_MESSRS4;
          this.params.NOTIFY_PARTY1 = res.Table[0].NOTIFY_PARTY1;
          this.params.NOTIFY_PARTY2 = res.Table[0].NOTIFY_PARTY2;
          this.params.NOTIFY_PARTY3 = res.Table[0].NOTIFY_PARTY3;
          this.params.NOTIFY_PARTY4 = res.Table[0].NOTIFY_PARTY4;
          this.params.NOTIFY_PARTY_TEL = res.Table[0].NOTIFY_PARTY_TEL;
          this.params.BANK_OF_NMT1 = res.Table[0].BANK_OF_NMT1;
          this.params.BANK_OF_NMT2 = res.Table[0].BANK_OF_NMT2;
          this.params.BANK_OF_NMT3 = res.Table[0].BANK_OF_NMT3;
          this.params.BANK_OF_NMT_TEL = res.Table[0].BANK_OF_NMT_TEL;
          this.params.BANK_OF_NMT_FAX = res.Table[0].BANK_OF_NMT_FAX;
          this.params.BANK_OF_NMT_SWIFT_CODE = res.Table[0].BANK_OF_NMT_SWIFT_CODE;
          this.params.BANK_OF_NMT_ACOUNT_ACCOUNT_NO = res.Table[0].BANK_OF_NMT_ACOUNT_ACCOUNT_NO;
          this.params.SHIPPED_PER = res.Table[0].SHIPPED_PER;
          this.params.PORT_OF_DISCHARGE = res.Table[0].PORT_OF_DISCHARGE;
          this.params.PORT_OF_LOADING = res.Table[0].PORT_OF_LOADING;
          this.params.FINAL_DESTINATION_FOR_REFERENCE_ONLY = res.Table[0].FINAL_DESTINATION_FOR_REFERENCE_ONLY;
          this.params.DESCRIPTION_OF_GOODS1 = res.Table[0].DESCRIPTION_OF_GOODS1;
          this.params.DESCRIPTION_OF_GOODS2 = res.Table[0].DESCRIPTION_OF_GOODS2;
          this.params.DESCRIPTION_OF_GOODS3 = res.Table[0].DESCRIPTION_OF_GOODS3;
          this.params.DESCRIPTION_OF_GOODS4 = res.Table[0].DESCRIPTION_OF_GOODS4;
          this.params.F_O_B = res.Table[0].F_O_B;
          this.params.COUNTRY_ORIGIN = res.Table[0].COUNTRY_ORIGIN;
          this.params.FREIGHT = res.Table[0].FREIGHT;
          this.params.SIGNATURE1 = res.Table[0].SIGNATURE1;
          this.params.SIGNATURE2 = res.Table[0].SIGNATURE2;
          this.params.SIGNATURE3 = res.Table[0].SIGNATURE3;
          this.params.PLACE = res.Table[0].PLACE;
          this.params.TERMS_METHOD_OF_PAYMENT = res.Table[0].TERMS_METHOD_OF_PAYMENT;
          this.ProcessPrintCover()
        }
      }, (err) => {
        console.log(err, "err")
        this.modal.warning("Found an error, please contact support team", this.viewRef);
        //return;
      })


  }

  public async ProcessPrintCover() {
    await this.http.post("SL", "SNSE225_Update_Invoice_Export", this.params)
      .subscribe(res => {

      }, (err) => {
        console.log(err, "err")
        this.modal.warning("Found an error, please contact support team", this.viewRef);
      });

    await this.http.post("SL", "SNSE225_PROCESS_PRINT", this.params)
      .subscribe(res => {
        // if (res.STATUS_MESSAGE == 'DONE') {
        // }
        // else {
        //   this.modal.error("Process incompleted!!", this.viewRef);
        // }
      }, (err) => {
        this.modal.error('Found an error, please contact support team.', this.viewRef);
      });
    await this.OpenReportCover()
  }

  public OpenReportCover() {

    var fileName = 'PMS_RPT_INVOICE_EXPORT_' + this.params.INVOICE_NO;

    if (this.params.DOCUMENT_TYPE == 'FS') {
      this.params.DOC_TYPE = 'SEA';
    } else if (this.params.DOCUMENT_TYPE == 'FA') {
      this.params.DOC_TYPE = 'AIR';
    }

    this.global.GoToExportName("PMS_RPT_INVOICE_EXPORT_" + this.params.DOC_TYPE + "_" + this.params.CUSTOMER_CODE,
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_CUSTOMER_GROUP_CODE: this.params.CUSTOMER_GROUP_CODE,
        P_INVOICE_NO: this.params.INVOICE_NO,
        P_MENU_FORM: "SNSE033_W"
      }
      , fileName, 'EXCELOPENXML'
    );
  }
}
