import { Component, OnInit, ViewChild, ViewContainerRef, ElementRef, ViewChildren } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';

@Component({
  selector: 'snse034W',
  templateUrl: './SNSE034_W.component.html',
  styleUrls: ['./SNSE034_W.component.css']
})



export class SNSE034_WComponent implements OnInit {

  constructor(
    private Http: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }
  @ViewChildren("input") Inputs: any;

  public params: any = {};
  public TableData: any = [];
  public DataIsSelected: any = [];

  ngOnInit() {
  }

  public lookupCustomerCodeConfig: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "WH",
    SourceMethodName: "SNSE034_W_GetCustomerCode",
    NoOfShowRecords: 100,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedCustomerCode(values: any) {
    this.params.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.params.CUSTOMER_NAME = values.CUSTOMER_NAME;
    this.params.BRANCH_CODE = values.BRANCH_CODE;
    this.params.BRANCH_NAME = values.BRANCH_NAME;
    this.Search();
  }

  private Search = () => {
    this.TableData = [];
    this.Http.post('WH', 'SNSE034_W_getData', this.params)
      .subscribe(res => {
        this.TableData = res.Table;
      })
  }

  public ConfirmSave() {
    var dataChange = 0;
    this.DataIsSelected = [];
    this.TableData.forEach((e) => {
      if (e.CONTAINER_NO != e.CONTAINER_NO_OLD) {
        this.DataIsSelected.push(e);
        dataChange = dataChange + 1;
      }
    });
    if (dataChange > 0) {
      this.modal.confirm('Do you want to update on this data?', this.viewref, this.Save)
    }
    else {
      this.modal.info('There is no data change.', this.viewref)
    }
  }

  private Save = () => {
    this.Http.post('WH', 'SNSE034_W_Update', this.DataIsSelected)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info('Update data successfully.', this.viewref);
          this.Search();
        }
        else {
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      }, (err) => {
          console.log(err, 'err')
          this.modal.warning("Found an error, please contract support team", this.viewref);
      });
  }
  public focusInput(rowIdx: number) {
    let inputEls = this.Inputs.toArray();
    inputEls[rowIdx].nativeElement.focus();
  }
  public shiftFocusDown(rowIdx: number) {
    rowIdx = Math.min(rowIdx + 1, this.TableData.length - 1);
    this.focusInput(rowIdx);
  }
  public shiftFocusUp(rowIdx: number) {
    rowIdx = Math.max(0, rowIdx - 1);
    this.focusInput(rowIdx);
  }
}
