import { Component, OnInit, ViewChild, ViewContainerRef, ElementRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Globals } from 'src/app/core/global';
import { ModalService } from 'src/app/core/modal.service';
import { MatDatepicker } from '@angular/material/datepicker';
import { DomSanitizer } from '@angular/platform-browser';


@Component({
  selector: 'snse044_W_ETG',
  templateUrl: './snse044_W_ETG.component.html',
  styleUrls: ['./snse044_W_ETG.component.css']
})

export class SNSE044_W_ETGComponent implements OnInit {

  constructor(
    private Http: HttpService,
    private global: Globals,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    public domsanitizer: DomSanitizer

  ) { }

  @ViewChild('myDiv', { read: ElementRef }) myDiv: ElementRef;

  public params: any = {};
  public tableData: any = [];

  public detailUrl: string;

  public btnDRG: HTMLElement;

  public lookupCustomerCodeConfig: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "WH",
    SourceMethodName: "SNSE044_W_getCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public lookupDocNoConfig: any = {
    ColName: "LOOKUP_DOCUMENT_NO",
    PlaceholderText: "Select Doc No.",
    SourceController: "WH",
    SourceMethodName: "SNSE044_W_getDocNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public SetSelectedCustomerCodeFrom(values: any) {
    this.params.CUSTOMER_CODE_FROM = values.CUSTOMER_CODE;
    if (!this.params.CUSTOMER_CODE_TO) {
      this.params.CUSTOMER_CODE_TO = values.CUSTOMER_CODE;
    }
    this.clearInput()
  }

  public SetSelectedCustomerCodeTo(values: any) {
    this.params.CUSTOMER_CODE_TO = values.CUSTOMER_CODE;
    this.clearInput()
  }

  public SetSelectedDocNoFrom(values: any) {
    this.params.DOC_NO_FROM = values.DOCUMENT_NO;
    if (!this.params.DOC_NO_TO) {
      this.params.DOC_NO_TO = values.DOCUMENT_NO;
    }
  }

  public SetSelectedDocNoTo(values: any) {
    this.params.DOC_NO_TO = values.DOCUMENT_NO;
  }

  ngOnInit() {
    this.params.SENT_BY = 'A'
    this.getDocType();
    this.params.CHK_PRN_MITH = 'Y'
  }

  ngAfterViewInit() {
    this.btnDRG = this.myDiv.nativeElement;
  }

  private clearInput() {
    this.params.INVOICE_DATE_FROM = null;
    this.params.INVOICE_DATE_TO = null;
    this.params.DOC_NO_FROM = null;
    this.params.DOC_NO_TO = null;
  }

  private getDocType() {
    this.Http.post('WH', 'SNSE044_W_getDocType', this.params)
      .subscribe(res => {
        this.params.DOC_TYPE = res.Table[0].DOCUMENT_TYPE;
      });
  }

  public OpenReport(type) {
    if (this.params.DOC_NO_FROM && this.params.DOC_NO_TO) {
      if (type == 1) { //REPORT
        this.global.GoToReport("PMS_RPT_SALES_SNSE044_W", {
          P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
          P_DOC_TYPE: this.params.DOC_TYPE,
          P_DOC_NO_S: this.params.DOC_NO_FROM,
          P_DOC_NO_E: this.params.DOC_NO_TO,
          P_DOC_DATE_S: this.global.ConvertDateToFormatSTD(this.params.INVOICE_DATE_FROM),
          P_DOC_DATE_E: this.global.ConvertDateToFormatSTD(this.params.INVOICE_DATE_TO),
          P_CUST_S: this.params.CUSTOMER_CODE_FROM,
          P_CUST_E: this.params.CUSTOMER_CODE_TO,
          P_SENT_BY: this.params.SENT_BY,
          P_TYPE: "REPRINT"
        })
      }
      else if (type == 2) { //PRINT CASE MASK
        this.global.GoToReport("PMS_RPT_SALES_SNSE044_W_SHIPPING_MARK", {
          P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
          P_DOC_TYPE: this.params.DOC_TYPE,
          P_DOC_NO_S: this.params.DOC_NO_FROM,
          P_DOC_NO_E: this.params.DOC_NO_TO,
          P_DOC_DATE_S: this.global.ConvertDateToFormatSTD(this.params.INVOICE_DATE_FROM),
          P_DOC_DATE_E: this.global.ConvertDateToFormatSTD(this.params.INVOICE_DATE_TO),
          P_CUST_S: this.params.CUSTOMER_CODE_FROM,
          P_CUST_E: this.params.CUSTOMER_CODE_TO,
          P_SHOW_ORIGIN: this.params.CHK_PRN_MITH
        })
      }
      else if (type == 3) { //ATTACHED CASE MASK
        this.global.GoToReport("PMS_RPT_SALES_SNSE044_W_SHIPPING_MARK_A", {
          P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
          P_DOC_TYPE: this.params.DOC_TYPE,
          P_DOC_NO_S: this.params.DOC_NO_FROM,
          P_DOC_NO_E: this.params.DOC_NO_TO,
          P_DOC_DATE_S: this.global.ConvertDateToFormatSTD(this.params.INVOICE_DATE_FROM),
          P_DOC_DATE_E: this.global.ConvertDateToFormatSTD(this.params.INVOICE_DATE_TO),
          P_CUST_S: this.params.CUSTOMER_CODE_FROM,
          P_CUST_E: this.params.CUSTOMER_CODE_TO,
          P_SENT_BY: this.params.SENT_BY
        })
      }
    } else {
      this.modal.error("Please input Customer Code and Invoice No.", this.viewref);
    }
  }

  public SentByChange() {
    this.getDocType();
    this.params.CUSTOMER_CODE_FROM = null;
    this.params.CUSTOMER_CODE_TO = null;
    this.clearInput();
  }

  public CheckOriginChange(value) {
    if (value.checked == true) {
      this.params.CHK_PRN_MITH = 'Y'
    }
    else {
      this.params.CHK_PRN_MITH = 'N'
    }
  }

  //public GenPaperless() {
  //  if (this.params.CUSTOMER_CODE_FROM && this.params.CUSTOMER_CODE_TO && this.params.DOC_NO_FROM && this.params.DOC_NO_TO && this.params.INVOICE_DATE_FROM && this.params.INVOICE_DATE_TO) {
  //    this.Http.post('WH', 'SNSE044_W_Paperless', this.params)
  //      .subscribe(res => {
  //        if (res.Table[0].STATUS == 'DONE') {
  //          this.modal.info('Done', this.viewref)
  //        }
  //      });
  //  } else {
  //    this.modal.warning('Please fill all data for Generate text file!!', this.viewref)
  //  }
  //}

  public GenDragon() {
    this.detailUrl = null;
    if (this.params.DOC_NO_FROM && this.params.DOC_NO_TO) {
      this.Http.post('WH', 'SNSE044_W_Dragon_Generate', this.params)
        .subscribe(async res => {
          if (res) {
            this.params.FILE_NAME = res.Detail.filename;
            this.detailUrl = "data:text/plain;charset=utf-8;base64," + res.Detail.file;
            function delay(ms: number) {
              return new Promise(resolve => setTimeout(resolve, ms));
            }
            await delay(2000);
            this.btnDRG.click();
          } else {
            this.modal.error('Download not complete', this.viewref)
          }
        });
    } else {
      this.modal.warning('Please fill all data for Generate text file!!', this.viewref)
    }
  }

  public OpendateFromPopup(datepicker: MatDatepicker<any>) {
    datepicker.open();
  }

  public OpendateToPopup(datepicker: MatDatepicker<any>) {
    datepicker.open();
  }

  public ExportExcel() {
    if (this.params.DOC_NO_FROM && !this.params.DOC_NO_TO) {
      this.params.DOC_NO_TO = this.params.DOC_NO_FROM
    }
    else if (this.params.DOC_NO_TO && !this.params.DOC_NO_FROM) {
      this.params.DOC_NO_FROM = this.params.DOC_NO_TO
    }
    if (this.params.DOC_NO_FROM && this.params.DOC_NO_TO) {
      this.Http.Download("WH", "SNSE044_W_getData", JSON.stringify(this.params))
        .subscribe(result => {
          if (result) {
            this.download(result)
          }
        }, (err) => {
          console.log(err, 'err')
        })
    }
    else {
      this.modal.warning('Please fill all data for Generate .CSV!!', this.viewref)
    }
  }

  private download(content) {
    const a = document.createElement('a');
    const file = new Blob([content], { type: content.type })
    a.href = URL.createObjectURL(file);
    if (this.params.DOC_NO_FROM == this.params.DOC_NO_TO) {
      a.download = "SNSE044_W_" + this.params.DOC_NO_FROM + ".csv"
    } else {
      a.download = "SNSE044_W_" + this.params.DOC_NO_FROM + "_TO_" + this.params.DOC_NO_TO + ".csv"
    }
    a.click()
  }

  public ExportReport() {
    let fileName;

    if (this.params.DOC_NO_FROM == this.params.DOC_NO_TO) {
      fileName = "SNSE044_W_Raw_" + this.params.DOC_NO_FROM
    } else {
      fileName = "SNSE044_W_Raw_" + this.params.DOC_NO_FROM + "_TO_" + this.params.DOC_NO_TO
    }

    this.global.GoToExportName("PMS_RPT_SALES_SNSE044_W_Raw", {
      P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      P_DOC_TYPE: this.params.DOC_TYPE,
      P_DOC_NO_S: this.params.DOC_NO_FROM,
      P_DOC_NO_E: this.params.DOC_NO_TO,
      P_DOC_DATE_S: this.global.ConvertDateToFormatSTD(this.params.INVOICE_DATE_FROM),
      P_DOC_DATE_E: this.global.ConvertDateToFormatSTD(this.params.INVOICE_DATE_TO),
      P_CUST_S: this.params.CUSTOMER_CODE_FROM,
      P_CUST_E: this.params.CUSTOMER_CODE_TO,
      P_SENT_BY: this.params.SENT_BY,
      P_TYPE: "REPRINT"
    }, fileName, "EXCELOPENXML"
    );

  }

  public DateChange(date) {
    if (!this.params.INVOICE_DATE_TO) {
      this.params.INVOICE_DATE_TO = date;
    }
  }

  public CheckParameter(){

    if(!this.params.CUSTOMER_CODE_FROM || !this.params.CUSTOMER_CODE_TO || !this.params.DOC_NO_FROM || !this.params.DOC_NO_TO)
      return false;

    return true;
  }

  public CheckParameterDocNo(){

    if(!this.params.DOC_NO_FROM || !this.params.DOC_NO_TO)
      return false;

    return true;
  }
}
