import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { DialogTemplateCallerComponent } from 'src/app/components/shared/dialog-template-caller/dialog-template-caller.component';
import { ModalService } from 'src/app/core/modal.service';

@Component({
    selector: 'snse064_m2',
    templateUrl: './SNSE064_M2.component.html',
    styleUrls: ['./SNSE064_M2.component.css']
})

export class SNSE064_M2Component implements OnInit {

    constructor(
        private http: HttpService,
        private router: Router,
        private modal : ModalService,
        private viewref : ViewContainerRef
    ) { }

    public ReturnRequestNo: string;
    public RequestDate: Date;
    public Customer: string;
    private CustomerCode: string;
    public CustomerName: string;
    public Branch: string;
    private BranchCode: string;
    public BranchName: string;
    public UpdateBy: string;
    public UpdateDate: Date;
    public TableData: Array<any> = [];
    public HeaderDetail: any = {};
    public TableDetail: Array<any> = [];
    public paramSearch : any = {}

    @ViewChild("dialogDetail") private dialogDetail: DialogTemplateCallerComponent

    public requestLookupConfig: any = {
        ColName: "REF_RO_NO",
        PlaceholderText: "Select Return Request No.",
        SourceController: "WH",
        SourceMethodName: "SNSE064_M2_REF_RO_NO",
        NoOfShowRecords: 50,
        MinLengthSearch: 0,
        UpperCase: true
    };
    public customerLookupConfig: any = {
        ColName: "CODE_NAME",
        PlaceholderText: "Select Customer",
        SourceController: "wPMS",
        SourceMethodName: "GetCustomerCode",
        NoOfShowRecords: 50,
        MinLengthSearch: 0,
        UpperCase: true
    };
    public branchLookupConfig: any = {
        ColName: "LOOKUP_BRANCH_NAME",
        PlaceholderText: "Select Customer",
        SourceController: "wPMS",
        SourceMethodName: "GetCustomerBranch",
        NoOfShowRecords: 50,
        MinLengthSearch: 0,
        SourceParams: {
            CUSTOMER_CODE: null
        },
        UpperCase: true
    };

    public tblFooter: any = [
        {
            fieldName: "LOCATION_NO",
            value: "Total Qty.",
            show: true
        },
        {
            fieldName: "RETURN_PART_QTY",
            show: true
        }
    ]

    ngOnInit() {
        this.paramSearch.REQUEST_DATE_SEARCH = new Date();
     }

    GetData() {

        if(this.paramSearch.REQUEST_DATE_SEARCH){
            this.paramSearch.REQUEST_DATE = this.FormatDate(this.paramSearch.REQUEST_DATE_SEARCH)
          }else{
            this.paramSearch.REQUEST_DATE = null
          }

          
        this.TableData = [];
        this.http.post("WH", "SNSE064_M2_Search",this.paramSearch)
            .subscribe(result => {
                this.TableData = result.Table;
            }, (err) => {
                this.modal.warning("Found an error, please contact support team", this.viewref);
            })
    }

    GetDetail(data) {
        this.HeaderDetail = {};
        this.TableDetail = []
        this.http.get("WH", "SNSE064_M2_GetDetail", data.REF_RO_NO)
            .subscribe(result => {
                this.HeaderDetail = result.Table.length > 0 && result.Table[0]
                this.TableDetail = result.Table1
            }, (err) => {
                console.log(err);
            })
        this.dialogDetail.title = data.REF_RO_NO;
        this.dialogDetail.width = "90vw";
        this.dialogDetail.OpenDialog();
    }

    SetRequestLookup(value) {
        //this.ReturnRequestNo = value.REF_RO_NO;
        this.paramSearch.REF_RO_NO = value.REF_RO_NO
    }

    SetCustomerLookup(value) {
        //this.Customer = value.CODE_NAME;
        ///this.CustomerCode = value.CUSTOMER_CODE
        //this.branchLookupConfig.SourceParams.CUSTOMER_CODE = this.CustomerCode;
        this.paramSearch.CUSTOMER_CODE = value.CUSTOMER_CODE
    }

    SetBranchLookup(value) {
        this.Branch = value.LOOKUP_BRANCH_NAME;
        this.BranchCode = value.BRANCH_CODE;
    }

    FormatDate(date) {

        let d = new Date(date);
        let Day = d.getDate().toString();
        let NewDay = Day.toString().length < 2 ? '0' + Day.toString() : Day.toString()
        let Month = d.getMonth() + 1;
        let NewMonth = Month.toString().length < 2 ? '0' + Month.toString() : Month.toString()
        let Year = d.getFullYear().toString();
        return Year + NewMonth + NewDay;
    }

}

