import { Component, OnInit, ViewContainerRef, ViewChild } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from '../../../core/global';

@Component({
    selector: 'snse184',
    templateUrl: './snse184.component.html',
    styleUrls: ['./snse184.component.css']
})

export class SNSE184Component implements OnInit {
    constructor(
      private http: HttpService,
      private router: Router,
      private modal: ModalService,
      private viewref: ViewContainerRef,
      private global: Globals
    ) { }

  @ViewChild("dialogViewLog", { static: false }) dialogViewLog: any;
    public data: any = [];
    public data_log: any = [];
    public tabIndex : number = 0;
    public opened1: boolean;
    public opened2: boolean;
    public PROCESS_LOG: any = [];

    public ConfigPart: any = {
        ColName: "LOOKUP_PART_NAME",
        ColValue: "PART_NO",
        PlaceholderText: "Select Part No.",
        SourceController: "wPMS",
        SourceMethodName: "GetPartNo",
        NoOfShowRecords: 50,
        MinLengthSearch: 5
      }

      public ConfigLocation: any = {
        ColName: "LOCATION_NO",
        ColValue: "LOCATION_NO",
        PlaceholderText: "Select Location.",
        SourceController: "WH",
        SourceMethodName: "GetLocation",
        NoOfShowRecords: 50,
        MinLengthSearch: 2,
        UpperCase: true
      }


      public ConfigNewLocation: any = {
        ColName: "NEW_LOCATION",
        ColValue: "NEW_LOCATION",
        PlaceholderText: "Select NewLocation.",
        SourceController: "WH",
        SourceMethodName: "GetNewLocation",
        NoOfShowRecords: 50,
        MinLengthSearch: 2,
        UpperCase: true
      }

      
      public ConfigPrintDate: any = {
        ColName: "PRINT_CODE",
        ColValue: "PRINT_CODE",
        PlaceholderText: "Select PrintDate.",
        SourceController: "WH",
        SourceMethodName: "GetPrintCode",
        NoOfShowRecords: 50,
        MinLengthSearch: 2,
        UpperCase: true
      }

    public params = {
        CURRENT_LOCATION_FROM : null,
        CURRENT_LOCATION_TO : null,
        PART_FROM : null,
        PART_TO : null,
        NEW_LOCATION_FROM : null,
        NEW_LOCATION_TO : null,
        PRINT_DATE_FROM : null,
        PRINT_DATE_TO : null,
        STATUS_NO : 'ALL',
        UPDATE_FLAG : 'ALL'
    }

    public StatusList = [
                         {NAME : 'ALL',ID : 'ALL'},
                         {NAME : '1 = Print Relocation Card',ID : '1'},
                         {NAME : '2 = Pick/Pack',ID : '2'},
                         {NAME : '3 = Shelve',ID : '3'},
                         {NAME : '4 = Relocation Complete',ID : '4'}
                        ]

    public UpdFlagList = [
                        {NAME : 'ALL',ID : 'ALL'},
                        {NAME : 'Y = Updated New Location',ID : 'Y'},
                        {NAME : 'N = Not Update New Location',ID : 'N'}
                        ]

    ngOnInit() {


    }


  public GetData(){
        this.data = []

        this.http.post("WH","SNSE184_GetData",this.params)
        .subscribe(res =>{
            console.log(res)
            this.data = res.Table
        })
    }


  public GetDataLog(param){
        this.http.post("WH","SNSE184_GetDataLog",param)
        .subscribe(res => {
            this.data_log = res.Table;
        })
    }

  //public Export() {
  //  console.log(this.data, 'this.data');
  //  this.http.Download("WH", "SNSE184_Export", JSON.stringify(this.data))
  //    .subscribe(res => {
  //      if (res) {
  //        this.writeContents(res)
  //        this.PROCESS_LOG.push('Export complete ' + this.data.length + ' records.');
  //      } else {
  //        this.modal.error('Download not complete', this.viewref)
  //      }
  //    })
  //}


  public Export() {
    this.global.GoToReport("PMS_RPT_WH_SNSE184",
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_CURRENT_LOCATION_FROM: this.params.CURRENT_LOCATION_FROM,
        P_CURRENT_LOCATION_TO: this.params.CURRENT_LOCATION_TO,
        P_PART_FROM: this.params.PART_FROM,
        P_PART_TO: this.params.PART_TO,
        P_NEW_LOCATION_FROM: this.params.NEW_LOCATION_FROM,
        P_NEW_LOCATION_TO: this.params.NEW_LOCATION_TO,
        P_PRINT_DATE_FROM: this.global.ConvertDateToFormatSTD(this.params.PRINT_DATE_FROM),
        P_PRINT_DATE_TO: this.global.ConvertDateToFormatSTD(this.params.PRINT_DATE_TO),
        P_STATUS_NO: this.params.STATUS_NO,
        P_UPDATE_FLAG: this.params.UPDATE_FLAG

      } 
    );
  }

  public  writeContents(content) {
      const a = document.createElement('a');
      const file = new Blob([content], { type: content.type });
      var date_export = new Date();
      a.href = URL.createObjectURL(file);
      a.download = "SNSE184" + "_" + date_export.getFullYear() + "/" + (date_export.getMonth() + 1) + "/" + date_export.getDate() + ".csv";
      a.click();
  }

  public SelectRow(data) {
    this.GetDataLog(data);
    console.log(data,'data')
    this.dialogViewLog.OpenDialog();
    
    }

    tabChanged(event){
        this.tabIndex = event.index
    }

  public  ClearData(){
         
            this.params.CURRENT_LOCATION_FROM = null
            this.params.CURRENT_LOCATION_TO = null
            this.params.PART_FROM= null
            this.params.PART_TO = null
            this.params.NEW_LOCATION_FROM= null
            this.params.NEW_LOCATION_TO = null
            this.params.PRINT_DATE_FROM = null
            this.params.PRINT_DATE_TO = null
            this.params.STATUS_NO = 'ALL'
            this.params.UPDATE_FLAG = 'ALL'
            this.data = [];
    }
}
