
import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewChildren, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router, ActivatedRoute } from '@angular/router';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from '../../../core/global';


@Component({
  selector: 'snsr040',
  templateUrl: './SNSR040.component.html',
  styleUrls: ['./SNSR040.component.css']
})



export class SNSR040Component implements OnInit {


  constructor(
    private HttpService: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private router: Router,
    private global: Globals

  ) { }

  @ViewChildren("input") Inputs: any;

  public fileUrl;
  public ListDataReportCondition: any = {
    CUSTOMER_CODE: null,//Step 1
    CUSTOMER_BRANCH: null,
    BRANCH_CODE: null,
    BRANCH_NAME: null,
    CASHEER_NO: null,//Step 2
    C_TOTAL_PAGE: null,//Step 3

    CUSTOMER_NAME: null,
    CUSTOMER_AMPHUR: null,
    DOCUMENT_NO: null,//Step 4
    CUSTOMER_PROVINCE: null
  };

  public dataListDialogInvoiceDate: any = [];
  public findingWord: string;

  public dataListDocNo: any = [];

  public ConfigCustomer: any = {
    ColName: "LOOKUP_CUSTOMER",
    ColValue: "CUSTOMER_BRANCH",
    PlaceholderText: "Select Customer Code",
    SourceController: "WH",
    SourceMethodName: "SNSR040_FindCustomer40",
    NoOfShowRecords: 100,
    MinLengthSearch: 1,
    UpperCase: true
  }

  public CustomerList: any = [];

  ngOnInit() {
    this.ListDataReportCondition.CASHEER_NO = 'C.1';
    this.ListDataReportCondition.C_TOTAL_PAGE = 1;

    console.log("Show IPAddress:", this.global.GetTokenDetail("ssIPAddress"));
  }

  FindCustInfo() {
    this.fillCustInfo(this.ListDataReportCondition.CUSTOMER_BRANCH);
  }

  public fillCustInfo(strCustomerBranch: any) {
    if (!!strCustomerBranch) {
      this.HttpService.get("WH", "SNSR040_Customer_Info", strCustomerBranch || "null")
        .subscribe(result => {


          if (result.Table.length > 0) {
            this.ListDataReportCondition.CUSTOMER_CODE = result.Table[0].CUSTOMER_CODE;
            this.ListDataReportCondition.CUSTOMER_NAME = result.Table[0].CUSTOMER_NAME;
            this.ListDataReportCondition.CUSTOMER_AMPHUR = result.Table[0].AMPHUR;
            this.ListDataReportCondition.CUSTOMER_PROVINCE = result.Table[0].PROVINCE;

            this.ListDataReportCondition.BRANCH_CODE = result.Table[0].BRANCH_CODE;
            this.ListDataReportCondition.BRANCH_NAME = result.Table[0].BRANCH_NAME;
            //console.log("ListData CustInfo: ",this.ListDataReportCondition);

            this.fillListDocNo(strCustomerBranch);
          }

        }, err => {
          this.modal.error(err.message, this.viewref);
        });

    } else {
      //alert('Please input customer code and branch code');
      this.modal.warning('Please input customer code and branch code', this.viewref);
    }
  }

  public fillListDocNo(strCustomerBranch: any) {
    if (!!strCustomerBranch) {
      //console.log("Data strCustBrach", strCustomerBranch);
      this.HttpService.get("WH", "SNSR040_DocumentByCustomer", strCustomerBranch || "null")
        .subscribe(result => {
          //console.log("list data DocNo: ",result);
          if (result.Table.length > 0) {
            this.dataListDocNo = result.Table;
            console.log(this.dataListDocNo, 'dddd');
          }
        }, err => {
          this.modal.error(err.message, this.viewref);
        });
    } else {
      alert('Please input customer code and branch code');
    }
  }

  DocNoSelectChange(value: any) {

  }

  CheckSearchCondition(): boolean {
    let boolHadSelectedCondition: boolean;
    boolHadSelectedCondition = false;//maening: User is not selecting condition search report.
    //check null and undefined
    if (this.ListDataReportCondition.CUSTOMER_CODE == null || this.ListDataReportCondition.CASHEER_NO == null || this.ListDataReportCondition.DOCUMENT_NO == null || this.ListDataReportCondition.C_TOTAL_PAGE <= 0) {
      boolHadSelectedCondition = false;
      this.modal.warning("Please fill all data for print report!!", this.viewref);
    } else {
      boolHadSelectedCondition = true;
    }
    return boolHadSelectedCondition;
  }//end CheckSearchCondition

  SaveStickerBeforePrint() {
    if (!!this.ListDataReportCondition.CUSTOMER_CODE) {
      console.log("Data save sticker:", this.ListDataReportCondition);
      this.HttpService.post("WH", "SNSR040_SaveStickerBeforePrint", JSON.stringify(this.ListDataReportCondition))
        .subscribe(result => {
          console.log("result of save sticker: ", result);
          this.GoToReport();//show roport viewer.                          
        }, err => {
          this.modal.error(err.message, this.viewref);
        });
    }
  }

  public OpenReport() {
    if (this.CheckSearchCondition()) {
      //save sticker into temp table for report viewer read it.
      this.SaveStickerBeforePrint();
    }
  }

  public GoToReport() {
    if (this.ListDataReportCondition.CUSTOMER_NAME && this.ListDataReportCondition.DOCUMENT_NO && this.ListDataReportCondition.CASHEER_NO) {
      //this.global.GoToReport("PMS_RPT_WH_SNSR040_PIK", {
      //  P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      //  P_IP: this.global.GetTokenDetail("ssIPAddress"),
      //  P_CUSTOMER_CODE: this.ListDataReportCondition.CUSTOMER_CODE,
      //  P_BRANCH_CODE: this.ListDataReportCondition.BRANCH_CODE,
      //  P_CASHEER_NO: this.ListDataReportCondition.CASHEER_NO,
      //  P_DOCUMENT_NO: this.ListDataReportCondition.DOCUMENT_NO
      //})
      this.GetReport();
    }
    else {
      this.modal.warning("Please fill all data for print report!!", this.viewref);
    }
  }


  private GetReport() {
    this.fileUrl = null;
    this.HttpService
      .Download("WH", "PrintLabelUpCountry", {
        ReportPrefix: "PMS_WH_UPC_",
        ReportSuffix: ".PDF",
        COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        IP: this.global.GetTokenDetail("ssIPAddress"),
        CUSTOMER_CODE: this.ListDataReportCondition.CUSTOMER_CODE,
        BRANCH_CODE: this.ListDataReportCondition.BRANCH_CODE,
        CASHEER_NO: this.ListDataReportCondition.CASHEER_NO,
        DOCUMENT_NO: this.ListDataReportCondition.DOCUMENT_NO,
      })
      .subscribe((res) => {
        if (res) {
          this.SetIFrameContent(res);
          // this.showPrintButton = true;
        }
      });
  }

  private SetIFrameContent(content: any) {
    const file = new Blob([content], { type: content.type });
    const fileUrl = URL.createObjectURL(file);

    this.fileUrl = fileUrl;
  }

  focusInput(rowIdx: number) {
    let inputEls = this.Inputs.toArray();
    inputEls[rowIdx].nativeElement.focus();

  }

  shiftFocusDown(rowIdx: number) {
    rowIdx = Math.min(rowIdx + 1, 3);
    let inputEls = this.Inputs.toArray();
    if (inputEls[rowIdx].nativeElement.disabled == true) {
      this.shiftFocusDown(rowIdx)
    } else {
      this.focusInput(rowIdx);
    }

  }

  shiftFocusUp(rowIdx: number) {
    rowIdx = Math.max(0, rowIdx - 1);
    let inputEls = this.Inputs.toArray();
    if (inputEls[rowIdx].nativeElement.disabled == true) {
      this.shiftFocusUp(rowIdx)
    } else {
      this.focusInput(rowIdx);
    }

  }
}
