
import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewContainerRef, ViewChildren } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router, ActivatedRoute } from '@angular/router';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from '../../../core/global';


@Component({
  selector: 'snsr041',
  templateUrl: './SNSR041.component.html',
  styleUrls: ['../warehouse.component.css']
})



export class SNSR041Component implements OnInit {


  constructor(
    private HttpService: HttpService,
    private modal: ModalService,
    private viewRef: ViewContainerRef,
    private router: Router,
    private global: Globals

  ) { }

  @ViewChildren("input") Inputs: any;

  public fileUrl;

  public ListDataReportCondition: any = {
    CUSTOMER_CODE: null,//Step 1
    CUSTOMER_BRANCH: null,
    BRANCH_CODE: null,
    BRANCH_NAME: null,
    CASHEER_NO: null,//Step 2
    C_TOTAL_PAGE: null,//Step 3

    CUSTOMER_NAME: null,
    CUSTOMER_AMPHUR: null,
    DOCUMENT_NO: null,//Step 4
    CUSTOMER_PROVINCE: null
  };

  public dataListDialogInvoiceDate: any = [];
  public findingWord: string;

  public dataListDocNo: any = [];

  public ConfigCustomer: any = {
    ColName: "LOOKUP_CUSTOMER",
    ColValue: "CUSTOMER_BRANCH",
    PlaceholderText: "Select Customer Code",
    SourceController: "WH",
    SourceMethodName: "SNSR041_FindCustomer",
    NoOfShowRecords: 100,
    MinLengthSearch: 1,
    UpperCase: true
  }

  public CustomerList: any = [];

  ngOnInit() {
    this.ListDataReportCondition.CASHEER_NO = 'C.1';
    this.ListDataReportCondition.C_TOTAL_PAGE = 1;

    console.log("Show IPAddress:", this.global.GetTokenDetail("ssIPAddress"));
  }



  public fillCustInfo(strCustomerBranch: any) {

    if (!!strCustomerBranch) {
      this.HttpService.get("WH", "SNSR041_Customer_Info", strCustomerBranch || "null")
        .subscribe(result => {

         
          if (result.Table.length > 0) {
            this.ListDataReportCondition.CUSTOMER_CODE = result.Table[0].CUSTOMER_CODE;
            this.ListDataReportCondition.CUSTOMER_NAME = result.Table[0].CUSTOMER_NAME;
            this.ListDataReportCondition.CUSTOMER_PROVINCE = result.Table[0].PROVINCE;
            this.ListDataReportCondition.BRANCH_CODE = result.Table[0].BRANCH_CODE;
            this.ListDataReportCondition.BRANCH_NAME = result.Table[0].BRANCH_NAME;

            this.fillListDocNo(strCustomerBranch);
          }

        }, err => {
          this.modal.error(err.message, this.viewRef);
        });

    } else {
      //alert('Please input customer code and branch code');
      this.modal.warning('Please input customer code and branch code', this.viewRef);
    }
  }

  public fillListDocNo(strCustomerBranch: any) {

  }

  DocNoSelectChange(value: any) {

  }

  CheckSearchCondition(): boolean {
    let boolHadSelectedCondition: boolean;
    boolHadSelectedCondition = false;//maening: User is not selecting condition search report.
    //check null and undefined
    if (this.ListDataReportCondition.CUSTOMER_CODE == null || this.ListDataReportCondition.CASHEER_NO == null || this.ListDataReportCondition.DOCUMENT_NO == null || this.ListDataReportCondition.C_TOTAL_PAGE <= 0) {
      boolHadSelectedCondition = false;
      this.modal.warning("Please fill all data for print report!!", this.viewRef);
    } else {
      boolHadSelectedCondition = true;
    }

    return boolHadSelectedCondition;
  }//end CheckSearchCondition



  OpenReport() {
    if (this.CheckSearchCondition()) {
 
      this.GoToReport();//show roport viewer.
    }
  }

  public GoToReport() {

 
    if (this.ListDataReportCondition.CUSTOMER_CODE && this.ListDataReportCondition.DOCUMENT_NO) {
      //this.global.GoToReport("PMS_RPT_WH_SNSR041_OUM", {
      //  P_CUSTOMER_CODE: this.ListDataReportCondition.CUSTOMER_CODE,
      //  P_CASHEER_NO: this.ListDataReportCondition.CASHEER_NO,
      //  P_DOCUMENT_NO: this.ListDataReportCondition.DOCUMENT_NO,
      //  P_TOTAL_PAGE: this.ListDataReportCondition.C_TOTAL_PAGE

      //})

      this.GetReport();
    }
    else {
      this.modal.warning("Please fill all data for print report!!", this.viewRef);
    }
  }

  private GetReport() {
    this.fileUrl = null;
    this.HttpService
      .Download("WH", "PrintLabelBKK", {
        ReportPrefix: "PMS_WH_BKK_",
        ReportSuffix: ".PDF",
        CUSTOMER_CODE: this.ListDataReportCondition.CUSTOMER_CODE,
        CASHEER_NO: this.ListDataReportCondition.CASHEER_NO,
        DOCUMENT_NO: this.ListDataReportCondition.DOCUMENT_NO,
        TOTAL_PAGE: this.ListDataReportCondition.C_TOTAL_PAGE,
      })
      .subscribe((res) => {
        if (res) {
          this.SetIFrameContent(res);
         // this.showPrintButton = true;
        }
      });
  }

  private SetIFrameContent(content: any) {
    const file = new Blob([content], { type: content.type });
    const fileUrl = URL.createObjectURL(file);

    this.fileUrl = fileUrl;
  }

  focusInput(rowIdx: number) {
    let inputEls = this.Inputs.toArray();
    inputEls[rowIdx].nativeElement.focus();

  }

  shiftFocusDown(rowIdx: number) {
    rowIdx = Math.min(rowIdx + 1, 3);
    let inputEls = this.Inputs.toArray();
    if (inputEls[rowIdx].nativeElement.disabled == true) {
      this.shiftFocusDown(rowIdx)
    } else {
      this.focusInput(rowIdx);
    }

  }

  shiftFocusUp(rowIdx: number) {
    rowIdx = Math.max(0, rowIdx - 1);
    let inputEls = this.Inputs.toArray();
    if (inputEls[rowIdx].nativeElement.disabled == true) {
      this.shiftFocusUp(rowIdx)
    } else {
      this.focusInput(rowIdx);
    }

  }


}
