import {
  Component,
  EventEmitter,
  OnInit,
  Output,
  ViewChild,
  ViewContainerRef,
} from "@angular/core";
import { DialogTemplateComponent } from "src/app/components/shared/dialog-template/dialog-template.component";
import { Globals } from "src/app/core/global";
import { HttpService } from "src/app/core/http.service";
import { ModalService } from "src/app/core/modal.service";

@Component({
  selector: "snwr005-list",
  templateUrl: "snwr005-list.component.html",
  styleUrls: ["../SNWR005.component.css"],
})
export class SNWR005ListComponent implements OnInit {
  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewRef: ViewContainerRef,
    private global: Globals
  ) {}

  public filter: any = {};
  public orderType: string = "EO";
  public pickingList: any[] = [];
  public pickingListFrom: string;
  public pickingListTo: string;
  public instructionNo: string;
  public configFlag : string = "";
  @Output() onAddPickingList: EventEmitter<any> = new EventEmitter();

  @ViewChild("printDialog") printDialog: DialogTemplateComponent;

  ngOnInit() {
    this.orderType = "EO";
    this.filter.zone = "BKK";
    this.GetConfigFlag();
  }

  private GetConfigFlag(){
    this.http.get("wPMS","GetConfigFlag","SNWR005_PICKING_LIST")
    .subscribe(res =>{
      this.configFlag = res.Table[0].CONFIG_VALUE
    })
  }

  public Search() {
    this.pickingList = [];
    this.http.post("WH", "SNWR005_GetPickingList", this.filter).subscribe(
      (res) => {
        this.pickingList = res.Table;
      },
      (err) => {
        this.modal.error(
          "Found an error, please contact support team",
          this.viewRef
        );
      }
    );
  }

  public PrintPickingList() {
    this.printDialog.OpenDialog();
  }

  public Generate() {
    if (this.orderType != 'KIT'){
    this.modal.confirm(
      "Are you sure to generate picking list.",
      this.viewRef,
      () => {
        this.http
          .post("WH", "SNWR005_GeneratePicking", { orderType: this.orderType, zone: this.filter.zone, class4: this.filter.class4 })
          .subscribe(
            (res) => {
              if (res.result === "DONE") {
                if (
                  res.pickingListFrom !== "null" &&
                  res.pickingListTo !== "null"
                ) {
                  this.pickingListFrom = res.pickingListFrom;
                  this.pickingListTo = res.pickingListTo;
                  this.modal.info(
                    `Generate picking list successfully.<br/><br/>Picking list no.<br/>${this.pickingListFrom} - ${this.pickingListTo}`,
                    this.viewRef,
                    () => {
                      setTimeout(() => this.PrintPickingList(), 500);
                    },
                    {
                      height: "20rem",
                    }
                  );
                } else {
                  this.modal.info(`No Picking list generated.`, this.viewRef);
                }
              }
            },
            (err) => {
              this.modal.error(
                "Found an error, please contact support team",
                this.viewRef
              );
            }
          );
      },
      () => {}
    );
    }else{
      this.modal.confirm(
        "Are you sure to generate picking list.",
        this.viewRef,
        () => {
          this.http
            .post("WH", "SNWR005_GeneratePicking_Kit", { orderType: this.orderType, zone: this.filter.zone, class4: this.filter.class4 })
            .subscribe(
              (res) => {
                if (res.result === "DONE") {
                  if (
                    res.pickingListFrom !== "null" &&
                    res.pickingListTo !== "null"
                  ) {
                    this.pickingListFrom = res.pickingListFrom;
                    this.pickingListTo = res.pickingListTo;
                    this.modal.info(
                      `Generate picking list successfully.<br/><br/>Picking list no.<br/>${this.pickingListFrom} - ${this.pickingListTo}`,
                      this.viewRef,
                      () => {
                        setTimeout(() => this.PrintPickingList(), 500);
                      },
                      {
                        height: "20rem",
                      }
                    );
                  } else {
                    this.modal.info(`No Picking list generated.`, this.viewRef);
                  }
                }
              },
              (err) => {
                this.modal.error(
                  "Found an error, please contact support team",
                  this.viewRef
                );
              }
            );
        },
        () => {}
      );
    }
  }

  public Add() {
    this.onAddPickingList.emit();
  }

  public Print() {

    if(this.configFlag != "ON"){
      if (this.filter.showQR) {

        this.global.GoToReport("PMS_RPT_WMS_SNWR005_PICKING_WithQR", {
          P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
          P_PICKING_LIST_FROM: this.pickingListFrom,
          P_PICKING_LIST_TO: this.pickingListTo,
          P_INSTRUCTION_NO: this.instructionNo || "",
        });
        //alert('Samart01');
      } else {

        this.global.GoToReport("PMS_RPT_WMS_SNWR005_PICKING", {
          P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
          P_PICKING_LIST_FROM: this.pickingListFrom,
          P_PICKING_LIST_TO: this.pickingListTo,
          P_INSTRUCTION_NO: this.instructionNo || "",
        });
        //alert('Samart02');
      }
      // if(this.orderType == 'KIT'){
      //   this.global.GoToReport(
      //     "PMS_RPT_WMS_SNWR005_PICKING_KIT_LIST", 
      //     {
      //       P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      //       P_PICKING_LIST_FROM: this.pickingListFrom,
      //       P_PICKING_LIST_TO: this.pickingListTo,
      //       P_INSTRUCTION_NO: this.instructionNo || "",
      //     },
      //     true,
      //     false
      //   );
      // }
    }
    else{
      this.Download()
    }
    
    //Set timer close the dialog when clicked print picking card | Requestor : P'AMM | Fixed By : Siwakorn Y.
    setTimeout(() => {
      this.printDialog.Close();
    }, 5000);
  
  }

  public PrintSingle(row: any) {

    if (this.filter.showQR) {
      this.global.GoToReport("PMS_RPT_WMS_SNWR005_PICKING_WithQR", {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_PICKING_LIST_FROM: row.PICKING_LIST_NO,
        P_PICKING_LIST_TO: row.PICKING_LIST_NO,
        P_INSTRUCTION_NO: "",
      });
      //alert('Samart');
    } else {
      this.global.GoToReport("PMS_RPT_WMS_SNWR005_PICKING", {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_PICKING_LIST_FROM: row.PICKING_LIST_NO,
        P_PICKING_LIST_TO: row.PICKING_LIST_NO,
        P_INSTRUCTION_NO: "",
      });
      //alert('Samart2');
    }
   
  }



  Download() {

    let data = {
      PICKING_LIST_FROM : this.pickingListFrom,
      PICKING_LIST_TO : this.pickingListTo,
      INSTRUCTION_NO : this.instructionNo,
      SHOWQR : this.filter.showQR ? "Y" : "N"
    }

    this.http.Download('WH', 'SNWR005_GeneratePickingListPDF',data)
      .subscribe(res => {
        if (res) {
          this.WriteContents(res)
        } else {
          this.modal.error('Cannot print picking list', this.viewRef)
        }
      },err => {
        this.modal.error('Cannot print picking list', this.viewRef)
      })
    if(this.orderType == 'KIT'){
      this.http.Download('WH', 'SNWR005_GeneratePickingListPDF_KIT',data)
      .subscribe(res => {
        if (res) {
          this.WriteContents(res)
        } else {
          this.modal.error('Cannot print picking list', this.viewRef)
        }
      },err => {
        this.modal.error('Cannot print picking list', this.viewRef)
      })
    }
  }

  WriteContents(content) {
    const a = document.createElement('a');
    const file = new Blob([content], { type: content.type });
    a.href = URL.createObjectURL(file);
    a.download = this.pickingListFrom + "_" + this.pickingListTo + "_" + this.global.CurrentDate() + (this.orderType == 'KIT'? "_KIT" : "");
    a.click();
  }
}
