import { SelectionModel } from "@angular/cdk/collections";
import { Component, OnInit, ViewChild, ViewContainerRef } from "@angular/core";
import { DialogTemplateComponent } from "src/app/components/shared/dialog-template/dialog-template.component";
import { Globals } from "src/app/core/global";
import { HttpService } from "src/app/core/http.service";
import { ModalService } from "src/app/core/modal.service";

@Component({
  selector: "snwr007_A",
  templateUrl: "SNWR007_A.component.html",
})
export class SNWR007AComponent implements OnInit {
  constructor(
    private http: HttpService,
    private global: Globals,
    private modal: ModalService,
    private viewRef: ViewContainerRef
  ) {}

  public params: any;
  public approveList: any[];
  public submitDetail: any[];
  public submitHeader: any = {};
  // public suspendList: any[];
  public selectedList = new SelectionModel<any>(true, []);
  // public readySuspendList = new SelectionModel<any>(true, []);
  public reasonCode: string;
  public remarks: string;
  public _reasonCode: string;
  public _reasonDescription: string;
  @ViewChild("suspendDialog") suspendDialog: DialogTemplateComponent;

  public ConfigReasonCode: any = {
    ColName: "LOOKUP_REASON",
    ColValue: "",
    PlaceholderText: "Select Reason Code",
    SourceController: "wPMS",
    SourceMethodName: "GetReasonCodeByJobType",
    NoOfShowRecords: 100,
    MinLengthSearch: 0,
    SourceParams: { JOB_TYPE: 5 },
    UpperCase: true,
  };

  ngOnInit() {
    this.Initialize();
  }

  public Initialize() {
    this.params = {};
    this.approveList = [];
    this.submitHeader = {};
    this.submitDetail = [];
    this.selectedList.clear();
    this.reasonCode = undefined;
    this.remarks = undefined;
    this._reasonCode = undefined;
    this._reasonDescription = undefined;
  }

  public Search() {
    this.selectedList.clear();
    this.http.get("WH", "SNWR007_GetApproveList").subscribe(
      (result) => {
        this.approveList = result.Table;
        // this.suspendList = result.Table1;
      },
      (err) => {
        this.modal.error(
          "Found error, please contact support team",
          this.viewRef
        );
      }
    );
  }

  public GetSubmitDetail(event: any) {
    this.submitDetail = [];
    this.submitHeader = event;
    this.reasonCode = undefined;
    this.remarks = undefined;
    this._reasonCode = undefined;
    this._reasonDescription = undefined;

    this.http.get("WH", "SNWR007_GetSubmitDetail", event.REF_DOC_NO).subscribe(
      (result) => {
            
        this.reasonCode = event.REASON_CODE;
        this.remarks = event.REMARKS;
        this._reasonCode = event.REASON_CODE;
        this._reasonDescription = event.REASON_NAME;

        this.submitDetail = result.Table;
        this.suspendDialog.OpenDialog();
      },
      (err) => {
        this.modal.error(
          "Found error, please contact support team",
          this.viewRef
        );
      }
    );
    
  }

  public ProcessSuspend() {
    this.modal.confirm(
      "Are you sure to process suspend?",
      this.viewRef,
      () => {
        this.http
          .post("WH", ["SNWR007_ProcessSuspend", this.submitHeader.REF_DOC_NO], {})
          .subscribe(
            (result) => {
              if (result === "Done") {
                this.modal.info("Successfully Process Suspend.", this.viewRef);
                this.suspendDialog.Close();
                this.Search();
              }
            },
            (err) => {
              this.modal.error(
                "Found error, please contact support team",
                this.viewRef
              );
            }
          );
      },
      () => {}
    );
  }

  public OpenSuspendDialog() {
    this.reasonCode = undefined;
    this.remarks = undefined;
    this._reasonCode = undefined;
    this._reasonDescription = undefined;
    this.suspendDialog.OpenDialog();
  }

  public ValidateSuspendQty(evt: any, data: any) {
    if (evt.target.value < 1 || evt.target.value > data.ACCEPT_QTY) {
      data.QTY = data.ACCEPT_QTY;
      evt.target.value = data.ACCEPT_QTY;
    }
  }

  SetReasonCode(event) {
    this.reasonCode = event.REASON_CODE;
    this._reasonCode = event.REASON_CODE;
    this._reasonDescription = event.REASON_NAME_EN;
  }
}
