import { SelectionModel } from "@angular/cdk/collections";
import { Component, OnInit, ViewChild, ViewContainerRef } from "@angular/core";
import { DialogTemplateComponent } from "src/app/components/shared/dialog-template/dialog-template.component";
import { Globals } from "src/app/core/global";
import { HttpService } from "src/app/core/http.service";
import { ModalService } from "src/app/core/modal.service";

@Component({
  selector: "snwr010_bkk_tmp",
  templateUrl: "SNWR010_BKK_TMP.component.html",
  styleUrls: ["SNWR010.component.css"],
})
export class SNWR010_BKK_TMPComponent implements OnInit {
  constructor(
    private global: Globals,
    private http: HttpService,
    private modal: ModalService,
    private viewRef: ViewContainerRef
  ) {}

  ngOnInit() {
    this.GetBKKDeliveryList();
    this.GetDeliveryRoute();
  }

  public sentList: SelectionModel<any> = new SelectionModel<any>(true, []);
  public unsentList: SelectionModel<any> = new SelectionModel<any>(true, []);
  public deliveryList: any[] = [];
  public unDeliveryList: any[] = [];
  public createRouteList: any[] = [];
  public _tempRouteNo: number[] = [11, 12, 13, 14, 15, 16, 17, 18, 19, 20];
  public selectedRouteNo: number;
  public carNo: string;
  public carType: string;
  public licenseNo: string;
  public driverName: string;
  public driverTel: string;
  public carList: any[] = [];

  @ViewChild("creatLineDialog", { read: DialogTemplateComponent })
  public creatLineDialog: DialogTemplateComponent;

  public GetBKKDeliveryList() {
    this.deliveryList = [];
    this.sentList.clear();
    this.unsentList.clear();
    this.http.get("WH", "SNWR010_GetTempDeliveryList").subscribe(
      (res) => {
        this.deliveryList = res.Table.filter((item) =>
          this._tempRouteNo.includes(item.DELIVERY_ROUTE)
        );
        this.unDeliveryList = res.Table1;
      },
      (err) => {
        console.log(err);
        this.modal.error(
          "Found eror, please contact support team.",
          this.viewRef
        );
      }
    );
  }

  public async SaveDeliveryList() {
    await this.http
      .post(
        "WH",
        ["SNWR010_SaveTempRouteList", this.selectedRouteNo.toString()],
        {
          CAR_NO: this.carNo,
          CAR_TYPE: this.carType,
          LICENSE_NO: this.licenseNo,
          DRIVER_NAME: this.driverName,
          DRIVER_TEL: this.driverTel,
          selectedList: this.sentList.selected,
        }
      )
      .toPromise()
      .then((res) => {
        this.creatLineDialog.Close();
      })
      .catch((err) => {
        this.modal.error(
          "Found eror, please contact support team.",
          this.viewRef
        );
      });

    this.modal.info("Save delivery completed.", this.viewRef);
    this.GetBKKDeliveryList();
  }

  public PrintDeliveryList() {
    this.global.GoToReport("PMS_RPT_WMS_SNWR010_DELIVERY_SHEET_DLR", {
      P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      P_TYPE: "TEMP",
      P_DELIVERY_DATE : ""
    });
  }

  public ToggleDelivery(event: any, data: any) {
    this.sentList.toggle(data);
  }

  public RouteNoSelected(event: any) {

    const route = event.value;
    this.sentList.clear();
    const matchedList = JSON.parse(
      JSON.stringify(
        this.deliveryList.filter((item) => (item.DELIVERY_ROUTE == route))
      )
    );

    matchedList.forEach((item) => {
      this.sentList.toggle(item);
    });

    this.createRouteList = JSON.parse(JSON.stringify(this.unDeliveryList));
    this.createRouteList = [...matchedList, ...this.createRouteList];
    this.createRouteList = this.createRouteList.slice();
  }

  public CreateTempRoute() {
    this.sentList.clear();
    this.createRouteList = JSON.parse(JSON.stringify(this.unDeliveryList));
    this.selectedRouteNo = null;
    this.creatLineDialog.OpenDialog();
  }

  private async GetDeliveryRoute() {
    this.carList = [];
    await this.http
      .get("WH", "SNWR010_GetRoute", "BKK")
      .toPromise()
      .then(
        (res) => {
          this.carList = res.Table1;
        },
        (err) => {
          this.modal.error(
            "Found eror, please contact support team.",
            this.viewRef
          );
        }
      );
  }

  public ChangeRouteCar(selected: any, changed?: boolean) {
    if (selected) {
      const carInfo = this.carList.find((car) => car.CAR_NO === selected);
      this.carNo = carInfo.CAR_NO;
      this.carType = carInfo.CAR_TYPE;
      this.licenseNo = carInfo.LICENSE_NO;
      this.driverName = carInfo.DRIVER_NAME;
      this.driverTel = carInfo.DRIVER_TEL;
    }
  }
}
