import {
  Component,
  ElementRef,
  OnInit,
  QueryList,
  ViewChild,
  ViewChildren,
  ViewContainerRef,
} from "@angular/core";
import { FormControl, Validators } from "@angular/forms";
import * as moment from "moment";
import { Subject } from "rxjs";
import { debounceTime, delay, map, take } from "rxjs/operators";
import { Globals } from "src/app/core/global";
import { HttpService } from "src/app/core/http.service";
import { ModalService } from "src/app/core/modal.service";

@Component({
  selector: "SNWR015",
  templateUrl: "SNWR015.component.html",
})
export class SNWR015Component implements OnInit {
  constructor(
    private modal: ModalService,
    private viewRef: ViewContainerRef,
    private http: HttpService,
    private el: ElementRef,
    private global: Globals
  ) { }

  private currentDate: moment.Moment = moment();
  public ShowList: boolean = false;
  public invoiceHeader: any = {};
  public invoiceDetail: any[] = [];
  public hideColumnDetail: string[] = [];
  private matchedPO: any[] = [];
  private duplicateCheck: Subject<boolean> = new Subject<boolean>();
  private invoiceType: string = "T_TMP";
  public invoiceList: any[] = [];
  public paramsSearch: any = {};
  public paramsMap: any = {};
  public isMultiLocation : boolean = false;

  @ViewChildren("acceptPartNoInput") partInputs: QueryList<ElementRef>;
  @ViewChildren("qtyInput") qtyInput: QueryList<ElementRef>;
  @ViewChild("dialogMapInvoice", { static: false }) dialogMapInvoice: any;
  private changeLineSubject: Subject<boolean> = new Subject<boolean>();
  SetReceiveDateControl = new FormControl('', [Validators.required])
  SetReceiveDocNoControl = new FormControl('', [Validators.required])

  public PartNoLookupConfig: any = {
    ColName: "LOOKUP_PART_NAME",
    PlaceholderText: "Select Part No.",
    SourceController: "wPMS",
    SourceMethodName: "GetPartNo",
    NoOfShowRecords: 20,
  };

  public vendorLookupConfig: any = {
    ColName: "LOOKUP_VENDOR_NAME",
    PlaceholderText: "Select Vendor",
    SourceController: "WH",
    SourceMethodName: "SNPE015_P_GetVendorCode",
    NoOfShowRecords: 50,
    UpperCase: true,
    MinLengthSearch: 1,
    SourceParams: {
      INV_TYPE: "L_PO",
    },
  };

  public tblFooter: any = [
    {
      fieldName: "PART_NAME",
      value: "Total",
      show: true,
    },

    {
      fieldName: "STICKER_UNIT",

      show: true,
    },
    {
      fieldName: "ORDER_QTY",

      show: true,
    },
    {
      fieldName: "QTY",

      show: true,
    },
    {
      fieldName: "NET_AMT_B",

      show: true,
    },
  ];

  ngOnInit() {
    this.InitAdd(this.invoiceType);
    this.duplicateCheck
      .pipe(debounceTime(200))
      .subscribe(
        (v) =>
          this.invoiceHeader.VENDOR_CODE &&
          this.invoiceHeader.INVOICE_NO &&
          this.CheckDuplicate()
      );
  }

  private InitAdd(invType?: string) {
    invType = invType;

    this.invoiceHeader = {
      VENDOR_CODE: null,
      INVOICE_NO: null,
      INVOICE_DATE: this.currentDate,
      INVOICE_STATUS: "N",
      INVOICE_STATUS_DESC: "New",
      INVOICE_TYPE: invType,
    };

    this.invoiceDetail = [];
    this.matchedPO = [];
    this.CreateDetailRow(0);

    this.vendorLookupConfig.SourceParams.INV_TYPE = invType;

    this.SetHideColumns(invType);
  }

  public Add() {
    this.ShowList = false;
    this.InitAdd(this.invoiceType);
    this.isMultiLocation = false
  }

  public MapInvoiceDialog(data) {
    this.paramsMap = { ...data }
    this.dialogMapInvoice.OpenDialog();
  }
  public MapInvoice() {
    if (this.paramsMap.RECEIVE_DATE && this.paramsMap.RECEIVE_DOC_NO && this.paramsMap.PRE_RECEIVE_DOC_NO) {
      this.modal.confirm("Do you want to save change you have made?", this.viewRef, this.ConfirmMap);
    }
    else {
      this.modal.warning("Please Input fill", this.viewRef);
    }
  }
  public ConfirmMap = () => {
    this.http.post("WH", "SNWR015_MapInvoice", this.paramsMap).subscribe(
      (res) => {
        this.modal.info('Transaction complete: applied and saved.', this.viewRef);
        this.ViewDetail(this.invoiceHeader);
        this.paramsMap = this.global.ClearObject(this.paramsMap);
        this.dialogMapInvoice.Close();
      },
      (err) => {
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewRef
        );
      }
    );
  }
  public CancelMap() {
    this.dialogMapInvoice.Close();
  }
  public Search() {
    this.invoiceList = [];
    this.http.post("WH", "SNWR015_GetData", this.paramsSearch).subscribe(
      (res) => {
        this.invoiceList = res.Table;
      },
      (err) => {
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewRef
        );
      }
    );
  }

  public InvoiceTypeChange(select) {
    this.InitAdd(select.value);
  }

  public ViewDetail(invoiceData) {

    this.invoiceDetail = [];

    this.ShowList = false;
    this.http.post("WH", "SNWR015_GetInvoiceDetail", invoiceData).subscribe(
      (res) => {
        this.invoiceHeader = res.Table[0] || {};
        this.invoiceDetail = res.Table1;

        if (this.invoiceHeader.INVOICE_NO) {
          this.invoiceHeader.VENDOR = this.invoiceHeader.VENDOR_CODE;
          this.SetHideColumns(this.invoiceType, ['CHECK']);

        }

        this.invoiceDetail.forEach(v => {
          v.ACCEPT_PART_NO = v.PART_NO;
          v._PART_NO = v.PART_NO;
        })
      },
      (err) => {
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewRef
        );
      }
    );
  }

  public CheckPO(event, elemID, index, data) {
    let currentElement = this.el.nativeElement.querySelector("#" + elemID);
    this.http
      .post("WH", "SNWR015_CheckWOPartNo", {
        VENDOR_CODE: this.invoiceHeader.VENDOR_CODE,
        PART_NO: event.PART_NO,
      })
      .subscribe(
        (res) => {
          this.matchedPO = res.Table;

          if (this.matchedPO.length === 1) {
            if (
              res.Table.find((v) => v.LOCATION_NO && v.LOCATION_NO.length > 0)
            ) {
              data = Object.assign(
                data,
                this.SetPartRow(data, this.matchedPO[0])
              );
            } else {
              data._PART_NO = null;
              currentElement.focus();
              this.modal.error(
                "Location hasn't configured for this part.",
                this.viewRef
              );
            }
          } else {
            data._PART_NO = null;
            currentElement.focus();
            this.modal.error("Unable to find part no.", this.viewRef);
          }

          this.changeLineSubject.next(true);
        },
        (err) => {
          this.modal.error(err.message, this.viewRef);
        }
      );
  }

  public Save() {
    var data = Object.assign({}, this.invoiceHeader);
    data.PART_LIST = this.invoiceDetail
      .slice()
      .filter((v) => v.ACCEPT_PART_NO)
      .map((v) => {
        if (this.invoiceHeader.INVOICE_TYPE.substr(-2) === "WO") {
          v.ORDER_CLASS = this.invoiceHeader.ORDER_CLASS;
          v.ORDER_TYPE = this.invoiceHeader.ORDER_TYPE;
        }
        return v;
      });

    let findLargeLotStickers = data.PART_LIST.find((v) => v.STICKER_UNIT > 200);
    if (findLargeLotStickers) {
      this.modal.warning(
        "Please input correct Receive pck.",
        this.viewRef
      );
      return;
    }

    this.modal.confirm(
      "Are you sure to confirm pre-receive",
      this.viewRef,
      () => {
        this.http.post("WH", "SNWR015_Save", data).subscribe(
          (res) => {
            if (res.Result == "Done") {
              this.invoiceHeader.DOCUMENT_NO = res.DocNo;
              this.modal.info(
                "Save data successfully.",
                this.viewRef
              );
              this.ViewDetail(this.invoiceHeader);
              this.isMultiLocation = false
            } else if (res.Result == "Duplicate invoice") {
              this.modal.warning(
                "Duplicate invoice : " + this.invoiceHeader.INVOICE_NO,
                this.viewRef
              );
            } else {
              this.modal.warning(
                "Found an error, please contact support team.",
                this.viewRef
              );
            }
          },
          (err) => {
            this.modal.warning(
              "Found an error, please contact support team",
              this.viewRef
            );
          }
        );
      },
      () => { }
    );
  }

  public CheckValidSave() {
    var validItems = this.invoiceDetail.filter((d, i) =>
      this.CheckRequiredFields(i, false)
    );
    var filledItems = this.invoiceDetail.filter((v) => v.ACCEPT_PART_NO);
    return (
      this.invoiceHeader.INVOICE_STATUS === "N" &&
      validItems.length === filledItems.length &&
      validItems.length > 0
    );
  }

  public CancelPreReceive() {
    this.modal.confirm(
      "Are you sure to cancel pre-receive?",
      this.viewRef,
      () => {
        this.http.post("WH", "SNWR015_Cancel", this.invoiceHeader).subscribe(
          (res) => {
            this.modal.info(
              "Transaction complete: applied and saved.",
              this.viewRef
            );
            this.BackToSearch();
          },
          (err) => {
            this.modal.warning(
              "Found an error, please contact support team",
              this.viewRef
            );
          }
        );
      },
      () => { }
    );
  }

  public OpenReport_Pre() {
    this.global.GoToReport("PMS_RPT_WMS_SNPR020_v3", {
      P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      P_DOCUMENT_NO: this.invoiceHeader.DOCUMENT_NO,
    });
  }

  public BackToSearch() {
    this.Search();
    this.ShowList = true;
    this.isMultiLocation = false
  }

  public CheckDuplicate() {
    this.http
      .post("WH", "SNWR015_CheckDuplicateInvoice", {
        VENDOR_CODE: this.invoiceHeader.VENDOR_CODE,
        INVOICE_NO: this.invoiceHeader.INVOICE_NO,
        INVOICE_DATE: this.invoiceHeader.INVOICE_DATE,
      })
      .subscribe((res) => {
        if (res !== "Done") {
          this.modal.warning("Duplicate invoice.", this.viewRef);
          this.InitAdd(this.invoiceHeader.INVOICE_TYPE);
        } else {
          if (this.invoiceHeader.INVOICE_TYPE != 'N_IV') {
              this.GetDocMultiLocation()
          }
        }
      });
  }

  public CheckRequiredFields(tblIndex, allowUnChange: boolean = true) {
    let valid: boolean =
      this.invoiceHeader.VENDOR_CODE &&
        this.invoiceHeader.INVOICE_NO &&
        this.invoiceHeader.INVOICE_DATE
        ? true
        : false;

    if (valid) {
      let thisRow = this.invoiceDetail[tblIndex];
      let countChangeItems: number = 0;

      if (thisRow.ACCEPT_PART_NO) countChangeItems++;
      if (thisRow.QTY) countChangeItems++;
      if (thisRow.ACCEPT_PART_NO) countChangeItems++;

      valid =
        (countChangeItems > 0 &&
          thisRow.ACCEPT_PART_NO &&
          thisRow.QTY &&
          thisRow.UNIT_TYPE) ||
          (allowUnChange && countChangeItems === 0)
          ? true
          : false;
    }

    return valid;
  }

  public async SetInvoice() {
    this.invoiceHeader.INVOICE_NO = this.invoiceHeader.INVOICE_NO.toUpperCase();
    await this.duplicateCheck.next(true);


  }

  public GetDocMultiLocation() {

    let doctype = this.invoiceHeader.INVOICE_NO.substring(0, 2)
    if (doctype == "RO" || doctype == "MA" || doctype == "PA" || doctype == "SP" || doctype == "RS" || doctype == "TF" || doctype == "RT"){
      this.http.post("WH", "SNWR005_GetDocFromMultiLocation", this.invoiceHeader)
        .subscribe(res => {
          if(res.Table.length > 0){
            this.invoiceDetail = res.Table
            this.isMultiLocation = true
          }
         
        })
    }
  }

  public InvoiceDateChange() {
    this.duplicateCheck.next(true);
  }

  private SetPartRow(row: any, data: any) {
    row = data;
    row._PART_NO = data.ACCEPT_PART_NO;
    row.RECEIVE_PACKAGE = data.QTY;
    return row;
  }

  public SetVendorCodeLookup(value) {
    if (value.VENDOR_CODE) {
      this.invoiceHeader.VENDOR = value.VENDOR_CODE;
      this.invoiceHeader.VENDOR_CODE = value.VENDOR_CODE;
      this.invoiceHeader.VENDOR_NAME = value.VENDOR_NAME_EN;

      // this.duplicateCheck.next(true)
    } else {
      this.invoiceHeader.VENDOR = null;
      this.invoiceHeader.VENDOR_CODE = null;
      this.el.nativeElement.querySelector("#vendorcode").focus();
      this.modal.error("Unable to find vendor.", this.viewRef);
    }
  }

  private SetHideColumns(invType: string, fixCols?: string[]) {
    let hideCols = [];

    hideCols = ["CHECK_2", "PO_NO", "PO_DATE", "ITEM_NO_SHOW", "ORDER_QTY", "UNIT_PRICE_B", "NET_AMT_B"]

    this.hideColumnDetail = hideCols.concat(fixCols || []);
  }

  public onPartInputEnter(event: any, index: number) {
    const nextIndex = index + 1;
    const nextPartInput = this.partInputs.toArray()[nextIndex];
    const currentQtyInput = this.qtyInput.toArray()[index];

    const subject = this.changeLineSubject
      .pipe(
        take(1),
        delay(100),
        map((v) => v)
      )
      .subscribe((v) => {
        currentQtyInput.nativeElement.focus();
        if (!nextPartInput.nativeElement.disabled)
          nextPartInput.nativeElement.focus();
        subject.unsubscribe();
      });

    if (this.changeLineSubject) {
      this.changeLineSubject.next(true);
    }
  }

  public onQtyInputEnter(event: any, index: number) {
    const nextIndex = index + 1;
    const nextPartInput = this.partInputs.toArray()[nextIndex];

    setTimeout(() => {
      if (!nextPartInput.nativeElement.disabled)
        nextPartInput.nativeElement.focus();
    }, 100);
  }

  public QuantityChange(data) {
    if (data.QTY > data.ACCEPT_QTY) {
      data.QTY = data.ACCEPT_QTY;
    }

    if (data.RECEIVE_HH_ON !== "Y") {
      data.RECEIVE_PACKAGE = data.QTY;
    }
    else {
      data.RECEIVE_PACKAGE = data.QTY;
    }
    if (data.QTY % data.RECEIVE_PACKAGE > 0) {
      this.modal.warning(
        "Receive QTY not matched by Receive package.",
        this.viewRef
      );
    }
    data.STICKER_UNIT = Math.ceil(data.QTY / data.RECEIVE_PACKAGE);
  }
  public RCQuantityChange(data) {
    if (data.RECEIVE_PACKAGE > data.QTY) {
      data.RECEIVE_PACKAGE = data.QTY;
    }

    if (data.QTY % data.RECEIVE_PACKAGE > 0) {
      this.modal.warning(
        "Receive QTY not matched by Receive package.",
        this.viewRef
      );
    }

    data.STICKER_UNIT = Math.ceil(data.QTY / data.RECEIVE_PACKAGE);
  }

  public CheckActiveRow(tblIndex) {
    let valid: boolean =
      this.invoiceHeader.VENDOR_CODE &&
        this.invoiceHeader.INVOICE_NO &&
        this.invoiceHeader.INVOICE_DATE
        ? true
        : false;

    if (valid) {
      valid =
        !this.invoiceHeader.INVOICE_STATUS ||
        this.invoiceHeader.INVOICE_STATUS === "N";
    }

    if (valid && tblIndex > 0) {
      let prevRow = this.invoiceDetail[tblIndex - 1];

      valid =
        prevRow.ACCEPT_PART_NO && prevRow.QTY //&& prevRow.UNIT_PRICE_B
          ? true
          : false;
    }

    if (valid && !this.isMultiLocation) {
      this.CreateDetailRow(tblIndex);
    }

    return valid;
  }

  public CreateDetailRow(tblIndex) {
    let currentMaxRow: number = this.invoiceDetail.length || 0;
    let nextMaxRow: number = (Math.floor(currentMaxRow / 10) + 1) * 10;

    if (currentMaxRow - tblIndex <= 2) {
      for (let i = currentMaxRow; i < nextMaxRow; i++) {
        this.invoiceDetail.push({});
      }

      this.invoiceDetail = this.invoiceDetail.slice();
    }
  }

  public DeleteRow(index) {
    this.modal.confirm(
      "Are you sure to remove this row?",
      this.viewRef,
      () => {
        this.invoiceDetail.splice(index, 1);
        this.invoiceDetail = [...this.invoiceDetail];
      },
      () => { }
    );
  }

  public TotalQty() {
    return this.invoiceDetail.reduce((a, b) => a + (b.QTY || 0), 0);
  }

  public TotalAmount() {
    return this.invoiceDetail.reduce(
      (a, b) => a + (b.QTY || 0) * (b.UNIT_PRICE_B || 0),
      0
    );
  }

  public TotalItem() {
    return this.invoiceDetail.reduce(
      (a, b) => a + ((b.QTY || 0) / b.RECEIVE_PACKAGE || 0),
      0
    );
  }


  public Report() {
    this.global.GoToReport("PMS_RPT_WMS_RECEIVE_WAIT",
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_START_DATE: this.global.ConvertDateToFormatSTD(this.paramsSearch.DOCUMENT_DATE_FROM),
        P_TO_DATE: this.global.ConvertDateToFormatSTD(this.paramsSearch.DOCUMENT_DATE_TO),
      }
    );
  }
  public Report_By_Part() {
    this.global.GoToReport("PMS_RPT_WMS_RECEIVE_WAIT_BY_PART",
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_START_DATE: this.global.ConvertDateToFormatSTD(this.paramsSearch.DOCUMENT_DATE_FROM),
        P_TO_DATE: this.global.ConvertDateToFormatSTD(this.paramsSearch.DOCUMENT_DATE_TO),
      }
    );
  }
}
