import {
  Component,
  ElementRef,
  HostListener,
  OnInit,
  ViewChild,
  ViewContainerRef,
} from "@angular/core";
import { HttpService } from "src/app/core/http.service";
import { ModalService } from "src/app/core/modal.service";
import { Observable, Subject } from "rxjs";
import {
  PickToken,
  PickTokenExtractor,
} from "src/app/core/WHOutboundController/PickTokenExtractor";
import {
  InvoiceControl,
  InvoiceControlSetValue,
  CaseNo,
} from "src/app/core/WHOutboundController/InvoiceControl";
import { map } from "rxjs/operators";
import * as moment from "moment";
import { DialogTemplateComponent } from "src/app/components/shared/dialog-template/dialog-template.component";
import { Globals } from "src/app/core/global";
import { SelectionModel } from "@angular/cdk/collections";

type ActionLog = {
  timestamp: moment.Moment;
  actionType: string;
  actionMessage: string;
};
@Component({
  selector: "SNWR023",
  templateUrl: "./SNWR023.component.html",
  styleUrls: ["../warehouse.component.css", "./SNWR023.component.css"],
  providers: [PickTokenExtractor],
})
export class SNWR023Component implements OnInit {
  constructor(
    private Http: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private extractor: PickTokenExtractor,
    private global: Globals
  ) { }

  public qrString: string;
  public params: any = {};
  private tableData: any = [];
  public tableDataFiltered: any = [];
  public totalItems: number = 0;

  public pickingList: string[] = [];
  public updateData: any = {};
  public gCaseNo: string;
  public gInvocieNo: string;
  public gInvocieNoTo: string;
  public onProcess: string;

  public fileUrl;

  public showHistory: boolean = false;
  public actionLogs: ActionLog[] = [];
  private actionLogsSubject: Subject<ActionLog> = new Subject<ActionLog>();

  public unlockPartDetail: any = {};
  //public lockQty: boolean = true;

  public paramReport : any = {}

  @ViewChild("InvoiceDialog") InvoiceDialog: DialogTemplateComponent;
  @ViewChild("PrintDialog") PrintDialog: DialogTemplateComponent;
  @ViewChild("saveButton", { read: ElementRef }) saveButton: ElementRef;
  @ViewChild("saveCaseTypeButton", { read: ElementRef })
  saveCaseTypeButton: ElementRef;
  @ViewChild("scannerInput", { read: ElementRef }) scannerInput: ElementRef;

  public initialControl: InvoiceControl = new InvoiceControl();
  private initialControlSubject: Subject<InvoiceControlSetValue> =
    new Subject<InvoiceControlSetValue>();

  public selectedParts: any[];
  public selectedPartsFiltered: any[];
  public scannedCase: any;
  public selectedCases: CaseNo[];
  public popupCase: CaseNo;
  public isInvoiceIssued: boolean = false;

  public scannedQR: PickToken;

  public fnName: any;

  public dataDetail1: any = [];
  public dataDetail2: any = [];
  public dataDetail3: any = [];
  public dataDetail4: any = [];
  public dataDetail5: any = [];
  public dataDetail6: any = [];
  //public dataDetail7: any = [];
  public invoiceDataList: any = [];

  public invoiceDetail: any = [];
  public dataIsSelected: any = [];
  public tabIndex: number = 0;

  public selection = new SelectionModel<any>(true, []);
  public configFlag : string = "";
  // public dataDetailRO: any = [];

  public lookupPickListNoConfig: any = {
    ColName: "PICKING_LIST_NO",
    PlaceholderText: "Select Picking List No.",
    SourceController: "WH",
    SourceMethodName: "SNWR023_GetPickListNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true,
  };

  public lookupOrderNoConfig: any = {
    ColName: "LOOKUP_ORDER_NO",
    PlaceholderText: "Select Order No",
    SourceController: "WH",
    SourceMethodName: "SNWR023_GetOrderNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      CUSTOMER_CODE: null,
      BRANCH_CODE: null,
    },
    UpperCase: true,
  };

  public lookupPickLotSeqConfig: any = {
    ColName: "LOOKUP_PICK_LOT_SEQ",
    PlaceholderText: "Select Pick Lot Seq",
    SourceController: "WH",
    SourceMethodName: "SNWR023_GetPickLotSeq",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params,
    },
    UpperCase: true,
  };

  ngOnInit() {
    this.InitialProcess();

    this.fnName = "SNWR023_GetPackEOBKK";
    this.GetPack();
    this.GetConfigFlag();
    this.onProcess = "OFF";

    this.actionLogsSubject.subscribe((action: ActionLog) => {
      this.actionLogs.push(action);
      this.actionLogs = this.actionLogs.slice();
    });
  }

  private GetConfigFlag(){
    this.Http.get("wPMS","GetConfigFlag","SNWR023_INVOICE_FLAG")
    .subscribe(res =>{
      this.configFlag = res.Table[0].CONFIG_VALUE
    })
  }

  private InitialProcess() {
    this.selectedCases = [];
    this.selectedParts = [];
    this.selectedPartsFiltered = [];
    this.totalItems = 0;
    this.scannedCase = {};
    //  this.lockQty = true;
    this.params = {};
    this.qrString = null;
    this.tableData = [];
    this.tableDataFiltered = [];
    this.pickingList = [];
    this.unlockPartDetail = {};
    this.actionLogs = [];
    this.initialControl.reset();
    this.isInvoiceIssued = false;
    //this.prevPicking = null;
  }

  public MainTabChange($event): void {
    this.params = {};
    this.selectedParts = [];
    this.selectedCases = [];
    this.selectedPartsFiltered = [];

    if ($event.index == 0) {
    } else if ($event.index == 1) {
      this.InvoiceList();
    }
  }

  public CheckboxChange(event, data) {
    if (event.checked) {
      this.dataIsSelected.push(data);
    } else {
      this.dataIsSelected.splice(this.dataIsSelected.indexOf(data), 1);
    }
    this.params.CNT_SEL = this.dataIsSelected.length;
  }

  public isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.invoiceDataList.length;
    return numSelected === numRows;
  }

  public Toggle() {
    if (this.isAllSelected()) {
      this.selection.clear();
      this.invoiceDataList.map((x) => {
        this.dataIsSelected = [];
      });
    } else {
      this.invoiceDataList.forEach((row) => this.selection.select(row));
      this.dataIsSelected = [];
      this.invoiceDataList.map((x) => {
        this.dataIsSelected.push(x);
      });
    }
    this.params.CNT_SEL = this.dataIsSelected.length;
  }

  public TabChange($event): void {
    this.params = {};
    this.selectedParts = [];
    this.selectedCases = [];
    this.selectedPartsFiltered = [];
    this.tabIndex = $event.index;

    if ($event.index == 0) {
      this.dataDetail1.forEach((r) => {
        r.CHECK = 0;
      });
    } else if ($event.index == 1) {
      this.dataDetail2.forEach((r) => {
        r.CHECK = 0;
      });
    } else if ($event.index == 2) {
      this.dataDetail3.forEach((r) => {
        r.CHECK = 0;
      });
    } else if ($event.index == 3) {
      this.dataDetail4.forEach((r) => {
        r.CHECK = 0;
      });
    } else if ($event.index == 4) {
      this.dataDetail5.forEach((r) => {
        r.CHECK = 0;
      });
    }
    else if ($event.index == 5) {
      this.dataDetail6.forEach((r) => {
        r.CHECK = 0;
      });
    }
    //else if ($event.index == 6) {
    //  this.dataDetail7.forEach((r) => {
    //    r.CHECK = 0;
    //  });
    //}
    this.GetPack();
  }

  public GetPack(): void {
    //this.InitialProcess();
    this.Http.post("WH", "SNWR023_GetPack", this.params).subscribe(
      (res) => {
        this.dataDetail1 = res.Table;
        this.dataDetail2 = res.Table1;
        this.dataDetail3 = res.Table2;
        this.dataDetail4 = res.Table3;
        this.dataDetail5 = res.Table4;
        this.dataDetail6 = res.Table5;
        //this.dataDetail7 = res.Table6;
      },
      (err) => {
        console.log(err);
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewref
        );
      }
    );
  }

  public InvoiceList() {
    // this.InvoiceListDialog.OpenDialog();
    this.Http.post("WH", "SNWR023_GetInvoiceList", this.params).subscribe(
      (res) => {
        this.invoiceDataList = res.Table;
      },
      (err) => {
        console.log(err);
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewref
        );
      }
    );
  }

  public SelectRow(i, row) {


    let methodName = "SNWR023_GetCaseAll";
    if (i == 1) {
      this.dataDetail1.forEach((r) => {
        r.CHECK = 0;
      });
    } else if (i == 2) {
      this.dataDetail2.forEach((r) => {
        r.CHECK = 0;
      });
    } else if (i == 3) {
      this.dataDetail3.forEach((r) => {
        r.CHECK = 0;
      });
    } else if (i == 4) {
      this.dataDetail4.forEach((r) => {
        r.CHECK = 0;
      });
    } else if (i == 5) {
      methodName = "SNWR023_GetCaseAllKit";
      this.dataDetail5.forEach((r) => {
        r.CHECK = 0;
      });
    } else if (i == 6) {
      this.dataDetail5.forEach((r) => {
        r.CHECK = 0;
      });
    }
    //} else if (i == 7) {
    //  this.dataDetail7.forEach((r) => {
    //    r.CHECK = 0;
    //  });
    //}

    row.CHECK = 1;

    this.updateData.PACK_BY = row.PACK_BY;
    this.updateData.CUSTOMER_CODE = row.CUSTOMER_CODE;
    this.updateData.BRANCH_CODE = row.BRANCH_CODE;
    this.updateData.ORDER_CLASS = row.ORDER_CLASS;
    this.updateData.ORDER_TYPE = row.ORDER_TYPE;

    this.Http.post("WH", methodName, this.updateData).subscribe(
      (result) => {
        this.selectedParts = result.Table;

        //Select and sort
        const selectedCases = result.Table.reduce((arr, item) => {
          if (!arr.find((a) => a.caseNo === item.CASE_NO)) {
            arr.push({
              caseNo: item.CASE_NO,
              caseDate: item.CASE_DATE,
              caseType: item.CASE_TYPE,
            });
          }
          return arr;
        }, []).sort((a, b) => a.caseNo < b.caseNo);
        this.selectedCases = selectedCases;

        this.params.CUSTOMER_CODE = row.CUSTOMER_CODE;
        this.params.BRANCH_CODE = row.BRANCH_CODE;

        this.params.CUSTOMER_NAME = row.CUSTOMER_NAME;
        this.params.BRANCH_NAME = row.BRANCH_NAME;
        this.params.CUSTOMER_ZONE = row.CUSTOMER_ZONE;
        //  this.params.ORDER_CLASS = result.Table[0].ORDER_CLASS;
        this.params.ORDER_TYPE = row.ORDER_TYPE;
        this.params.QTY = row.QTY;
        this.params.NO_OF_CASE = row.NO_OF_CASE;
        this.params.TRANSPORT_CODE = row.TRANSPORT_CODE;
        this.params.ROUTE_CODE = row.ROUTE_CODE;
        this.params.TOTAL_AMOUNT = row.TOTAL_AMOUNT;

        this.FilterTableData();
      },
      (err) => {
        console.log(err, "err");
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewref
        );
      }
    );
  }

  public RefreshSelect() {
    this.Http.post("WH", "SNWR023_GetCaseAll", this.updateData).subscribe(
      (result) => {
        this.selectedParts = result.Table;

        //Filter show data
        this.FilterSelectedParts(this.gCaseNo);
      },
      (err) => {
        console.log(err, "err");
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewref
        );
      }
    );
  }

  public TabCaseChanged(caseNo) {
    this.gCaseNo = caseNo;
    this.FilterSelectedParts(caseNo);
  }

  public ViewData(row) {
    this.InvoiceDialog.OpenDialog();

    var invoiceData = row;
    this.params = row;

    this.Http.post("WH", "SNWR023_GetInvoiceDetail", invoiceData).subscribe(
      (res) => {
        this.invoiceDetail = res.Table;
      },
      (err) => {
        console.log(err);
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewref
        );
      }
    );
  }

  public ResetData() {
    if (this.scannedCase) {
      this.modal.confirm("Are you sure to reset data?", this.viewref, () => {
        this.InitialProcess();
        this.TabChange({ index: 0 });
      });
    } else {
      this.InitialProcess();
    }
    this.scannerInput.nativeElement.focus();
  }

  public ConfirmIssueInvoice() {
    var iHold = 0;
    var iCase = 0;
    var gCaseNo = "";

    this.onProcess = 'ON';

    this.selectedParts.forEach((row) => {
      if (row.CASE_STATUS == "H") {
        iHold = iHold + 1;
        if (gCaseNo == "" || gCaseNo.indexOf(row.CASE_NO) <= 0) {
          iCase = iCase + 1;
          gCaseNo = gCaseNo + "," + row.CASE_NO;
        }
      }
    });

    if (this.totalItems - iHold <= 0) {
      this.modal.warning("No active case", this.viewref);
      this.onProcess = 'OFF';
      return;
    }

    if (iHold > 0) {
      this.modal.confirm(
        "Do you want to issue invoice? " +
        "<br> There are " +
        iHold +
        " items in " +
        iCase +
        " case  on hold. " +
        "[Selected : " +
        (this.totalItems - iHold) +
        " Items]",
        this.viewref,
        this.IssueInvoice,
        () => { this.onProcess = 'OFF';}
      );
    } else {
      this.modal.confirm(
        "Do you want to issue invoice? " +
        "[Selected : " +
        this.totalItems +
        " Items]",
        this.viewref,
        this.IssueInvoice,
        () => { this.onProcess = 'OFF'; }
      );
    }

    // }
  }

  private IssueInvoice = () => {

    
    this.selectedCases.forEach((caseNo) => {
      this.selectedParts
        .filter((item) => item.CASE_NO === caseNo.caseNo)
        .forEach((item) => {
          item.CASE_DATE = caseNo.caseDate;
          item.CASE_TYPE = caseNo.caseType;
        });
    });
    let methodName = "";
    if (this.tabIndex != 4) {
      methodName = "SNWR023_IssueInvoice";
    } else {
      methodName = "SNWR023_IssueInvoiceKit";
    }
    this.Http.post(
      "WH",
      [methodName, this.updateData.PACK_BY],
      this.selectedParts
    ).subscribe(
      (res) => {
        if (res.status === "Done") {
          this.gInvocieNo = res.invoiceNoFrom;
          this.gInvocieNoTo = res.invoiceNoTo;
          this.isInvoiceIssued = true;
          this.onProcess = 'OFF';
          if(this.configFlag == "OFF"){
            this.PrintInvoices();
          }else{
            this.modal.info("Invoice no " + this.gInvocieNo + ' - ' + this.gInvocieNoTo,this.viewref)
          }
          
          this.GetPack();
          this.params = {};
          this.selectedParts = [];
          this.selectedCases = [];
          this.selectedPartsFiltered = [];
          // this.Search();
        } else if (res.status === "Fail") {
          this.onProcess = 'OFF';
          this.GetPack();
          this.modal.error(res.message, this.viewref);
        } else if (res.status === "Wait") {
          this.onProcess = 'OFF';
          this.modal.warning(res.message, this.viewref);
          this.GetPack();
          
        } else {
          this.onProcess = 'OFF';
          this.modal.error(
            "Found error, please contact support team",
            this.viewref
          );
        }
      },
      (err) => {
        console.log("err", err);
        this.onProcess = 'OFF';
        this.modal.error(
          "Found error, please contact support team",
          this.viewref
        );
      }
    );
  };


  public PrintInvoices() {
    this.PrintDialog.OpenDialog();

    this.fileUrl = null;
    this.Http.Download("WH", "PrintInvoice", {
      ReportPrefix: "PMS_" + this.gInvocieNo + "_" + this.gInvocieNoTo,
      ReportSuffix: ".PDF",
      P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      P_INVOICE_NO_FROM: this.gInvocieNo,
      P_INVOICE_NO_TO: this.gInvocieNoTo,
    }).subscribe((res) => {
      if (res) {
        this.SetIFrameContent(res);
      }
    });
  }

  private SetIFrameContent(content: any) {
    const file = new Blob([content], { type: content.type });
    const fileUrl = URL.createObjectURL(file);

    this.fileUrl = fileUrl;
  }

  public PrintDelivery() {
    this.global.GoToReport("PMS_RPT_WMS_SNWR023_DELIVERY", {
      P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      P_INVOICE_NO_FROM: this.params.INVOICE_NO_FROM,
      P_INVOICE_NO_TO: this.params.INVOICE_NO_TO,
    });
  }

  public PrintInvoices2(data) {
   

    this.gInvocieNo = data.DOCUMENT_NO;
    this.gInvocieNoTo = data.DOCUMENT_NO;
    this.PrintDialog.OpenDialog();
    this.fileUrl = null;
    this.Http.Download("WH", "PrintInvoice", {
      ReportPrefix: "PMS_" + data.DOCUMENT_NO,
      ReportSuffix: ".PDF",
      P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      P_INVOICE_NO_FROM: data.DOCUMENT_NO,
      P_INVOICE_NO_TO: data.DOCUMENT_NO,
    }).subscribe((res) => {
      if (res) {
        this.SetIFrameContent(res);
      }
    });



  }

  public OpenReport() {
    this.PrintDialog.OpenDialog();
    this.fileUrl = null;
    this.Http.Download("WH", "PrintInvoice", {
      ReportPrefix: "PMS_" + this.paramReport.INVOICE_NO_FROM + "_" + this.paramReport.INVOICE_NO_TO,
      ReportSuffix: ".PDF",
      P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      P_INVOICE_NO_FROM: this.paramReport.INVOICE_NO_FROM,
      P_INVOICE_NO_TO: this.paramReport.INVOICE_NO_TO,
    }).subscribe((res) => {
      if (res) {
        this.SetIFrameContent(res);
      }
    });
  }



  public OrderClassChange(event) {
    this.params.ORDER_CLASS = event.value;
  }

  public HoldCase(CaseNo: CaseNo, caseIndex: number) {
    const foundParts = this.selectedParts.find(
      (item) => item.CASE_NO === CaseNo.caseNo
    );
    if (!foundParts) {
      this.modal.warning("There is no case.", this.viewref);
    } else {
      var caseStatus = this.selectedPartsFiltered[0].CASE_STATUS;
      var gMessage = "Do you confirm to hold this case?";
      var fnName = "SNWR023_HoldCase";
      var gResult = "Case no " + CaseNo.caseNo + " has been hold.";
      if (caseStatus == "H") {
        gMessage = "Do you confirm to active this case?";
        fnName = "SNWR023_ActiveCase";
        gResult = "Case no " + CaseNo.caseNo + " has been active.";
      } else {
        gMessage = "Do you confirm to hold this case?";
        fnName = "SNWR023_HoldCase";
        gResult = "Case no " + CaseNo.caseNo + " has been hold.";
      }

      this.modal.confirm(
        gMessage,
        this.viewref,
        () => {
          this.Http.post("WH", fnName, CaseNo).subscribe(
            (res) => {
              if (res.status === "Done") {
                this.modal.info(gResult, this.viewref);
                this.RefreshSelect();
              } else if (res.status === "Fail") {
                this.modal.error(res.message, this.viewref);
              } else {
                this.modal.error(
                  "Found error, please contact support team",
                  this.viewref
                );
              }
            },
            (err) => {
              console.log("err", err);
              this.modal.error(
                "Found error, please contact support team",
                this.viewref
              );
            }
          );
        },
        () => { }
      );
    }
  }

  public RemoveSelectedParts(partItem: any, caseNo?: string) {
    if (!this.isInvoiceIssued) {
      this.modal.confirm(
        "Are you sure to remove selected part?",
        this.viewref,
        () => {
          let foundIndex = 0;
          let qty = 0;
          while (foundIndex >= 0) {
            foundIndex = this.selectedParts.findIndex(
              (item) =>
                item.PART_NO === partItem.PART_NO &&
                item.UNIT_PRICE === partItem.UNIT_PRICE &&
                item.CASE_NO === (caseNo || item.CASE_NO)
            );
            qty = this.selectedParts[foundIndex]?.QTY;

            if (foundIndex >= 0) {
              let removedItem = this.selectedParts.splice(foundIndex, 1);
              this.RevertRemainingData(partItem, qty);

              this.actionLogsSubject.next({
                timestamp: moment(),
                actionType: "Manual",
                actionMessage: `Remove Part No. ${partItem.PART_NO} ${qty} Qty from ${removedItem[0].CASE_NO}`,
              });
            }
          }
          this.selectedParts = this.selectedParts.slice();
          this.scannerInput.nativeElement.focus();
        },
        () => { }
      );
    } else {
      this.modal.warning("Cannot remove issued invoice!!", this.viewref);
    }
  }

  private RevertRemainingData(partItem: any, qty: number) {
    //Remove from current picking list
    let foundAllPart = this.tableData.filter(
      (item) =>
        item.PART_NO === partItem.PART_NO &&
        item.UNIT_PRICE === partItem.UNIT_PRICE &&
        item.INVOICE_QTY > 0 &&
        item.PICKING_LIST_NO === this.initialControl.QR.PICKING_LIST_NO
    );
    foundAllPart.forEach((item) => {
      const revertableQty = Math.min(item.INVOICE_QTY, qty);
      item.INVOICE_QTY = item.INVOICE_QTY - revertableQty;
      item.AVAILABLE_QTY = item.AVAILABLE_QTY + revertableQty;
      qty = qty - revertableQty;
    });

    //Remove from all picking list
    if (qty > 0) {
      foundAllPart = this.tableData.filter(
        (item) =>
          item.PART_NO === partItem.PART_NO &&
          item.UNIT_PRICE === partItem.UNIT_PRICE &&
          item.INVOICE_QTY > 0
      );
      foundAllPart.forEach((item) => {
        const revertableQty = Math.min(item.INVOICE_QTY, qty);
        item.INVOICE_QTY = item.INVOICE_QTY - revertableQty;
        item.AVAILABLE_QTY = item.AVAILABLE_QTY + revertableQty;
        qty = qty - revertableQty;
      });
    }

    this.FilterTableData();
  }

  public CalculateInvoiceAmount() {
    const invoiceAmount = this.selectedParts.reduce(
      (amount, item) => amount + item.QTY * item.UNIT_PRICE,
      0
    );
    return invoiceAmount;
  }

  private FilterTableData() {
    this.tableDataFiltered = this.tableData.filter(
      (row) =>
        row.PICKING_LIST_NO === this.initialControl.QR.PICKING_LIST_NO &&
        row.AVAILABLE_QTY > 0
    );

    //Filter show data
    this.FilterSelectedParts(this.scannedCase?.caseNo);

    //Get total items
    this.totalItems = this.GetFilteredSelectedParts(null).length;
  }

  public FilterSelectedParts(caseNo: string, isReturn: boolean = false) {
    caseNo = caseNo === "All" ? null : caseNo;

    //Set case number tab and filter show data
    let caseIndex = this.selectedCases.findIndex(
      (item) => item.caseNo === caseNo
    );
    this.scannedCase.index = caseIndex + 1;

    //Get filtered part
   // this.selectedPartsFiltered = this.GetFilteredSelectedParts(caseNo);
  }

  private GetFilteredSelectedParts(caseNo: string) {
    //Group part number
    let count = 0;
    const selectedParts = JSON.parse(JSON.stringify(this.selectedParts));
    const filtered = selectedParts
      .filter((item) => item.CASE_NO === (caseNo || item.CASE_NO))
      .reduce((list: any[], item: any) => {
        let foundMatched = list.find(
          (v) => v.PART_NO === item.PART_NO && v.UNIT_PRICE === item.UNIT_PRICE
        );

        if (!foundMatched) {
          count++;
          item.SEQ = count;
          list.push(item);
        } else {
          foundMatched.QTY = foundMatched.QTY + item.QTY;
          foundMatched.TOTAL_AMOUNT =
            foundMatched.QTY * foundMatched.UNIT_PRICE;
        }

        return list;
      }, []);

    return filtered;
  }

  public OnCloseDialog(evt: string) {
    this.modal.confirm(
      "Are you sure to close invoice?",
      this.viewref,
      () => {
        this.PrintDialog.Close();
      },
      () => { }
    );
  }
}
