import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewContainerRef, ViewChildren } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router, ActivatedRoute } from '@angular/router';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from '../../../core/global';


@Component({
  selector: 'SNWR024_UPC',
  templateUrl: './SNWR024_UPC.component.html',
  styleUrls: ['../warehouse.component.css']
})



export class SNWR024_UPCComponent implements OnInit {


  constructor(
    private HttpService: HttpService,
    private modal: ModalService,
    private viewRef: ViewContainerRef,
    private router: Router,
    private global: Globals,
    private route: ActivatedRoute
  ) {
  }

  @ViewChildren("input") Inputs: any;

  public fileUrl;

  public params: any = {};
  public invoiceDataList: any = [];
  public customerZone: any = 'UPC';
  public CustomerList: any = [];

  ngOnInit() {
    this.route.data.subscribe(data => {
      this.customerZone = data.customerZone
      this.GetInvoiceList();
    })
  }


  public GetInvoiceList() {

    // this.InvoiceListDialog.OpenDialog();
    this.HttpService.post("WH", "SNWR024_UPC_GetInvoiceLast", this.params).subscribe(
      (res) => {
        this.invoiceDataList = res.Table;
      },
      (err) => {
        console.log(err);
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewRef
        );
      }
    );
  }

  public GetData() {
    this.HttpService.post("WH", "SNWR024_UPC_GetInvoiceForPrint", this.params)
      .subscribe(result => {
        if (result.status === "Done") {
          if (this.params.INVOICE_NO_FROM == "X") {
            this.modal.info(
              "All new invoices have been printed label delivery completely",
              this.viewRef
            );
          } else {
            this.params.INVOICE_NO_FROM = result.invoiceNoFrom;
            this.params.INVOICE_NO_TO = result.invoiceNoTo;
          }
        }
      }, (err) => {
        console.log(err, 'err');
        this.modal.warning("Found an error, please contact support team", this.viewRef);
      })
    this.GetInvoiceList();
  }

  public OpenReport() {
    this.fileUrl = null;
    this.HttpService
      .Download("WH", "PrintDeliveryLabelUPC", {
        ReportPrefix: "PMS_RPT_WMS_DELIVERY_",
        ReportSuffix: ".PDF",
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_INVOICE_NO_FROM: this.params.INVOICE_NO_FROM,
        P_INVOICE_NO_TO: this.params.INVOICE_NO_TO
      })
      .subscribe((res) => {
        if (res) {
          this.SetIFrameContent(res);
          // this.showPrintButton = true;
        }
      });
  }

  //public PrintDelivery() {
  //  this.global.GoToReport("PMS_RPT_WMS_SNWR023_DELIVERY", {
  //    P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
  //    P_INVOICE_NO_FROM: this.params.INVOICE_NO_FROM,
  //    P_INVOICE_NO_TO: this.params.INVOICE_NO_TO,
  //  });
  //}

  public PrintDelivery(data) {
    this.fileUrl = null;
    this.HttpService
      .Download("WH", "PrintDeliveryLabelUPC", {
        ReportPrefix: "PMS_RPT_WMS_DELIVERY_",
        ReportSuffix: ".PDF",
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_INVOICE_NO_FROM: data.MIN_DOCUMENT_NO,
        P_INVOICE_NO_TO: data.MAX_DOCUMENT_NO
      })
      .subscribe((res) => {
        if (res) {
          this.SetIFrameContent(res);
          // this.showPrintButton = true;
        }
      });
  }

  private SetIFrameContent(content: any) {
    const file = new Blob([content], { type: content.type });
    const fileUrl = URL.createObjectURL(file);

    this.fileUrl = fileUrl;
  }

  focusInput(rowIdx: number) {
    let inputEls = this.Inputs.toArray();
    inputEls[rowIdx].nativeElement.focus();

  }

  shiftFocusDown(rowIdx: number) {
    rowIdx = Math.min(rowIdx + 1, 3);
    let inputEls = this.Inputs.toArray();
    if (inputEls[rowIdx].nativeElement.disabled == true) {
      this.shiftFocusDown(rowIdx)
    } else {
      this.focusInput(rowIdx);
    }

  }

  shiftFocusUp(rowIdx: number) {
    rowIdx = Math.max(0, rowIdx - 1);
    let inputEls = this.Inputs.toArray();
    if (inputEls[rowIdx].nativeElement.disabled == true) {
      this.shiftFocusUp(rowIdx)
    } else {
      this.focusInput(rowIdx);
    }

  }
}
