import {
  Component,
  ElementRef,
  HostListener,
  OnInit,
  ViewChild,
  ViewContainerRef,
} from "@angular/core";
import { HttpService } from "src/app/core/http.service";
import { ModalService } from "src/app/core/modal.service";
import { Observable, Subject } from "rxjs";
import {
  CaseNoExport,
  InvoiceExportControl,
  InvoiceExportControlSetValue,
} from "src/app/core/WHOutboundController/InvoiceControl";
import {
  PackExportToken,
  PackExportTokenExtractor
} from "src/app/core/WHOutboundController/PackTokenExtractor";
import { map } from "rxjs/operators";
import * as moment from "moment";
import { DialogTemplateComponent } from "src/app/components/shared/dialog-template/dialog-template.component";
import { Globals } from "src/app/core/global";

type ActionLog = {
  timestamp: moment.Moment;
  actionType: string;
  actionMessage: string;
};
@Component({
  selector: "SNWR027",
  templateUrl: "./SNWR027.component.html",
  styleUrls: ["./SNWR027.component.css"],
  providers: [PackExportTokenExtractor],
})
export class SNWR027Component implements OnInit {
  constructor(
    private Http: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private extractor: PackExportTokenExtractor,
    private global: Globals
  ) { }

  public selectedCases: CaseNoExport[];
  public customerInfo: {
    code: string;
    name: string;
    zone: string;
    routeCode: string;
    orderType: string;
    customerCode: string;
    customerName: string;
    branchCode: string;
    branchName: string;
  };
  public existItem: any;
  public caseTypeList: any = [];
  public qrString: string;
  public params: any = {};
  public totalItems: number = 0;
  public packingList: any = [];
  public packingList_unpack: any = [];
  public packingListFiltered: any = [];

  public selectedPartsFiltered: any[];
  public scannedCase: CaseNoExport;
  public scannedBaby: any;
  public scannedInner: any;
  public popupCase: CaseNoExport;
  public popupCaseExtension: any = [];
	public caseIsVanConfirmed: string;
	public caseIsPreInvoiced: string;
  private repackCase: boolean = false;
  public showHistory: boolean = false;

  public resultList: any;
  public checkBabyMode: boolean = false;

  @ViewChild("scannerInput", { read: ElementRef }) scannerInput: ElementRef;
  @ViewChild("inputCaseDialog") inputCaseDialog: DialogTemplateComponent;
  @ViewChild("saveCaseTypeButton", { read: ElementRef }) saveCaseTypeButton: ElementRef;

	public calculateData: any = [];
	@ViewChild("infoCaseDialog") infoCaseDialog: DialogTemplateComponent;

  public initialControl: InvoiceExportControl = new InvoiceExportControl();
  private initialControlSubject: Subject<InvoiceExportControlSetValue> = new Subject<InvoiceExportControlSetValue>();
  public actionLogs: ActionLog[] = [];
  private actionLogsSubject: Subject<ActionLog> = new Subject<ActionLog>();


  public lookupPickListNoConfig: any = {
    ColName: "PICKING_LIST_NO",
    PlaceholderText: "Select Picking List No.",
    SourceController: "WH",
    SourceMethodName: "SNWR027_GetPickListNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true,
  };

  public lookupOrderNoConfig: any = {
    ColName: "LOOKUP_ORDER_NO",
    PlaceholderText: "Select Order No",
    SourceController: "WH",
    SourceMethodName: "SNWR027_GetOrderNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      CUSTOMER_CODE: null,
      BRANCH_CODE: null,
    },
    UpperCase: true,
  };

  public lookupPickLotSeqConfig: any = {
    ColName: "LOOKUP_PICK_LOT_SEQ",
    PlaceholderText: "Select Pick Lot Seq",
    SourceController: "WH",
    SourceMethodName: "SNWR027_GetPickLotSeq",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params,
    },
    UpperCase: true,
  };

  ngOnInit() {
    this.InitialProcess();
    this.GetCaseType();
    this.initialControlSubject
      .pipe(map((control) => control))
      .subscribe((control) => {
        if (control) {
          this.initialControl.set(control);
          if (control.propName === "QR")
            this.SetScannedQR(this.initialControl.QR);
          // if (control.propName === "partNo")
          // 	this.SetScannedPart(this.initialControl.partNo);
          if (control.propName === "caseNoExport")
            this.SetScannedCase(this.initialControl.caseNoExport);
          if (control.propName === "baBy")
            this.SetScannedBaby(this.initialControl.baBy);
          if (control.propName === "caseType")
            this.SetScannedCaseType(this.initialControl.caseType);
          this.qrString = undefined;
        }
      });

    this.actionLogsSubject.subscribe((action: ActionLog) => {
      this.actionLogs.push(action);
      this.actionLogs = this.actionLogs.slice();
    });
  }

  private GetCaseType() {
    this.caseTypeList = []
    this.Http.get("WH", "SNWR027_GetCaseTypeAll")
      .subscribe(res => {
        this.caseTypeList = res.Table
      }, err => {
        console.log(err, 'err');
        this.modal.error("พบปัญหาการใช้งาน กรุณาแจ้งผู้ดูแลระบบ", this.viewref);
      })
  }

  private InitialProcess() {
    this.initialControl.reset();
    this.actionLogs = [];
    this.params = {};
    this.qrString = null;
    this.totalItems = 0;
    this.selectedCases = [];
    this.customerInfo = undefined;
    this.scannedCase = undefined;
    this.scannedBaby = undefined;
    this.scannedInner = undefined;
    this.packingList = [];
    this.packingList_unpack = [];
    this.packingListFiltered = [];
    this.selectedPartsFiltered = [];
		this.caseIsVanConfirmed = "N";
    this.caseIsPreInvoiced = "N";
  }

  public async Reset() {
    if (this.scannedCase) {
      this.modal.confirm("คุณแน่ใจที่จะแพ็คใหม่ใช่หรือไม่?", this.viewref, () => {
        const params = {
          DELETE_BY_USER: 'Y'
        }
        this.Http.post("WH", "SNWR027_ClearCaseExportTemp", params)
          .subscribe(
            (res) => {
              if (res) { 
                console.log("Done ClearInnerCaseExporTemp"); 
                this.InitialProcess();
              }
              else { console.log("Error ClearInnerCaseExporTemp"); }
            },
            (err) => {
              console.log(err, "error");
            }
          );
      });
    } else {
      this.InitialProcess();
    }
    this.scannerInput.nativeElement.focus();
  }

  public async Enter() {
    if (this.qrString?.trim() === "" || this.qrString == "" || !this.qrString) {
      return;
    }
    const value = this.qrString?.trim();
    try {
      const tokenDetail: PackExportToken = this.extractor.getToken(value);
      //Initial scan
      if (tokenDetail instanceof PackExportToken) {
        //Set QR code
        this.initialControlSubject.next({
          propName: "QR",
          value: tokenDetail
        });
      }
    }
    catch (ex) {
      if (ex === "Invalid QR") {
        let scanValue = value.split("-");
        if (scanValue.length == 2 && scanValue[0].toUpperCase() === "I") {
          if (!this.scannedCase) {
            let qrcode = null;
            qrcode = await this.CheckPackInnerCase(value)
              .then((res) => {
                const response = res[0];
                if (response.STATUS === "Done") {
                  return response.QRCODE;
                } else if (response.STATUS === "OnUsing") {
                  this.modal.warning("เคสนี้กำลังถูกใช้โดยพนักงานอื่น<br/>รหัสพนักงานที่ใช้งาน: " + response.USERS,
                    this.viewref,
                    () => {
                      this.ReFocus();
                    }
                  );
                } else {
                  this.modal.warning("ไม่พบข้อมูล",
                    this.viewref, () => { this.ReFocus() }
                  );
                  return null;
                }
              });

            if (qrcode) {
              const tokenDetail: PackExportToken = this.extractor.getToken(qrcode);
              //Initial scan
              if (tokenDetail instanceof PackExportToken) {
                //Set QR code
                this.existItem = { INNERCASE_NO: value, FROM_CHECK_EXIST_INNERCASE: true };
                this.initialControlSubject.next({
                  propName: "QR",
                  value: tokenDetail
                });
              }
            }
          } else {
            if (await this.CheckInnerCase(value)) {
              return null;
            } else {
              const checkType = this.caseTypeList.find(item => item.CASE_NAME == value);
              if (checkType) {
                this.initialControlSubject.next({
                  propName: "caseType",
                  value: value,
                });
              } else {
                this.modal.warning("ไม่พบข้อมูล",
                  this.viewref, () => { this.ReFocus() }
                );
              }
            }
          }
        }
        else if (scanValue.length == 3) {
          if (!this.scannedCase) {
            let qrcode = null;
            qrcode = await this.CheckPackBabyCard(value)
              .then((res) => {
                const response = res[0];
                if (response.STATUS === "Done") {
                  return response.QRCODE;
                } else if (response.STATUS === "OnUsing") {
                  this.modal.warning("เคสนี้กำลังถูกใช้โดยพนักงานอื่น<br/>รหัสพนักงานที่ใช้งาน: " + response.USERS,
                    this.viewref,
                    () => {
                      this.ReFocus();
                    }
                  );
                } else {
                  this.modal.warning("ไม่พบข้อมูล",
                    this.viewref, () => { this.ReFocus() }
                  );
                  return null;
                }
              });

            if (qrcode) {
              const tokenDetail: PackExportToken = this.extractor.getToken(qrcode);
              //Initial scan
              if (tokenDetail instanceof PackExportToken) {
                //Set QR code
                this.existItem = { BABYCARD_NO: value, FROM_CHECK_EXIST_BABYCARD: true };
                this.initialControlSubject.next({
                  propName: "QR",
                  value: tokenDetail
                });
              }
            }
          } else {
            const checkType = this.caseTypeList.find(item => item.CASE_NAME == value);
            if (checkType) {
              this.initialControlSubject.next({
                propName: "caseType",
                value: value,
              });
            } else {
              if (scanValue[0] !== this.customerInfo.customerCode) {
                this.modal.warning("รหัสลูกค้าไม่ตรงกับงานที่ทำอยู่",
                  this.viewref, () => { this.ReFocus() }
                );
              }
              else if (scanValue[0] === this.customerInfo.customerCode) {
                this.initialControlSubject.next({
                  propName: "baBy",
                  value: value,
                });
              } else {
                this.modal.warning("ไม่พบข้อมูล",
                  this.viewref, () => { this.ReFocus() }
                );
              }
            }
          }
        }
        else {
          if (!this.scannedCase) {
            this.modal.warning("กรุณาสแกนเปิดเคส",
              this.viewref, () => { this.ReFocus() }
            );
            return;
          }
          const checkType = this.caseTypeList.find(item => item.CASE_NAME == value);
          if (checkType) {
            this.initialControlSubject.next({
              propName: "caseType",
              value: value,
            });
          } else {
            this.modal.warning("ไม่พบข้อมูล",
              this.viewref, () => { this.ReFocus() }
            );
          }
        }

      }
      else {
        this.modal.warning("ข้อมูลที่สแกนไม่ถูกต้อง", this.viewref, () => { this.ReFocus() });
      }
    }
  }

  private SetCustomerInfo(packData: any) {
    const customerInfo = {
      code: `${packData.CUSTOMER_CODE}${packData.BRANCH_CODE}`,
      name: `${packData.CUSTOMER_NAME}${packData.BRANCH_NAME ?? ""}`,
      zone: packData.CUSTOMER_ZONE,
      routeCode: packData.ROUTE_CODE,
      orderType: packData.ORDER_TYPE,
      customerCode: packData.CUSTOMER_CODE,
      customerName: packData.CUSTOMER_NAME,
      branchCode: packData.BRANCH_CODE,
      branchName: packData.BRANCH_NAME
    };
    if (!this.customerInfo) {
      this.customerInfo = customerInfo;
    }

    if (this.customerInfo && this.packingList.length === 0) {
      this.customerInfo = customerInfo;
    }

    if (this.customerInfo.code != customerInfo.code) {
      this.modal.warning("รหัสลูกค้าไม่ตรงกับงานที่ทำอยู่", this.viewref, () => { this.ReFocus() });
      return false;
    }
    if (this.customerInfo.orderType != packData.ORDER_TYPE) {
      this.modal.warning("ประเภทออร์เดอร์ไม่ถูกต้อง", this.viewref, () => { this.ReFocus() });
      return false;
    }
    return true;
  }

  private SetScannedQR(packToken: PackExportToken) {
    if (packToken.PROCESS != "PackExport") {
      this.modal.warning("ข้อมูลที่สแกนไม่ถูกต้อง", this.viewref, () => { this.ReFocus() });
      return;
    }
    const customerCode = packToken.CUSTOMER_CODE;
    const branchCode = packToken.BRANCH_CODE;
    const orderType = packToken.ORDER_TYPE;
    const caseNo = packToken.CASE_NO;
    const foundCase = this.selectedCases.find((item) =>
      item.customerCode === customerCode &&
      item.branchCode === branchCode &&
      item.orderType === orderType &&
      item.caseNo === caseNo
    );
    if (foundCase) {
      this.initialControlSubject.next({
        propName: "caseNoExport",
        value: foundCase
      });
    } else {
      this.GetCaseNo(packToken).then((res) => {
        if (res)
          if (res.Result === "Done") {
            const caseData = res.Data[0] || undefined;
            if (!this.SetCustomerInfo(caseData)) {
              return;
            }
            const caseNoExport: CaseNoExport = new CaseNoExport(
              caseData.CUSTOMER_CODE,
              caseData.CUSTOMER_NAME,
              caseData.BRANCH_CODE,
              caseData.BRANCH_NAME,
              caseData.ORDER_TYPE,
              caseData.CASE_NO,
              caseData.CASE_DATE,
              null,
              null,
              caseData.ORDER_TYPE
            );
            this.initialControlSubject.next({
              propName: "caseNoExport",
              value: caseNoExport
            });
          }
          else if (res.Result === "Exist") {
            this.modal.confirm(
              "หมายเลขเคสถูกใช้งานแล้ว<br>คุณต้องการที่จะเปิดกล่องเพื่อแก้ไข ใช่หรือไม่?",
              this.viewref,
              () => {
                this.GetCaseDetail(packToken);
              },
              () => {
                this.ReFocus();
              }
            );
          }
          else if (res.Result === "Invoice") {
            this.modal.confirm(
              "ไม่สามารถใช้เคสนี้ได้<br>เนื่องจากมีการออก invoice หรือ pre-invoice แล้ว<br>คุณต้องการที่จะเปิดกล่องเพื่อดูข้อมูลใช่หรือไม่",
              this.viewref,
              () => {
                this.GetCaseDetail(packToken);
              },
              () => {
                this.ReFocus();
              }
            );
          }
          else if (res.Result === "OnUsing") {
            this.modal.warning(
              "เคสนี้กำลังถูกใช้โดยพนักงานอื่น<br/>รหัสพนักงานที่ใช้งาน: " + res.User,
              this.viewref,
              () => {
                this.ReFocus();
              }
            );
          }
          else { }
      });
    }
  }

  private SetScannedCase(CaseNo?: CaseNoExport) {
    if (CaseNo) {
      let foundIndex = this.selectedCases.findIndex((item) =>
        item.customerCode === CaseNo.customerCode &&
        item.branchCode === CaseNo.branchCode &&
        item.orderType === CaseNo.orderType &&
        item.caseNo === CaseNo.caseNo
      );
      if (foundIndex < 0) {
        if (this.selectedCases.length > 0) {
          if (this.packingList.length === 0 || this.caseIsVanConfirmed == 'Y' || this.caseIsPreInvoiced == 'Y') {
            this.selectedCases = [];
            this.packingList = [];
            this.packingList_unpack = [];
            this.packingListFiltered = [];
						this.caseIsVanConfirmed = "N";
            this.caseIsPreInvoiced = 'N';
            this.repackCase = false;
          }
          else {
            this.modal.warning("กรุณาทำเคสนี้ให้จบก่อน", this.viewref, () => { this.ReFocus() });
            return;
          }
        }
        CaseNo.caseType = CaseNo.caseType;
        this.scannedCase = CaseNo;
        this.selectedCases.push(CaseNo);
        this.actionLogsSubject.next({
          timestamp: moment(),
          actionType: "Scan Case",
          actionMessage: `${CaseNo.caseNo}, ${CaseNo.orderType}, ${CaseNo.customerCode}`,
        });
      } else {
        this.scannedCase = this.selectedCases[foundIndex];
      }
      if (this.existItem?.FROM_CHECK_EXIST_BABYCARD) {
        const babycard = JSON.parse(JSON.stringify(this.existItem.BABYCARD_NO));
        this.initialControlSubject.next({
          propName: "baBy",
          value: babycard
        });
      } else if (this.existItem?.FROM_CHECK_EXIST_INNERCASE) {
        const innerCase = JSON.parse(JSON.stringify(this.existItem.INNERCASE_NO));
        this.CheckInnerCase(innerCase);
      } else {
        this.ReFocus();
      }
      // if (!this.repackCase) {
      // 	this.OpenCaseTypeDialog();
      // }
    }
  }

  private async SetScannedBaby(babyNo: string) {
    let caseType = babyNo.substring(babyNo.lastIndexOf('-') + 1) == 'A' ? 'AIR' : 'SEA';
    if (caseType !== this.scannedCase.caseGroup) {
      this.modal.warning("Baby ผิดออเดอร์ Class", this.viewref, () => { this.ReFocus() });
      return;
    }
    let foundBaby: any;
    foundBaby = this.packingList.find((item) =>
      item.BABYCARD_NO == babyNo
    );
    if (foundBaby) {
      this.scannedBaby = foundBaby;
      this.scannedInner = undefined;
      if (this.existItem?.FROM_CHECK_EXIST_BABYCARD) {
        this.existItem = undefined;
      } else {
        this.modal.warning("สแกนเบบี้การ์ดตรงกับรายการที่กำลังดำเนินการอยู่",
          this.viewref, () => { this.ReFocus() }
        );
      }
      this.ReFocus();
      return;
    }

    await this.GetReceiveDetail(babyNo)
      .then(res => {
        let babyData;
        const babyData_search = res.Table[0] || undefined;
        const babyData_unpack = this.packingList_unpack.find(item => item.BABYCARD_NO == babyNo && !item.INNER_CASE_NO) || undefined;
        if (babyData_search) {
          if (babyData_search.MESSAGE == "BABYCARD_ALREADY_PACKED" && !babyData_unpack) {
            this.modal.warning("ไม่สามารถทำรายการนี้ได้ babycard นี้ถูกทำแพคลงลังแล้ว", this.viewref, () => { this.ReFocus() });
            return;
          }
        }
        if (babyData_unpack) {
          babyData = { ...babyData_search, ...babyData_unpack };
        } else {
          babyData = babyData_search;
        }

        if (babyData) {
          if (!this.SetCustomerInfo(babyData)) {
            return;
          }
        } else {
          this.modal.warning("ไม่พบข้อมูล", this.viewref, () => { this.ReFocus() });
					return;
        }

        if (babyData) {
          babyData.PACK_QTY = babyData.RECEIVE_QTY;
          this.scannedBaby = babyData;
          this.scannedInner = undefined;
        }

        if (babyData) {
          let caseItemLength = this.packingList.length;
          let packingData = JSON.parse(JSON.stringify(this.scannedBaby));
          packingData.CASE_NO = this.scannedCase.caseNo;
          packingData.CASE_DATE = this.scannedCase.caseDate;
          packingData.CASE_TYPE = this.scannedCase.caseType;
          packingData.CASE_NAME = this.scannedCase.caseName;
          packingData.PACK_QTY = babyData.RECEIVE_QTY;
          packingData.CASE_SEQ = caseItemLength + 1;
          this.packingList.push(packingData);
          this.packingList.sort((a, b) => b.CASE_SEQ - a.CASE_SEQ);
          this.actionLogsSubject.next({
            timestamp: moment(),
            actionType: "Scan Baby",
            actionMessage: `${packingData.BABYCARD_NO}`,
          });
          this.FilterTableData();
          this.ReFocus();
        }
      })
  }

  private async GetReceiveDetail(babyNo: string) {
    return await this.Http
      .get("WH", "SNWR027_GetData", babyNo)
      .toPromise()
      .catch((err) => {
        console.log(err, 'err');
        this.modal.warning("พบปัญหาการใช้งาน กรุณาแจ้งผู้ดูแลระบบ", this.viewref);
      });
  }

  private async SetScannedCaseType(type: string) {
    const data = this.caseTypeList.find(item => item.CASE_NAME == type) || undefined;
    if (data) {
      let foundCase = this.selectedCases.find((item) =>
        item.customerCode === this.scannedCase.customerCode &&
        item.branchCode === this.scannedCase.branchCode &&
        item.orderType === this.scannedCase.orderType &&
        item.caseNo === this.scannedCase.caseNo
      );
      foundCase.caseType = data.CASE_TYPE;
      foundCase.caseName = data.CASE_NAME;
      this.scannedCase.caseType = data.CASE_TYPE;
      this.scannedCase.caseName = data.CASE_NAME;
      this.packingList.map((item) => {
        item.CASE_TYPE = data.CASE_TYPE;
        item.CASE_NAME = data.CASE_NAME;
      });
      this.actionLogsSubject.next({
        timestamp: moment(),
        actionType: "Scan Type",
        actionMessage: `${this.scannedCase.caseName} - ${this.scannedCase.caseType}`,
      });
      this.ReFocus();
    }
    else {
      this.modal.warning("ไม่พบข้อมูล", this.viewref, () => { this.ReFocus() });
    }
  }

  private async GetCaseNo(packToken: PackExportToken) {
    return await this.Http
      .get("WH", "SNWR027_GetAvailableCase"
        , packToken.CUSTOMER_CODE
        , packToken.BRANCH_CODE
        , packToken.ORDER_TYPE
        , packToken.CASE_NO)
      .toPromise()
      .catch((err) => {
        console.log(err, 'err');
        this.modal.error(
          "พบปัญหาการใช้งาน กรุณาแจ้งผู้ดูแลระบบ",
          this.viewref,
          () => {
            this.scannerInput.nativeElement.focus();
          }
        );
      });
  }

  private async GetCaseDetail(packToken: PackExportToken) {
    this.Http
      .get("WH", "SNWR027_GetCaseInfo"
        , packToken.CUSTOMER_CODE
        , packToken.BRANCH_CODE
        , packToken.CASE_GROUP
        , packToken.CASE_NO)
      .subscribe(
        (res) => {
          if (res.status == "Done") {
            const caseData = res.Data[0] || undefined;
            this.customerInfo = undefined;
            if (!this.SetCustomerInfo(caseData)) {
              return;
            }
            this.selectedCases = [];
            this.scannedCase = undefined;
            this.scannedBaby = undefined;
            this.scannedInner = undefined;

            this.packingList = res.Data;
            this.packingList_unpack = JSON.parse(JSON.stringify(res.Data));
            this.caseIsVanConfirmed = caseData.IS_VAN_CONFIRMED;
            this.caseIsPreInvoiced = caseData.IS_PRE_INVOICED;
            //this.packingList = [...this.packingList, ...res.Data];
            let checkCase: CaseNoExport = new CaseNoExport(
              caseData.CUSTOMER_CODE,
              caseData.CUSTOMER_NAME,
              caseData.BRANCH_CODE,
              caseData.BRANCH_NAME,
              caseData.ORDER_TYPE,
              caseData.CASE_NO,
              caseData.CASE_DATE,
              caseData.CASE_TYPE,
              caseData.CASE_NAME,
              caseData.CASE_GROUP
            );
            this.repackCase = true;
            this.initialControlSubject.next({
              propName: "caseNoExport",
              value: checkCase
            });
            setTimeout(() => {
              this.FilterTableData();
            }, 200);
          }
          else if (res.status == "OnUsing") {
            this.modal.warning("เคสนี้กำลังถูกใช้โดยพนักงานอื่น<br/>รหัสพนักงานที่ใช้งาน: " + res.User,
              this.viewref,
              () => {
                this.ReFocus();
              }
            );
          }
          else {
            this.modal.warning("ไม่พบข้อมูล",
              this.viewref, () => { this.ReFocus(); }
            );
          }
        },
        (err) => {
          console.log(err, 'err');
          this.modal.error("พบปัญหาการใช้งาน กรุณาแจ้งผู้ดูแลระบบ", this.viewref,
            () => {
              this.ReFocus();
            });
        });
  }

  private async CheckPackBabyCard(baByNo: string) {
    return await this.Http
      .post("WH", "SNWR027_CheckPackBabyCard", { BABYCARD_NO: baByNo })
      .toPromise()
      .catch((err) => {
        console.log(err, 'err');
        this.modal.error("พบปัญหาการใช้งาน กรุณาแจ้งผู้ดูแลระบบ", this.viewref,
          () => {
            this.ReFocus();
          });
      });
  }

  private async CheckPackInnerCase(innerCaseNo: string) {
    return await this.Http
      .post("WH", "SNWR027_CheckPackInnerCase", { INNERCASE_NO: innerCaseNo })
      .toPromise()
      .catch((err) => {
        console.log(err, 'err');
        this.modal.error("พบปัญหาการใช้งาน กรุณาแจ้งผู้ดูแลระบบ", this.viewref,
          () => {
            this.ReFocus();
          });
      });
  }

  public ConfirmCase() {
    if (!this.ValidateCustomerCaseType()) {
      this.modal.warning("กรุณาเลือกประเภทเคสให้ถูก<br/>สแกนเคสเพื่อเลือกอีกครั้ง", this.viewref,
        () => {
          this.ReFocus();
        }
      );
      return;
    }

    if (this.CheckPackComplete()) {
      this.modal.warning("กรุณาแพ็คงานให้เสร็จ", this.viewref,
        () => {
          this.ReFocus();
        }
      );
      return;
    }

    if (this.packingList.length < 1) {
      this.modal.warning("กรุณาสแกนเบบี้การ์ด", this.viewref,
        () => {
          this.ReFocus();
        }
      );
      return;
    }

    if (!this.scannedCase.caseType) {
      this.modal.warning("กรุณาสแกนประเภทของเคส", this.viewref,
        () => {
          this.ReFocus();
        }
      );
      return;
    }
    this.modal.confirm("คุณต้องการบันทึกการทำงานใช่หรือไม่?"
      + "<br>[Selected : " + this.totalItems + " Items]",
      this.viewref,
      () => {
        this.Http.post("WH", "SNWR027_IssueCase", {
          scannedCase: this.scannedCase,
          packingList: this.packingList
        })
          .subscribe(
            (res) => {
              if (res.status === "Done") {
                this.modal.info("บันทึกเสร็จสิ้น", this.viewref,
                  () => {
                    this.ReFocus();
                  });
                this.InitialProcess();
              }
              else if (res.status === "Fail") {
                this.modal.error(res.message, this.viewref,
                  () => {
                    this.ReFocus();
                  });
              }
            },
            (err) => {
              console.log(err, 'err');
              this.modal.error("พบปัญหาการใช้งาน กรุณาแจ้งผู้ดูแลระบบ", this.viewref,
                () => {
                  this.ReFocus();
                });
            }
          );
      },
      () => { this.ReFocus() }
    );
  }

  public EditCaseNo(CaseNo: CaseNoExport) {
    this.popupCase = JSON.parse(JSON.stringify(CaseNo));
    this.inputCaseDialog.OpenDialog();
  }

  public SaveCaseType(CaseNo: CaseNoExport) {
    if (CaseNo.caseName) {
      // if(  (this.popupCaseExtension.grossWeight  == null || this.popupCaseExtension.grossWeight  == ''|| typeof this.popupCaseExtension.grossWeight  == 'undefined')
      //   || (this.popupCaseExtension.grossMM == null || this.popupCaseExtension.grossMM == ''|| typeof this.popupCaseExtension.grossMM == 'undefined')
      //   || (this.popupCaseExtension.caseWidth  == null || this.popupCaseExtension.caseWidth  == ''|| typeof this.popupCaseExtension.caseWidth  == 'undefined')
      //   || (this.popupCaseExtension.caseLength == null || this.popupCaseExtension.caseLength == ''|| typeof this.popupCaseExtension.caseLength == 'undefined')
      //   || (this.popupCaseExtension.caseHeight == null || this.popupCaseExtension.caseHeight == ''|| typeof this.popupCaseExtension.caseHeight == 'undefined')
      //   || (this.popupCaseExtension.caseWeight == null || this.popupCaseExtension.caseWeight == ''|| typeof this.popupCaseExtension.caseWeight == 'undefined')
      //    ){
      //   this.modal.warning("กรุณาระบุข้อมูลให้ครบก่อนดำเนินการ", this.viewref);
      //   return;
      // }
      // if (this.params.CUSTOMER_ZONE === "UPC" && !["BOX", "PIECE"].includes(CaseNo.caseType)) {
      //   this.modal.warning("กรุณาเลือกประเภทเคสให้ถูก", this.viewref);
      //   return;
      // }

      let foundIndex = this.selectedCases.findIndex(
        (item) => item.caseNo === CaseNo.caseNo
      );
      let findCaseType = this.caseTypeList.find(x => x.CASE_NAME == CaseNo.caseName)
      //this.scannedCase = CaseNo;
      CaseNo.caseType = findCaseType.CASE_TYPE
      this.scannedCase = { ...CaseNo, ...this.popupCaseExtension };
      if (foundIndex < 0) {
        this.selectedCases.push({ ...CaseNo, ...this.popupCaseExtension });
        //this.scannedCase.index = this.selectedCases.length + 1;
      } else {
        const caseNo = this.selectedCases.find((item) => item.caseNo === CaseNo.caseNo).caseNo;
        this.selectedCases[foundIndex] = { ...CaseNo, ...this.popupCaseExtension };
        // this.selectedCases = this.selectedCases.map(items => {
        //   if (items.caseNo === caseNo) {
        //     return {...items,...this.popupCaseExtension};
        //   }
        //   return items;
        // });
        //this.scannedCase.index = foundIndex + 1;
      }
      this.packingList.map((item) => {
        item.CASE_TYPE = findCaseType.CASE_TYPE;
        item.CASE_NAME = findCaseType.CASE_NAME;
      });
      this.inputCaseDialog.Close();
      this.scannerInput.nativeElement.focus();
    } else {
      this.modal.warning("กรุณาเลือกประเภทเคส", this.viewref);
    }
  }

  public CancelSaveCase(CaseNo: CaseNoExport) {
    this.inputCaseDialog.Close();
    this.scannerInput.nativeElement.focus();
  }

  public ClearCase() {
    const is_packed = this.repackCase;//this.packingList.some(x => x.IS_PACKED == "Y");
    this.modal.confirm(
      (is_packed ? "เคสนี้ได้ทำการแพคในระบบแล้ว<br>" : "") +
      "คุณแน่ใจที่จะลบเคสนี้ใช่หรือไม่?",
      this.viewref,
      () => {
        //if (this.packingList.length > 0) {
        if (is_packed) {
          const params = {
            scannedCase: this.scannedCase,
          }
          this.Http.post("WH", "SNWR027_ClearCaseExport", params)
            .subscribe(
              (res) => {
                if (res.status == "Done") {
                  this.InitialProcess();
                  this.modal.info("ข้อมูลเคสได้ทำถูกลบออกระบบ", this.viewref, () => {
                    this.ReFocus();
                  });
                } else {
                  console.log(res.Message, 'err');
                  this.modal.error("ไม่สามารถบันทึกได้ กรุณาแจ้งผู้ดูแลระบบ", this.viewref,
                    () => {
                      this.ReFocus();
                    });
                }
              },
              (err) => {
                console.log(err, 'err');
                this.modal.error("พบปัญหาการใช้งาน กรุณาแจ้งผู้ดูแลระบบ", this.viewref,
                  () => {
                    this.ReFocus();
                  });
              })
        } else {
          this.InitialProcess();
        }
        //}
      },
      () => {
        this.ReFocus();
      }
    );
  }

  public DeleteCard(packingItem: any) {
    this.modal.confirm(
      (packingItem.IS_INNER_CASE == 'Y'
        ? "ข้อมูลทั้งหมดของเคสย่อยนี้จะถูกลบออกทั้งหมด" + "<br>" + "คุณต้องการลบข้อมูลเคสนี้ ใช่หรือไม่?"
        : "คุณต้องการลบข้อมูลเบบี้การ์ดนี้ ใช่หรือไม่?"),
      this.viewref,
      () => {
        if (packingItem.IS_INNER_CASE == 'Y') {
          let caseseq = 0;
          this.packingList = this.packingList.filter(item => item.INNER_CASE_NO !== packingItem.INNER_CASE_NO);
          this.packingList.map(item => item.CASE_SEQ = caseseq++);
          const params = {
            CASE_NO: packingItem.INNER_CASE_NO
          }
          this.Http.post("WH", "SNWR039_ClearInnerCaseExportTemp", params)
            .subscribe(
              (res) => {
                if (res) { console.log("Done ClearInnerCaseExporTemp"); }
                else { console.log("Error ClearInnerCaseExporTemp"); }
              },
              (err) => {
                console.log(err, "error");
              }
            );
          this.actionLogsSubject.next({
            timestamp: moment(),
            actionType: "Delete Inner",
            actionMessage: `${packingItem.INNER_CASE_NO}`,
          });
        } else {
          let caseseq = 0;
          let index = this.packingList.findIndex(item => item.BABYCARD_NO == packingItem.BABYCARD_NO);
          this.packingList.splice(index, 1);
          this.packingList.map(item => item.CASE_SEQ = caseseq++);
          this.actionLogsSubject.next({
            timestamp: moment(),
            actionType: "Delete Baby",
            actionMessage: `${packingItem.BABYCARD_NO}`,
          });
        }
        if (this.packingList.length == 0) {
          this.scannedBaby = undefined;
        }
        this.FilterTableData();
        this.ReFocus();
      },
      () => {
        this.ReFocus();
      }
    );
  }

  public ReFocus() {
    setTimeout(() => {
      this.qrString = null;
      this.scannerInput.nativeElement.focus();
    }, 200);
  }

  private ValidateCustomerCaseType(): boolean {
    // if (
    // 	this.customerInfo?.zone.substring(0, 3) == "UPC" &&
    // 	this.selectedCases.find(
    // 		(item) => !["BOX", "PIECE"].includes(item.caseType)
    // 	)
    // ) {
    // 	return false;
    // }

    return true;
  }

  private async CheckInnerCase(caseNo: string) {
    let isInnerCase: boolean = false;
    await this.Http
      .get("WH", "SNWR027_GetAvailableInnerCase", caseNo)
      .toPromise()
      .then((res) => {
        if (res.status === "Done") {
					let innerPackData = res.Data || undefined;
          if (innerPackData.length > 0) {
            isInnerCase = true;
            if (this.customerInfo.customerCode != innerPackData[0].CUSTOMER_CODE) {
              this.modal.warning("รหัสลูกค้าไม่ตรงกับงานที่ทำอยู่",
                this.viewref, () => { this.ReFocus() }
              );
              return isInnerCase;
            }
            if (this.customerInfo.orderType !== innerPackData[0].ORDER_TYPE) {
              this.modal.warning("Baby ผิดออเดอร์ Class",
                this.viewref, () => { this.ReFocus() }
              );
              return isInnerCase;
            }

            // if (!this.SetCustomerInfo(innerPackData[0])) {
            // 	return isInnerCase;
            // }

            const foundInner = this.packingList.find((item) =>
              item.INNER_CASE_NO === caseNo
            )
            if (foundInner) {
              this.initialControl.latestScanned = null;
              this.initialControl.baBy = null;
              this.scannedBaby = undefined;
              this.scannedInner = foundInner;
              if (this.existItem?.FROM_CHECK_EXIST_INNERCASE) {
                this.existItem = undefined;
              } else {
                this.modal.warning("สแกนเคสย่อยตรงกับเคสที่กำลังดำเนินการอยู่",
                  this.viewref, () => { this.ReFocus() }
                );
              }
              this.ReFocus();
              return isInnerCase;
            }

            if (innerPackData[0].OUTER_CASE && innerPackData[0].OUTER_CASE != this.scannedCase.caseNo) {
              this.modal.warning("หมายเลขเคสย่อยนี้ถูกบันทึกลงเคสอื่นเรียบร้อยแล้ว",
                this.viewref,
                () => {
                  this.ReFocus();
                }
              );
              return isInnerCase;
            }

            let caseItemLength = this.packingList.length;
            let i = 1;
            innerPackData.map((item) => {
              item.IS_INNER_CASE = 'Y'
              item.INNER_CASE_NO = caseNo;
              item.CASE_NO = this.scannedCase.caseNo;
              item.CASE_DATE = this.scannedCase.caseDate;
              item.CASE_TYPE = this.scannedCase.caseType;
              item.CASE_NAME = this.scannedCase.caseName;
              item.CASE_SEQ = caseItemLength + i;
              i++;
              return { ...item };
            })
            //this.repackCase = false;
            this.initialControl.latestScanned = null;
            this.initialControl.baBy = null;
            this.scannedBaby = undefined;
            this.scannedInner = innerPackData[0];
            this.packingList.push(...innerPackData);
            this.packingList.sort((a, b) => b.CASE_SEQ - a.CASE_SEQ);
            this.actionLogsSubject.next({
              timestamp: moment(),
              actionType: "Scan Inner",
              actionMessage: `${innerPackData[0].CASE_NO}`,
            });
            this.FilterTableData();
          }
          else {
            isInnerCase = false;
            return isInnerCase;
          }
        }
        else if (res.status === "OnUsing") {
          this.modal.warning(
            "เคสนี้กำลังถูกใช้โดยพนักงานอื่น<br/>รหัสพนักงานที่ใช้งาน: " + res.User,
            this.viewref,
            () => {
              this.ReFocus();
            }
          );
          isInnerCase = true;
          return isInnerCase;
        }
      })
      .catch((err) => {
        console.log(err, 'err');
        this.modal.error("พบปัญหาการใช้งาน กรุณาแจ้งผู้ดูแลระบบ", this.viewref, () => { this.ReFocus() });
      });

    return isInnerCase;
  }

  private CheckCompleteBaby() {
    let checkbaBy = this.packingList.some(x => x.BABYCARD_NO == this.initialControl.baBy && x.PACK_QTY != x.RECEIVE_QTY)

    if (checkbaBy) {
      this.modal.warning("กรุณาแพ็คงานให้เสร็จ", this.viewref);
      this.scannerInput.nativeElement.focus();
    }
    return checkbaBy;
  }

  private CheckDupBaby(babyNo: string) {
    let checkbaBy = this.packingList.some(x => x.BABYCARD_NO == babyNo)
    // if (checkbaBy) {
    // 	this.modal.warning("กรุณาแพ็คงานให้เสร็จ", this.viewRef);
    // 	//this.scannerInput.nativeElement.focus();
    // }
    return checkbaBy;
  }

  private CheckPackComplete() {
    return this.packingList.some(x => x.PACK_QTY != x.RECEIVE_QTY);
  }

  public FilterTableData() {
    //Get total items
    this.totalItems = this.packingList.length;
    //Get filtered part
    this.packingListFiltered = this.packingList.filter(
      (row) => row.BABYCARD_NO
    );

    //Filter show data
    this.FilterInstrutionParts(this.scannedCase?.caseNo);
  }

  private FilterInstrutionParts(caseNo: string) {
    caseNo = caseNo === "All" ? null : caseNo;
    this.selectedPartsFiltered = this.GetFilteredInstrutionParts(caseNo);
  }

  private GetFilteredInstrutionParts(caseNo: string) {
    //Group part number
    let count = 0;
    const selectedParts = JSON.parse(JSON.stringify(this.packingListFiltered.sort(function (a, b) {
      return a.PART_NO.localeCompare(b.PART_NO) && (a.INSTRUCTION_NO > b.INSTRUCTION_NO ? 1 : -1);
    })));
    const filtered = selectedParts
      .filter((item) => item.CASE_NO === (caseNo || item.CASE_NO))
      .reduce((list: any[], item: any) => {
        let foundMatched = list.find((v) =>
          v.PART_NO === item.PART_NO &&
          v.INSTRUCTION_NO === item.INSTRUCTION_NO
        );

        if (!foundMatched) {
          count++;
          item.SEQ = count;
          list.push(item);
        } else {
          foundMatched.PACK_QTY = foundMatched.PACK_QTY + item.PACK_QTY;
          foundMatched.TOTAL_AMOUNT = foundMatched.PACK_QTY * foundMatched.UNIT_PRICE;
        }

        return list;
      }, []);
    return filtered;
  }

	public OpenInfoCaseDialog(){
		let foundItem: any;
		const instructionFiltered = this.packingList
			.reduce((list: any[], item: any) => {
				let foundItem = list.find((x) => x.INSTRUCTION_NO === item.INSTRUCTION_NO);
				if (!foundItem) {
					list.push(item);
				}
				return list;
			}, []);

		let totalqty = 0;
		const babyFiltered = this.packingList
			.reduce((list: any[], item: any) => {
				foundItem = list.find((x) => x.BABYCARD_NO === item.BABYCARD_NO);
				if (!foundItem) {
					list.push(item);
					totalqty = totalqty + item.PACK_QTY
				}
				return list;
			}, []);

		this.calculateData = {
			TOTAL_INSTRUCTION: instructionFiltered.length
			, TOTAL_BABYCARD: babyFiltered.length
			, TOTAL_QTY: totalqty
		};

		this.infoCaseDialog.width = "67.5vw";
		this.infoCaseDialog.height = "60vh";
		this.infoCaseDialog.title = "Case list: " + this.scannedCase.customerCode + "-"  + this.scannedCase.orderType + "-" + this.scannedCase.caseNo;
		this.infoCaseDialog.OpenDialog();
	}

  @HostListener("window:keydown", ["$event"])
  async onKeyDown(event: KeyboardEvent) {
    if (
      event.key.toUpperCase() === "ENTER" &&
      (<HTMLElement>event.target).id.toUpperCase() === "QRINPUT"
    ) {
      this.Enter();
    }
  }
}
