import { Component, OnInit, ViewContainerRef } from "@angular/core";
import { HttpService } from "src/app/core/http.service";
import { ModalService } from "src/app/core/modal.service";
import { Globals } from "src/app/core/global";

@Component({
  selector: "SNWR028",
  templateUrl: "SNWR028.component.html",
})
export class SNWR028Component implements OnInit {
  constructor(
    private modal: ModalService,
    private viewRef: ViewContainerRef,
    private http: HttpService,
    private global: Globals
  ) {}

  public params: any = {};
  public paramsReprint: any = {};
  public customerCode: any;
  public branchCode: any;
  public orderType: any;
  public caseNoFrom: any;
  public caseNoTo: any;
  public fileUrl;

  public lookupCustomerCodeConfig: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "WH",
    SourceMethodName: "SNWR028_GetCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }
  public SetSelectedCustomerCode(values: any) {
    this.params.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.params.CUSTOMER_NAME = values.CUSTOMER_NAME;
  }
  public SetSelectedCustomerCodeReprint(values: any) {
    this.paramsReprint.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.paramsReprint.CUSTOMER_NAME = values.CUSTOMER_NAME;
    this.paramsReprint.CASE_NO_FROM = undefined;
    this.paramsReprint.CASE_NO_TO = undefined;
  }

  public lookupReprintFrom: any = {
    ColName: "LOOKUP_CASE_NO_REPRINT",
    PlaceholderText: "Select Case No.",
    SourceController: "WH",
    SourceMethodName: "SNWR028_GetCaseNoReprintFrom",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.paramsReprint
    },
    UpperCase: true
  }
  public SetSelectedReprintFrom(values: any) {
    this.paramsReprint.CASE_NO_FROM = values.CASE_NO;
  }
  public lookupReprintTo: any = {
    ColName: "LOOKUP_CASE_NO_REPRINT",
    PlaceholderText: "Select Case No.",
    SourceController: "WH",
    SourceMethodName: "SNWR028_GetCaseNoReprintTo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.paramsReprint
    },
    UpperCase: true
  }
  public SetSelectedReprintTo(values: any) {
    this.paramsReprint.CASE_NO_TO = values.CASE_NO;
  }


  public ngOnInit() {
    this.params.PRINT_NUMBER = 0;
  }


  public Print() {
    this.global.GoToReport("PMS_RPT_WMS_SNWR028_CASE", {
      P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      P_CUSTOMER_CODE: this.customerCode,
      P_BRANCH_CODE: this.branchCode,
      P_ORDER_TYPE: this.orderType,
      P_CASE_NO_FROM: this.caseNoFrom,
      P_CASE_NO_TO: this.caseNoTo,
    }, true, false);
  }

  public FindCaseNo() {
    this.http.post("WH", "SNWR028_Get_Case_Number", this.params).subscribe(
      (res) => {
        if (res.Table[0]) {
          const case_no = res.Table[0].CASE_NO;
          this.global.GoToReport("PMS_RPT_WMS_SNWR028_CASE", {
            P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
            P_CASE_NO_FROM: case_no,
            P_CASE_NO_TO: case_no,
          });
        } else {
          this.modal.error("Unavailable Case Number.", this.viewRef);
        }
      },
      (err) => {
        console.log(err);
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewRef
        );
      }
    );
  }

  public PreviewCaseNumber() {
    if (typeof this.params.CUSTOMER_CODE =='undefined' || this.params.CUSTOMER_CODE == ''){
      this.modal.warning("Please select Customer before printing the baby card.", this.viewRef);
    } 
    else if (typeof this.params.ORDER_TYPE =='undefined' || this.params.ORDER_TYPE == ''){
      this.modal.warning("Please select Order Type.", this.viewRef);
    } 
    else if (this.params.PRINT_NUMBER < 1) {
      this.modal.warning("Package QTY must be more than 0.", this.viewRef);
    }
    else {
      this.http
        .post("WH", "SNWR028_Print_Case_Number", this.params)
        .subscribe((res) => {
          if (res.Result == "Done") {
            this.customerCode = res.CustomerCode;
            this.branchCode = res.BranchCode;
            this.orderType = res.OrderType;
            this.caseNoFrom = res.CaseNoFrom;
            this.caseNoTo = res.CaseNoTo;
            this.params.isPreview = true;
            this.modal.info(
              `Preview Case Number : <BR>${res.CustomerCode}-${res.CaseNoFrom} to ${res.CustomerCode}-${res.CaseNoTo}`,
              this.viewRef,
              () => {
                this.Preview();
                //this.params.PRINT_NUMBER = 0;
              }
              ,{height: "16rem"}
            );
          }
        },
        (err) => {
          console.log(err);
          this.modal.warning(
            "Found an error, please contact support team",
            this.viewRef
          );
        });
    }
  }

  public PreviewCaseNumberReprint() {
    if (typeof this.paramsReprint.CUSTOMER_CODE =='undefined' || this.paramsReprint.CUSTOMER_CODE == ''){
      this.modal.warning("Please select Customer before printing the baby card.", this.viewRef);
    } 
    else if (typeof this.paramsReprint.ORDER_TYPE =='undefined' || this.paramsReprint.ORDER_TYPE == ''){
      this.modal.warning("Please select Order Type.", this.viewRef);
    } 
    else if (typeof this.paramsReprint.CASE_NO_FROM =='undefined' || this.paramsReprint.CASE_NO_FROM == '') {
      this.modal.warning("Please select Case No.", this.viewRef);
    }
    else if (typeof this.paramsReprint.CASE_NO_TO =='undefined' || this.paramsReprint.CASE_NO_TO == '') {
      this.modal.warning("Please select Case No.", this.viewRef);
    }
    else {
      this.customerCode = this.paramsReprint.CUSTOMER_CODE;
      this.branchCode = this.paramsReprint.BRANCH_CODE;
      this.orderType = this.paramsReprint.ORDER_TYPE;
      this.caseNoFrom = this.paramsReprint.CASE_NO_FROM;
      this.caseNoTo = this.paramsReprint.CASE_NO_TO;
      this.params.isPreview = true;
      this.Preview();
    }
  }

  public Preview() {
    this.fileUrl = null;
    this.http
      .Download("WH", "SNWR028_Preview_Case", {
        ReportPrefix: "PMS_RPT_WMS_SNWR028_CASE",
        ReportSuffix: ".PDF",
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_CUSTOMER_CODE: this.customerCode,
        P_BRANCH_CODE: this.branchCode,
        P_ORDER_TYPE: this.orderType,
        P_CASE_NO_FROM: this.caseNoFrom,
        P_CASE_NO_TO: this.caseNoTo,
      })
      .subscribe((res) => {
        if (res) {
          this.SetIFrameContent(res);
        }
      });
  }

  private SetIFrameContent(content: any) {
    const file = new Blob([content], { type: content.type });
    const fileUrl = URL.createObjectURL(file);

    this.fileUrl = fileUrl;
  }
  
}
