import { Component, OnInit, ViewContainerRef } from "@angular/core";
import { HttpService } from "src/app/core/http.service";
import { ModalService } from "src/app/core/modal.service";
import { Globals } from "src/app/core/global";

@Component({
  selector: "SNWR030",
  templateUrl: "SNWR030.component.html",
})
export class SNWR030Component implements OnInit {
  constructor(
    private modal: ModalService,
    private viewRef: ViewContainerRef,
    private http: HttpService,
    private global: Globals
  ) {}

  public params: any = {};
  public vanNoFrom: any;
  public vanNoTo: any;
  public fileUrlPart;

  public ngOnInit() {
    this.params.PRINT_NUMBER = 0;
  }

  public ConfigVan: any = {
    ColName: "LOOKUP_TEXT",
    ColValue: "",
    PlaceholderText: "Select Van No",
    SourceController: "WH",
    SourceMethodName: "SNWR044_N_GetVanNo",
    NoOfShowRecords: 25,
    MinLengthSearch: 0,
    UpperCase: false,
    SourceParams: {
      CUSTOMER_CODE: null
    },
  } 


  public FindVanNumber() {
    this.http.post("WH", "SNWR030_Get_Van_Number", this.params).subscribe(
      (res) => {
        if (res.Table[0]) {
          const van_no = res.Table[0].VAN_NO;
          this.global.GoToReport("PMS_RPT_WMS_SNWR030_VAN", {
            P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
            P_VAN_NO_FROM: van_no,
            P_VAN_NO_TO: van_no,
          });
        } else {
          this.modal.error("Unavailable Van Number.", this.viewRef);
        }
      },
      (err) => {
        console.log(err);
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewRef
        );
      }
    );
  }

  public Print() {
    this.global.GoToReport("PMS_RPT_WMS_SNWR030_VAN", {
      P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      P_VAN_NO_FROM: this.vanNoFrom,
      P_VAN_NO_TO: this.vanNoTo,
    });
  }

  public PreviewVanNumber() {
    if (this.params.PRINT_NUMBER < 1) {
      this.modal.warning("Van QTY must be more than 0.", this.viewRef);
    } else {
      this.http
        .post("WH", "SNWR030_Print_Van_Number", this.params)
        .subscribe((res) => {
          if (res.Result == "Done") {
            this.vanNoFrom = res.VanNoFrom;
            this.vanNoTo = res.VanNoTo;
            this.modal.info(`Print Van Number : ${res.VanNoFrom} - ${res.VanNoTo}.`, this.viewRef,
              () => {
                this.Preview();
                //this.params.PRINT_NUMBER = 0;
              }
            );
          }
        },
        (err) => {
          console.log(err);
          this.modal.warning(
            "Found an error, please contact support team",
            this.viewRef
          );
        });
    }
  }

  public Preview() {
    

    if(!this.params.VAN_NO_FROM){
      this.modal.warning('Please enter your Van No. From !!', this.viewRef);
      return false;
    }
    let vanNoFrom : any = this.params.VAN_NO_FROM.substring(1);
    let vanNoTo : any = (!this.params.VAN_NO_TO ? this.params.VAN_NO_FROM :this.params.VAN_NO_TO).substring(1);
    
    if(vanNoFrom>vanNoTo){
      this.modal.warning('Van No. from must be less than the Van No. to', this.viewRef);
      return false;
    }

    this.fileUrlPart = null;
    this.http
      .Download("WH", "SNWR030_Preview_Vannumber", {
        ReportPrefix: "PMS_RPT_WMS_SNWR030_VAN",
        ReportSuffix: ".PDF",
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_VAN_NO_FROM: this.params.VAN_NO_FROM,
        P_VAN_NO_TO: !this.params.VAN_NO_TO ? this.params.VAN_NO_FROM : this.params.VAN_NO_TO
      })
      .subscribe((res) => {
        if (res) {
          this.SetIFramePartContent(res);
        }
      },
      (err) => {
        console.log(err);
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewRef
        );
      });
  }

  private SetIFramePartContent(content: any) {
    const file = new Blob([content], { type: content.type });
    const fileUrlPart = URL.createObjectURL(file);
    this.fileUrlPart = fileUrlPart;
  }

  public VanSelected(event,idex) {
    if (idex==1){
      this.params.VAN_NO_FROM = event.VAN_NO;
    }else{
      this.params.VAN_NO_TO = event.VAN_NO;
    }
  }
}
