import { Component, OnInit, ViewContainerRef } from "@angular/core";
import { HttpService } from "src/app/core/http.service";
import { ActivatedRoute } from '@angular/router';
import { ModalService } from "src/app/core/modal.service";
import { Globals } from "src/app/core/global";

@Component({
  selector: "SNWR031",
  templateUrl: "SNWR031.component.html",
})
export class SNWR031Component implements OnInit {
  constructor(
    private modal: ModalService,
    private viewRef: ViewContainerRef,
    private http: HttpService,
    private global: Globals,
    private route: ActivatedRoute,
  ) {}

  public params: any = {};
  public customerCode: any;
  public babyCardGroup: any;
  public babyCardNoFrom: any;
  public babyCardNoTo: any;
  public fileUrl;

  public lookupCustomerCodeConfig: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "WH",
    SourceMethodName: "SNWR031_GetCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }
  public SetSelectedCustomerCode(values: any) {
    this.params.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.params.CUSTOMER_NAME = values.CUSTOMER_NAME;
  }

  public ngOnInit() {
    this.params.PRINT_NUMBER = 0;
  }

  public FindBabyCardNumber() {
    this.http.post("WH", "SNWR031_Get_Babycard_Number", this.params).subscribe(
      (res) => {
        if (res.Table[0]) {
          this.global.GoToReport("PMS_RPT_WMS_SNWR031_BABYCARD", {
            P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
            P_CUSTOMER_CODE: res.Table[0].CUSTOMER_CODE,
            P_BABYCARD_GROUP: res.Table[0].BABYCARD_GROUP,
            P_BABYCARD_NO_FROM: res.Table[0].BABYCARD_NO,
            P_BABYCARD_NO_TO: res.Table[0].BABYCARD_NO,
          });
        } else {
          this.modal.error("Unavailable baby card number.", this.viewRef);
        }
      },
      (err) => {
        console.log(err, 'err');
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewRef
        );
      }
    );
  }

  public Print() {
    this.global.GoToReport(
      "PMS_RPT_WMS_SNWR031_BABYCARD", 
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_CUSTOMER_CODE: this.customerCode,
        P_BABYCARD_GROUP: this.babyCardGroup,
        P_BABYCARD_NO_FROM: this.babyCardNoFrom,
        P_BABYCARD_NO_TO: this.babyCardNoTo,
      }, true, false);

    this.global.GoToExport("PMS_RPT_WMS_SNWR031_BABYCARD_EXCEL",
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_CUSTOMER_CODE: this.customerCode,
        P_BABYCARD_GROUP: this.babyCardGroup,
        P_BABYCARD_NO_FROM: this.babyCardNoFrom,
        P_BABYCARD_NO_TO: this.babyCardNoTo,
      }, true, "EXCELOPENXML");
  }

  public PreviewBabyCardNumber() {
    
    if (typeof this.params.CUSTOMER_CODE =='undefined' || this.params.CUSTOMER_CODE == ''){
      this.modal.warning("Please select a customer before printing the baby card.", this.viewRef);
    } 
    else if (typeof this.params.BABYCARD_GROUP =='undefined' || this.params.BABYCARD_GROUP == ''){
      this.modal.warning("Please select Order Type.", this.viewRef);
    } 
    else if (this.params.PRINT_NUMBER < 1) {
      this.modal.warning("Baby card QTY must be more than 0.", this.viewRef);
    }
    else {
      this.http
        .post("WH", "SNWR031_Print_Babycard_Number", this.params)
        .subscribe((res) => {
          if (res.Result == "Done") {
            this.customerCode = res.CustomerCode;
            this.babyCardGroup = res.BabyCardGroup;
            this.babyCardNoFrom = res.BabyCardNoFrom;
            this.babyCardNoTo = res.BabyCardNoTo;
            this.params.isPreview = true;
            this.modal.info(`Preview baby card number :<br>${res.BabyCardNoFrom} to ${res.BabyCardNoTo}`
              ,this.viewRef
              ,() => {
                this.Preview();
                // this.params.PRINT_NUMBER = 0;
              }
              ,{height: "16rem"}
            );
          }
        },
        (err) => {
          console.log(err);
          this.modal.warning(
            "Found an error, please contact support team",
            this.viewRef
          );
        });
    }
  }

  private Preview() {
      this.fileUrl = null;
      this.http
        .Download("WH", "SNWR031_Preview_BabyCard", {
          ReportPrefix: "PMS_RPT_WMS_SNWR031_BABYCARD",
          ReportSuffix: ".PDF",
          P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
          P_CUSTOMER_CODE: this.customerCode,
          P_BABYCARD_GROUP: this.babyCardGroup,
          P_BABYCARD_NO_FROM: this.babyCardNoFrom,
          P_BABYCARD_NO_TO: this.babyCardNoTo,
        })
        .subscribe((res) => {
          if (res) {
            this.SetIFrameContent(res);
          }
        });
  }

  private SetIFrameContent(content: any) {
    const file = new Blob([content], { type: content.type });
    const fileUrl = URL.createObjectURL(file);

    this.fileUrl = fileUrl;
  }

  public DLExcelBabyCardNumber() {
    this.global.GoToExport("PMS_RPT_WMS_SNWR031_BABYCARD_EXCEL",
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_CUSTOMER_CODE: this.customerCode,
        P_BABYCARD_GROUP: this.babyCardGroup,
        P_BABYCARD_NO_FROM: this.babyCardNoFrom,
        P_BABYCARD_NO_TO: this.babyCardNoTo,
      }, true, "EXCELOPENXML");
  }
}
