import { Component, ElementRef, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { ModalService } from 'src/app/core/modal.service';
import { SelectionModel } from '@angular/cdk/collections';


@Component({
    selector: 'SNWR032',
    templateUrl: 'SNWR032.component.html',
    styleUrls: ['SNWR032.component.css']
})

export class SNWR032Component implements OnInit {
    constructor(
        private http: HttpService,
        private router: Router,
        private global: Globals,
        private modal: ModalService,
        private viewref: ViewContainerRef
  ) { }

  @ViewChild("dialogAction", { static: false }) dialogAction: any;
  @ViewChild("fileInput") fileInput: ElementRef;
  @ViewChild("dialogupload", { static: false }) dialogupload: any;

  public paramSearch: any = {PART_NO: ""};
  public formData: any = {};
  public tableDataBabyCardLevel: Array<any> = [];
  public tableDataBabyCardLevelTemporary: Array<any> = [];
  public FileName: string = "";
  private File : any;
  public tableUpload = []
  public tableUploadFilter = []
  public selection = new SelectionModel<any>(true, []);
  public total_error :number = 0;
  public error_list = []

  public lookupPartNoConfig: any = {
    ColName: "LOOKUP_PART_NAME_EN",
    PlaceholderText: "Select Part no",
    SourceController: "WH",
    SourceMethodName: "SNWR032_GetPartNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedPartNo(val) {
    this.paramSearch.PART_NO = val.PART_NO;
    this.paramSearch.PART_NAME_TH = val.PART_NAME_TH;
    this.paramSearch.PART_NAME_EN = val.PART_NAME_EN;
    this.SearchBabyCardLevel();
  }

  public SetSelectedPartNoDialog(val) {
    if(val){
      this.formData.PART_NO = val.PART_NO;
      this.formData.PART_NAME_TH = val.PART_NAME_TH;
      this.formData.PART_NAME_EN = val.PART_NAME_EN;
      this.formData.LEVEL_1 = val.SALES_PACKAGE;
    }else{
      this.formData.PART_NO = null;
      this.formData.PART_NAME_TH = null;
      this.formData.PART_NAME_EN = null;
      this.formData.LEVEL_1 = null;
    }
  }

  ngOnInit() {
    //this.SearchBabyCardLevel();
  }

  public SearchBabyCardLevel() {
    this.http.post('WH', 'SNWR032_GetBabyCardLevelMaster', this.paramSearch)
    .subscribe(res => {
      if(res.result == "Done"){
        this.tableDataBabyCardLevel = res.set.Table;
        this.tableDataBabyCardLevelTemporary = res.set.Table1;
      }
      else{
        this.modal.error(res.message, this.viewref)
      }
    },(err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contact support team", this.viewref);
  });
  }
  
  public Add() {
    this.formData = {}
    this.formData.TABLE = "MASTER";
    this.formData.TYPE = "ADD";
    this.dialogAction.height = "580px" 
    this.dialogAction.title = "Add Babycard Type Master" 
    this.dialogAction.OpenDialog();
  }

  public Edit(data) {
    this.formData = { ...data }
    this.formData.TABLE = "MASTER";
    this.formData.TYPE = "EDIT";
    this.formData.LEVEL_4_CHK = this.formData.LEVEL_4 ? true : false;
    this.dialogAction.height = "650px" 
    this.dialogAction.title = "Edit Babycard Type Master" 
    this.dialogAction.OpenDialog();
  }
  
  public Level4Toggle() {
    if(this.formData.LEVEL_4_CHK){
      this.formData.LEVEL_2 = null;
      this.formData.LEVEL_4 = this.formData.LEVEL_1;
    }
    else{
      this.formData.LEVEL_2 = null;
      this.formData.LEVEL_4 = null;
    }
  }

  private ValidateControl(){
    let validate = false;
    if (IsNullOrEmpty(this.formData.PART_NO)) {
      this.modal.warning("Please input fill part no.", this.viewref);
    } 
   
    // else if (IsNullOrEmpty(this.formData.LEVEL_2) && IsNullOrEmpty(this.formData.LEVEL_3) && IsNullOrEmpty(this.formData.LEVEL_4)){
    //   this.modal.warning("Can't set up baby only level 1, please input another level.", this.viewref);
    // }
    else if (isNegativeNumber(this.formData.LEVEL_2)) {
      this.modal.warning("Please input validate value in Type A number.", this.viewref);
    } 
    else if (isNegativeNumber(this.formData.LEVEL_3)) {
      this.modal.warning("Please input validate value in Type B number.", this.viewref);
    } 
    else if (isNegativeNumber(this.formData.LEVEL_1)) {
      this.modal.warning("Please input validate value in Type C number.", this.viewref);
    } 
    // else if (isNegativeNumber(this.formData.LEVEL_4)) {
    //   this.modal.warning("Please input validate value in level 4 number.", this.viewref);
    // } 
    // else if (!IsNullOrEmpty(this.formData.LEVEL_2) && !IsNullOrEmpty(this.formData.LEVEL_4)  && this.formData.LEVEL_2 != 0 && this.formData.LEVEL_4 != 0 ){
    //   this.modal.warning("Can not set Level 2 Qty and Level4 Qty at the same time!.", this.viewref);
    // } 
    // else if (!IsNullOrEmpty(this.formData.LEVEL_2) && this.formData.LEVEL_2 != 0 && Number(this.formData.LEVEL_2) % Number(this.formData.LEVEL_1) !== 0){
    //   this.modal.warning("Level 2 / Level 1 Qty must be a number without remainder!.", this.viewref);
    // } 
    // else if (!IsNullOrEmpty(this.formData.LEVEL_3) && this.formData.LEVEL_3 != 0 && Number(this.formData.LEVEL_3) % Number(this.formData.LEVEL_1) !== 0){
    //   this.modal.warning("Level 3 / Level 1 Qty must be a number without remainder!.", this.viewref);
    // } 
    // else if (!IsNullOrEmpty(this.formData.LEVEL_4) && this.formData.LEVEL_4 != 0 && this.formData.LEVEL_4 != this.formData.LEVEL_1){
    //   this.modal.warning("Level 4 must be equal to Level 1!.", this.viewref);
    // } 
    else {
      validate = true;
    }

    return validate;
  }

  public SaveAdd() {
    if(this.ValidateControl()) {
      this.modal.confirm("Do you want to save change you have made?", this.viewref, this.ConfirmAdd);
    }
  }

  public ConfirmAdd = () => {
    this.http.post('WH', 'SNWR032_InsertBabyCardLevelMaster', this.formData)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'Done') {
          this.SearchBabyCardLevel();
          this.dialogAction.Close();
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
        } else if (res.Table[0].STATUS == 'Duplicate') {
          this.modal.warning('No change to save. Found duplicate record.', this.viewref);
        } else {
          this.modal.error('No change to save. Something went wrong.', this.viewref);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team.", this.viewref);
      })
  }

  public CancelAdd() {
    this.dialogAction.Close();
  }

  public SaveEdit() {
    if(this.ValidateControl()) {
      this.modal.confirm("Do you want to save change you have made?", this.viewref, this.ConfirmEdit);
    }
  }

  public ConfirmEdit = () => {
    this.http.post('WH', 'SNWR032_UpdateBabyCardLevelMaster', this.formData)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'Done') {
          this.SearchBabyCardLevel();
          this.dialogAction.Close();
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
        } else if (res.Table[0].STATUS == 'Duplicate') {
          this.modal.warning('No change to save. Found duplicate record.', this.viewref);
        } else {
          this.modal.error('No change to save. Something went wrong.', this.viewref);
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team.", this.viewref);
      });
  }

  public CancleEdit() {
    this.dialogAction.Close();
  }

  public DownloadTemplate(){
    let link = "assets/templates/SNWR032_Upload_Template.xlsx"
    window.open(link,'_blank')
  }

  public OpenUpload(){
    this.total_error = 0
    this.FileName = "";
    this.error_list = []
    this.tableUpload = []
    this.tableUploadFilter = []
    this.dialogupload.title = "Baby Card Type Upload"
    this.dialogupload.OpenDialog()
  }

  public OpenReport(){
    this.global.GoToReport("PMS_RPT_WMS_SNWR032_BABYCARD_NO",
    {
      P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      P_PART_NO: this.paramSearch.PART_NO,
    });
  }
  
  public openFileBrowser() {
    this.FileName = "";
    this.fileInput.nativeElement.value = '';
    this.fileInput.nativeElement.click();
  }

  public selectFile(evt) {
    let Files: Array<File> = evt.target.files;
    if (Files.length > 0) {
      //let File: File = Files[0];
      this.File = Files[0];
      this.FileName = this.File.name;
      this.PreView();
    }
  }

  public PreView() {
    if (!this.FileName) {
      this.modal.warning("Please Open File First...", this.viewref)
      return;
    }

    let formData = new FormData();
    formData.append('file', this.File);

    this.tableUpload = [];
    this.error_list = [];
    this.http.postFile("WH", "SNWR032_UploadFile", formData)
      .subscribe(result => {
        if(result.status == "Done"){
          this.tableUpload = result.set.Table;
          this.tableUploadFilter = this.tableUpload.filter(x => x.ERR_FLAG == 'N')
          let countrow = 0;
          this.tableUpload.map((x,i) => {
            if(x.ERR_FLAG == 'Y'){
                countrow += 1;
                this.error_list.push({
                  record : i + 1,
                  message : x.ERR_MSG
                })
            } 
            this.total_error = countrow;
          })
        } else {
          console.log(result, 'err');
          this.modal.error("Upload not complete", this.viewref);
        }
      }, err => {
        console.log(err, 'err');
        this.modal.error("Upload not complete", this.viewref);
      })
  }

  public SaveUpload(){
    this.modal.confirm("Do you want to save change you have made?",this.viewref,() => ConfirmSave())

    let ConfirmSave = () => {
      this.http.post("WH","SNWR032_SaveByUpload",this.tableUploadFilter)
      .subscribe(res => {
        if(res.status == "DONE"){
          this.SearchBabyCardLevel();
          this.dialogupload.Close();
          this.modal.info(res.message,this.viewref);
        }else{
          this.modal.error(res.message,this.viewref)
        }
      },err => {
        console.log(err, 'err');
        this.modal.error("Save data not complete, please contact support team.",this.viewref)
      })
    }
  }
  
  public AddTempBabyLevel() {
    this.formData = {}
    this.formData.TABLE = "TEMPORARY";
    this.formData.TYPE = "ADD";
    this.dialogAction.height = "600px" 
    this.dialogAction.title = "Add Temporary Babycard Type" 
    this.dialogAction.OpenDialog();
  }

  public EditTempBabyLevel(data) {
    this.formData = { ...data }
    this.formData.TABLE = "TEMPORARY";
    this.formData.TYPE = "EDIT";
    this.formData.LEVEL_4_CHK = this.formData.LEVEL_4 ? true : false;
    this.dialogAction.height = "675px" 
    this.dialogAction.title = "Edit Temporary Babycard Type" 
    this.dialogAction.OpenDialog();
  }

  public DeleteTempBabyLevel(data){
    this.modal.confirm("Do you want to delete this temp data?"
                        + "<br>Part No: " + data.PART_NO
                        + "<br>Part Name: " + data.PART_NAME_EN
                       , this.viewref
                       , ()=> ConfirmDelete(), () => {}, {height: "20rem", width: "20rem"});

    let ConfirmDelete = () => {
      const params = { ID : data.ID };
      this.http.post("WH","SNWR032_DeleteBabyCardTemporary", params)
      .subscribe(res =>{
        if (res.STATUS == 'DONE') {
          this.modal.info('Delete record complete: applied and saved.', this.viewref);
          this.SearchBabyCardLevel();
        } else {
          this.modal.error('Found an error, please contract support team.', this.viewref);
        }
      },err =>{
        console.log(err, 'err')
        this.modal.error('Found an error, please contract support team.', this.viewref);
      })
    }
  }

  public ConfirmTempBabyLevel (data){
    this.modal.confirm("Do you want to confirm this temp into master?"
                        + "<br>Part No: " + data.PART_NO
                        + "<br>Part Name: " + data.PART_NAME_EN
                       , this.viewref
                       , ()=> Confirm(), () => {}, {height: "20rem", width: "20rem"});

    let Confirm = () => {
      const params = { ID : data.ID };
      this.http.post("WH","SNWR032_ConfirmBabyCardTemporary", params)
      .subscribe(res =>{
        if (res.STATUS == 'DONE') {
          this.modal.info('Confirm record complete: applied and moved to master.', this.viewref);
          this.SearchBabyCardLevel();
        } else {
          this.modal.error('Found an error, please contract support team.', this.viewref);
        }
      },err =>{
        console.log(err, 'err')
        this.modal.error('Found an error, please contract support team.', this.viewref);
      })
    }
  }

  public SaveTempBabyLevel (){
    if(this.ValidateControl()) {
      this.modal.confirm("Do you want to save change you have made?", this.viewref, ()=> ConfirmSaveTempBaby());
    }

    let ConfirmSaveTempBaby = () => {
      const method = this.formData.TYPE == "ADD" ? "SNWR032_InsertBabyCardTemporary" : "SNWR032_UpdateBabyCardTemporary";
      this.http.post('WH', method, this.formData)
        .subscribe(res => {
          if (res.Table[0].STATUS == 'Done') {
            this.SearchBabyCardLevel();
            this.dialogAction.Close();
            this.modal.info('Transaction complete: applied and saved.', this.viewref);
          } else if (res.Table[0].STATUS == 'Duplicate') {
            this.modal.warning('No change to save. Found duplicate record.', this.viewref);
          } else {
            this.modal.error('No change to save. Something went wrong.', this.viewref);
          }
        }, (err) => {
          console.log(err, 'err')
          this.modal.warning("Found an error, please contact support team.", this.viewref);
        });
    };
  }

}

function IsNullOrEmpty(value: any): boolean {
  if (value == '' || value == null || typeof value == 'undefined') {
    return true;
  } else {
    return false;
  }
}


function isNegativeNumber(value: any): boolean {
  if (typeof value == 'undefined') {
    return false;
  }
  if(isNaN(Number(value))){
    return true;
  }
  else{
    if (Number(value) == 0){
      return false;
    } 
    if(Number(value) < 0){
      return true;
    } else{
      return false;
    }
  }
}
