import {
	Component,
	ElementRef,
	HostListener,
	OnInit,
	ViewChild,
	ViewContainerRef,
} from "@angular/core";
import { HttpService } from "src/app/core/http.service";
import { ModalService } from "src/app/core/modal.service";
import { Observable, Subject } from "rxjs";
import {
	ReceiveControl,
	ReceiveControlSetValue
} from "src/app/core/WHOutboundController/ReceiveControl";
import {
	ReceiveExportToken,
	ReceiveExportTokenExtractor
} from "src/app/core/WHOutboundController/ReceiveTokenExtractor";
import { map } from "rxjs/operators";
import * as moment from "moment";
import { Globals } from "src/app/core/global";
import { DialogTemplateComponent } from "src/app/components/shared/dialog-template/dialog-template.component";

type ActionLog = {
	timestamp: moment.Moment;
	actionType: string;
	actionMessage: string;
};
@Component({
	selector: "SNWR033",
	templateUrl: "./SNWR033.component.html",
	styleUrls: ["../warehouse.component.css", "./SNWR033.component.css"],
	providers: [ReceiveExportTokenExtractor],
})
export class SNWR033Component implements OnInit {
	constructor(
		private Http: HttpService,
		private modal: ModalService,
		private viewref: ViewContainerRef,
		private extractor: ReceiveExportTokenExtractor,
		private global: Globals
	) { }

	public customerInfo: {
		code: string;
		name: string;
		zone: string;
		routeCode: string;
		orderType: string;
		customerCode: string;
		customerName: string;
		branchCode: string;
		branchName: string;
	};
	public existItem: any;
	public qrString: string;
	public params: any = {};
	public totalItems: number = 0;
	public receiveList: any = [];
	public receiveListTemp: any = [];
	public receiveListFiltered: any = [];

	public scannedCard: any;
	public scannedBaby: any;
	public scannedPart: any;
	public qtyLock: boolean = true;
	public showHistory: boolean = false;

	public resultList: any;
	public checkBabyMode: boolean = false;
	public checkCompareMode: boolean = false;

	@ViewChild("scannerInput", { read: ElementRef }) scannerInput: ElementRef;

	public formSetBabyData: any = [];
	@ViewChild("setBabyDialog") setBabyDialog: DialogTemplateComponent;

	public initialControl: ReceiveControl = new ReceiveControl();
	private initialControlSubject: Subject<ReceiveControlSetValue> = new Subject<ReceiveControlSetValue>();
	public actionLogs: ActionLog[] = [];
	private actionLogsSubject: Subject<ActionLog> = new Subject<ActionLog>();

	ngOnInit() {
		this.InitialProcess();
		this.initialControlSubject
			.pipe(map((control) => control))
			.subscribe((control) => {
				if (control) {
					this.initialControl.set(control);
					if (control.propName === "QR")
						// this.CheckFinishedForChangeInstruction() &&
						this.SetScannedQR(this.initialControl.QR);
					if (control.propName === "partNo")
						this.SetScannedPart(this.initialControl.partNo);
					if (control.propName === "baBy")
						this.SetScannedBaby(this.initialControl.baBy);
					this.qrString = undefined;
				}
			});
		this.actionLogsSubject.subscribe((action: ActionLog) => {
			this.actionLogs.push(action);
			this.actionLogs = this.actionLogs.slice();
		});
	}

	private InitialProcess() {
		this.initialControl.reset();
		this.actionLogs = [];
		this.params = {};
		this.qrString = null;
		this.totalItems = 0;
		this.customerInfo = undefined;
		this.scannedCard = undefined;
		this.scannedBaby = undefined;
		this.scannedPart = undefined;
		this.receiveList = [];
		this.receiveListTemp = [];
	}

	public async Reset() {
		this.modal.confirm(
			"คุณต้องการยกเลิกการแก้ไข ใช่หรือไม่?",
			this.viewref,
			() => {
				this.InitialProcess();
				this.scannerInput.nativeElement.focus();
			},
			() => {
				this.ReFocus();
			}
		);
	}

	public async Enter() {
		if (this.qrString?.trim() === "" || this.qrString == "" || !this.qrString) {
			return;
		}
		const value = this.qrString?.trim();
		try {
			const tokenDetail: ReceiveExportToken = this.extractor.getToken(value);
			//Initial scan
			if (tokenDetail instanceof ReceiveExportToken) {
				//Set QR code
				this.initialControlSubject.next({
					propName: "QR",
					value: tokenDetail
				});
			}
		} catch (ex) {
			if (ex === "Invalid QR") {
				let splitValue = value.split("-");
				if (splitValue.length == 3) {
					if (!this.scannedCard) {
						let qrcode = null;
						qrcode = await this.CheckReceiveBabyCard(value)
							.then((response) => {
								if (response.status === "Y") {
									return response.qrcode;
								} else {
									this.modal.warning("ไม่พบข้อมูล",
										this.viewref, () => { this.ReFocus() }
									);
									return null;
								}
							});

						if (qrcode) {
							const tokenDetail: ReceiveExportToken = this.extractor.getToken(qrcode);
							//Initial scan
							if (tokenDetail instanceof ReceiveExportToken) {
								//Set QR code
								this.existItem = { BABYCARD_NO: value, FROM_CHECK_EXIST_BABYCARD: true };
								this.initialControlSubject.next({
									propName: "QR",
									value: tokenDetail
								});
							}
						}
					}
					else {
						if (splitValue[0] !== this.customerInfo?.customerCode) {
							this.modal.warning("รหัสลูกค้าไม่ตรงกับงานที่ทำอยู่",
								this.viewref, () => { this.ReFocus() }
							);
						}
						else if (splitValue[0] === this.customerInfo?.customerCode) {
							this.initialControlSubject.next({
								propName: "baBy",
								value: value
							});
						}
					}
				} else {
					if (!this.scannedCard) {
						this.modal.warning("กรุณาสแกนการ์ด",
							this.viewref, () => { this.ReFocus() }
						);
						return;
					}
					try {
						const checkPart = this.scannedCard.PART_NO === value;
						if (checkPart) {
							this.initialControlSubject.next({
								propName: "partNo",
								value: value
							});
						} else {
							this.modal.warning("ข้อมูลไม่ถูกต้อง",
								this.viewref, () => { this.ReFocus() }
							);
						}
					} catch (ex) {
						if (!this.scannedCard) {
							this.modal.warning("กรุณาสแกนการ์ด",
								this.viewref, () => { this.ReFocus() }
							);
							return;
						} else {
							this.modal.warning("ข้อมูลที่สแกนไม่ถูกต้อง",
								this.viewref, () => { this.ReFocus() }
							);
						}
					}
				}
			} else {
				this.modal.warning("ข้อมูลที่สแกนไม่ถูกต้อง",
					this.viewref, () => { this.ReFocus() }
				);
			}
		}
	}

	private SetCustomerInfo(packData: any): boolean {
		const customerInfo = {
			code: `${packData.CUSTOMER_CODE}${packData.BRANCH_CODE}`,
			name: `${packData.CUSTOMER_NAME}${packData.BRANCH_NAME ?? ""}`,
			zone: packData.CUSTOMER_ZONE,
			routeCode: packData.ROUTE_CODE,
			orderType: packData.ORDER_TYPE,
			customerCode: packData.CUSTOMER_CODE,
			customerName: packData.CUSTOMER_NAME,
			branchCode: packData.BRANCH_CODE,
			branchName: packData.BRANCH_NAME
		};
		if (!this.customerInfo) {
			this.customerInfo = customerInfo;
		}

		if (this.customerInfo.code != customerInfo.code) {
			this.modal.warning("รหัสลูกค้าไม่ตรงกับงานที่ทำอยู่",
				this.viewref, () => { this.ReFocus() }
			);

			return false;
		}
		return true;
	}

	private async SetScannedQR(receiveToken: ReceiveExportToken) {
		if (this.scannedCard) {
			let found = this.scannedCard.INSTRUCTION_NO == receiveToken.INSTRUCTION_NO
			if (found) {
				this.modal.warning("สแกนการ์ดตรงกับการ์ดที่กำลังดำเนินการอยู่",
					this.viewref, () => { this.ReFocus() }
				);
				return;
			}
		}

		this.GetReceiveDetail().then((res) => {
			if (res) {
				const message = res.message || undefined;
				const processflag = res.processflag || undefined;
				const processmessage = res.processmessage || undefined;
				const partno = res.partno || undefined;
				if (message) {
					if (message == "NO_DATA_FOUND") {
						this.modal.warning(
							"รายการนี้ไม่ได้อยู่ในขั้นตอนนี้" + "<br>" + "รายการนี้สถานะอยู่ในขั้นตอน: " + processmessage,
							this.viewref, () => { this.ReFocus() }
						);
						return;
					} else if (message == "NO_DATA_FOUND_LEVEL") {
						this.modal.warning(
							"กรุณากำหนดค่าเลเวลของเบบี้การ์ด" + "<br>" + "Part no: " + partno,
							this.viewref, () => { this.ReFocus() }
						);
						return;
					} else if (message == "BABYCARD_ALREADY_PACKED") {
						this.modal.warning(
							"ไม่สามารถทำรายการนี้ได้ babycard นี้ถูกทำแพคลงลังแล้ว",
							this.viewref, () => { this.ReFocus() }
						);
						return;
					}
				}

				let GetDetail = () => {
					this.receiveList = res.data.Table;
					this.receiveListTemp = JSON.parse(JSON.stringify(res.data.Table));
					const reCeiveData = res.data.Table[0] || undefined;
					if (reCeiveData) {
						if (!this.SetCustomerInfo(reCeiveData)) {
							return;
						}
						this.scannedCard = reCeiveData;
						this.scannedCard.COMPLETE_FLAG = processflag;
						this.scannedCard.RECEIVING_QTY = this.receiveList.map(x => x.RECEIVE_QTY).reduce((prev, next) => prev + next);
						this.scannedCard.TOTAL_QTY = this.receiveList.map(x => x.BABY_QTY).reduce((prev, next) => prev + next);
						this.scannedCard.HAVE_REMAIN = this.receiveList.some(x => x.STATUS_CODE == 'R');
						this.scannedCard.HAVE_PACKED = this.receiveList.some(x => x.STATUS_CODE == 'C' || x.STATUS_CODE == 'I');
						if (this.existItem?.FROM_CHECK_EXIST_BABYCARD) {
							const babycard = JSON.parse(JSON.stringify(this.existItem.BABYCARD_NO));
							this.actionLogsSubject.next({
								timestamp: moment(),
								actionType: "Scan Baby",
								actionMessage: `${babycard.substring(babycard.indexOf("-") + 1)}`,
							});
							this.initialControlSubject.next({
								propName: "baBy",
								value: babycard
							});
						} else {
							this.actionLogsSubject.next({
								timestamp: moment(),
								actionType: "Scan Instruction",
								actionMessage: `${this.scannedCard.INSTRUCTION_NO}`,
							});
							this.ReFocus();
						}
					} else {
						this.modal.warning("ไม่พบข้อมูล", this.viewref, () => { this.ReFocus() });
					}
				}

				if (this.receiveList.length > 0) {
					this.modal.confirm("คุณต้องการยกเลิกการแก้ไข ใช่หรือไม่?",
						this.viewref,
						() => {
							this.InitialProcess();
							GetDetail();
							this.ReFocus();
						},
						() => { this.ReFocus() }
					);
					// this.modal.warning(
					// 	this.global.GetMessageOf().DUPLICATE_PACK,
					// 	this.viewRef
					// );
					// return;
				} else {
					GetDetail();
				}
			} else {
				this.InitialProcess();
			}

		});
	}

	private async SetScannedPart(part: string) {
		if (!this.scannedBaby?.BABYCARD_NO) {
			this.modal.warning("กรุณาสแกนเบบี้การ์ด",
				this.viewref, () => { this.ReFocus() }
			);
			return;
		}
		if (this.scannedBaby && this.scannedBaby?.STATUS_CODE != 'R') {
			this.modal.info("ไม่สามารถทำรายการนี้ได้ babycard ถูกแพคลงลังแล้ว",
				this.viewref, () => { this.ReFocus() }
			);
			return;
		}

		let foundPart = this.receiveList.find((item) =>
			item.BABYCARD_NO == this.scannedBaby.BABYCARD_NO && item.PART_NO == part
		); //Find all matched part number

		if (foundPart) {
			let available = foundPart.BABY_QTY - foundPart.RECEIVE_QTY;
			if (this.qtyLock) {
				if (available > 0) {
					let index = this.receiveList.findIndex(x => x.BABYCARD_NO == foundPart.BABYCARD_NO)
					if (foundPart.BABY_LEVEL == "TYPE B") {
						this.receiveList[index].RECEIVE_QTY = foundPart.BABY_QTY;
						this.actionLogsSubject.next({
						  timestamp: moment(),
						  actionType: "Scan Part",
						  actionMessage: `${part} ${foundPart.BABY_QTY} qty`,
						});
					}
					else {
                        if (foundPart.SALES_PACKAGE > available) {
                            this.receiveList[index].RECEIVE_QTY += available;
                        } else {
                            this.receiveList[index].RECEIVE_QTY += foundPart.SALES_PACKAGE;
                        }
						this.actionLogsSubject.next({
						  timestamp: moment(),
						  actionType: "Scan Part",
						  actionMessage: `${part} ${foundPart.SALES_PACKAGE} qty`,
						});
					}
					//const totalQty: number = this.scannedBaby.BABY_QTY;
					//this.receiveList[index].RECEIVE_QTY = totalQty;
					this.scannedCard.RECEIVING_QTY = this.receiveList.map(x => x.RECEIVE_QTY).reduce((prev, next) => prev + next);
					this.scannedCard.TOGGLE_INPUT = 'N';
					this.qtyLock = true;
					if (this.receiveList[index].RECEIVE_QTY == this.receiveList[index].BABY_QTY) {
						this.SetNextBabyCard();
					}
				} else {
					this.modal.warning("รับเข้าเกินจำนวน ของเบบี้การ์ด",
						this.viewref, () => { this.ReFocus() }
					);
					return;
				}
			}
			else {
				//this.OpenInputQtyDialog();
			}
		}
		else {
			//Case not found matched part number
			this.modal.error("เบอร์อะไหล่ไม่ถูกต้อง", this.viewref, () => {
				this.ReFocus();
			});
		}
	}

	private async SetScannedBaby(babyNo: string) {
		let babyType = babyNo.substring(babyNo.lastIndexOf('-') + 1) == 'A' ? 'AIR' : 'SEA';
		if (babyType !== this.customerInfo.orderType) {
			this.modal.info("Baby ผิดออเดอร์ Class", this.viewref, () => {
				this.ReFocus();
			});
			return;
		}

		let checkbaBy = null;
		checkbaBy = await this.GetBabyNumber(babyNo)
			.then((response) => {
				if (response.Result === "Done" && response.BABYCARD_NO === babyNo) {
					return response.BABYCARD_NO;
				}
				else {
					let findExists = this.receiveListTemp.find((item) =>
						item.BABYCARD_NO == babyNo
					);
					if (findExists) {
						return findExists.BABYCARD_NO;
					} else {
						this.modal.warning("มีเบบี้การ์ดใบนี้อยู่แล้ว",
							this.viewref, () => { this.ReFocus() }
						);
						return null;
					}
				}
			});

		if (checkbaBy == null) {
			return;
		}
		if (this.scannedBaby && this.scannedBaby?.BABYCARD_NO == babyNo && this.scannedBaby?.STATUS_CODE != 'R') {
			this.modal.info("ไม่สามารถทำรายการนี้ได้ babycard ถูกแพคลงลังแล้ว",
				this.viewref, () => { this.ReFocus() }
			);
			return;
		}

		let foundBaby = this.receiveList.find((item) =>
			item.BABYCARD_NO == babyNo
		); //Find all matched part number

		if (foundBaby) {
			let index = this.receiveList.findIndex(x => x.SEQ == foundBaby.SEQ);
			this.scannedBaby = this.receiveList[index];
			this.scannedBaby.isSelected = false;
			this.initialControl.latestScanned = 'baBy';
			this.qtyLock = true;
			if (this.existItem?.FROM_CHECK_EXIST_BABYCARD) {
				this.existItem = undefined;
			} else {
				this.modal.warning("มีเบบี้การ์ดใบนี้อยู่แล้ว",
					this.viewref, () => { this.ReFocus() }
				);
			}
			this.ReFocus();
			return;
		}

		let findBaby: any;
		if (this.scannedBaby?.isSelected == true) {
			findBaby = this.receiveList.find((item) =>
				item.SEQ == this.scannedBaby.SEQ && item.STATUS_CODE == 'R'
			);
		} else {
			//find next empthy baby from current SEQ
			findBaby = this.receiveList.find((item) =>
				item.BABYCARD_NO == null && item.SEQ > this.scannedBaby?.SEQ && item.STATUS_CODE == 'R'
			);
			if (!findBaby) {
				//find next empthy baby from first SEQ
				findBaby = this.receiveList.find((item) =>
					item.BABYCARD_NO == null && item.STATUS_CODE == 'R'
				);
			}
		}

		if (!findBaby) {
			this.modal.warning("เบบี้การ์ดครบจำนวนแล้ว", this.viewref, () => { this.ReFocus() });
			return
		}

		if (findBaby.IS_LEVEL_SALES_PACKAGE == "Y" && findBaby.TEMP_BABY != babyNo) {
			this.modal.warning("หมายเลขเบบี้การ์ดไม่ถูกต้อง", this.viewref, () => { this.ReFocus() });
			return
		}

		if (this.scannedBaby?.BABYCARD_NO && this.scannedBaby.isSelected == true) {
			this.modal.confirm("ท่านต้องการเปลี่ยนเป็นเบบี้การ์ดใบนี้ใช่หรือไม่",
				this.viewref,
				() => {
					let index = this.receiveList.findIndex(x => x.SEQ == findBaby.SEQ);
					this.receiveList[index].BABYCARD_NO = babyNo;
					this.receiveList[index].BABYCARD_NO_TEXT = babyNo.substring(babyNo.indexOf("-") + 1);
					this.receiveList[index].RECEIVE_QTY = 0;
					this.scannedBaby = this.receiveList[index];
					this.scannedBaby.isSelected = false;
					this.initialControl.latestScanned = 'baBy';
					this.qtyLock = true;
					this.ReFocus();
					this.actionLogsSubject.next({
						timestamp: moment(),
						actionType: "Replace Baby",
						actionMessage: `${babyNo.substring(babyNo.indexOf("-") + 1)}`,
					});
				},
				() => {
					this.ReFocus();
				});
		} else {
			let index = this.receiveList.findIndex(x => x.SEQ == findBaby.SEQ);
			this.receiveList[index].BABYCARD_NO = babyNo;
			this.receiveList[index].BABYCARD_NO_TEXT = babyNo.substring(babyNo.indexOf("-") + 1);
			this.scannedBaby = this.receiveList[index];
			this.scannedBaby.isSelected = false;
			this.initialControl.latestScanned = 'baBy';
			this.qtyLock = true;
			this.ReFocus();
			this.actionLogsSubject.next({
				timestamp: moment(),
				actionType: "Add Baby",
				actionMessage: `${babyNo.substring(babyNo.indexOf("-") + 1)}`,
			});
		}
	}

	public DeleteBaby(data) {
		this.modal.confirm(
			"คุณต้องการลบข้อมูล ใช่หรือไม่?",
			this.viewref,
			() => {
				this.actionLogsSubject.next({
					timestamp: moment(),
					actionType: "Remove Baby",
					actionMessage: `${data.BABYCARD_NO_TEXT}`,
				});
				let index = this.receiveList.findIndex(x => x.BABYCARD_NO == data.BABYCARD_NO);
				if (this.scannedCard.RECEIVING_QTY) {
					this.scannedCard.RECEIVING_QTY -= this.receiveList[index].RECEIVE_QTY;
				}
				this.receiveList[index].BABYCARD_NO = null;
				this.receiveList[index].BABYCARD_NO_TEXT = null;
				this.receiveList[index].RECEIVE_QTY = 0;
				this.scannedBaby = undefined;
				this.qtyLock = true;
				this.ReFocus();
			},
			() => {
				this.ReFocus();
			},
		);
	}

	private SetNextBabyCard() {
		if (!this.scannedBaby?.BABYCARD_NO) {
			this.scannedBaby = this.receiveList[0];
			this.qtyLock = true;
			this.ReFocus();
		} else {
			//setTimeout(() => {
			const undoneBaby = this.receiveList.some((item) => item.BABYCARD_NO && item.RECEIVE_QTY < item.BABY_QTY && (item.STATUS_CODE == 'N' || item.STATUS_CODE == 'R'));
			//if have undone baby -> suggest item
			if (undoneBaby) {
				let nextIndex: number;
				//find next from current seq
				nextIndex = this.receiveList.findIndex((item) => item.BABYCARD_NO && item.RECEIVE_QTY < item.BABY_QTY && item.SEQ > this.scannedBaby.SEQ && (item.STATUS_CODE == 'N' || item.STATUS_CODE == 'R'));
				if (nextIndex != -1) {
					this.scannedBaby = this.receiveList[nextIndex];
					this.qtyLock = true;
					this.ReFocus();
				}
				else {
					//back to find from first seq
					nextIndex = this.receiveList.findIndex((item) => item.BABYCARD_NO && item.RECEIVE_QTY < item.BABY_QTY && (item.STATUS_CODE == 'N' || item.STATUS_CODE == 'R'));
					if (nextIndex != -1) {
						this.scannedBaby = this.receiveList[nextIndex];
						this.qtyLock = true;
					}
					this.ReFocus();
				}
			} else {
				this.ReFocus();
			}
			//}, 300);
		}
	}

	public SelectBabyCard(data: any) {
		let index = this.receiveList.findIndex(x => x.SEQ == data.SEQ);
		this.scannedBaby = this.receiveList[index];
		this.scannedBaby.isSelected = true;
		this.initialControl.latestScanned = 'baBy';
		this.ReFocus();
	}

	private async GetReceiveDetail() {
		return await
			this.Http.post("WH", "SNWR033_GetData", this.initialControl.QR)
				.toPromise()
				.catch((err) => {
					console.log(err, 'err');
					this.modal.error(
						"พบปัญหาการใช้งาน กรุณาแจ้งผู้ดูแลระบบ",
						this.viewref,
						() => {
							this.ReFocus();
						});
				});
	}

	private async GetBabyNumber(baByNo: string) {
		return await this.Http
			//.get("WH", "SNWR033_GetAvailableBaby", this.global.EscapeCharacter(baByNo))
			.get("WH", "SNWR033_GetAvailableBaby", baByNo)
			.toPromise()
			.catch((err) => {
				console.log(err, 'err');
				this.modal.error(
					"พบปัญหาการใช้งาน กรุณาแจ้งผู้ดูแลระบบ",
					this.viewref,
					() => {
						this.ReFocus();
					}
				);
			});
	}

	private async CheckReceiveBabyCard(baByNo: string) {
		return await this.Http
			.post("WH", "SNWR033_CheckReceiveBabyCard", { BABYCARD_NO: baByNo })
			.toPromise()
			.catch((err) => {
				console.log(err, 'err');
				this.modal.error(
					"พบปัญหาการใช้งาน กรุณาแจ้งผู้ดูแลระบบ",
					this.viewref,
					() => {
						this.ReFocus();
					}
				);
			});
	}

	public ConfirmSave() {
		this.receiveList.forEach((item) => {
			if (item.BABYCARD_NO && item.RECEIVE_QTY == 0) {
				item.BABY_CARD_UNDONE = true;
			} else {
				item.BABY_CARD_UNDONE = false;
			}
		});
		if (this.CheckFinishedForSaveInstruction()) {
			this.modal.warning("กรุณารับเข้างานให้เสร็จ", this.viewref, () => { this.ReFocus() });
			return;
		}

		this.modal.confirm(
			(this.CheckReceiveUndone() ? "รับเข้าเบบี้การ์ดไม่เต็มจำนวน" + "<br>" : "") +
			"คุณต้องการบันทึกการทำงานใช่หรือไม่? ",
			this.viewref,
			() => {
				//const data = this.receiveList.filter((item) => item.STATUS_CODE == 'R');
				const data = {
					SCANNED_CARD: this.scannedCard,
					RECEIVE_LIST: this.receiveList
				};
				this.Http
					.post("WH", "SNWR033_Receive", data)
					.subscribe(
						(res) => {
							if (res.status === "Done") {
								this.modal.info(`บันทึกเสร็จสิ้น`, this.viewref, () => {
									this.ReFocus();
								});
								this.InitialProcess();
							} else {
								this.modal.error(
									"พบปัญหาการใช้งาน กรุณาแจ้งผู้ดูแลระบบ",
									this.viewref
								);
							}
						},
						(err) => {
							console.log(err, 'err');
							this.modal.error("พบปัญหาการใช้งาน กรุณาแจ้งผู้ดูแลระบบ",
								this.viewref,
								() => {
									this.ReFocus();
								}
							);
						}
					);

			},
			() => {
				this.ReFocus();
			}
		);
	}

	public ReFocus() {
		setTimeout(() => {
			this.qrString = null;
			this.scannerInput.nativeElement.focus();
		}, 200);
	}

	private CheckFinishedForSaveInstruction() {
		let foundUnfinishedInstruction = this.receiveList
			.filter((item) => item.STATUS_CODE == "R")
			.some(
				(item) => item.BABYCARD_NO && item.RECEIVE_QTY == 0
			);
		return foundUnfinishedInstruction;
	}

	private CheckReceiveUndone() {
		let foundReceiveUndone = this.receiveList.find(
			(item) => !item.BABYCARD_NO || item.BABY_QTY != item.RECEIVE_QTY
		);
		return foundReceiveUndone;
	}

	private CheckCompleteBaby() {
		let checkbaBy = this.receiveList.some(x => x.BABYCARD_NO && x.BABYCARD_NO == this.initialControl.baBy && x.RECEIVE_QTY != x.BABY_QTY)
		if (checkbaBy) {
			this.modal.warning("กรุณาสแกนอะไหล่ให้ครบตามจำนวน", this.viewref, () => { this.ReFocus() });
		}
		return checkbaBy;
	}

	public SetLevelCard() {
        if (this.scannedCard.BABY_LEVEL == 'LVS') {
            this.modal.warning("ไม่สามารถดำเนินการได้",
                this.viewref, () => { this.ReFocus(); }
            );
            return;
        }
        if (this.scannedCard.HAVE_PACKED) {
            this.modal.warning("ไม่สามารถทำรายการนี้ได้ babycard ถูกแพคลงลังแล้ว",
                this.viewref, () => { this.ReFocus(); }
            );
            return;
        }
		this.formSetBabyData = JSON.parse(JSON.stringify(this.scannedCard));
		this.formSetBabyData.TYPE_A_TEMP = this.formSetBabyData.TYPE_A_TEMP ? this.formSetBabyData.TYPE_A_TEMP : this.formSetBabyData.LEVEL2_QTY;
		this.formSetBabyData.TYPE_B_TEMP = this.formSetBabyData.TYPE_B_TEMP ? this.formSetBabyData.TYPE_B_TEMP : this.formSetBabyData.LEVEL3_QTY;
		this.formSetBabyData.TYPE_C_TEMP = this.formSetBabyData.TYPE_C_TEMP ? this.formSetBabyData.TYPE_C_TEMP : this.formSetBabyData.LEVEL1_QTY;
		this.setBabyDialog.title = "Level Setting";
		this.setBabyDialog.OpenDialog();
	}

	public SaveBabyLevel() {
		this.modal.confirm(
			"เบบี้การ์ดทั้งหมดจะถูกนำออกและปรับโครงสร้างใหม่ตามเลเวลที่กำหนด"
			+ "<br>" + "คุณต้องการที่จะแพ็คการ์ดใบนี้ใหม่ ใช่หรือไม่?",
			this.viewref,
			() => {
                const param = this.formSetBabyData;
                this.Http
                    .post("WH", "SNWR033_CalculateBabyLevelExport", param)
                    .subscribe(
                        (res) => {
                            this.receiveList = res.data.Table;
							this.scannedCard = JSON.parse(JSON.stringify(this.formSetBabyData));
                            this.scannedCard.USER_SETTING_LEVEL = 'Y';
                            this.scannedCard.RECEIVING_QTY = this.receiveList.map(x => x.RECEIVE_QTY).reduce((prev, next) => prev + next);
                            this.scannedCard.TOTAL_QTY = this.receiveList.map(x => x.BABY_QTY).reduce((prev, next) => prev + next);
                            this.scannedCard.HAVE_REMAIN = this.receiveList.some(x => x.STATUS_CODE == 'R');
                            this.scannedCard.HAVE_PACKED = this.receiveList.some(x => x.STATUS_CODE == 'C' || x.STATUS_CODE == 'I');
                            this.scannedBaby = undefined;
                            this.qtyLock = true;
                            this.ReFocus();
							this.actionLogsSubject.next({
								timestamp: moment(),
								actionType: "Set new level",
								actionMessage: `TYPE A: ${this.scannedCard?.TYPE_A_TEMP}, TYPE B: ${this.scannedCard?.TYPE_B_TEMP}, TYPE C: ${this.scannedCard?.TYPE_C_TEMP}`,
							});
							this.setBabyDialog.Close();
                        },
                        (err) => {
                            console.log(err, 'err');
                            this.modal.error("พบปัญหาการใช้งาน กรุณาแจ้งผู้ดูแลระบบ",
                                this.viewref,
                                () => {
                                    this.ReFocus();
                                }
                            );
                        }
                    );
			},
			() => {
			}
		);

	}

	@HostListener("window:keydown", ["$event"])
	async onKeyDown(event: KeyboardEvent) {
		if (
			event.key.toUpperCase() === "ENTER" &&
			(<HTMLElement>event.target).id.toUpperCase() === "QRINPUT"
		) {
			this.Enter();
		}
	}

}
