import {
  Component,
  Input,
  OnInit,
  ViewChild,
  ViewContainerRef,
} from "@angular/core";
import { HttpService } from "src/app/core/http.service";
import { ModalService } from "src/app/core/modal.service";
import { Globals } from "src/app/core/global";
import { SelectionModel } from "@angular/cdk/collections";
import { MatTabGroup } from "@angular/material/tabs";


@Component({
  selector: "snwr035",
  templateUrl: "./SNWR035.component.html",
  styleUrls: ["./SNWR035.component.css"]
})
export class SNWR035Component implements OnInit {
  constructor(
    private Http: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private global: Globals
  ) { }

  public CustomerCodeConfig: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "WH",
    SourceMethodName: "SNWR035_GetCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 1,
    UpperCase: true
  }

  public BranchCodeConfig: any = {
    ColName: "LOOKUP_BRANCH_CODE",
    PlaceholderText: "Select Branch Code",
    SourceController: "WH",
    SourceMethodName: "SNWR035_GetBranchCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      CUSTOMER_CODE: ''
    },
    UpperCase: true
  }
  @Input("showHeader") showHeader: boolean = true;

  public paramSearch: any = {}
  public selectedVan: any = undefined
  public isVan: boolean = false;
  public caseList: any = []
  public selection = new SelectionModel<any>(true, []);
  public selectionCase = new SelectionModel<any>(true, []);
  public vanList: any = []
  public newVanList: any = []
  public vanDetail : any = []
  public vanView : any = []
  public tempVan : any =[]
  @ViewChild("dialogVanDetail",{static:false}) dialogVanDetail : any;
  @ViewChild("dialogVanHeader",{static:false}) dialogVanHeader : any;
  @ViewChild('tabs') tabGroup: MatTabGroup;
  @ViewChild("dialogCaseDetail",{static:false}) dialogCaseDetail : any;
  //public tabIndex: number = 0;
  public tempCase : any = []
  public isEdit : boolean = false
  public caseDetail : any = []

  
  ngOnInit() {
    this.paramSearch.STATUS = "ALL";
  }

  public tabClick(tab: any) {
      //this.tabIndex = tab
      if(tab == 0){
        this.SearchVan();
      }
  }

  public SetSelectedCustomerCode(value: any) {
    this.paramSearch.CUSTOMER_CODE = value.CUSTOMER_CODE;
    this.paramSearch.CUSTOMER_NAME = value.CUSTOMER_NAME;
    this.paramSearch.BRANCH_CODE = value.BRANCH_CODE;
    this.BranchCodeConfig.SourceParams.CUSTOMER_CODE = value.CUSTOMER_CODE;

  }

  public SetSelectedBranchCode(value: any) {
    this.paramSearch.BRANCH_CODE = value.BRANCH_CODE;
  }

  public SearchVan() {
    // if (!this.paramSearch.CUSTOMER_CODE  || !this.paramSearch.ORDER_TYPE) {
    //   this.modal.warning("Please input customer code and order type", this.viewref)
    //   return;
    // }
    this.isVan = false;
    this.tabGroup.selectedIndex = 0;
    this.selection.clear();
    
    
    
    this.selectionCase.clear();
    this.caseList = []
    this.vanDetail =[]
    this.newVanList =[]

    this.Http.post("WH", "SNWR035_GetVan", this.paramSearch)
      .subscribe(res => {
        this.vanList = res.Table
        
      }, err => {
        console.log(err, 'err');
        this.modal.error("Found an error, please contact support team", this.viewref);
      })
  }


  public SearchNewVan() {
    if (!this.paramSearch.CUSTOMER_CODE  || !this.paramSearch.ORDER_TYPE) {
      this.modal.warning("Please input customer code and order type", this.viewref)
      return;
    }

    this.isVan =false;
    this.selection.clear();
    this.selectionCase.clear();
    this.caseList = []
    this.vanDetail =[]
    this.Http.post("WH", "SNWR035_GetNewVan", this.paramSearch)
      .subscribe(res => {
        this.newVanList = res.Table
        this.dialogVanHeader.OpenDialog();
      }, err => {
        console.log(err, 'err');
        this.modal.error("Found an error, please contact support team", this.viewref);
      })
  }

  public AddVan(){
    if(this.newVanList.length == 0){
      this.SearchNewVanForEdit()
    }
    this.dialogVanHeader.OpenDialog();
  }

  public SearchNewVanForEdit(){
    
      this.Http.post("WH", "SNWR035_GetNewVan", this.paramSearch)
      .subscribe(res => {
        this.newVanList = res.Table
        //this.dialogVanHeader.OpenDialog();
      }, err => {
        console.log(err, 'err');
        this.modal.error("Found an error, please contact support team", this.viewref);
      })
  }

  public EditVanDetail(data : any){
    
    if(data.STATUS == "CONFIRM"){
      this.SelectNewVan(data)
    }else{
      this.SelectVanForEdit(data)
    }
   
  }

  public SelectVanForEdit(data : any){
    this.isEdit = true
    const param = {
      CUSTOMER_CODE : data.CUSTOMER_CODE,
      BRANCH_CODE : '01',
      ORDER_TYPE : data.ORDER_TYPE,
      VAN_GROUP : data.VAN_GROUP
    }
    this.paramSearch.VAN_GROUP = data.VAN_GROUP
    this.tempVan = this.vanList.filter(x => x.VAN_GROUP == data.VAN_GROUP)
    this.tabGroup.selectedIndex = 1
    this.isVan = true
    this.selectionCase.clear()
    this.Http.post("WH","SNWR035_GetVanForEdit",param)
      .subscribe(res => {
        this.vanDetail = res.Table
        this.caseList = res.Table1;
        this.caseList.map(x => {
          if(x.VAN_GROUP == data.VAN_GROUP)
          this.selectionCase.select(x)
        })
        this.FindTotalCase();
        //this.dialogVanDetail.OpenDialog();
      })
  }

  

  public SelectNewVan(data : any){
    // if(this.selection.selected.length == 0){
    //   this.modal.warning("Please select van number",this.viewref)
    //   return
    // }

    this.tempCase = []
    //this.tempCase = this.selectionCase.selected
    // const x = this.selection.selected.map(x => x.VAN_NO).join(",")
    const x = data.VAN_NO
    //this.paramSearch.VAN_NO = x
    this.isVan = true
    this.tabGroup.selectedIndex = 1
    //this.tempVan = []
    this.tempVan = this.vanList.filter(x => x.VAN_NO == data.VAN_NO)
    const param = {
      CUSTOMER_CODE : data.CUSTOMER_CODE,
      BRANCH_CODE : '01',
      ORDER_TYPE : data.ORDER_TYPE,
      VAN_NO : x
    }
    this.Http.post("WH","SNWR035_GetCaseByNewVan",param)
    .subscribe(res =>{
      console.log(res,"SNWR035_GetCaseByNewVan")
      this.selectionCase.clear();
      this.vanDetail = res.Table
      this.caseList = res.Table1;
      if(this.tempCase.length > 0){
        this.tempCase.map(x =>{
          let find = this.caseList.find(z => z.CASE_NO == x.CASE_NO)
          const totalQty = this.vanDetail.find(c => c.CASE_NAME == x.CASE_NAME).QTY
          const totalCase = this.tempCase.filter(v => v.CASE_NAME == x.CASE_NAME).length
          if(find && (totalQty >= totalCase)){
            this.selectionCase.select(find)
          }
        })
      }
      this.FindTotalCase();
      
      //this.dialogVanHeader.Close()
    })
  }


  // public SelectVanForEdit(){
  //   const x = this.selection.selected.map(x => x.VAN_NO).join(",")
  //   this.paramSearch.VAN_NO = x
  //   this.tempCase = []
  //   this.tempCase = this.selectionCase.selected
  //   this.tempVan = this.vanList.filter(x => x.VAN_GROUP == this.paramSearch.VAN_GROUP)
  //   this.selection.selected.map(x =>{
  //     this.tempVan.push(x)
  //   })
  //   this.Http.post("WH","SNWR035_GetCaseByNewVan",this.paramSearch)
  //   .subscribe(res =>{
  //     this.selectionCase.clear();

  //     res.Table.map(x => {
  //       let find = this.vanDetail.find(z => z.CASE_NAME == x.CASE_NAME)
  //       if(find){
  //         find.QTY += x.QTY
  //       }else{
  //         this.vanDetail.push(x)
  //       }
  //     })

  //     this.caseList = this.caseList.filter(x => x.VAN_GROUP)
  //     Array.prototype.push.apply(this.caseList,res.Table1);
  //     if(this.tempCase.length > 0){
  //       this.tempCase.map(x =>{
  //         let find = this.caseList.find(z => z.CASE_NO == x.CASE_NO)
  //         const totalQty = this.vanDetail.find(c => c.CASE_NAME == x.CASE_NAME).QTY
  //         const totalCase = this.tempCase.filter(v => v.CASE_NAME == x.CASE_NAME).length
  //         if(find && (totalQty >= totalCase)){
  //           this.selectionCase.select(find)
  //         }
  //       })
  //     }
  //     this.FindTotalCase();
  //     this.dialogVanHeader.Close()
  //   })
  // }


  public GetCaseDetail(data : any){
    this.Http.post("WH","SNWR035_GetCaseDetail",data)
    .subscribe(res =>{
      this.caseDetail = res.Table
      this.dialogCaseDetail.OpenDialog()
    })
  }

  private FindTotalCase(){
    this.vanDetail.map(x => {
      const totalCase = this.selectionCase.selected.filter(z => z.CASE_NAME == x.CASE_NAME).length
      x.TOTAL_CASE = totalCase
    })
  }

  public Clear() {
    this.caseList = []
    this.vanList = []
    this.selection.clear()
    this.selectionCase.clear()
    this.paramSearch = {}
    this.selectedVan = undefined
  }

  public Save() {
    if(this.selectionCase.selected.length == 0){
      this.modal.warning("Please select case number",this.viewref)
      return;
    }
    this.modal.confirm("Do you want to save?", this.viewref, () => Confirm())
    let Confirm = () => {
      let data = {
        vanNo : "",
        // vanList: this.isEdit ? this.tempVan : this.selection.selected,
        vanList : this.tempVan,
        customer: this.tempVan[0].CUSTOMER_CODE,
        branch : "01",
        order_type: this.tempVan[0].ORDER_TYPE,
        caseList: this.selectionCase.selected
      }

      this.Http.post("WH", "SNWR035_SaveVan", data)
        .subscribe(res => {
          if (res.STATUS_MESSAGE == "DONE") {
            // this.modal.info("Save data complete, Van Group Number is " + res.VAN_GROUP, this.viewref)
            this.modal.info("Save data complete", this.viewref)
            this.isVan = false;
            
            this.SearchVan();
            //this.tabGroup.selectedIndex = 0;
          } else {
            this.modal.error("Found an error, please contact support team", this.viewref)
          }
        }, err => {
          console.log(err, 'err');
          this.modal.error("Found an error, please contact support team", this.viewref);
        })
    }
  }

  public isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.vanList.length;
    return numSelected === numRows;
  }

  public Toggle() {
    if (this.isAllSelected()) {
      this.selection.clear()
    } else {
      this.vanList.forEach((row) => {

        this.selection.select(row);

      })
    }
  }

  public CheckVanChange(event, row) {

    if (event.checked) {
      this.vanList.forEach((x) => {
        if(x.VAN_GROUP && x.VAN_GROUP == row.VAN_GROUP)
          this.selection.select(x);
        })
    } else {
      this.vanList.forEach((x) => {
        if(x.VAN_GROUP && x.VAN_GROUP == row.VAN_GROUP)
          this.selection.deselect(x);
        })
    }
  }


  public isAllSelectedCase() {
    const numSelected = this.selectionCase.selected.length;
    const numRows = this.vanList.length;
    return numSelected === numRows;
  }

  public ToggleCase() {
    if (this.isAllSelectedCase()) {
      this.selectionCase.clear()
    } else {
      this.caseList.forEach((row) => {

        this.selectionCase.select(row);

      })
    }
  }

  public CheckboxChange(event, row) {
    let find = this.vanDetail.find(x => x.CASE_NAME == row.CASE_NAME)
    if (event.checked) {
          if(find)
          find.TOTAL_CASE += 1;
    } else {
          if(find)
          find.TOTAL_CASE -= 1;
    }
  }

  public DisableCheckbox(caseName){
    return this.vanDetail.some(x => x.CASE_NAME == caseName && x.QTY == x.TOTAL_CASE)
  }

  // public DisableCheckbox(caseName) {
  //   let find = this.vanDetail.find(x => x.CASE_NAME == caseName)
  //   let filter = this.selectionCase.selected.filter(x => x.CASE_NAME == caseName).length
  //   return find.QTY == filter
  // }

  public Return(data : string) {

    this.modal.confirm("Do you want to return?", this.viewref, () => Confirm())

    let Confirm = () => {
     
      this.Http.post("WH", "SNWR035_ReturnVan", data)
        .subscribe(res => {
          if (res.STATUS_MESSAGE == "DONE") {
            this.modal.info("Return complete", this.viewref)
            this.SearchVan();
          } else {
            this.modal.error("Found an error, please contact support team", this.viewref)
          }
        }, err => {
          console.log(err, 'err');
          this.modal.error("Found an error, please contact support team", this.viewref)
        })
    }
  }


  public BackToVan() {
    //this.tabIndex = 0;
    
    this.isVan = false;
    this.selection.clear();
    this.selectionCase.clear();
    this.caseList = []
    this.vanDetail =[]
    this.newVanList =[]
    this.tabGroup.selectedIndex = 0;

    if (this.paramSearch.CUSTOMER_CODE  && this.paramSearch.ORDER_TYPE) {
      this.Http.post("WH", "SNWR035_GetVan", this.paramSearch)
      .subscribe(res => {
        this.vanList = res.Table
        //this.tabGroup.selectedIndex = 0;
      }, err => {
        console.log(err, 'err');
        this.modal.error("Found an error, please contact support team", this.viewref);
      })
    }

  
  }


}
