import { Component, ElementRef, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { ModalService } from 'src/app/core/modal.service';
import { SelectionModel } from '@angular/cdk/collections';


@Component({
    selector: 'SNWR037',
    templateUrl: 'SNWR037.component.html',
    styleUrls: ['SNWR037.component.css']
})

export class SNWR037Component implements OnInit {
    constructor(
        private http: HttpService,
        private router: Router,
        private global: Globals,
        private modal: ModalService,
        private viewref: ViewContainerRef
  ) { }

  @ViewChild("dialogAction", { static: false }) dialogAction: any;
  @ViewChild("dialogPrint", { static: false }) dialogPrint: any;
  
  public tabindex: number = 0;
  public caseGroup: any = {};
  public formData: any = {};
  public formDataPrint: any = {};

  //Outer Case
  public paramSearchOuter: any = {};
  public tableDataOuter: Array<any> = [];

  //Inner Case
  public paramSearchInner: any = {};
  public tableDataInner: Array<any> = [];

  //File Upload
  public FileName: string = "";
  public fileUrl;
  public tableUpload = []
  public tableUploadFilter = []
  public selection = new SelectionModel<any>(true, []);
  public total_error :number = 0;
  public error_list = []

  public lookupOuterCaseTypeConfig: any = {
    ColName: "LOOKUP",
    PlaceholderText: "Select Case Type",
    SourceController: "WH",
    SourceMethodName: "SNWR037_GetCaseType",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedOuterCaseType(val) {
    this.paramSearchOuter.CASE_TYPE = val.CASE_TYPE;
    this.Search();
  }

  public lookupInnerCaseTypeConfig: any = {
    ColName: "LOOKUP",
    PlaceholderText: "Select Case Type",
    SourceController: "WH",
    SourceMethodName: "SNWR037_GetCaseTypeInner",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedInnerCaseType(val) {
    this.paramSearchInner.CASE_TYPE = val.CASE_TYPE;
    this.Search();
  }

  public lookupTypeListConfigDialog: any = {
    ColName: "LOOKUP_CASE_TYPE",
    PlaceholderText: "Select Type List",
    SourceController: "WH",
    SourceMethodName: "SNWR037_GetTypeList",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }
  public lookupInnerTypeListConfigDialog: any = {
    ColName: "LOOKUP_CASE_TYPE",
    PlaceholderText: "Select Inner Type List",
    SourceController: "WH",
    SourceMethodName: "SNWR037_GetInnerTypeList",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public lookupPackageListConfigDialog: any = {
    ColName: "LOOKUP_PACKAGE_TYPE",
    ColValue: "",
    PlaceholderText: "Select Package List",
    SourceController: "WH",
    SourceMethodName: "SNWR037_GetPackageList",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true,
    SourceParams: {
      P_CASE_GROUP: "OT"
    },
  }

  public SetSelectedTypeListDialog(val) {
    this.formData.CASE_TYPE = val.CASE_TYPE;
    this.formData.CASE_TYPE_DESCRIPTION = val.CASE_TYPE_DESCRIPTION;
  }

  public SetSelectedPackageListDialog(val) {
    
    this.formData.PACKAGE = val.PACKAGE_TYPE;
    this.formData.CASE_IN_INVOICE = val.CASE_IN_INVOICE;
  }

  ngOnInit() {
    this.GetDataByTabIndex();
  }

  public SelectedTabChange(event: any) {
    this.tabindex = event.index;
    this.GetDataByTabIndex();
  }

  public GetDataByTabIndex() {
    if (this.tabindex === 0) {
      this.caseGroup.VALUE = "OT";
      this.caseGroup.TEXT = "Outer Case";
    } else if (this.tabindex === 1) {
      this.caseGroup.VALUE = "IN";
      this.caseGroup.TEXT = "Inner Case";
    }
    this.lookupPackageListConfigDialog.SourceParams.P_CASE_GROUP = this.caseGroup.VALUE;
  }

  public Search() {
    const index = this.tabindex;
    const type = index == 0? this.paramSearchOuter.CASE_TYPE : this.paramSearchInner.CASE_TYPE;
    const caseType = !type ? "NULL" : this.global.EscapeCharacter(type);
    const caseGroup = this.caseGroup.VALUE;
    this.http.get('WH', 'SNWR037_Search', caseType, caseGroup)
    .subscribe(res => {
      if(this.tabindex === 0){
        this.tableDataOuter = res.Table;
      }else if(this.tabindex === 1){
        this.tableDataInner = res.Table;
      }
    },(err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contract support team", this.viewref);
  });
  }
  
  public Add() {
    this.formData = {};
    this.formData.TYPE = "ADD";
    this.formData.CAN_CONFIG = "N";
    this.formData.CASE_GROUP = this.caseGroup.VALUE;
    this.formData.CASE_GROUP_TEXT = this.caseGroup.TEXT;
    this.dialogAction.width="650px";
    this.dialogAction.height = "400px"; 
    this.dialogAction.title = "Add " + this.caseGroup.TEXT + "";
    this.dialogAction.OpenDialog();
  }

  public Edit(data) {    
    this.formData = { ...data };
    this.formData.TYPE = "EDIT";
    this.formData.CASE_GROUP = data.CASE_GROUP;
    this.formData.CASE_GROUP_TEXT = this.caseGroup.TEXT;
    this.dialogAction.width="650px";
    this.dialogAction.height = "450px";
    this.dialogAction.title = "Edit " + this.caseGroup.TEXT + "";
    this.dialogAction.OpenDialog();
  }

  public Delete(data) {
    this.modal.confirm("Do you want to delete record", this.viewref, ()=> ConfirmDelete());

    let ConfirmDelete = () => {
      const params = {  CASE_GROUP : data.CASE_GROUP, ID : data.ID };
      this.http.post("WH","SNWR037_Delete", params)
      .subscribe(res =>{
        if (res.STATUS == 'DONE') {
          this.modal.info('Delete record complete', this.viewref);
          this.Search();
        } else {
          this.modal.error('Found an error, please contract support team.', this.viewref);
        }
      },err =>{
        console.log(err, 'err')
        this.modal.error('Found an error, please contract support team.', this.viewref);
      })
    }
  }

  public SaveAdd() {
    if(!this.formData.CASE_TYPE || !this.formData.CASE_NAME ){
      this.modal.warning("Please input Case Type and Case Name",this.viewref);
      return;
    }
    else if(!this.formData.PACKAGE){
      this.modal.warning("Please input PACKAGE",this.viewref);
      return;
    }
    else if(this.caseGroup.VALUE == 'OT' && this.formData.CAN_CONFIG == 'N' && (!this.formData.CASE_WIDTH || !this.formData.CASE_DEPTH || !this.formData.CASE_HEIGHT)){
      this.modal.warning("If Able config size = 'N'<br>Please input all units<br>Width, Depth, Height",this.viewref);
      return;
    }

    this.modal.confirm("Do you want to save change you have made?", this.viewref, ()=> ConfirmAdd());

    let ConfirmAdd = () => {
      this.http.post('WH', 'SNWR037_Insert', this.formData)
        .subscribe(res => {
          if (res.STATUS == 'DONE') {
            this.Search();
            this.dialogAction.Close();
            this.modal.info(res.MESSAGE, this.viewref);
          } else {
            this.modal.warning(res.MESSAGE, this.viewref);
          }
        }, (err) => {
          console.log(err, 'err')
          this.modal.error("Found an error, please contact support team", this.viewref);
        })
    }
  }

  public CancelAdd() {
    this.dialogAction.Close();
  }

  public SaveEdit() {
    if(!this.formData.CASE_TYPE || !this.formData.CASE_NAME){
      this.modal.warning("Please input Case Type and Case Name",this.viewref);
      return;
    }
    else if(!this.formData.PACKAGE){
      this.modal.warning("Please input PACKAGE",this.viewref);
      return;
    }
    else if(this.caseGroup.VALUE == 'OT' && this.formData.CAN_CONFIG == 'N' && (!this.formData.CASE_WIDTH || !this.formData.CASE_DEPTH || !this.formData.CASE_HEIGHT)){
      this.modal.warning("If Able config size = 'N'<br>Please input all units<br>Width, Depth, Height",this.viewref);
      return;
    }

    this.modal.confirm("Do you want to save change you have made?", this.viewref, () => ConfirmEdit());

    let ConfirmEdit = () => {
      this.http.post('WH', 'SNWR037_Update', this.formData)
        .subscribe(res => {
          if (res.STATUS == 'DONE') {
            this.Search();
            this.dialogAction.Close();
            this.modal.info(res.MESSAGE, this.viewref);
          } else {
            this.modal.warning(res.MESSAGE, this.viewref);
          }
        }, (err) => {
          console.log(err, 'err')
          this.modal.error("Found an error, please contact support team", this.viewref);
        });
    }
  }

  public CancleEdit() {
    this.dialogAction.Close();
  }

  public lookupOuterCaseNameConfig: any = {
    ColName: "LOOKUP_CASE_NAME",
    PlaceholderText: "Select Outer Case Name",
    SourceController: "WH",
    SourceMethodName: "SNWR037_GetCaseName",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public lookupInnerCaseNameConfig: any = {
    ColName: "LOOKUP_CASE_NAME",
    PlaceholderText: "Select Inner Case Name",
    SourceController: "WH",
    SourceMethodName: "SNWR037_GetCaseNameInner",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedCaseName(values: any) {
    this.formDataPrint.CASE_NAME = values.CASE_NAME;
    this.formDataPrint.CASE_TYPE = values.CASE_TYPE;
    this.formDataPrint.PACKAGE = values.PACKAGE;
  }

  public OpenPrintDialog(){
    this.fileUrl = null;
    this.formDataPrint = {};
    this.formDataPrint.CASE_GROUP = this.caseGroup.VALUE;
    this.formDataPrint.CASE_GROUP_TEXT = this.caseGroup.TEXT;
    this.formDataPrint.QTY = 1;
    this.dialogPrint.width ="840px";
    this.dialogPrint.height = "625px"; 
    this.dialogPrint.title = "Print " + this.caseGroup.TEXT + " QR code";
    this.dialogPrint.OpenDialog();
  }

  public PrintCaseNameQRCode(){
    if(!this.formDataPrint.CASE_NAME ){
      this.modal.warning("Please select Case Name to print.",this.viewref);
      return;
    }
    // else if(!this.formDataPrint.QTY){
    //   this.modal.warning("Please input quantity to print.",this.viewref);
    //   return;
    // }
    if(this.formDataPrint.CASE_GROUP == "OT"){
      this.global.GoToReport("PMS_RPT_WMS_SNWR037_PRINT_OUTER_CASE",
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_CASE_NAME: this.formDataPrint.CASE_NAME,
        P_QTY: this.formDataPrint.QTY
      });
    }else if(this.formDataPrint.CASE_GROUP == "IN"){
      this.global.GoToReport("PMS_RPT_WMS_SNWR037_PRINT_INNER_CASE",
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_CASE_NAME: this.formDataPrint.CASE_NAME,
        P_QTY: this.formDataPrint.QTY
      });
    }
  }
  
  public PreviewCaseNameQRCode() {
    let params: any;
    if(this.formDataPrint.CASE_GROUP == "OT"){
      params = {
        ReportName: "PMS_RPT_WMS_SNWR037_PRINT_OUTER_CASE",
        ReportType: "PDF",
        ReportPrefix: this.formDataPrint.CASE_TYPE + "_" + this.formDataPrint.CASE_NAME,
        ReportSuffix: ".PDF",
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_CASE_NAME: this.formDataPrint.CASE_NAME,
        P_QTY: this.formDataPrint.QTY,
      };
    }else if(this.formDataPrint.CASE_GROUP == "IN"){
      params = {
        ReportName: "PMS_RPT_WMS_SNWR037_PRINT_INNER_CASE",
        ReportType: "PDF",
        ReportPrefix: this.formDataPrint.CASE_TYPE + "_" + this.formDataPrint.CASE_NAME,
        ReportSuffix: ".PDF",
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_CASE_NAME: this.formDataPrint.CASE_NAME,
        P_QTY: this.formDataPrint.QTY,
      };
    }
    this.http
      .Download("WH", "SNWR037_Preview_Case", params)
      .subscribe((res) => {
        if (res) {
          this.SetIFrameContent(res);
        }
      });
  }

  private SetIFrameContent(content: any) {
    const file = new Blob([content], { type: content.type });
    const fileUrl = URL.createObjectURL(file);
    this.fileUrl = fileUrl;
  }
}