import { Component, OnInit, ViewContainerRef } from "@angular/core";
import { HttpService } from "src/app/core/http.service";
import { ModalService } from "src/app/core/modal.service";
import { Globals } from "src/app/core/global";

@Component({
  selector: "SNWR038",
  templateUrl: "SNWR038.component.html",
})
export class SNWR038Component implements OnInit {
  constructor(
    private modal: ModalService,
    private viewRef: ViewContainerRef,
    private http: HttpService,
    private global: Globals
  ) {}

  public params: any = {};
  public noFrom: any;
  public noTo: any;
  public fileUrlPart;

  public ngOnInit() {
    this.params.PRINT_NUMBER = 0;
  }

  public FindInnerCaseNumber() {
    this.http.post("WH", "SNWR038_Get_Innercase_Number", this.params).subscribe(
      (res) => {
        if (res.Table[0]) {
          const innercase_no = res.Table[0].INNERCASE_NO;
          this.global.GoToReport("PMS_RPT_WMS_SNWR038_INNER_CASE", {
            P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
            P_NO_FROM: innercase_no,
            P_NO_TO: innercase_no,
          });
        } else {
          this.modal.error("Unavailable inner case number.", this.viewRef);
        }
      },
      (err) => {
        console.log(err, 'err');
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewRef
        );
      }
    );
  }

  public Print() {
    this.global.GoToReport("PMS_RPT_WMS_SNWR038_INNER_CASE", {
      P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      P_NO_FROM: this.noFrom,
      P_NO_TO: this.noTo,
    }, true, false);
    
    this.global.GoToExport("PMS_RPT_WMS_SNWR038_INNER_CASE_EXCEL", {
      P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      P_NO_FROM: this.noFrom,
      P_NO_TO: this.noTo,
    }, true, "EXCELOPENXML");
  }

  public PrevinnercaseNumber() {
    if (this.params.PRINT_NUMBER < 1) {
      this.modal.warning("Inner case QTY must be more than 0.", this.viewRef);
    } else {
      this.http
        .post("WH", "SNWR038_Print_Innercase_Number", this.params)
        .subscribe((res) => {
          if (res.Result == "Done") {
            this.noFrom = res.NoFrom;
            this.noTo = res.NoTo;
            this.modal.info(`Preview inner case number : <BR> ${res.NoFrom} to ${res.NoTo}`, this.viewRef,
              () => {
                this.Preview();
                //this.params.PRINT_NUMBER = 0;
              }
            );
          }
        }, (err) => {
          console.log(err, 'err');
          this.modal.error("Found an error, please contact support team", this.viewRef);
        });
    }
  }

  public Preview() {
    this.fileUrlPart = null;
    this.http
      .Download("WH", "SNWR038_Preview_Casenumber", {
        ReportPrefix: "PMS_RPT_WMS_SNWR038_INNER_CASE",
        ReportSuffix: ".PDF",
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_NO_FROM: this.noFrom,
        P_NO_TO: this.noTo,
      })
      .subscribe((res) => {
        if (res) {
          this.SetIFramePartContent(res);
        }
      });
  }

  private SetIFramePartContent(content: any) {
    const file = new Blob([content], { type: content.type });
    const fileUrlPart = URL.createObjectURL(file);
    this.fileUrlPart = fileUrlPart;
  }

}
