import {
	Component,
	ElementRef,
	HostListener,
	OnInit,
	ViewChild,
	ViewContainerRef,
} from "@angular/core";
import { HttpService } from "src/app/core/http.service";
import { ModalService } from "src/app/core/modal.service";
import { Observable, Subject } from "rxjs";
import {
	CaseNoExport,
	InvoiceExportControl,
	InvoiceExportControlSetValue,
} from "src/app/core/WHOutboundController/InvoiceControl";
import {
	PackExportToken,
	PackExportTokenExtractor
} from "src/app/core/WHOutboundController/PackTokenExtractor";
import { map } from "rxjs/operators";
import * as moment from "moment";
import { DialogTemplateComponent } from "src/app/components/shared/dialog-template/dialog-template.component";
import { Globals } from "src/app/core/global";

type ActionLog = {
	timestamp: moment.Moment;
	actionType: string;
	actionMessage: string;
};
@Component({
	selector: "SNWR039",
	templateUrl: "./SNWR039.component.html",
	styleUrls: ["./SNWR039.component.css"],
	providers: [PackExportTokenExtractor],
})
export class SNWR039Component implements OnInit {
	constructor(
		private Http: HttpService,
		private modal: ModalService,
		private viewref: ViewContainerRef,
		private extractor: PackExportTokenExtractor,
		private global: Globals
	) { }

	public customerInfo: {
		code: string;
		name: string;
		zone: string;
		routeCode: string;
		orderType: string;
		customerCode: string;
		customerName: string;
		branchCode: string;
		branchName: string;
	};
	public existItem: any;
	public caseTypeList: any = [];
	public qrString: string;
	public params: any = {};
	public totalItems: number = 0;
	public packingList: any = [];
	public packingList_unpack: any = [];
	public packingListFiltered: any = [];

	public selectedPartsFiltered: any[];
	public scannedCase: any;
	public scannedBaby: any;
	public popupCase: CaseNoExport;
	public popupCaseExtension: any = [];
	public caseIsPacked: string;
	public caseIsPreInvoiced: string;
	private repackCase: boolean = false;
	public showHistory: boolean = false;

	@ViewChild("scannerInput", { read: ElementRef }) scannerInput: ElementRef;
	@ViewChild("inputCaseDialog") inputCaseDialog: DialogTemplateComponent;
	@ViewChild("saveCaseTypeButton", { read: ElementRef }) saveCaseTypeButton: ElementRef;
	
	public calculateData: any = [];
	@ViewChild("infoCaseDialog") infoCaseDialog: DialogTemplateComponent;

	public initialControl: InvoiceExportControl = new InvoiceExportControl();
	private initialControlSubject: Subject<InvoiceExportControlSetValue> = new Subject<InvoiceExportControlSetValue>();
	public actionLogs: ActionLog[] = [];
	private actionLogsSubject: Subject<ActionLog> = new Subject<ActionLog>();
	private packedWatcher: Subject<boolean> = new Subject<boolean>();

	ngOnInit() {
		this.InitialProcess();
		this.GetInnerCaseType();
		this.initialControlSubject
			.pipe(map((control) => control))
			.subscribe((control) => {
				if (control) {
					this.initialControl.set(control);
					if (control.propName === "caseNoExport")
						this.SetScannedCase(this.initialControl.caseNoExport);
					if (control.propName === "baBy")
						this.SetScannedBaby(this.initialControl.baBy);
					if (control.propName === "caseType")
						this.SetScannedCaseType(this.initialControl.caseType);
					this.qrString = undefined;
				}
			});

		this.actionLogsSubject.subscribe((action: ActionLog) => {
			this.actionLogs.push(action);
			this.actionLogs = this.actionLogs.slice();
		});
	}

	private GetInnerCaseType() {
		this.caseTypeList = []
		//GetInnerCaseTypeExportAll
		this.Http.get("WH", "SNWR039_GetCaseTypeAll")
			.subscribe(res => {
				this.caseTypeList = res.Table
			}, err => {
				console.log(err, 'err');
				this.modal.error("พบปัญหาการใช้งาน กรุณาแจ้งผู้ดูแลระบบ", this.viewref);
			})
	}

	private InitialProcess() {
		this.initialControl.reset();
		this.actionLogs = [];
		this.params = {};
		this.qrString = null;
		this.totalItems = 0;
		this.customerInfo = undefined;
		this.scannedCase = undefined;
		this.scannedBaby = undefined;
		this.packingList = [];
		this.packingList_unpack = [];
		this.packingListFiltered = [];
		this.selectedPartsFiltered = [];
		this.repackCase = false;
	}

	public async Reset() {
		if (this.scannedCase) {
			this.modal.confirm("คุณแน่ใจที่จะแพ็คใหม่ใช่หรือไม่?", this.viewref, () => {
				const params = {
				  CASE_NO: this.scannedCase.caseNo
				}
				this.Http.post("WH", "SNWR039_ClearInnerCaseExportTemp", params)
				  .subscribe(
					(res) => {
					  if (res) { console.log("Done ClearInnerCaseExporTemp"); 
					  this.InitialProcess();
					}
					  else { console.log("Error ClearInnerCaseExporTemp"); }
					},
					(err) => {
					  console.log(err, "error");
					}
				  );
			});
		} else {
			this.InitialProcess();
		}
		this.ReFocus();
	}

	public async Enter() {
		if (this.qrString?.trim() === "" || this.qrString == "" || !this.qrString) {
			return;
		}
		try {
			const value = this.qrString.trim();
			let scanValue = value.split("-");
			if (scanValue.length == 2 && scanValue[0].toUpperCase() === "I") {
				//Check Case No that was used or avaliable to used
				const checkCase: any = await this.GetCaseNo(value);
				if (checkCase) {
					if (checkCase.Result == "Done") {
						if (this.caseIsPacked == 'Y' || this.caseIsPreInvoiced == 'Y') {
							this.caseIsPacked = 'N'
							this.caseIsPreInvoiced = 'N'
							this.customerInfo = undefined;
							this.scannedBaby = undefined;
							this.packingList = [];
							this.packingList_unpack = [];
							this.packingListFiltered = [];
						}
						const caseNo: CaseNoExport = new CaseNoExport(
							null,
							null,
							null,
							null,
							null,
							checkCase.CaseNo,
							checkCase.CaseDate,
							null,
							null,
							null
						);
						this.initialControlSubject.next({
							propName: "caseNoExport",
							value: caseNo
						});
					}
				} else {
					const checkType = this.caseTypeList.find(item => item.CASE_NAME == value);
					if (checkType) {
						this.initialControlSubject.next({
							propName: "caseType",
							value: value,
						});
					} else {
						this.modal.warning("ไม่พบข้อมูล",
							this.viewref, () => { this.ReFocus() }
						);
					}
				}
			}
			else if (scanValue.length == 3) {
				const checkType = this.caseTypeList.find(item => item.CASE_NAME == value);
				if (checkType) {
					this.initialControlSubject.next({
						propName: "caseType",
						value: value,
					});
				} else {
					if (!this.scannedCase) {
						let qrcode = null;
						qrcode = await this.CheckInnerPackBabyCard(value)
							.then((res) => {
								const response = res[0];
								if (response.STATUS === "Done") {
									return response.QRCODE;
								} else if (response.STATUS === "OnUsing") {
									this.modal.warning(
										"เคสนี้กำลังถูกใช้โดยพนักงานอื่น<br/>รหัสพนักงานที่ใช้งาน: " + response.USERS,
										this.viewref,
										() => {
											this.ReFocus();
										}
									);
								} else {
									this.modal.warning("ไม่พบข้อมูล", this.viewref,
									() => { this.ReFocus(); });
									return null;
								}
							});

						if (qrcode) {
							//Set QR code
							this.existItem = { BABYCARD_NO: value, FROM_CHECK_EXIST_BABYCARD: true };
							this.GetCaseDetail(qrcode);
						}

					} else {
						if (!this.customerInfo) {
							this.initialControlSubject.next({
								propName: "baBy",
								value: value,
							});
						} else {
							if (scanValue[0] !== this.customerInfo.customerCode) {
								this.modal.warning("รหัสลูกค้าไม่ตรงกับงานที่ทำอยู่",
									this.viewref, () => { this.ReFocus() }
								);
							}
							else if (scanValue[0] === this.customerInfo.customerCode) {
								this.initialControlSubject.next({
									propName: "baBy",
									value: value,
								});
							} else {
								this.modal.warning("ไม่พบข้อมูล",
									this.viewref, () => { this.ReFocus() }
								);
							}
						}
					}
				}
			}
			else {
				const checkType = this.caseTypeList.find(item => item.CASE_NAME == value);
				if (checkType) {
					this.initialControlSubject.next({
						propName: "caseType",
						value: value,
					});
				} else {
					this.modal.warning("ไม่พบข้อมูล",
						this.viewref, () => { this.ReFocus() }
					);
				}
			}
		}
		catch (ex) {
			this.modal.warning("ข้อมูลที่สแกนไม่ถูกต้อง",
				this.viewref, () => { this.ReFocus() }
			);
		}
	}

	private async GetCaseNo(caseNo: string): Promise<CaseNoExport> {
		let checkCase = null;
		await this.Http
			.get("WH", "SNWR039_GetAvailableCase", "EXPORT", caseNo)
			.toPromise()
			.then((res) => {
				if (res.Result === "Done" && res.CaseNo === caseNo) {
					checkCase = res;
				}
				else if (res.Result === "Exist") {
					this.modal.confirm(
						"หมายเลขเคสถูกใช้งานแล้ว <br>คุณต้องการที่จะเปิดกล่องเพื่อแก้ไข ใช่หรือไม่?",
						this.viewref,
						() => {
							this.GetCaseDetail(caseNo);
						},
						() => {
							this.ReFocus();
						}
					);
					checkCase = res; //return not null state for not search case type
				}
				else if (res.Result === "Invoice") {
					this.modal.confirm(
						"ไม่สามารถใช้เคสนี้ได้ <br>เนื่องจากมีการออก invoice หรือ pre-invoice แล้ว<br>คุณต้องการที่จะเปิดกล่องเพื่อดูข้อมูลใช่หรือไม่",
						this.viewref,
						() => {
							this.GetCaseDetail(caseNo);
						},
						() => {
							this.ReFocus();
						}
					);
					checkCase = res; //return not null state for not search case type
				}
				else if (res.Result === "OnUsing") {
					this.modal.warning(
						"เคสนี้กำลังถูกใช้โดยพนักงานอื่น<br/>รหัสพนักงานที่ใช้งาน: " + res.User,
						this.viewref,
						() => {
							this.ReFocus();
						}
					);
					checkCase = res; //return not null state for not search case type
				}
				else {
					//return null to give state not found!!!
				}
			})
			.catch((err) => {
				console.log(err, 'err');
				this.modal.error(
					"พบปัญหาการใช้งาน กรุณาแจ้งผู้ดูแลระบบ",
					this.viewref, () => { this.ReFocus() }
				);
			});

		return checkCase;
	}

	private async GetCaseDetail(caseNo: string): Promise<CaseNoExport> {
		let checkCase: CaseNoExport = null;
		await this.Http.get("WH", "SNWR039_GetCaseInfo", caseNo)
			.subscribe((res) => {
				if (res.Data.length > 0) {
					this.customerInfo = undefined;
					if (!this.SetCustomerInfo(res.Data[0])) {
						return;
					}
					this.scannedCase = undefined;
					this.scannedBaby = undefined;
					this.packingList = res.Data;
					this.packingList_unpack = JSON.parse(JSON.stringify(res.Data));
					this.packingList.sort((a, b) => b.CASE_SEQ - a.CASE_SEQ);
					const caseNo: CaseNoExport = new CaseNoExport(
						res.Data[0].CUSTOMER_CODE,
						res.Data[0].CUSTOMER_NAME,
						res.Data[0].BRANCH_CODE,
						res.Data[0].BRANCH_NAME,
						res.Data[0].ORDER_TYPE,
						res.Data[0].CASE_NO,
						res.Data[0].CASE_DATE,
						res.Data[0].CASE_TYPE,
						res.Data[0].CASE_NAME,
						null
					);
					this.repackCase = true;
					this.scannedBaby = res.Data[0];
					this.caseIsPacked = res.Data[0].IS_PACKED;
					this.caseIsPreInvoiced = res.Data[0].IS_PRE_INVOICED;
					//Get total items
					this.totalItems = this.packingList.length;
					//Get filtered part
					this.initialControlSubject.next({
						propName: "caseNoExport",
						value: caseNo
					});
					checkCase = caseNo;
					this.FilterTableData();
				}
				else if (res.status == "OnUsing") {
					this.modal.warning(
						"เคสนี้กำลังถูกใช้โดยพนักงานอื่น<br/>รหัสพนักงานที่ใช้งาน: " + res.User,
						this.viewref,
						() => {
							this.ReFocus();
						}
					);
				}
				else {
					this.modal.warning(
						"ไม่พบข้อมูล",
						this.viewref, () => { this.ReFocus() }
					);
				}
			},
				(err) => {
					console.log(err, 'err');
					this.modal.error("พบปัญหาการใช้งาน กรุณาแจ้งผู้ดูแลระบบ", this.viewref,
						() => {
							this.ReFocus();
						}
					);
				});

		return checkCase;
	}

	private async CheckInnerPackBabyCard(baByNo: string) {
		return await this.Http
			.post("WH", "SNWR039_CheckInnerPackBabyCard", { BABYCARD_NO: baByNo })
			.toPromise()
			.catch((err) => {
				console.log(err, 'err');
				this.modal.error(
					"พบปัญหาการใช้งาน กรุณาแจ้งผู้ดูแลระบบ",
					this.viewref,
					() => { }
				);
			});
	}

	private SetCustomerInfo(packData: any) {
		const customerInfo = {
			code: `${packData.CUSTOMER_CODE}${packData.BRANCH_CODE}`,
			name: `${packData.CUSTOMER_NAME}${packData.BRANCH_NAME ?? ""}`,
			zone: packData.CUSTOMER_ZONE,
			routeCode: packData.ROUTE_CODE,
			orderType: packData.ORDER_TYPE,
			customerCode: packData.CUSTOMER_CODE,
			customerName: packData.CUSTOMER_NAME,
			branchCode: packData.BRANCH_CODE,
			branchName: packData.BRANCH_NAME
		};
		if (!this.customerInfo) {
			this.customerInfo = customerInfo;
		}
		if (this.customerInfo.code != customerInfo.code) {
			this.modal.warning("รหัสลูกค้าไม่ตรงกับงานที่ทำอยู่", this.viewref, () => { this.ReFocus() });
			return false;
		}
		if (this.customerInfo.orderType != packData.ORDER_TYPE) {
			this.modal.warning("ประเภทออร์เดอร์ไม่ถูกต้อง", this.viewref, () => { this.ReFocus() });
			return false;
		}

		return true;
	}

	private async SetScannedCase(CaseNo?: CaseNoExport): Promise<void> {
		if (CaseNo) {
			if (this.scannedCase) {
				if (this.packingList.length > 0) {
					this.modal.warning("กรุณาทำเคสนี้ให้จบก่อน",
						this.viewref, () => { this.ReFocus() }
					);
					return;
				}

				if (this.packingList.length <= 0) {
					this.customerInfo = undefined;
					this.scannedBaby = undefined;
					this.repackCase = false;
				}
				CaseNo.caseType = CaseNo.caseType;
				this.scannedCase = CaseNo;
			}
			else {
				this.scannedCase = CaseNo;
			}
			if (this.existItem?.FROM_CHECK_EXIST_BABYCARD) {
				const babycard = JSON.parse(JSON.stringify(this.existItem.BABYCARD_NO));
				this.initialControlSubject.next({
					propName: "baBy",
					value: babycard
				});
			}

			// if (!this.repackCase) {
			// 	this.OpenCaseTypeDialog();
			// }
			this.actionLogsSubject.next({
				timestamp: moment(),
				actionType: "Scan Case",
				actionMessage: `${CaseNo.caseNo}`,
			  });
			this.packedWatcher.next(true);
		}
	}

	private async SetScannedCaseType(type: string): Promise<void> {
		if (!this.scannedCase) {
			this.modal.warning("กรุณาสแกนเปิดเคส",
				this.viewref, () => { this.ReFocus() }
			);
			return;
		}

		this.Http
			.get("WH", "SNWR039_GetInnerCaseTypeExport", type)
			.toPromise()
			.then((res) => {
				const data = res.Table[0] || undefined;
				if (data) {
					this.scannedCase.caseType = data.CASE_TYPE;
					this.scannedCase.caseName = data.CASE_NAME;
					this.packingList.map((item) => {
					  item.CASE_TYPE = data.CASE_TYPE;
					  item.CASE_NAME = data.CASE_NAME;
					});
					this.ReFocus();
					this.actionLogsSubject.next({
						timestamp: moment(),
						actionType: "Scan Type",
						actionMessage: `${this.scannedCase.caseName} - ${this.scannedCase.caseType}`,
					  });
				}
				else {
					this.modal.warning(
						"ไม่พบข้อมูล",
						this.viewref, () => { this.ReFocus() }
					);
				}
			})
			.catch((err) => {
				console.log(err, 'err');
				this.modal.warning(
					"พบปัญหาการใช้งาน กรุณาแจ้งผู้ดูแลระบบ",
					this.viewref, () => { this.ReFocus() }
				);
			});
	}

	private async SetScannedBaby(babyNo: string) {
		if (!this.scannedCase) {
			this.modal.warning("กรุณาสแกนเปิดเคส",
				this.viewref, () => { this.ReFocus() }
			);
			return;
		}
		let orderType = babyNo.substring(babyNo.lastIndexOf('-') + 1) == 'A' ? 'AIR' : 'SEA';;
		if (this.customerInfo && orderType !== this.customerInfo.orderType) {
			this.modal.warning("Baby ผิดออเดอร์ Class",
				this.viewref, () => { this.ReFocus() }
			);
			return;
		}

		await this.GetBabyCardDetail(babyNo)
			.then(res => {
				let babyData: any;
				const babyData_search = res.Table[0] || undefined;
				const babyData_unpack = this.packingList_unpack.find(item => item.BABYCARD_NO == babyNo) || undefined;
				if (babyData_unpack) {
					babyData = babyData_unpack;
				} else {
					babyData = babyData_search;
				}

				if (babyData) {
					if (!this.SetCustomerInfo(babyData)) {
						return;
					}
				} else {
					this.modal.warning("ไม่พบข้อมูล",
						this.viewref, () => { this.ReFocus() }
					);
					return;
				}

				if (babyData) {
					//Find all matched baby card number
					let foundBaby = this.packingList.some((item) => item.BABYCARD_NO == babyNo);
					if (foundBaby) {
						let index = this.packingList.findIndex((item) => item.BABYCARD_NO == babyNo);
						this.scannedBaby = this.packingList[index];
						if (this.existItem?.FROM_CHECK_EXIST_BABYCARD) {
							this.existItem = undefined;
						} else {
							this.modal.warning("สแกนเบบี้การ์ดตรงกับรายการที่กำลังดำเนินการอยู่",
								this.viewref, () => { this.ReFocus() }
							);
						}
						return;
					}
					//Add scanned case data
					this.scannedCase.customerCode = this.customerInfo.customerCode;
					this.scannedCase.branchCode = this.customerInfo.branchCode;
					this.scannedCase.orderType = this.customerInfo.orderType;
					//Adjust data before push into packing item
					babyData.PACK_QTY = babyData.RECEIVE_QTY;
					this.scannedBaby = babyData;
				}

				if (babyData) {
					const caseItemLength = this.packingList.filter(
						(item) => item.CASE_NO === this.scannedCase.caseNo
					).length;
					let packingData = JSON.parse(JSON.stringify(this.scannedBaby));
					packingData.CASE_NO = this.scannedCase.caseNo;
					packingData.CASE_DATE = this.scannedCase.caseDate;
					packingData.CASE_TYPE = this.scannedCase.caseType;
					packingData.CASE_NAME = this.scannedCase.caseName;
					packingData.PACK_QTY = babyData.RECEIVE_QTY;
					packingData.CASE_SEQ = caseItemLength + 1;
					this.packingList.push(packingData);
					this.packingList.sort((a, b) => b.CASE_SEQ - a.CASE_SEQ);
					//Get total items
					this.totalItems = this.packingList.length;
					//Get filtered part
					this.FilterTableData();
					this.actionLogsSubject.next({
						timestamp: moment(),
						actionType: "Scan Baby",
						actionMessage: `${packingData.BABYCARD_NO}`,
					  });
					this.packedWatcher.next(true);
				}
			})

	}

	private async GetBabyCardDetail(baby: string) {
		return await this.Http
			.get("WH", "SNWR039_GetData", baby)
			.toPromise()
			.catch((err) => {
				console.log(err, 'err');
				this.modal.warning(
					"พบปัญหาการใช้งาน กรุณาแจ้งผู้ดูแลระบบ",
					this.viewref, () => { this.ReFocus() }
				);
			});
	}

	public ConfirmCase() {
		if (!this.ValidateCustomerCaseType()) {
			this.modal.warning("กรุณาเลือกประเภทเคสให้ถูก<br/>สแกนเคสเพื่อเลือกอีกครั้ง",
				this.viewref, () => { this.ReFocus() }
			);
			return;
		}
		if (this.CheckPackIsComplete()) {
			this.modal.confirm("คุณต้องการบันทึกการทำงานใช่หรือไม่?" + "<br>[Selected : " + this.totalItems + " Items]",
				this.viewref,
				() => {
					this.Http.post("WH", "SNWR039_IssueCase", {
						scannedCase: this.scannedCase,
						packingList: this.packingList
					})
						.subscribe(
							(res) => {
								if (res === "Done") {
									this.modal.info("บันทึกเสร็จสิ้น", this.viewref,
										() => {
											this.ReFocus();
										}
									);
									this.InitialProcess();
								} else if (res === "Fail") {
									this.modal.error(res.message, this.viewref,
										() => {
											this.ReFocus();
										}
									);
								} else {
									this.modal.error("ไม่สามารถบันทึกได้ กรุณาแจ้งผู้ดูแลระบบ",
										this.viewref,
										() => {
											this.ReFocus();
										}
									);
								}
							},
							(err) => {
								console.log(err, 'err');
								this.modal.error("พบปัญหาการใช้งาน กรุณาแจ้งผู้ดูแลระบบ",
									this.viewref,
									() => {
										this.ReFocus();
									}
								);
							}
						);
				},
				() => {
					this.ReFocus();
				}
			);
		}
	}

	public EditCaseNo(CaseNo: CaseNoExport) {
		this.popupCase = JSON.parse(JSON.stringify(CaseNo));
		this.inputCaseDialog.OpenDialog();
	}

	public SaveCaseType(CaseNo: CaseNoExport) {
		if (CaseNo.caseName) {
			let findCaseType = this.caseTypeList.find(x => x.CASE_NAME == CaseNo.caseName);
			CaseNo.caseName = findCaseType.CASE_NAME
			CaseNo.caseType = findCaseType.CASE_TYPE
			this.scannedCase = CaseNo;
			this.packingList.map((item) => {
			  item.CASE_TYPE = findCaseType.CASE_TYPE;
			  item.CASE_NAME = findCaseType.CASE_NAME;
			});
			this.inputCaseDialog.Close();
			this.ReFocus();
			this.actionLogsSubject.next({
				timestamp: moment(),
				actionType: "Select Type",
				actionMessage: `${CaseNo.caseName} - ${CaseNo.caseType}`,
			  });
			this.packedWatcher.next(true);
		} else {
			this.modal.warning("กรุณาเลือกประเภทเคส", this.viewref, () => { this.ReFocus() });
		}
	}

	public CancelSaveCase(CaseNo: CaseNoExport) {
		this.inputCaseDialog.Close();
		this.ReFocus();
	}

	public ClearCase() {
		if (this.caseIsPacked == 'Y') {
			this.modal.warning(
				"ไม่สามารถทำรายการนี้ได้ babycard นี้ถูกทำแพคลงลังแล้ว",
				this.viewref, () => { this.ReFocus() }
			);
			return;
		}

		const is_packed = this.repackCase;//this.tableData.some(x => x.IS_PACKED == "Y");
		this.modal.confirm(
			(is_packed ? "เคสย่อยนี้ได้ทำการแพคในระบบแล้ว<br>" : "") +
			"คุณแน่ใจที่จะลบเคสนี้ใช่หรือไม่?",
			this.viewref,
			() => {
				if (is_packed) {
					const params = {
						scannedCase: this.scannedCase
					};
					this.Http.post("WH", "SNWR039_ClearInnerCaseExport", params)
						.subscribe(
							(res) => {
								if (res.status == "Done") {
									this.InitialProcess();
									this.modal.warning(
										"ลบรายการเสร็จสิ้น",
										this.viewref,
										() => {
											this.ReFocus();
										}
									);
								} else if (res.status == "Used") {
									this.modal.warning(
										"ไม่สามารถทำรายการนี้ได้ babycard นี้ถูกทำแพคลงลังแล้ว",
										this.viewref,
										() => {
											this.ReFocus();
										}
									);
								} else {
									console.log(res.Message, 'err');
									this.modal.error("ไม่สามารถบันทึกได้ กรุณาแจ้งผู้ดูแลระบบ", this.viewref,
										() => {
											this.ReFocus();
										});
								}
							},
							(err) => {
								console.log(err, 'err');
								this.modal.error("พบปัญหาการใช้งาน กรุณาแจ้งผู้ดูแลระบบ", this.viewref,
									() => {
										this.ReFocus();
									}
								);
							})
				}else {
					this.InitialProcess();
				}
			},
			() => {
				this.ReFocus();
			}
		);
	}

	public DeleteCard(packingItem: any) {
		this.modal.confirm(
			"คุณแน่ใจที่จะลบเบบี้การ์ดนี้ใช่หรือไม่?",
			this.viewref,
			() => {
				let i = 0;
				let index = this.packingList.findIndex(item => item.BABYCARD_NO == packingItem.BABYCARD_NO);
				this.packingList.splice(index, 1);
				this.packingList.map(item => item.CASE_SEQ = i++);
				this.totalItems = this.packingList.length;
				this.FilterTableData();
				this.actionLogsSubject.next({
					timestamp: moment(),
					actionType: "Delete Baby",
					actionMessage: `${packingItem.BABYCARD_NO}`,
				  });
				this.packedWatcher.next(true);
			},
			() => {
				this.ReFocus();
			}
		);
	}

	public ReFocus() {
		setTimeout(() => {
			this.qrString = null;
			this.scannerInput.nativeElement.focus();
		}, 200);
	}

	private ValidateCustomerCaseType(): boolean {
		return true;
	}

	private CheckPackIsComplete() {
		if (!this.scannedCase.caseNo) {
			this.modal.warning("กรุณาสแกนเปิดเคส",
				this.viewref,
				() => {
					this.ReFocus();
				}
			);
			return false;
		}
		else if (this.packingList.length == 0) {
			this.modal.warning("กรุณาสแกนการ์ด",
				this.viewref,
				() => {
					this.ReFocus();
				}
			);
			return false;
		}
		else if (!this.scannedCase.caseType) {
			this.modal.warning("กรุณาสแกนประเภทของเคส",
				this.viewref,
				() => {
					this.ReFocus();
				}
			);
			return false;
		}
		else {
			return true;
		}
	}

	private FilterTableData() {
		//Get total items
		this.totalItems = this.packingList.length;
		//Get filtered part
		this.packingListFiltered = this.packingList.filter(
			(row) => row.BABYCARD_NO
		);

		//Filter show data
		this.FilterInstrutionParts(this.scannedCase?.caseNo);
	}

	public FilterInstrutionParts(caseNo: string, isReturn: boolean = false) {
		caseNo = caseNo === "All" ? null : caseNo;
		this.selectedPartsFiltered = this.GetFilteredInstrutionParts(caseNo);

	}

	private GetFilteredInstrutionParts(caseNo: string) {
		//Group part number
		let count = 0;
		const selectedParts = JSON.parse(JSON.stringify(this.packingListFiltered.sort(function (a, b) {
			return a.PART_NO.localeCompare(b.PART_NO) && (a.INSTRUCTION_NO > b.INSTRUCTION_NO ? 1 : -1);
		})));
		const filtered = selectedParts
			.filter((item) => item.CASE_NO === (caseNo || item.CASE_NO))
			.reduce((list: any[], item: any) => {
				let foundMatched = list.find((v) =>
					v.PART_NO === item.PART_NO &&
					v.INSTRUCTION_NO === item.INSTRUCTION_NO
				);

				if (!foundMatched) {
					count++;
					item.SEQ = count;
					list.push(item);
				} else {
					foundMatched.PACK_QTY = foundMatched.PACK_QTY + item.PACK_QTY;
					foundMatched.TOTAL_AMOUNT = foundMatched.PACK_QTY * foundMatched.UNIT_PRICE;
				}

				return list;
			}, []);
		return filtered;
	}

	public OpenInfoCaseDialog(){
		let foundItem: any;
		const instructionFiltered = this.packingList
			.reduce((list: any[], item: any) => {
				let foundItem = list.find((x) => x.INSTRUCTION_NO === item.INSTRUCTION_NO);
				if (!foundItem) {
					list.push(item);
				}
				return list;
			}, []);

		let totalqty = 0;
		const babyFiltered = this.packingList
			.reduce((list: any[], item: any) => {
				foundItem = list.find((x) => x.BABYCARD_NO === item.BABYCARD_NO);
				if (!foundItem) {
					list.push(item);
					totalqty = totalqty + item.PACK_QTY
				}
				return list;
			}, []);

		this.calculateData = {
			TOTAL_INSTRUCTION: instructionFiltered.length
			, TOTAL_BABYCARD: babyFiltered.length
			, TOTAL_QTY: totalqty
		};

		this.infoCaseDialog.width = "67.5vw";
		this.infoCaseDialog.height = "60vh";
		this.infoCaseDialog.title = "Case list: " + this.scannedCase.caseNo;
		this.infoCaseDialog.OpenDialog();
	}

	@HostListener("window:keydown", ["$event"])
	async onKeyDown(event: KeyboardEvent) {
		if (
			event.key.toUpperCase() === "ENTER" &&
			(<HTMLElement>event.target).id.toUpperCase() === "QRINPUT"
		) {
			this.Enter();
		}
	}
}
