import { Component, OnInit, AfterViewInit, ViewChild, ViewContainerRef } from '@angular/core';
import { animate, state, style, transition, trigger } from "@angular/animations";
import { HttpService } from 'src/app/core/http.service';
import { Globals } from 'src/app/core/global';
import { ModalService } from "../../../core/modal.service";
import { DomSanitizer, SafeResourceUrl } from '@angular/platform-browser';
import * as moment from 'moment';
import { environment } from 'src/environments/environment';

@Component({
  selector: 'SNWR040',
  templateUrl: './SNWR040.component.html',
  styleUrls: ['./SNWR040.component.scss'],
  animations: [
    trigger('detailExpand', [
      state('collapsed', style({height: '0px', minHeight: '0'})),
      state('expanded', style({height: '*'})),
      transition('expanded <=> collapsed', animate('225ms cubic-bezier(0.4, 0.0, 0.2, 1)')),
    ]),
  ],
})

export class SNWR040Component implements OnInit {
  //private origin: string = window.location.protocol + "//" + window.location.hostname + ":5000/";
  private origin: string = environment.reportLocation;
  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private global: Globals,
    private sanitizer: DomSanitizer
  ) { }
  public fyObj = GetFYObject();

  public tabindex: number = 0;
  public tabReportindex: number = 0;
  public param: any = {
    tabPerformance: {},
    tabOverview: {},
  };
  public tableDataOverViewInventory: any = [];
  public tableDataOverViewInbound: any = [];
  public tableDataOverViewOutbound: any = [];
  public tableDataTotalActive: any = [];
  public tableDataTotalInActive: any = [];
  public reports: any = [
    { id: 1, no: 1, name: "Performance EO-BKK", value: "EO_BKK_BY_DAY", reportName: "PMS_RPT_WMS_SNWR040_EO_BKK_BY_DAY", tran_type: "BOTH" },
    { id: 2, no: 2, name: "Performance EO-BKK Overdue", value: "EO_BKK_BY_DAY_OVERDUE", reportName: "PMS_RPT_WMS_SNWR040_EO_BKK_BY_DAY_OVERDUE", tran_type: "BOTH" },
    { id: 3, no: 3, name: "Performance EO-UPC", value: "EO_UPC_BY_DAY", reportName: "PMS_RPT_WMS_SNWR040_EO_UPC_BY_DAY", tran_type: "BOTH" },
    { id: 4, no: 4, name: "Performance EO-UPC Overdue", value: "EO_UPC_BY_DAY_OVERDUE", reportName: "PMS_RPT_WMS_SNWR040_EO_UPC_BY_DAY_OVERDUE", tran_type: "BOTH" },
    { id: 5, no: 5, name: "Performance RO", value: "RO_BY_DAY", reportName: "PMS_RPT_WMS_SNWR040_RO_BY_DAY", tran_type: "BOTH" },
    { id: 6, no: 6, name: "Performance RO Picking Overdue", value: "RO_BY_DAY_OVERDUE", reportName: "PMS_RPT_WMS_SNWR040_RO_BY_DAY_OVERDUE", tran_type: "PICK" },
    { id: 7, no: 7, name: "Performance RO Checking Overdue", value: "RO_BY_DAY_OVERDUE", reportName: "PMS_RPT_WMS_SNWR040_RO_BY_DAY_OVERDUE", tran_type: "PACK" },
    { id: 8, no: 8, name: "Performance IO", value: "IO_BY_DAY", reportName: "PMS_RPT_WMS_SNWR040_IO_BY_DAY", tran_type: "BOTH" },
    { id: 9, no: 9, name: "Performance IO Picking Overdue", value: "IO_BY_DAY_OVERDUE", reportName: "PMS_RPT_WMS_SNWR040_IO_BY_DAY_OVERDUE", tran_type: "PICK" },
    { id: 10, no: 10,name:"Performance IO Checking Overdue", value: "IO_BY_DAY_OVERDUE", reportName: "PMS_RPT_WMS_SNWR040_IO_BY_DAY_OVERDUE", tran_type: "PACK" },
    { id: 11, no: 11, name: "Pick User Performance", value: "PICK_PERFORMANCE", reportName: "PMS_RPT_WMS_SNWR040_PICK_PERFORMANCE_CHART" },
    { id: 12, no: 12, name: "Check User Performance", value: "PACK_PERFORMANCE", reportName: "PMS_RPT_WMS_SNWR040_PACK_PERFORMANCE_CHART" },
  ];
  public reportsExport: any = [
    { id: 1, no: 1, name: "Performance Air", value: "AIR_BY_DAY", reportName: "PMS_RPT_WMS_SNWR040_AIR_BY_DAY" },
    { id: 2, no: 2, name: "Performance Air Overdue", value: "AIR_BY_DAY_OVERDUE", reportName: "PMS_RPT_WMS_SNWR040_AIR_BY_DAY_OVERDUE" },
    { id: 3, no: 3, name: "Performance Sea", value: "SEA_BY_DAY", reportName: "PMS_RPT_WMS_SNWR040_SEA_BY_DAY" },
    { id: 4, no: 4, name: "Performance Sea Overdue", value: "SEA_BY_DAY_OVERDUE", reportName: "PMS_RPT_WMS_SNWR040_SEA_BY_DAY_OVERDUE" },
    { id: 5, no: 5, name: "Pick User Performance", value: "PICK_PERFORMANCE", reportName: "PMS_RPT_WMS_SNWR040_PICK_EXPORT_CHART" },
    { id: 6, no: 6, name: "Receive User Performance", value: "RECEIVE_PERFORMANCE", reportName: "PMS_RPT_WMS_SNWR040_RECEIVE_EXPORT_CHART" },
    { id: 7, no: 7, name: "Pack User Performance", value: "PACK_PERFORMANCE", reportName: "PMS_RPT_WMS_SNWR040_PACK_EXPORT_CHART" },
  ];
  // public reports: any = [
  //   { id: 1, no: 0, name: "Performance", isgroup: true, 
  //     group: [
  //       { id: 11, no: 1, name: "EO-BKK", value: "EO_BKK_BY_DAY", reportName: "PMS_RPT_WMS_SNWR040_EO_BKK_BY_DAY", isgroup: true, 
  //         group: [ 
  //           { id: 111, no: 2, name: "Overdue", value: "EO_BKK_BY_DAY_OVERDUE", reportName: "PMS_RPT_WMS_SNWR040_EO_BKK_BY_DAY_OVERDUE", tran_type: "BOTH" },
  //         ] 
  //       },
  //       { id: 12, no: 3, name: "EO-UPC", value: "EO_UPC_BY_DAY", reportName: "PMS_RPT_WMS_SNWR040_EO_UPC_BY_DAY", isgroup: true, 
  //         group: [ 
  //           { id: 121, no: 4, name: "Overdue", value: "EO_UPC_BY_DAY_OVERDUE", reportName: "PMS_RPT_WMS_SNWR040_EO_UPC_BY_DAY_OVERDUE", tran_type: "BOTH" },
  //         ] 
  //       },
  //       { id: 13, no: 5, name: "RO", value: "RO_BY_DAY", reportName: "PMS_RPT_WMS_SNWR040_RO_BY_DAY", isgroup: true, 
  //         group: [ 
  //           { id: 131, no: 6, name: "Picking Overdue", value: "RO_BY_DAY_OVERDUE", reportName: "PMS_RPT_WMS_SNWR040_RO_BY_DAY_OVERDUE", tran_type: "PICK" },
  //           { id: 132, no: 7, name: "Checking Overdue", value: "RO_BY_DAY_OVERDUE", reportName: "PMS_RPT_WMS_SNWR040_RO_BY_DAY_OVERDUE", tran_type: "PACK" },
  //         ] 
  //       },
  //       { id: 14, no: 8, name: "IO", value: "IO_BY_DAY", reportName: "PMS_RPT_WMS_SNWR040_IO_BY_DAY", isgroup: true, 
  //         group: [ 
  //           { id: 141, no: 9, name: "Picking Overdue", value: "IO_BY_DAY_OVERDUE", reportName: "PMS_RPT_WMS_SNWR040_IO_BY_DAY_OVERDUE", tran_type: "PICK" },
  //           { id: 142, no: 10, name: "Checking Overdue", value: "IO_BY_DAY_OVERDUE", reportName: "PMS_RPT_WMS_SNWR040_IO_BY_DAY_OVERDUE", tran_type: "PACK" },
  //         ] 
  //       },
  //     ]
  //   },
  //   { id: 2, no: 11, name: "Pick User Performance", isgroup: false, value: "PICK_PERFORMANCE", reportName: "PMS_RPT_WMS_SNWR040_PICK_PERFORMANCE_CHART" },
  //   { id: 3, no: 12, name: "Check User Performance", isgroup: false, value: "PACK_PERFORMANCE", reportName: "PMS_RPT_WMS_SNWR040_PACK_PERFORMANCE_CHART" },
  // ];

  public formDialogData: any = {};
  public safeSrc1: SafeResourceUrl;
  public safeSrc2: SafeResourceUrl;
  public safeSrc3: SafeResourceUrl;
  public safeSrc4: SafeResourceUrl;
  @ViewChild("dialogPopUp", { static: false }) dialogPopUp: any;

  public async ngOnInit(): Promise<void> {
    this.tabindex = 0;
    this.param.tabOverview.TYPE = "TODAY";
    this.param.tabOverview.START_DATE = moment().format("DD-MMM-YYYY");
    this.param.tabOverview.END_DATE = moment().format("DD-MMM-YYYY");
    this.param.tabOverview.SELECTED_DATE = moment();
    this.param.tabOverview.SELECTED_MONTH = moment();
    this.param.tabPerformance.TYPE = "MONTH";
    this.param.tabPerformance.YEAR = moment().year().toString();
    this.param.tabPerformance.MONTH = (moment().month() + 1).toString().padStart(2, "0");
    this.param.tabPerformance.DATE_FROM = moment();
    this.param.tabPerformance.DATE_TO = moment();
    await this.DataMonthChanged();
    await this.GetOverViewData();
    await this.ExpandTotalData();
  }

  public SelectedTabChange(event: any): void {
    this.tabindex = event.index
  }

  public SelectedTabReportChange(event: any): void {
    this.tabReportindex = event.index
  }

  //#region tab OverView

  public TypeChanged() {
    if(this.param.tabOverview.TYPE == "TODAY"){
      this.param.tabOverview.START_DATE = moment().format("DD-MMM-YYYY");
      this.param.tabOverview.END_DATE = moment().format("DD-MMM-YYYY");
      if(moment(this.param.tabOverview.SELECTED_DATE).format("DD-MMM-YYYY") != moment().format("DD-MMM-YYYY")){
        this.GetOverViewData();
      }
    }
    else if(this.param.tabOverview.TYPE == "DATE"){
      var startMonth = moment(this.param.tabOverview.SELECTED_DATE).format("DD-MMM-YYYY");
      var endMonth= moment(this.param.tabOverview.SELECTED_DATE).format("DD-MMM-YYYY");
      this.param.tabOverview.START_DATE = startMonth;
      this.param.tabOverview.END_DATE = endMonth;
      if(moment(this.param.tabOverview.SELECTED_DATE).format("DD-MMM-YYYY") != moment().format("DD-MMM-YYYY")){
        this.GetOverViewData();
      }
    }
  }

  public SelectedDateChanged(): void {
    var startMonth = moment(this.param.tabOverview.SELECTED_DATE).format("DD-MMM-YYYY");
    var endMonth= moment(this.param.tabOverview.SELECTED_DATE).format("DD-MMM-YYYY");
    this.param.tabOverview.START_DATE = startMonth;
    this.param.tabOverview.END_DATE = endMonth;
    this.GetOverViewData();
  }

  public SelectedMonthChanged(event: any, datepicker: any): void {
    this.param.tabOverview.SELECTED_MONTH = event;
    var startMonth = moment(event).startOf("month").format("DD-MMM-YYYY");
    var endMonth= moment(event).endOf("month").format("DD-MMM-YYYY");
    this.param.tabOverview.START_DATE = startMonth;
    this.param.tabOverview.END_DATE = endMonth;
    datepicker.close();
    this.GetOverViewData();
  }

  private GetOverViewData(): void{
    const startDate = this.param.tabOverview.START_DATE;
    const endDate = this.param.tabOverview.END_DATE;
    this.http.get("WH", "SNWR040_GetOverViewData", startDate, endDate)
    .subscribe(res => {
      this.tableDataOverViewInventory.TOTAL_COST = res.set.Table[0]?.TOTAL_COST ? res.set.Table[0].TOTAL_COST : 0.00;
      this.tableDataOverViewInventory.TOTAL_ITEM = res.set.Table[0]?.TOTAL_ITEM ? res.set.Table[0].TOTAL_ITEM : 0.00;
      this.tableDataOverViewInventory.LOCAL_COST = res.set.Table[1]?.TOTAL_COST ? res.set.Table[1].TOTAL_COST : 0.00;
      this.tableDataOverViewInventory.LOCAL_ITEM = res.set.Table[1]?.TOTAL_ITEM ? res.set.Table[1].TOTAL_ITEM : 0.00;
      this.tableDataOverViewInventory.IMPORT_COST = res.set.Table[2]?.TOTAL_COST ? res.set.Table[2].TOTAL_COST : 0.00;
      this.tableDataOverViewInventory.IMPORT_ITEM = res.set.Table[2]?.TOTAL_ITEM ? res.set.Table[2].TOTAL_ITEM : 0.00;
      this.tableDataOverViewInbound = res.set.Table1;
      this.tableDataOverViewOutbound = res.set.Table2;
    },(err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contract support team", this.viewref);
    });
  }

  private ExpandTotalData(): void{
    // if(row.VENDOR_TYPE_NAME == "Total"){
      const startDate = this.param.tabOverview.START_DATE;
      const endDate = this.param.tabOverview.END_DATE;
      this.http.get("WH", "SNWR040_GetTotalData", startDate, endDate)
      .subscribe(res => {
        this.tableDataTotalActive.COST_TOTAL = res.set.Table[0]?.COST ? res.set.Table[0].COST : 0;
        this.tableDataTotalActive.ITEM_TOTAL = res.set.Table[0]?.ITEM ? res.set.Table[0].ITEM : 0;
        this.tableDataTotalActive.COST_LOCAL = res.set.Table[1]?.COST ? res.set.Table[1].COST : 0;
        this.tableDataTotalActive.ITEM_LOCAL = res.set.Table[1]?.ITEM ? res.set.Table[1].ITEM : 0;
        this.tableDataTotalActive.COST_IMPORT = res.set.Table[2]?.COST ? res.set.Table[2].COST : 0;
        this.tableDataTotalActive.ITEM_IMPORT = res.set.Table[2]?.ITEM ? res.set.Table[2].ITEM : 0;
        this.tableDataTotalInActive.COST_TOTAL = res.set.Table1[0]?.COST ? res.set.Table1[0].COST : 0;
        this.tableDataTotalInActive.ITEM_TOTAL = res.set.Table1[0]?.ITEM ? res.set.Table1[0].ITEM : 0;
        this.tableDataTotalInActive.COST_LOCAL = res.set.Table1[1]?.COST ? res.set.Table1[1].COST : 0;
        this.tableDataTotalInActive.ITEM_LOCAL = res.set.Table1[1]?.ITEM ? res.set.Table1[1].ITEM : 0;
        this.tableDataTotalInActive.COST_IMPORT = res.set.Table1[2]?.COST ? res.set.Table1[2].COST : 0;
        this.tableDataTotalInActive.ITEM_IMPORT = res.set.Table1[2]?.ITEM ? res.set.Table1[2].ITEM : 0;
      },(err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contract support team", this.viewref);
      });
    // }
  }

  public async OpenPopUpDialog(data: any, ordertype: string){
    this.dialogPopUp.width="1350px";
    this.dialogPopUp.width="1350px";
    this.dialogPopUp.height="725px";
    this.dialogPopUp.title = "WH Report: " + ordertype;
    this.formDialogData = data;
    const params = {
      P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      P_ORDER_TYPE: ordertype,
      P_START_DATE: SetFormatDate(this.param.tabOverview.START_DATE), 
      P_END_DATE: SetFormatDate(this.param.tabOverview.END_DATE) 
    };
    this.safeSrc1 = await this.GetReportURL("PMS_RPT_WMS_SNWR040_EO_DOM", params);
    this.safeSrc2 = await this.GetReportURL("PMS_RPT_WMS_SNWR040_RO_DOM", params);
    this.safeSrc3 = await this.GetReportURL("PMS_RPT_WMS_SNWR040_IO_DOM", params);
    this.safeSrc4 = await this.GetReportURL("PMS_RPT_WMS_SNWR040_EO_EXT", params);
    await this.dialogPopUp.OpenDialog();
  }
  
  private GetReportURL(reportName: string, reportParam: any): SafeResourceUrl {
    let path = this.global.GetReportUrlForIFrame(reportName, reportParam);
    let url = this.origin + path;
    return this.sanitizer.bypassSecurityTrustResourceUrl(url);
  }

  //#endregion

  //#region tab Performance

  public TypeReportChanged() {
    if(this.param.tabPerformance.TYPE == "MONTH"){
      this.DataMonthChanged();
    }
    else if(this.param.tabPerformance.TYPE == "DATE"){
      this.DataRangeChanged();
    }
  }
  
  public DataMonthChanged(): void {
    var month = "01" + "-" + this.param.tabPerformance.MONTH + "-" + this.param.tabPerformance.YEAR;
    var startMonth = moment(month, 'DD-MM-YYYY').startOf("month").toDate();
    var endMonth= moment(month, 'DD-MM-YYYY').endOf("month").toDate();
    this.param.tabPerformance.START_DATE = startMonth;
    this.param.tabPerformance.END_DATE = endMonth;
  }

  public DataRangeChanged(): void {
    this.param.tabPerformance.START_DATE = this.param.tabPerformance.DATE_FROM;
    this.param.tabPerformance.END_DATE = this.param.tabPerformance.DATE_TO;
  }

  public OpenReport(report: any) : void {
    if(!this.ValidateParamPerformance()){
      return;
    }

    let params: any = {};
    switch (report.value) {
      case "PICK_PERFORMANCE":
      case "PACK_PERFORMANCE":
        params = {
            P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
            P_START_DATE: SetFormatDate(this.param.tabPerformance.START_DATE), 
            P_END_DATE: SetFormatDate(this.param.tabPerformance.END_DATE), 
          }
        break;
      case "RO_BY_DAY":
      case "IO_BY_DAY":
      case "EO_BKK_BY_DAY":
      case "EO_UPC_BY_DAY":
        params = {
            P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
            P_START_DATE: SetFormatDate(this.param.tabPerformance.START_DATE), 
            P_END_DATE: SetFormatDate(this.param.tabPerformance.END_DATE), 
          }
        break;
      case "RO_BY_DAY_OVERDUE":
      case "IO_BY_DAY_OVERDUE":
      case "EO_BKK_BY_DAY_OVERDUE":
      case "EO_UPC_BY_DAY_OVERDUE":
        params = {
            P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
            P_TRAN_TYPE: report.tran_type, 
            P_START_DATE: SetFormatDate(this.param.tabPerformance.START_DATE), 
            P_END_DATE: SetFormatDate(this.param.tabPerformance.END_DATE), 
          }
        break;
    }

    this.global.GoToReport(report.reportName, params);
  }

  public OpenReportExport(report: any) : void {
    if(!this.ValidateParamPerformance()){
      return;
    }

    let params: any = {};
    switch (report.value) {
      case "PICK_PERFORMANCE":
      case "RECEIVE_PERFORMANCE":
      case "PACK_PERFORMANCE":
        params = {
            P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
            P_START_DATE: SetFormatDate(this.param.tabPerformance.START_DATE), 
            P_END_DATE: SetFormatDate(this.param.tabPerformance.END_DATE), 
          }
        break;
      case "AIR_BY_DAY":
      case "SEA_BY_DAY":
        params = {
            P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
            P_START_DATE: SetFormatDate(this.param.tabPerformance.START_DATE), 
            P_END_DATE: SetFormatDate(this.param.tabPerformance.END_DATE), 
          }
        break;
      case "AIR_BY_DAY_OVERDUE":
      case "SEA_BY_DAY_OVERDUE":
        params = {
            P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
            P_TRAN_TYPE: report.tran_type, 
            P_START_DATE: SetFormatDate(this.param.tabPerformance.START_DATE), 
            P_END_DATE: SetFormatDate(this.param.tabPerformance.END_DATE), 
          }
        break;
    }

    this.global.GoToReport(report.reportName, params);
  }

  public ValidateParamPerformance(): boolean {
    const params = this.param.tabPerformance;
    let validate: boolean = false;
    if(params.TYPE == "MONTH"){
      if (IsNullOrEmpty(params.YEAR)) {
        this.modal.warning("Please select year", this.viewref);
      }
      else if (IsNullOrEmpty(params.MONTH)) {
        this.modal.warning("Please select month", this.viewref);
      }
      else{
        validate = true;
      }
    }
    else if(params.TYPE == "DATE"){
      if (IsNullOrEmpty(params.DATE_FROM)) {
        this.modal.warning("Please input Start date", this.viewref);
      }
      else if (IsNullOrEmpty(params.DATE_TO)) {
        this.modal.warning("Please input End date", this.viewref);
      }
      else if (params.DATE_FROM > params.DATE_TO) {
        this.modal.warning("Please input Start date < End date", this.viewref);
      }
      else{
        validate = true;
      }
    }
    return validate;
  }

  //#endregion

}

function IsNullOrEmpty(value: any): boolean {
  if (value == '' || value == null || typeof value == 'undefined') {
    return true;
  } else {
    return false;
  }
}

function SetFormatDate(date) {
  if (date) {
    let d = new Date(date);
    let day = d.getDate();
    let newDay = day.toString().length < 2 ? 0 + '' + day : day
    let year = d.getFullYear()
    let month = d.getMonth() + 1;
    let newMonth = month.toString().length < 2 ? 0 + '' + month : month
    return newDay + '-' + newMonth + '-' + year;
  }
}

function GetFYObject() {
  const fyObj: any = { FY: [], FYMonths: [] };
  const currentYear = moment().year();
  for (let _year = currentYear + 1; _year >= 2018; _year--) {
    const fy = _year.toString().substr(-2);
    fyObj.FY.push({
      fiscalYear: fy,
      fullYearNumber: _year,
      fullYearText: _year.toString(),
      CURRENT_YEAR: _year == currentYear,
    });
  }

  const _FYMonths = [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11];
  _FYMonths.forEach((item, key) => {
    const _fyMonth = new Date(1990, item, 1).toLocaleString('en-us', {
      month: 'long',
    });
    const _fyMonthShort = new Date(1990, item, 1).toLocaleString('en-us', {
      month: 'short',
    });
    const _fyMonthTH = new Date(1990, item, 1).toLocaleString('th-th', {
      month: 'long',
    });
    fyObj.FYMonths.push({
      MONTH_INDEX: key,
      MONTH: ('0' + (item + 1).toString()).substr(-2),
      MONTH_NAME: _fyMonth,
      MONTH_NAME_SHORT: _fyMonthShort,
      MONTH_NAME_TH: _fyMonthTH,
      AddYear: item < 3 ? 1 : 0,
      Month: item + 1,
      Quarter:
        item >= 3
          ? Math.ceil((item + 1) / 3) - 1
          : Math.ceil((item + 13) / 3) - 1, // Q1:3-5, Q2:6-8, Q3:9-11, Q4:0-2
      CURRENT_MONTH: item == moment().month() - 1,
    });
  });

  return fyObj;
}