import { Component, OnInit, Renderer2, ElementRef, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Globals } from 'src/app/core/global';
import { ModalService } from "../../../core/modal.service";
import { DateAdapter, MAT_DATE_FORMATS, MAT_DATE_LOCALE } from "@angular/material/core";
import { MAT_MOMENT_DATE_ADAPTER_OPTIONS, MomentDateAdapter } from "@angular/material-moment-adapter";
import * as moment from 'moment';
export const MY_FORMATS = {
  parse: {
    dateInput: ['MM-YYYY', 'MM/YYYY', 'MMYYYY', 'MMM-YY', 'MMM-YYYY'],
  },
  display: {
    dateInput: 'MMM-YYYY',
    monthYearLabel: 'MMM YYYY',
    dateA11yLabel: 'LL',
    monthYearA11yLabel: 'MMMM YYYY',
  },
};

@Component({
  selector: 'SNWR041',
  templateUrl: './SNWR041.component.html',
  styleUrls: ['./SNWR041.component.css'],
  providers: [
    {
      provide: DateAdapter,
      useClass: MomentDateAdapter,
      deps: [MAT_DATE_LOCALE, MAT_MOMENT_DATE_ADAPTER_OPTIONS],
    },

    { provide: MAT_DATE_FORMATS, useValue: MY_FORMATS },
  ],
})

export class SNWR041Component implements OnInit {

  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private renderer: Renderer2,
    private global: Globals
  ) { }

  public tabindex: number = 0;
  public tab: any = {};
  public paramsSearch: any = {};

  public formData: any = {};
  public formConfig: any = {};
  public tableDataCapacity: Array<any> = [];
  public tableDataCapNormal: Array<any> = [];
  //Upload File
  public FileName: string = "";
  private File : any;
  public uploadData: any = {};
  public tableUpload = []
  public total_error :number = 0;
  public error_list = []
  public jobTypeList = [
    {JOB_TYPE: "EO-BKK", DESCRIPTION: "EO-BKK"},
    {JOB_TYPE: "EO-UPC", DESCRIPTION: "EO-UPC"},
    {JOB_TYPE: "PO", DESCRIPTION: "PO"},
    {JOB_TYPE: "IO", DESCRIPTION: "IO"},
  ]
  public filteredCapacityData: Array<any> = [];
  public filteredCapNormalData: Array<any> = [];


  @ViewChild("dialogAction", { static: false }) dialogAction: any;
  @ViewChild("fileInput") fileInput: ElementRef;
  @ViewChild("dialogUpload", { static: false }) dialogUpload: any;

  public async ngOnInit(): Promise<void> {
    this.paramsSearch.START_DATE = moment().startOf("year");
    this.paramsSearch.END_DATE = moment().endOf("year");
    await this.GetDataByTabIndex();
    await this.Search();
  }

  public SelectedTabChange(event: any): void {
    this.tabindex = event.index;
    this.GetDataByTabIndex();
  }

  private GetDataByTabIndex(): void {
    if (this.tabindex === 0) {
      this.formConfig = { 
        CONFIG_TYPE: 'CAPACITY', 
        CONFIG_TEXT: 'Capacity Per Day', 
        TABLE_NAME: 'SNWR041_CAPACITY_UPLOAD', 
        TEMPLANE: 'PMS_RPT_WMS_SNWR041_CAPACITY_UPLOAD_TEMPLATE', 
        DIALOG_WIDTH: "500px", 
        DIALOG_HEIGHT: "500px" 
      };
    } else if (this.tabindex === 1) {
      this.formConfig = { 
        CONFIG_TYPE: 'CAP_NORMAL', 
        CONFIG_TEXT: 'Cap-Normal', 
        TABLE_NAME: 'SNWR041_CAP_NORMAL_UPLOAD', 
        TEMPLANE: 'PMS_RPT_WMS_SNWR041_CAP_NORMAL_UPLOAD_TEMPLATE', 
        DIALOG_WIDTH: "500px", 
        DIALOG_HEIGHT: "455px" 
      };
    }
  }

  public SelectMonthAndYearFrom(event: any, datepicker: any): void {
    this.paramsSearch.START_DATE = event;
    datepicker.close();
  }
 
  public SelectMonthAndYearTo(event: any, datepicker: any): void {
    this.paramsSearch.END_DATE = event;
    datepicker.close();
  }

  public SelectMonthAndYearFromDialog(event: any, datepicker: any): void {
    this.formData.START_DATE = event;
    datepicker.close();
  }
 
  public SelectMonthAndYearToDialog(event: any, datepicker: any): void {
    this.formData.END_DATE = event;
    datepicker.close();
  }
 
  public SelectMonthAndYearUpload(event: any, datepicker: any): void {
    this.uploadData.MONTH_UPLOAD = event;
    datepicker.close();
  }

  public Search(): void{ 
    const startDate = this.paramsSearch.START_DATE ? moment(this.paramsSearch.START_DATE).format("MMYYYY") : "NULL";
    const endDate = this.paramsSearch.END_DATE ? moment(this.paramsSearch.END_DATE).format("MMYYYY") : "NULL";
    this.http.get("WH", "SNWR041_GetDashConfigData", "NULL", startDate, endDate, "NULL")
    .subscribe(res => {
        this.tableDataCapacity = res.set.Table;
        this.filteredCapacityData = res.set.Table;
        this.tableDataCapNormal = res.set.Table1;
        this.filteredCapNormalData = res.set.Table1;
    },(err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contract support team", this.viewref);
    });
  }
  
  public filterCapacityConfig(event){
    this.tableDataCapacity = this.filteredCapacityData.filter(e => e.USER_CODE.includes(event));
  }
  
  public filterCapNormalConfig(event){
    this.tableDataCapNormal = this.filteredCapNormalData.filter(e => e.JOB_TYPE.includes(event));
  }

  public async AddConfig(): Promise<void> {
    this.formData = {};
    this.formData.ACTION = "ADD";
    this.formData.START_DATE = moment();
    this.formData.END_DATE = moment();
    this.formData.CONFIG_TEXT = this.formConfig.CONFIG_TEXT;
    this.formData.CONFIG_TYPE = this.formConfig.CONFIG_TYPE;
    this.formData.CONFIG_VALUE = 0;
    this.formData.CONFIG_VALUE_CHECK = 0;
    this.dialogAction.width = this.formConfig.DIALOG_WIDTH;
    this.dialogAction.height = this.formConfig.DIALOG_HEIGHT;
    this.dialogAction.title = "Add WH Dashboard: " + this.formConfig.CONFIG_TEXT ;
    await this.dialogAction.OpenDialog();
  }

  public async EditConfig(data): Promise<void> {
    this.formData = { ...data };
    this.formData.ACTION = "EDIT";
    this.formData.START_DATE = moment(data.START_DATE);
    this.formData.END_DATE = moment(data.END_DATE);
    this.dialogAction.width = this.formConfig.DIALOG_WIDTH;
    this.dialogAction.height = this.formConfig.DIALOG_HEIGHT;
    this.dialogAction.title = "Edit WH Dashboard: " + this.formConfig.CONFIG_TEXT;
    await this.dialogAction.OpenDialog();
  }

  public ValidateCapacityField(): boolean{
    if(IsNullOrEmpty(this.formData.START_DATE)){
      this.modal.warning("Please select Start Date.",this.viewref);
      return false;
    }
    else if(IsNullOrEmpty(this.formData.END_DATE)){
      this.modal.warning("Please select End Date.",this.viewref);
      return false;
    }
    else if(IsNullOrEmpty(this.formData.USER_CODE)){
      this.modal.warning("Please fill User Code.",this.viewref);
      return false;
    }
    else if(IsNullOrEmpty(this.formData.CONFIG_VALUE)){
      this.modal.warning("Please fill Picking Capacity.",this.viewref);
      return false;
    }
    else if(IsNullOrEmpty(this.formData.CONFIG_VALUE_CHECK)){
      this.modal.warning("Please fill Checking Capacity.",this.viewref);
      return false;
    }

    return true;
  }

  public SaveCapacity(): void {
    if(this.ValidateCapacityField() === false){
      return;
    }
    this.modal.confirm("Do you want to save this config?", this.viewref, () => ConfirmSave());
    let ConfirmSave = () =>  {
      if(this.formData.ACTION == "ADD") this.InsertCapacity();
      else if(this.formData.ACTION == "EDIT") this.UpdateCapacity();
    }
  }

  private InsertCapacity(): void{
    const params = {
      START_DATE: moment(this.formData.START_DATE).startOf("month").format("DD-MMM-YYYY"),
      END_DATE: moment(this.formData.END_DATE).endOf("month").format("DD-MMM-YYYY"),
      USER_CODE: this.formData.USER_CODE,
      CONFIG_TYPE: this.formData.CONFIG_TYPE,
      CONFIG_VALUE: this.formData.CONFIG_VALUE,
      CONFIG_VALUE_CHECK: this.formData.CONFIG_VALUE_CHECK
    }
    this.http.post("WH", 'SNWR041_InsertCapacity', params)
    .subscribe(res => {
      if (res.status == 'DONE') {
        this.formData = {};
        this.Search();
        this.dialogAction.Close();
        this.modal.info(res.message, this.viewref, () => {});
      }  
      else {
        this.modal.error(res.message, this.viewref, () => {}, { height:"22rem" });
      }
    }, (err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contact support team", this.viewref);
    })
  }

  private UpdateCapacity(): void{
    const params = {
      ROWID: this.formData.ID,
      START_DATE: moment(this.formData.START_DATE).startOf("month").format("DD-MMM-YYYY"),
      END_DATE: moment(this.formData.END_DATE).endOf("month").format("DD-MMM-YYYY"),
      USER_CODE: this.formData.USER_CODE,
      CONFIG_TYPE: this.formData.CONFIG_TYPE,
      CONFIG_VALUE: this.formData.CONFIG_VALUE,
      CONFIG_VALUE_CHECK: this.formData.CONFIG_VALUE_CHECK
    }
    this.http.post("WH", 'SNWR041_UpdateCapacity', params)
    .subscribe(res => {
      if (res.status == 'DONE') {
        this.formData = {};
        this.Search();
        this.dialogAction.Close();
        this.modal.info(res.message, this.viewref, () => {});
      }  
      else {
        this.modal.error(res.message, this.viewref, () => {}, { height:"22rem" });
      }
    }, (err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contact support team", this.viewref);
    })
  }

  public ValidateCapNormalField(): boolean{
    if(IsNullOrEmpty(this.formData.START_DATE)){
      this.modal.warning("Please select Start Date.",this.viewref);
      return false;
    }
    else if(IsNullOrEmpty(this.formData.END_DATE)){
      this.modal.warning("Please select End Date.",this.viewref);
      return false;
    }
    else if(IsNullOrEmpty(this.formData.JOB_TYPE)){
      this.modal.warning("Please select Job Type.",this.viewref);
      return false;
    }
    else if(IsNullOrEmpty(this.formData.CONFIG_VALUE)){
      this.modal.warning("Please fill Picking Cap Normal.",this.viewref);
      return false;
    }
    else if(IsNullOrEmpty(this.formData.CONFIG_VALUE_CHECK)){
      this.modal.warning("Please fill Checking Cap Normal.",this.viewref);
      return false;
    }

    return true;
  }

  public SaveCapNormal(): void {
    if(this.ValidateCapNormalField() === false){
      return;
    }
    this.modal.confirm("Do you want to save this config?", this.viewref, () => ConfirmSave());
    let ConfirmSave = () =>  {
      if(this.formData.ACTION == "ADD") this.InsertCapNormal();
      else if(this.formData.ACTION == "EDIT") this.UpdateCapNormal();
    }
  }

  private InsertCapNormal(): void{
    const params = {
      ROWID: this.formData.ID,
      START_DATE: moment(this.formData.START_DATE).startOf("month").format("DD-MMM-YYYY"),
      END_DATE: moment(this.formData.END_DATE).endOf("month").format("DD-MMM-YYYY"),
      JOB_TYPE: this.formData.JOB_TYPE,
      CONFIG_TYPE: this.formData.CONFIG_TYPE,
      CONFIG_VALUE: this.formData.CONFIG_VALUE,
      CONFIG_VALUE_CHECK: this.formData.CONFIG_VALUE_CHECK
    }
    this.http.post("WH", 'SNWR041_InsertCapNormal', params)
    .subscribe(res => {
      if (res.status == 'DONE') {
        this.formData = {};
        this.Search();
        this.dialogAction.Close();
        this.modal.info(res.message, this.viewref, () => {});
      }  
      else {
        this.modal.error(res.message, this.viewref, () => {}, { height:"22rem" });
      }
    }, (err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contact support team", this.viewref);
    })
  }

  private UpdateCapNormal(): void{
    const params = {
      ROWID: this.formData.ID,
      START_DATE: moment(this.formData.START_DATE).startOf("month").format("DD-MMM-YYYY"),
      END_DATE: moment(this.formData.END_DATE).endOf("month").format("DD-MMM-YYYY"),
      JOB_TYPE: this.formData.JOB_TYPE,
      CONFIG_TYPE: this.formData.CONFIG_TYPE,
      CONFIG_VALUE: this.formData.CONFIG_VALUE,
      CONFIG_VALUE_CHECK: this.formData.CONFIG_VALUE_CHECK
    }
    this.http.post("WH", 'SNWR041_UpdateCapNormal', params)
    .subscribe(res => {
      if (res.status == 'DONE') {
        this.formData = {};
        this.Search();
        this.dialogAction.Close();
        this.modal.info(res.message, this.viewref, () => {});
      }  
      else {
        this.modal.error(res.message, this.viewref, () => {}, { height:"22rem" });
      }
    }, (err) => {
      console.log(err, 'err')
      this.modal.warning("Found an error, please contact support team", this.viewref);
    })
  }

  public DeleteConfig(data): void {
    this.modal.confirm(
      "Do you want to delete this config?"
        + ( this.formConfig.CONFIG_TYPE == "CAPACITY" ? "<br>User Code: " + data.USER_CODE : "<br>Job Type: " + data.JOB_TYPE)
        + "<br>Month Start: " + data.START_DATE_TEXT
        + "<br>Month End: " + data.END_DATE_TEXT
        //+ "<br>" + this.formConfig.CONFIG_TEXT + ": " + data.CONFIG_VALUE
      , this.viewref
      , () => ConfirmDelete()
      , () => {}
      , { height:"20rem", width:"32rem" });

    let ConfirmDelete = () =>  {
      const params = {
        ROWID: data.ID
      }
      this.http.post("WH", 'SNWR041_DeleteConfig', params)
      .subscribe(res => {
        if (res.status == 'DONE') {
          this.formData = {};
          this.Search();
          this.dialogAction.Close();
          this.modal.info(res.message, this.viewref, () => {});
        }  
        else {
          this.modal.error(res.message, this.viewref, () => {});
        }
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewref);
      })
    }
  }

  //#region File Upload

  public OpenUpload(){
    this.uploadData = {};
    this.uploadData.TABLE_NAME = this.formConfig.TABLE_NAME;
    this.uploadData.CONFIG_TYPE = this.formConfig.CONFIG_TYPE
    this.uploadData.MONTH_UPLOAD = moment();
    this.total_error = 0;
    this.FileName = "";
    this.error_list = [];
    this.tableUpload = [];
    this.dialogUpload.width="1150px";
    this.dialogUpload.height="625px";
    this.dialogUpload.title = "Upload Config: " + this.formConfig.CONFIG_TEXT;
    this.dialogUpload.OpenDialog()
  }

  public DownloadTemplate(){
    this.global.GoToExport(this.formConfig.TEMPLANE,
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      }, true, "EXCELOPENXML")
  }
  
  public openFileBrowser() {
    this.FileName = "";
    this.fileInput.nativeElement.value = '';
    this.fileInput.nativeElement.click();
  }

  public selectFile(evt) {
    let Files: Array<File> = evt.target.files;
    if (Files.length > 0) {
      this.File = Files[0];
      this.FileName = this.File.name;
    }
  }

  public PreView() {
    if (!this.FileName) {
      this.modal.warning("Please Open File First...", this.viewref)
      return;
    }
    else if (!this.uploadData.MONTH_UPLOAD) {
      this.modal.warning("Please select month for update the data.", this.viewref)
      return;
    }
    
    let formData = new FormData();
    formData.append('file', this.File);
    formData.append('month_start', moment(this.uploadData.MONTH_UPLOAD).startOf("M").format("DD-MMM-YYYY"));
    formData.append('month_end', moment(this.uploadData.MONTH_UPLOAD).endOf("M").format("DD-MMM-YYYY"));
    formData.append('type', this.uploadData.CONFIG_TYPE);

    this.tableUpload = [];
    this.error_list = [];
    this.http.postFile("WH", "SNWR041_UploadFile", formData)
      .subscribe(result => {
        this.tableUpload = result.set.Table;
        let countrow = 0;
        this.tableUpload.map((x,i) => {
          if(x.ERR_FLAG == 'Y'){
              countrow += 1;
              this.error_list.push({
                  record : i + 1,
                  message : x.ERR_MSG
              })
          } 
          this.total_error = countrow;
      })
    }, err => {
      console.log(err, 'err')
      this.modal.error('Found an error, please contract support team.', this.viewref);
    })
  }

  public SaveUpload(){
    this.modal.confirm("Do you want to save change you have made?",this.viewref,() => ConfirmSave())

    let ConfirmSave = () => {
      const params = {}
      this.http.post("WH", "SNWR041_SaveByUpload", params)
      .subscribe(res => {
        if(res.status == "DONE"){
          this.Search();
          this.dialogUpload.Close();
          this.modal.info(res.message,this.viewref);
        }else{
          this.modal.error(res.message,this.viewref)
        }
      },err => {
        console.log(err, 'err')
        this.modal.error('Found an error, please contract support team.', this.viewref);
      })
    }
  }

  //#endregion

}

function IsNullOrEmpty(value: any): boolean {
  if (value === '' || value === null || typeof value === 'undefined') {
    return true;
  } else {
    return false;
  }
}

function isNumber(str: string): boolean{
  return !Number.isNaN(Number(str));
}