import { Component, OnInit, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from '../../../core/modal.service';


@Component({
  selector: 'SNWR042',
  templateUrl: './SNWR042.component.html',
  styleUrls: ['./SNWR042.component.css']
})

export class SNWR042Component implements OnInit {

  public params: any = {};
  public tableDataUpload: any = [];
  public files: any = [];

  constructor(
    private Http: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  ngOnInit() {
    this.params.TOTAL_RECORD = 0;
    this.params.TOTAL_ERROR = 0;
    this.params.FILE_NAME = null;
  }

  public DownloadTemplate() {
    let link = "assets/templates/SNWR042_Upload_ShipDate_Template.xlsx"
    window.open(link, '_blank')
  }

  public OnFileSelect(fileInput) {
    this.files = [];
    this.params.FILE_NAME = null;
    this.files = fileInput.target.files;
    this.params.FILE_NAME = this.files[0].name;
  }

  public Preview() {
    this.tableDataUpload = [];
    this.params.TOTAL_RECORD = 0;
    this.params.TOTAL_ERROR = 0;

    if (this.files.length == 0) {
      this.modal.error('Please Choose .xlsx File First...', this.viewref)
    }
    else {
      let formData = new FormData();
      formData.append('file', this.files[0]);

      this.Http.postFile('WH', 'SNWR042_Preview', formData).subscribe(res => {
        if (res.Table.length > 0) {
          this.tableDataUpload = res.Table;
          this.tableDataUpload.forEach((x) => {
            if (x.REMARK) {
              this.params.TOTAL_ERROR = this.params.TOTAL_ERROR + 1;
            }
          });
          this.params.TOTAL_RECORD = this.tableDataUpload.length;

        } else {
          this.modal.error("Upload error! Please check file or data for upload.", this.viewref);
        }
      }, (err) => {
        this.modal.error("Upload error! Please check file or data for upload.", this.viewref);
      });
    }
  }

  public ConfirmUpload() {
    if (this.params.TOTAL_ERROR > 0) {
      this.modal.error('Please check error message on some record!!', this.viewref);
      return;
    }
    this.modal.confirm('Do you want to upload order?', this.viewref, this.Upload)
  }

  public Upload = () => {
    this.Http.post('WH', 'SNWR042_ConfirmSaveShipDate', this.tableDataUpload).subscribe(res => {
      if (res.Table[0].STATUS == 'DONE') {
        this.modal.info("Update Ship Date Completed!", this.viewref);
        this.tableDataUpload = [];
        this.params.TOTAL_RECORD = 0;
        this.params.TOTAL_ERROR = 0;
        this.params.FILE_NAME = null;
      } else {
        this.modal.warning(res.Table[0].ERR_MESSAGE, this.viewref);
      }
    }, (err) => {
      this.modal.error("Upload error! Please check file or data for upload.", this.viewref);
    });
  }
}
