import { Component, OnInit, ViewContainerRef } from "@angular/core";
import { HttpService } from "src/app/core/http.service";
import { ModalService } from "src/app/core/modal.service";
import { Globals } from "src/app/core/global";
import * as moment from "moment";

@Component({
  selector: "SNWR043",
  templateUrl: "SNWR043.component.html",
})
export class SNWR043Component implements OnInit {
  constructor(
    private modal: ModalService,
    private viewRef: ViewContainerRef,
    private http: HttpService,
    private global: Globals,
  ) { }

  public fileUrl;
  public fileUrlBaby;
  public fileUrlPart;
  public params: any = {};
  public PartNo: any;
  public PickingListNo: any;
  public NoPrint: any;
  public DataList: any = [];
  public iSelectTab: number = 0;
  public iShowBy: number = 0;
  public tabIndex: number = 0;

  public lookupPartNoConfig: any = {
    ColName: "LOOKUP_PART_NO",
    PlaceholderText: "Select Part No",
    SourceController: "WH",
    SourceMethodName: "SNWR043_GetPartNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }
  public SetSelectedPartNo(values: any) {
    this.params.PART_NO = values.PART_NO;
    this.params.PART_NAME = values.PART_NAME;
  }

  public ngOnInit() {
    this.GetPickingList();
  }

  public tabClick(tab: any) {
    this.iSelectTab = tab;
    if (tab == 0){
      this.GetPickingList();
    }else{
      this.params.PRINT_NUMBER = 0;
      this.params.PART_NO = '';
      this.params.PART_NAME = '';
      this.fileUrlPart = null;
    }
  }

  public GetPickingList() {
    this.http.post("WH", "SNWR043_GetPickinglistLast", this.params).subscribe(
      (res) => {
        this.DataList = res.Table;
      },
      (err) => {
        console.log(err);
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewRef
        );
      }
    );
  }
 
  public PrintPickingList(data) {
    this.fileUrl = null;
    data.PRINT_PICK_DATE = moment(data.PRINT_PICK_DATE, 'YYYY-MM-DD').format('YYYY-MM-DD');
    this.http 
      .Download("WH", "SNWR043_Print_PickingList_Part", {
        ReportPrefix: "PMS_RPT_WMS_SNWR043_PRINT_PICKINGLIST_PARTNO",
        ReportSuffix: ".PDF",
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_PICKING_LIST_NO: data.PICKING_LIST_NO,
        P_PRINT_PICK_DATE: data.PRINT_PICK_DATE
      })
      .subscribe((res) => {
        if (res) {
          this.SetIFrameContent(res);
        }
      });
    this.fileUrlBaby = null;
    this.http
      .Download("WH", "SNWR043_Print_PickingList_Baby", {
        ReportPrefix: "PMS_RPT_WMS_SNWR043_PRINT_PICKINGLIST_BABYNO",
        ReportSuffix: ".PDF",
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_PICKING_LIST_NO: data.PICKING_LIST_NO,
        P_PRINT_PICK_DATE: data.PRINT_PICK_DATE
      })
      .subscribe((res) => {
        if (res) {
          this.SetIFrameBabyContent(res);
        }
      });
  }

  private SetIFrameContent(content: any) {
    const file = new Blob([content], { type: content.type });
    const fileUrl = URL.createObjectURL(file);

    this.fileUrl = fileUrl;
  }
  private SetIFrameBabyContent(content: any) {
    const file = new Blob([content], { type: content.type });
    const fileUrlBaby = URL.createObjectURL(file);

    this.fileUrlBaby = fileUrlBaby;
  }

  public PreviewQRCodePartNo() {

    if ((typeof this.params.PART_NO == 'undefined' || this.params.PART_NO == '')) {
      this.modal.warning("Please select a part no before printing the qr code.", this.viewRef);
    }
    else if (this.params.PRINT_NUMBER < 1) {
      this.modal.warning("Part no amount must be more than 0.", this.viewRef);
    }
    else {
      this.http
        .post("WH", "SNWR043_Print_PartNo", this.params)
        .subscribe((res) => {
          if (res.Result == "Done") {
            this.PartNo = res.PartNo;
            this.NoPrint = res.NoPrint;
            if (this.NoPrint != 'null' && this.NoPrint != '') {
              this.PreviewPartNo();
            } else {
              this.modal.warning("Part no incorrect.", this.viewRef);
            }
          }
        });
    }
  }

  public PreviewPartNo() {
    this.fileUrlPart = null;
    this.http
      .Download("WH", "SNWR043_Print_QRCodePartNo", {
        ReportPrefix: "PMS_RPT_WMS_SNWR043_PRINT_PARTNO",
        ReportSuffix: ".PDF",
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_PART_NO: this.PartNo,
        P_PRINT_NUMBER: this.params.PRINT_NUMBER,
      })
      .subscribe((res) => {
        if (res) {
          this.SetIFramePartContent(res);
        }
      });
  }

  private SetIFramePartContent(content: any) {
    const file = new Blob([content], { type: content.type });
    const fileUrlPart = URL.createObjectURL(file);

    this.fileUrlPart = fileUrlPart;
  }

}
