import { SelectionModel } from "@angular/cdk/collections";
import { Component, OnInit, ViewChild, ViewContainerRef } from "@angular/core";
import { DialogTemplateComponent } from "src/app/components/shared/dialog-template/dialog-template.component";
import { Globals } from "src/app/core/global";
import { HttpService } from "src/app/core/http.service";
import { ModalService } from "src/app/core/modal.service";

@Component({
  selector: "snwr045",
  templateUrl: "SNWR045.component.html",
})
export class SNWR045Component implements OnInit {
  constructor(
    private http: HttpService,
    private global: Globals,
    private modal: ModalService,
    private viewRef: ViewContainerRef
  ) { }

  public params: any;
  public incompleteList: any[];
  // public suspendList: any[];
  public selectedList = new SelectionModel<any>(true, []);
  // public readySuspendList = new SelectionModel<any>(true, []);
  public reasonCode: string;
  public remarks: string;
  public _reasonCode: string;
  public _reasonDescription: string;
  @ViewChild("suspendDialog") suspendDialog: DialogTemplateComponent;
  @ViewChild("returnDialog") returnDialog: DialogTemplateComponent;

  public ConfigReasonCode: any = {
    ColName: "LOOKUP_REASON",
    ColValue: "",
    PlaceholderText: "Select Reason Code",
    SourceController: "WH",
    SourceMethodName: "SNWR045_GetReasonCode",
    NoOfShowRecords: 100,
    MinLengthSearch: 0,
    UpperCase: true,
  };

  ngOnInit() {
    this.Initialize();
  }

  public Initialize() {
    this.params = {};
    this.incompleteList = [];
    // this.suspendList = [];
    this.selectedList.clear();
    // this.readySuspendList.clear();
    this.reasonCode = undefined;
    this.remarks = undefined;
    this._reasonCode = undefined;
    this._reasonDescription = undefined;
  }

  public Search() {
    this.selectedList.clear();
    this.http.get("WH", "SNWR045_GetIncompleteList").subscribe(
      (result) => {
        this.incompleteList = result.Table;
        // this.suspendList = result.Table1;
      },
      (err) => {
        this.modal.error(
          "Found error, please contact support team",
          this.viewRef
        );
      }
    );
  }

  public ReturnReport() {
    this.modal.confirm(
      "Are you sure to return these items to checker?",
      this.viewRef,
      () => {
        const data = this.selectedList.selected;
        this.http.post("WH", "SNWR045_ReturnItems", data).subscribe(
          (result) => {
            if (result === "Done") {
              this.modal.info(
                "Successfully return items to checker.",
                this.viewRef
              );
              this.returnDialog.Close();
              this.Search();
            //} else if (result === "Invoiced") {
            //  this.modal.warning(
            //    "รายการของการ์ดใบนี้ออกอินวอยด์ไปแล้ว ไม่สามารถ return ส่วนที่เหลือได้ ต้องทำการ approve suspend และ allocate ใหม่",
            //    this.viewRef
            //  );
            }
          },
          (err) => {
            console.log(err);
            this.modal.error(
              "Found error, please contact support team",
              this.viewRef
            );
          }
        );
      },
      () => { }
    );
  }

  public SubmitSuspend() {
    if (this._reasonCode) {
      this.modal.confirm(
        "Are you sure to submit suspend to manager?",
        this.viewRef,
        () => {
          const data = this.selectedList.selected;


          this.http
            .post("WH","SNWR045_Submit", {
              remarks: this.remarks,
              data: data,
              reasonCode : this.reasonCode
            })
            .subscribe(
              (result) => {
                if (result === "Done") {
                  this.modal.info("Successfully Submit Suspend to Manager.", this.viewRef);
                  this.suspendDialog.Close();
                  this.Search();
                }
              },
              (err) => {
                this.modal.error(
                  "Found error, please contact support team",
                  this.viewRef
                );
              }
            );
        },
        () => { }
      );
    } else {
      this.modal.warning("Please input suspend reason code.", this.viewRef);
    }
  }

  public OpenReturnDialog() {
    this.returnDialog.OpenDialog();
  }

  public OpenSuspendDialog() {

    // let find = this.selectedList.selected.some(x => x.INVOICE_STATUS != "NOT_PACK")
    // if(find){
    //   this.modal.warning("รายการที่เลือก มีรายการที่ pack สินค้าไปแล้ว กรุณาเลือกใหม่",this.viewRef)
    //   return
    // }
    //---- Remove submit status 
    // this.selectedList.selected;
    let check = this.selectedList.selected.some(x => x.STATUS == "Submit")
    if(check){
      this.modal.warning("รายการที่เลือก มีรายที่ทำ submit ไปแล้ว กรุณาเลือกใหม่", this.viewRef)
      return
    }
    
    this.reasonCode = undefined;
    this.remarks = undefined;
    this._reasonCode = undefined;
    this._reasonDescription = undefined;
    this.suspendDialog.OpenDialog();
    

  }

  public ValidateSuspendQty(evt: any, data: any) {
    if (evt.target.value < 1 || evt.target.value > data.SUSPEND_QTY) {
      data.QTY = data.SUSPEND_QTY;
      evt.target.value = data.SUSPEND_QTY;
      this.modal.warning("Incorrect Suspend Qty", this.viewRef)
    }
  }

  SetReasonCode(event) {
    this.reasonCode = event.REASON_CODE;
    this._reasonCode = event.REASON_CODE;
    this._reasonDescription = event.REASON_NAME_EN;
  }
}
