import { Component, OnInit, ViewContainerRef } from "@angular/core";
import { HttpService } from "src/app/core/http.service";
import { ActivatedRoute } from '@angular/router';
import { ModalService } from "src/app/core/modal.service";
import { Globals } from "src/app/core/global";

@Component({
  selector: "SNWR046",
  templateUrl: "SNWR046.component.html",
})
export class SNWR046Component implements OnInit {
  constructor(
    private modal: ModalService,
    private viewRef: ViewContainerRef,
    private http: HttpService,
    private global: Globals,
    private route: ActivatedRoute,
  ) {}

  public params: any = {};
  public customerCode: any;
  public babyCardGroup: any;
  public babyCardNoFrom: any;
  public babyCardNoTo: any;
  public fileUrl;

  public lookupCustomerCodeConfig: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "WH",
    SourceMethodName: "SNWR031_GetCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }


  public lookupBabycardNoConfig: any = {
    ColName: "LOOKUP_BABY_CARD_NO",
    PlaceholderText: "Select Baby Card No.",
    SourceController: "WH",
    SourceMethodName: "SNWR046_GetBabyCardNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true,
    SourceParams: {
      CUSTOMER_CODE: null,
      BABYCARD_GROUP:null
    },
  }

  public SetSelectedCustomerCode(values: any) {
    this.params.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.params.CUSTOMER_NAME = values.CUSTOMER_NAME;
    this.lookupBabycardNoConfig.SourceParams.CUSTOMER_CODE = values.CUSTOMER_CODE;
  }

  public setData(values: any) {  
    this.lookupBabycardNoConfig.SourceParams.BABYCARD_GROUP = values.value;
  }

  

  public ngOnInit() {
    this.params.PRINT_NUMBER = 0;
  }

  public FindBabyCardNumber() {
    this.http.post("WH", "SNWR031_Get_Babycard_Number", this.params).subscribe(
      (res) => {
        if (res.Table[0]) {
          this.global.GoToReport("PMS_RPT_WMS_SNWR031_BABYCARD", {
            P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
            P_CUSTOMER_CODE: res.Table[0].CUSTOMER_CODE,
            P_BABYCARD_GROUP: res.Table[0].BABYCARD_GROUP,
            P_BABYCARD_NO_FROM: res.Table[0].BABYCARD_NO,
            P_BABYCARD_NO_TO: res.Table[0].BABYCARD_NO,
          });
        } else {
          this.modal.error("Unavailable baby card number.", this.viewRef);
        }
      },
      (err) => {
        console.log(err, 'err');
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewRef
        );
      }
    );
  }

  public Print() {
    this.global.GoToReport(
      "PMS_RPT_WMS_SNWR031_BABYCARD", 
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_CUSTOMER_CODE: this.customerCode,
        P_BABYCARD_GROUP: this.babyCardGroup,
        P_BABYCARD_NO_FROM: this.babyCardNoFrom,
        P_BABYCARD_NO_TO: this.babyCardNoTo,
      }, true, false);

    this.global.GoToExport("PMS_RPT_WMS_SNWR031_BABYCARD_EXCEL",
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_CUSTOMER_CODE: this.customerCode,
        P_BABYCARD_GROUP: this.babyCardGroup,
        P_BABYCARD_NO_FROM: this.babyCardNoFrom,
        P_BABYCARD_NO_TO: this.babyCardNoTo,
      }, true, "EXCELOPENXML");
  }

 

  public Preview() {
      this.fileUrl = null;
      this.http
        .Download("WH", "SNWR046_Preview_BabyCard", {
          ReportPrefix: "PMS_RPT_WMS_SNWR046_BABYCARD",
          ReportSuffix: ".PDF",
          P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
          P_CUSTOMER_CODE: this.customerCode,
          P_BABYCARD_GROUP: this.babyCardGroup,
          P_BABYCARD_NO_FROM: this.babyCardNoFrom,
          P_BABYCARD_NO_TO: this.babyCardNoTo,
        })
        .subscribe((res) => {
          if (res) {
            this.SetIFrameContent(res);
          }
        });
  }

  public ReprintBabyCard() {

    if (typeof this.params.CUSTOMER_CODE =='undefined' || this.params.CUSTOMER_CODE == ''){
      this.modal.warning("Please select a customer before printing the baby card.", this.viewRef);
    } 
    else if (typeof this.params.BABYCARD_GROUP =='undefined' || this.params.BABYCARD_GROUP == ''){
      this.modal.warning("Please select Order Type.", this.viewRef);
    } 
    else if (!this.params.PRINT_NUMBER_FROM) {
      this.modal.warning("Baby card No. From", this.viewRef);
    }

    this.fileUrl = null;
    this.http
      .Download("WH", "SNWR046_Preview_BabyCard", {
        ReportPrefix: "PMS_RPT_WMS_SNWR046_BABYCARD",
        ReportSuffix: ".PDF",
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_CUSTOMER_CODE: this.params.CUSTOMER_CODE,
        P_BABYCARD_GROUP: this.params.BABYCARD_GROUP,
        P_BABYCARD_NO_FROM: this.params.PRINT_NUMBER_FROM,
        P_BABYCARD_NO_TO: !this.params.PRINT_NUMBER_TO ? this.params.PRINT_NUMBER_FROM : this.params.PRINT_NUMBER_TO,
      })
      .subscribe((res) => {
        if (res) {
          this.SetIFrameContent(res);
        }
      });
  } 

  private SetIFrameContent(content: any) {
    const file = new Blob([content], { type: content.type });
    const fileUrl = URL.createObjectURL(file);

    this.fileUrl = fileUrl;
  }

  public DLExcelBabyCardNumber() {
    this.global.GoToExport("PMS_RPT_WMS_SNWR031_BABYCARD_EXCEL",
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_CUSTOMER_CODE: this.customerCode,
        P_BABYCARD_GROUP: this.babyCardGroup,
        P_BABYCARD_NO_FROM: this.babyCardNoFrom,
        P_BABYCARD_NO_TO: this.babyCardNoTo,
      }, true, "EXCELOPENXML");
  }
}
