import {
  Component,
  Input,
  OnInit,
  ViewChild,
  ViewContainerRef,
} from "@angular/core";
import { HttpService } from "src/app/core/http.service";
import { ModalService } from "src/app/core/modal.service";
import { Globals } from "src/app/core/global";
import { SelectionModel } from "@angular/cdk/collections";

@Component({
  selector: "snwr047",
  templateUrl: "./snwr047.component.html",
  styleUrls: ["./snwr047.component.css"]
})
export class SNWR047Component implements OnInit {
  constructor(
    private Http: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private global: Globals
  ) { }

  public CustomerCodeConfig: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "WH",
    SourceMethodName: "SNWR035_GetCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 1,
    UpperCase: true
  }


  public paramSearch: any = {}
  public selection = new SelectionModel<any>(true, []);
  @ViewChild("dialogVanDetail",{static:false}) dialogVanDetail : any;
  @ViewChild("autoCompleteCustomerCode",{static:false}) autoCompleteCustomerCode : any;
  public vanDetail : any = []
  public vanList : any = []

  public selectedRow : any;

  
  ngOnInit() {
    // this.paramSearch.CUSTOMER_CODE = "1JPN01";
    // setTimeout(() => {
    //   this.autoCompleteCustomerCode.query();
    // }, 100);

  }


  public SetSelectedCustomerCode(value: any) {
    this.paramSearch.CUSTOMER_CODE = value.CUSTOMER_CODE;
    this.paramSearch.CUSTOMER_NAME = value.CUST_NAME_EN;
    this.paramSearch.BRANCH_CODE = value.BRANCH_CODE;

  }

  public SetSelectedBranchCode(value: any) {
    this.paramSearch.BRANCH_CODE = value.BRANCH_CODE;
  }

  public radioSelected(data : any) {
    //console.log(this.selectedRow);
  }

  public CheckBoxChange(event :any,data : any){
    if(!event.checked){
      if(this.selectedRow && this.selectedRow.VAN_NO == data.VAN_NO){
        this.selectedRow = null;
      }
    }
  }

  public Search(){
    if(!this.paramSearch.CUSTOMER_CODE){
      this.modal.warning("Please input customer code",this.viewref)
      return
    }


    this.selectedRow = null
    this.vanList = []
    this.selection.clear()

    this.Http.post("WH","SNWR047_GetVan",this.paramSearch)
    .subscribe(res => {
      this.vanList = res.Table
    })
  }

  public GetVanDetail(data : any){
    this.Http.post("WH","SNWR047_GetVanDetail",data)
    .subscribe(res =>{
      this.vanDetail = res.Table
      this.dialogVanDetail.OpenDialog()
    })
  }

  public Clear() {
 
  }

  public Save(){
    if(!this.selectedRow){
      this.modal.warning("Please select colum move to for van target",this.viewref)
      return;
    }

    if(this.selection.selected.length < 2){
      this.modal.warning("Please select more than 1 van ",this.viewref)
      return
    }

    this.modal.confirm("Do you want to merge van ",this.viewref,()=> Confirm())

    let Confirm = () => {

      const param = {
        vanTarget : this.selectedRow,
        vanList : this.selection.selected.filter(x => x.VAN_GROUP != this.selectedRow.VAN_GROUP)
      }

      this.Http.post("WH","SNWR047_Save",param)
      .subscribe(res => {
        if(res.STATUS == "DONE"){
          this.modal.info("Merge van complete",this.viewref)
          this.Search()
        }else{
          this.modal.error("Found an error, please contact support team", this.viewref);
        }
      },err => {
        console.log(err, 'err');
        this.modal.error("Found an error, please contact support team", this.viewref);
      })
    }
  }



  public isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.vanList.length;
    return numSelected === numRows;
  }

  public Toggle() {
    if (this.isAllSelected()) {
      this.selection.clear()
    } else {
      this.vanList.forEach((row) => {

        this.selection.select(row);

      })
    }
  }


}
