import {
  Component,
  ElementRef,
  OnInit,
  ViewChild,
  ViewContainerRef, 
  ViewChildren,
} from "@angular/core";
import { FormControl, Validators } from "@angular/forms";
import { Globals } from "src/app/core/global";
import { HttpService } from "src/app/core/http.service";
import { ModalService } from "src/app/core/modal.service";
import { SelectionModel } from '@angular/cdk/collections';
import * as moment from "moment";

@Component({
  selector: "SNWR049",
  templateUrl: "SNWR049.component.html",
})
export class SNWR049Component implements OnInit {
  constructor(
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private http: HttpService,
    private el: ElementRef,
    private global: Globals
  ) {}
  
  @ViewChild("dialogAddHeader", { static: false }) dialogAddHeader: any;
  @ViewChild("dialogSelected", { static: false }) dialogSelected: any;
  @ViewChild("dialogUpload", { static: false }) dialogUpload: any;
  @ViewChild("dialogError", { static: false }) dialogError: any;
  @ViewChild("dialogStockTaking", { static: false }) dialogStockTaking: any;
  @ViewChild("fileInput") fileInput: any;
  @ViewChild("fileLocation") fileLocation: any;
  @ViewChild("filePart") filePart: any;
  @ViewChildren("inputPartQty") Inputs : any;
  
  public selection = new SelectionModel<any>(true, []);

  public isSavePage: boolean = false;
  public paramSearch: any = {};
  public paramAdd: any = {};
  public checkType: any = [
    // { ID: 1, TYPE: "CHECK_STOCK", DESC: "Check stock" },
    { ID: 2, TYPE: "CYCLE_COUNT", DESC: "Cycle count" },
    { ID: 3, TYPE: "STOCK_TAKING", DESC: "Stock Taking" },
  ];

  public tabSelected: number = 0;
  public dataCheckStock: any = {};
  public tableDataHeader: any = [];
  public tableDataPreview: any = [];
  public tableDataInitial: any = [];
  public tableDataStockTaking: any;
  public paramStockTaking: any = {
    AMT_A: null,
    QTY_A: null,
    ITEM_A: null,
    AMT_M: null,
    QTY_M: null,
    ITEM_M: null,
    AMT_ALL: null,
    QTY_ALL: null,
    ITEM_ALL: null,
    CREATE_BY: null,
    CREATE_DATE: null,
    LAST_UPD_PGM: null,
    LAST_UPD_BY: null,
    LAST_UPD_DATE: null,
    LAST_IP_ADDR: null,
    LAST_UPD_NAME: null,
  };
  
  //Upload File
  public file: any = [];
  public files: any = [];
  public fileName: any = [];
  public paramUpload: any = {};
  public tableDataUpload = [];
  public error_list: any = [];
  public total_error = 0;

  //Select Location
  public paramSelected: any = {};
  public tableDataLocationSelected: any = [];

  //Adjust Shelve
  public paramShelveCheck: any = {};
  public tableDataShelveCheck: any = [];

  public lookupPartNo: any = {
    ColName: "LOOKUP_PART_NAME",
    PlaceholderText: "Select Part No.",
    SourceController: "WH",
    SourceMethodName: "SNWR049_GetPartNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 3,
    UpperCase: true,
  };
  
  public lookupLocationNo: any = {
    ColName: "LOOKUP_LOCATION_NO",
    PlaceholderText: "Select Location no.",
    SourceController: "WH",
    SourceMethodName: "SNWR049_GetLocationNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 2,
    UpperCase: true,
  };

  //Validate
  SetCheckStockDateControl = new FormControl("", [Validators.required]);
  SetCheckStockTypeControl = new FormControl("", [Validators.required]);
  SetCheckRemarksControl = new FormControl("", [Validators.required]);

  public ngOnInit() {
    this.Search();
    this.paramStockTaking = {};
    this.paramStockTaking.LAST_UPD_DATE = new Date();
    this.paramStockTaking.LAST_UPD_NAME = this.global.GetTokenDetail("ssNameEN");
  }

  public Search() {
    this.http
      .post("WH", "SNWR049_GetData", this.paramSearch)
      .subscribe((res) => {
        this.tableDataHeader = res.Table;
      },
      (err) => {
        console.log("err", err);
        this.modal.warning(
          "Found an error, please contract support team",
          this.viewref
        );
      });
  }

  public CreateCheckStock() {
    this.paramAdd = {};
    this.dialogAddHeader.OpenDialog();
  }

  public SaveCreateCheckStock() {
    if (this.paramAdd.CHECK_DATE && this.paramAdd.CHECK_TYPE && this.paramAdd.REMARKS) {
      this.modal.confirm(
        "Do you want to save change you have made?",
        this.viewref,
        this.ConfirmSaveCheckStock
      );
    } else {
      this.modal.warning("Please Input fill.", this.viewref);
    }
  }

  private ConfirmSaveCheckStock = () => {
    this.http.post("WH", "SNWR049_INIT", this.paramAdd).subscribe(
      (res) => {
        if (res.Table[0].STATUS == "Done") {
          this.modal.info(
            "Transaction complete: applied and saved.",
            this.viewref
          );
          this.Search();
          this.paramAdd = this.global.ClearObject(this.paramAdd);
          this.dialogAddHeader.Close();
          this.SetCheckStockDateControl.reset();
          this.SetCheckStockTypeControl.reset();
          this.SetCheckRemarksControl.reset();
        } else if (res.Table[0].STATUS == "Duplicate") {
          this.modal.warning(
            "No change to save. Please submit before create new round.",
            this.viewref
          );
        } else {
          this.modal.error(
            "No change to save. Something went wrong.",
            this.viewref
          );
        }
      },
      (err) => {
        console.log("err", err);
        this.modal.warning(
          "Found an error, please contract support team",
          this.viewref
        );
      }
    );
  };

  public ViewDetail(data) {
    this.selection.clear();
    this.tabSelected = 0;
    this.dataCheckStock = data;
    this.dataCheckStock.errorCount = 0;
    this.paramShelveCheck = {};
    this.paramShelveCheck.HIDE_COLUMN = [''];
    this.tableDataPreview = [];
    this.tableDataInitial = [];
    this.tableDataShelveCheck = [];
    this.error_list = [];
    //this.CheckInit();
    this.GetDataByID();
    if(this.dataCheckStock.STATUS == 'Confirm') { 
      this.paramShelveCheck.SHELVE_FILTER = 'GET_ALL';
      this.GetShelveAll(); 
    }
    this.isSavePage = !this.isSavePage;
  }

  public CheckInit() {
    this.tableDataInitial.push({
      LOCATION_NO: null,
      PART_NO: null,
      PART_NAME_EN: null,
      PART_NAME_TH: null,
      COUNT_QTY: 0,
    });
  }

  public GetDataByID() {
    this.http
      .get("WH", "SNWR049_GetData_ByID", this.dataCheckStock.HEADER_ID)
      .subscribe((res) => {
        this.tableDataPreview = res.Table;
      });
  }

  public Back() {
    this.isSavePage = !this.isSavePage;
  }

  public ReturnProcess(){
    this.modal.confirm(
      "Do you want to return process?"
      + "<br>" + "Date: " + moment(this.dataCheckStock.CHECK_DATE).format("DD-MMM-YYYY")
      + "<br>" + "Round: " + this.dataCheckStock.CHECK_ROUND
      + "<br>" + "Remarks: " + this.dataCheckStock.REMARKS
      + "<br><br>" + "<label style='color:red;'>#Return process all confirm adjust shelve staus can't any action</label>",
      this.viewref,
      () => {
        this.http.post("WH", "SNWR049_ReturnProcess", this.dataCheckStock).subscribe(
          (res) => {
            if (res == "Done") {
              this.Search();
              this.Back();
              this.modal.info(
                "Transaction complete: applied and saved.",
                this.viewref
              );
            } else {
              this.modal.error(
                "No change to save. Something went wrong.",
                this.viewref
              );
            }
          },
          (err) => {
            console.log("err", err);
            this.modal.warning(
              "Found an error, please contract support team",
              this.viewref
            );
          }
        );
      },
      () => {},
      {width: "37.5rem", height: "20rem"}
    );
  }

  public ConfirmCountShelve() {
    if (this.tableDataPreview.length > 0 && this.dataCheckStock.HEADER_ID) {
      this.modal.confirm(
        "Do you want to confirm count process to adjust location shelve?"
        + "<br>" + "Date: " + moment(this.dataCheckStock.CHECK_DATE).format("DD-MMM-YYYY")
        + "<br>" + "Round: " + this.dataCheckStock.CHECK_ROUND
        + "<br>" + "Remarks: " + this.dataCheckStock.REMARKS,
        this.viewref,
        () => {
          this.http.post("WH", "SNWR049_ConfirmCountStock", this.dataCheckStock).subscribe(
            (res) => {
              if (res == "Done") {
                this.Search();
                this.Back();
                this.modal.info(
                  "Transaction complete: applied and saved.",
                  this.viewref
                );
              } else {
                this.modal.error(
                  "No change to save. Something went wrong.",
                  this.viewref
                );
              }
            },
            (err) => {
              console.log("err", err);
              this.modal.warning(
                "Found an error, please contract support team",
                this.viewref
              );
            }
          );
        },
        () => {},
        {width: "37.5rem", height: "20rem"}
      );
    } else {
      this.modal.warning(
        "Don't have data for submit, please try again.",
        this.viewref
      );
    }
  }

  public ConfirmAdjustShelve() {
    if(this.tableDataPreview.some((x) => x.STATUS != "ADJUST")){
      this.modal.warning("กรุณาคอนเฟิร์มโลเคชั่นทั้งหมดก่อนดำเนินการ confirm ไปยัง process ถัดไป", this.viewref);
      return;
    }
    if (this.tableDataPreview.length > 0 && this.dataCheckStock.HEADER_ID) {
      this.modal.confirm(
        "Do you want to confirm adjust process to account?"
        + "<br>" + "Date: " + moment(this.dataCheckStock.CHECK_DATE).format("DD-MMM-YYYY")
        + "<br>" + "Round: " + this.dataCheckStock.CHECK_ROUND
        + "<br>" + "Remarks: " + this.dataCheckStock.REMARKS,
        this.viewref,
        () => {  
          this.http.post("WH", "SNWR049_ConfirmAdjustStock", this.dataCheckStock).subscribe(
            (res) => {
              if (res == "Done") {
                this.modal.info(
                  "Transaction complete: applied and saved.",
                  this.viewref
                );
                this.Search();
                this.Back();
              } else {
                this.modal.error(
                  "No change to save. Something went wrong.",
                  this.viewref
                );
              }
            },
            (err) => {
              console.log("err", err);
              this.modal.warning(
                "Found an error, please contract support team",
                this.viewref
              );
            }
          );
        },
        () => {},
        {width: "35rem", height: "20rem"}
      );
    } else {
      this.modal.warning(
        "Don't have data for submit, please try again.",
        this.viewref
      );
    }
  }

  public EntryCheckQty() {
    this.paramStockTaking.LAST_UPD_DATE = new Date();
    
    if(this.tableDataPreview.some((x) => x.STATUS != "ADJUST")){
      this.modal.warning("กรุณาคอนเฟิร์มโลเคชั่นทั้งหมดก่อนดำเนินการ confirm ไปยัง process ถัดไป", this.viewref, () => { this.tabSelected = 1});
      return;
    }

    const params = {
      HEADER_ID: this.dataCheckStock.HEADER_ID
    }
    this.http.post("WH", "SNWR049_GetStockTakingPart", params)
      .subscribe((res) => {
        this.tableDataStockTaking = res.Table;
        this.dialogStockTaking.title = "Check Stock Taking Part";
        this.dialogStockTaking.OpenDialog();
      },
      (err) => {
        console.log("err", err);
        this.modal.warning(
          "Found an error, please contract support team",
          this.viewref
        );
      });
  }

  public ConfirmToStockTaking() {
    let forsave = this.tableDataStockTaking.filter(x => x.O_CHK_QTY != x.CHECK_QTY)
    
    if(forsave.length > 0 ){
      this.modal.confirm(
        "Do you want to confirm cycle count process to stock taking?"
        + "<br>" + "Date: " + moment(this.dataCheckStock.CHECK_DATE).format("DD-MMM-YYYY")
        + "<br>" + "Round: " + this.dataCheckStock.CHECK_ROUND
        + "<br>" + "Remarks: " + this.dataCheckStock.REMARKS,
        this.viewref,
        () => {  
          const params = {
            HEADER_ID: this.dataCheckStock.HEADER_ID,
            STOCK_TAKING: forsave
          }
          this.http.post("WH", "SNWR049_ConfirmStockTaking", params).subscribe(
            (res) => {
              if (res == "Done") {
                this.dialogStockTaking.Close();
                this.modal.info('Transaction complete: '+ forsave.length + ' record applied and saved.', this.viewref);
              } else {
                this.modal.error(
                  "No change to save. Something went wrong.",
                  this.viewref
                );
              }
            },
            (err) => {
              console.log("err", err);
              this.modal.warning(
                "Found an error, please contract support team",
                this.viewref
              );
            }
          );
        },
        () => {},
        {width: "35rem", height: "20rem"}
      );
    }else{
      this.modal.warning("No data change",this.viewref);
    }
  }

  public SaveHeader(){
    if (this.dataCheckStock.CHECK_DATE && this.dataCheckStock.CHECK_TYPE && this.dataCheckStock.REMARKS) {
      this.modal.confirm(
        "Do you want to save header detail you have made?",
        this.viewref,
        this.ConfirmSaveHeader
      );
    } else {
      if(this.dataCheckStock.CHECK_DATE == ''){
        this.modal.warning("Please Input check", this.viewref);
      }
      else if(this.dataCheckStock.REMARKS == ''){
        this.modal.warning("Please Input remarks", this.viewref);
      }
      else{
        this.modal.warning("Please Input fill", this.viewref);
      }
    }
  }

  private ConfirmSaveHeader = () => {
    this.http.post("WH", "SNWR049_SaveHeader", this.dataCheckStock).subscribe(
      (res) => {
        if (res.Table[0].STATUS == "Done") {
          this.Search();
          this.modal.info(
            "Transaction header complete: applied and saved.",
            this.viewref
          );
        } else if (res.Table[0].STATUS == "Duplicate") {
          this.modal.warning( res.Table[0].MESSAGE, this.viewref);
        } else {
          this.modal.error(
            "No change to save. Something went wrong.",
            this.viewref
          );
        }
      },
      (err) => {
        console.log("err", err);
        this.modal.warning(
          "Found an error, please contract support team",
          this.viewref
        );
      }
    );
  };

  public Delete(data){
    this.modal.confirm(
      !data.PART_NO 
      ? "Do you want to delete?<br>Location: "+ data.LOCATION_NO 
      : "Do you want to delete all location in this part no?<br>Part no: "+ data.PART_NO,
      this.viewref,
      ()=>{
        this.http.post("WH", "SNWR049_DeleteDetail", data).subscribe(
          (res) => {
            if (res.Table[0].STATUS == "Done") {
              this.GetDataByID();
              this.modal.info(
                "Transaction delete complete: applied and saved.",
                this.viewref
              );
            } 
            else {
              this.modal.error(
                "No change to save. Something went wrong.",
                this.viewref
              );
            }
          },
          (err) => {
            console.log("err", err);
            this.modal.warning(
              "Found an error, please contract support team",
              this.viewref
            );
          }
        );
      },
      () => {

      },
      {width: "35rem", height: "20rem"}
    );
  }

  public Report(number) {
    switch (number) {
      case 1:
          this.global.GoToReport("PMS_RPT_WMS_SNWR049_SUMMARY_COUNT_BY_PART", {
            P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
            P_HEADER_ID: this.dataCheckStock.HEADER_ID
          });
        break;
      case 2:
          this.global.GoToReport("PMS_RPT_WMS_SNWR049_SUMMARY_COUNT_BY_LOCAITON", {
            P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
            P_HEADER_ID: this.dataCheckStock.HEADER_ID
          });
        break;
      case 3:
          this.global.GoToReport("PMS_RPT_WMS_SNWR049_SUMMARY_ADJUST", {
            P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
            P_HEADER_ID: this.dataCheckStock.HEADER_ID
          });
        break;
      case 4:
          this.global.GoToReport("PMS_RPT_WMS_SNWR049_SUMMARY_ADJUST_LOG", {
            P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
            P_HEADER_ID: this.dataCheckStock.HEADER_ID
          });
        break;
    }
  }

  public onInputCountQty(data) {
    if (!data.COUNT_QTY) {
      data.ERR_FLAG = "Y";
      data.ERR_MSG = "Count qty can't null";
      this.dataCheckStock.errorList = [];
      this.dataCheckStock.errorCount = 0;
      let countrow = 0;
      this.tableDataInitial.filter((x, i) => {
        if (x.ERR_FLAG == "Y") {
          countrow += 1;
          this.dataCheckStock.errorList.push({
            record : i + 1,
            message : x.ERR_MSG
          });
        }
      });
      this.dataCheckStock.errorCount = countrow;
    }
  }

  public CheckDuplicate(locationNo?: any, partNo?: any){
    let list = [];
    if (partNo) {
      const filter = this.tableDataInitial.filter((x) => x.PART_NO && x.PART_NO.toString() === partNo && x.LOCATION_NO.toString() === locationNo)
      const foundDuplicate = filter.length > 0;
      if (foundDuplicate) {
        list.push({ LOCATION_NO: locationNo, PART_NO: partNo });
      }
    } else {
      list = this.tableDataInitial.filter(
          (item) => this.tableDataInitial.filter(
              (x) => x.PART_NO 
                  && x.PART_NO == item.PART_NO
                  && x.LOCATION_NO == item.LOCATION_NO
            ).length > 1
        )
        .map((item) => [{ LOCATION_NO: item.LOCATION_NO, PART_NO: item.PART_NO }]);
      list = [...new Set(list)];
    }
    return list;
  }

  public AddRecord() {
    this.tableDataInitial.push({
      LOCATION_NO: null,
      PART_NO: null,
      PART_NAME_EN: null,
      PART_NAME_TH: null,
      COUNT_QTY: 0,
    });
    this.tableDataInitial = this.tableDataInitial.slice();
  }

  public RemoveRecord(data) {
    this.modal.confirm(
      !data.PART_NO 
        ? "Do you want to delete?<br>Location: "+ data.LOCATION_NO 
        : "Do you want to delete all location in this part no?<br>Part no: "+ data.PART_NO,
      this.viewref,
      ()=>{
        let idx;
        if(!data.PART_NO){
          idx = this.tableDataInitial.findIndex((main) => main.LOCATION_NO === data.LOCATION_NO);
          this.tableDataInitial.splice(idx, 1);
        } else {
          this.tableDataInitial
          .filter((main) => 
            main.PART_NO == data.PART_NO
          )
          .map((value) => {
            idx = this.tableDataInitial.findIndex((main) => main.LOCATION_NO === value.LOCATION_NO);
            if (idx !== -1){
              this.tableDataInitial.splice(idx, 1);
            }
          });
        }
        this.tableDataInitial = this.tableDataInitial.slice();
        this.dataCheckStock.errorList = [];
        this.dataCheckStock.errorCount = 0;
        let countrow = 0;
        this.tableDataInitial.map((value, index) => {
          value.ROWNO = this.paramSelected.TYPE !== "STOCK_TAKING" ? index + 1 : value.ROWNO ;
          if (value.ERR_FLAG == "Y") {
            countrow += 1;
            this.dataCheckStock.errorList.push({
              record : value.SEQ,
              message : value.ERR_MSG
            });
          }
        });
        this.dataCheckStock.errorCount = countrow;
      },
      () => {

      },
      {width: "35rem", height: "20rem"}
    );
  }

  public SaveDetail() {
    if (this.tableDataInitial.length > 0 && this.dataCheckStock.HEADER_ID) {
      this.modal.confirm(
        "Do you want to add these change you have made?",
        this.viewref, () => {
          this.ConfirmSaveDetail()
        }
      );
    } else {
      this.modal.warning(
        "Don't have data for save, please try again.",
        this.viewref
      );
    }
  }

  private ConfirmSaveDetail() {
    const saveData = this.tableDataInitial.filter((value) => value.LOCATION_NO);
    if (saveData.length > 0) {
      const params = {
        HEADER_ID: this.dataCheckStock.HEADER_ID,
        CHECKSTOCK_LIST: this.tableDataInitial
      }
      this.http
        .post("WH", "SNWR049_SaveDetail", params)
        .subscribe(
          (res) => {
            if (res === "Done") {
              //this.Search();
              this.GetDataByID();
              this.tableDataInitial = [];
              this.modal.info(
                "Transaction complete: applied and saved.",
                this.viewref,
                () => {
                  this.tabSelected = 0;
                }
              );
            }
          },
          (err) => {
            console.log("err", err);
            this.modal.warning(
              "Found an error, please contract support team",
              this.viewref
            );
          }
        );
    } else {
      this.modal.warning(`No change to save.`, this.viewref);
    }
  };

  //Select Location
  public OpenLocationSelected(){
    this.paramSelected = {};
    this.paramSelected.TYPE = this.dataCheckStock.CHECK_TYPE !== 'STOCK_TAKING'? "PART" : "STOCK_TAKING";
    this.paramSelected.errorList = [];
    this.paramSelected.errorCount = 0;
    this.tableDataLocationSelected = [];
    this.dialogSelected.width="1000px";
    this.dialogSelected.height="625px";
    this.dialogSelected.title = "Add Location";
    this.dialogSelected.OpenDialog()
  }

  public SelectedTypeChanged() {
    if(this.paramSelected.TYPE == "PART"){
      this.paramSelected.PART_NO = "";
      this.paramSelected.LOCATION_NO = "";
    }
    else if(this.paramSelected.TYPE == "LOCATION"){
      this.paramSelected.PART_NO = "";
      this.paramSelected.LOCATION_NO = "";
    }
  }

  public CheckPart(data, event){
    if(event){
      data.PART_NO = event.LOOKUP_PART_NAME;
    
      data.LOCATION_NO_SEARCH = event.LOCATION_NO;
      data.PART_NO_SEARCH = event.PART_NO;
      if(data.PART_NO){
        this.GetAllLocation(data);
      }
    }else{
    }
  }

  public CheckLocation(data, event){
    if(event){
      data.LOCATION_NO = event.LOOKUP_LOCATION_NO;

      data.LOCATION_NO_SEARCH = event.LOCATION_NO;
      data.PART_NO_SEARCH = event.PART_NO;
      if(data.LOCATION_NO){
        this.GetAllLocation(data);
      }
    }else{
    }
  }

  private GetAllLocation(data){
    this.tableDataLocationSelected = [];
    this.paramSelected.errorList = [];
    this.paramSelected.errorCount = 0;
    const params = {
      HEADER_ID: this.dataCheckStock.HEADER_ID,
      LOCATION_NO: data.LOCATION_NO_SEARCH,
      PART_NO: data.PART_NO_SEARCH
    }
    this.http
      .post("WH", "SNWR049_GetAllLocation", params)
      .subscribe(
        (res) => {
          this.tableDataLocationSelected = res.Table;
          let countrow = 0;
          this.tableDataLocationSelected.map((x,i) => {
            if(x.ERR_FLAG == 'Y'){
                countrow += 1;
                this.paramSelected.errorList.push({
                    record : i + 1,
                    message : x.ERR_MSG
                })
            } 
            this.paramSelected.errorCount = countrow;
          })
        },
        (err) => {
          console.log(err);
          this.modal.warning(
            "Found an error, please contract support team",
            this.viewref
          );
        });
  }

  public CheckStockTaking(){
    if (!this.paramSelected.SEQ_NO_FROM || !this.paramSelected.SEQ_NO_TO) {
      this.modal.warning("กรุณาใส่ค่า Seq. From และ Seq. To", this.viewref);
      return;
    } 
    else if (this.paramSelected.SEQ_NO_FROM > this.paramSelected.SEQ_NO_TO){
      this.modal.warning("ค่า Seq. To ต้องมากกว่าหรือเท่ากับค่า Seq. From", this.viewref);
      return;
    }else{
      this.tableDataLocationSelected = [];
      this.paramSelected.errorList = [];
      this.paramSelected.errorCount = 0;
      const params = {
        HEADER_ID: this.dataCheckStock.HEADER_ID,
        SEQ_NO_FROM: this.paramSelected.SEQ_NO_FROM,
        SEQ_NO_TO: this.paramSelected.SEQ_NO_TO
      }
      this.http
        .post("WH", "SNWR049_GetAllLocationStockTaking", params)
        .subscribe(
          (res) => {
            this.tableDataLocationSelected = res.Table;
            let countrow = 0;
            this.tableDataLocationSelected.map((x,i) => {
              if(x.ERR_FLAG == 'Y'){
                  countrow += 1;
                  this.paramSelected.errorList.push({
                      record : i + 1,
                      message : x.ERR_MSG
                  })
              } 
              this.paramSelected.errorCount = countrow;
            })
          },
          (err) => {
            console.log(err);
            this.modal.warning(
              "Found an error, please contract support team",
              this.viewref
            );
          });
    }
  }

  public SaveLocationSelected(){
    //this.modal.confirm("Do you want to save change you have made?",this.viewref,() => ConfirmSave())

    //let ConfirmSave = () => {
      this.tableDataInitial = this.UpdateTableInitial(this.tableDataLocationSelected);
      this.tableDataInitial.sort((a,b) => {
        if (a.ERR_FLAG < b.ERR_FLAG) {
          return 1;
        }
        if (a.ERR_FLAG > b.ERR_FLAG) {
          return -1;
        }
        return 0;
      });
      this.dataCheckStock.errorList = [];
      this.dataCheckStock.errorCount = 0;
      let countrow = 0;
      this.tableDataInitial.map((x, i) => {
        if (x.ERR_FLAG == "Y") {
          countrow += 1;
          this.dataCheckStock.errorList.push({
            record : i + 1,
            message : x.ERR_MSG
          });
        }
      });
      this.dataCheckStock.errorCount = countrow;
      this.dialogSelected.Close();
    //}
  }

  private UpdateTableInitial(data){
    let LocationInMain = [];
    let LocationNotInMain = [];
    let idx;
    const maxno = this.tableDataInitial.length;
    
    LocationInMain = data.filter(
      (selected) => this.tableDataInitial.some((main) => main.LOCATION_NO === selected.LOCATION_NO)
    );
    LocationNotInMain = data.filter(
      (selected) => !this.tableDataInitial.some((main) => main.LOCATION_NO === selected.LOCATION_NO)
    );

    LocationInMain.map((value) => {
      idx = this.tableDataInitial.findIndex((main) => main.LOCATION_NO === value.LOCATION_NO);
      if (idx !== -1){
        this.tableDataInitial.splice(idx, 1, {
          ROWNO: this.paramSelected.TYPE !== "STOCK_TAKING" ? idx + 1 : value.ROWNO,
          COMPANY_CODE: value.COMPANY_CODE,
          HEADER_ID: value.HEADER_ID,
          LOCATION_NO: value.LOCATION_NO,
          PART_NO: value.PART_NO,
          PART_NAME_EN: value.PART_NAME_EN,
          PART_NAME_TH: value.PART_NAME_TH,
          ROUND_MAX: value.ROUND_MAX,
          COUNT_QTY: value.COUNT_QTY || 0,
          ERR_FLAG: value.ERR_FLAG,
          ERR_MSG: value.ERR_MSG,
        });
      }
    });

    const list = LocationNotInMain.map((value, index) => ({
      ROWNO: this.paramSelected.TYPE !== "STOCK_TAKING" ? maxno + index + 1 : value.ROWNO,
      COMPANY_CODE: value.COMPANY_CODE,
      HEADER_ID: value.HEADER_ID,
      LOCATION_NO: value.LOCATION_NO,
      PART_NO: value.PART_NO,
      PART_NAME_EN: value.PART_NAME_EN,
      PART_NAME_TH: value.PART_NAME_TH,
      ROUND_MAX: value.ROUND_MAX,
      COUNT_QTY: value.COUNT_QTY || 0,
      ERR_FLAG: value.ERR_FLAG,
      ERR_MSG: value.ERR_MSG,
    }));

    return [...this.tableDataInitial, ...list];
  }

  //Upload File
  public OpenUpload(){
    this.paramUpload = {};
    this.paramUpload.errorList = [];
    this.paramUpload.errorCount = 0;
    this.tableDataUpload = [];
    this.fileName = "";
    this.dialogUpload.width="1350px";
    this.dialogUpload.height="725px";
    this.dialogUpload.title = "Upload Location";
    this.dialogUpload.OpenDialog()
  }

  public DownloadTemplate(){
    //this.global.GoToExport("PMS_RPT_WMS_SNWR049_UPLOAD_TEMPLATE", {}, true, "EXCELOPENXML")
    let link = "assets/templates/SNWR049_Upload_Template.xlsx";
    window.open(link, "_blank");
  }
  
  public OpenFileBrowser() {
    this.fileName = "";
    this.fileInput.nativeElement.value = '';
    this.fileInput.nativeElement.click();
  }

  public SelectFile(evt) {
    let Files: Array<File> = evt.target.files;
    if (Files.length > 0) {
      this.file = Files[0];
      this.fileName = this.file.name;
      this.PreView();
    }
  }

  public PreView() {
    if (!this.fileName) {
      this.modal.warning("Please Open File First...", this.viewref)
      return;
    }
    
    let formData = new FormData();
    formData.append('file', this.file);

    this.tableDataUpload = [];
    this.paramUpload.errorList = [];
    this.paramUpload.errorCount = 0;
    this.http.postFile("WH", `SNWR049_PreviewUploadExcel/${this.dataCheckStock.HEADER_ID.toString()}`, formData)
      .subscribe((result) => {
        this.tableDataUpload = result.set.Table;
        let countrow = 0;
        this.tableDataUpload.map((x,i) => {
          if(x.ERR_FLAG == 'Y'){
              countrow += 1;
              this.paramUpload.errorList.push({
                  record : x.SEQ,
                  message : x.ERR_MSG
              })
          } 
          this.paramUpload.errorCount = countrow;
        })
    }, (err) => {
      console.log("err", err);
      this.modal.error('Found an error, please contract support team.', this.viewref);
    })
  }

  public SaveUpload(){
    this.modal.confirm("Do you want to save change you have made?",this.viewref,() => ConfirmSave())

    let ConfirmSave = () => {
      this.tableDataInitial = this.UpdateTableInitial(this.tableDataUpload);
      this.tableDataInitial.sort((a,b) => {
        if (a.ERR_FLAG < b.ERR_FLAG) {
          return 1;
        }
        if (a.ERR_FLAG > b.ERR_FLAG) {
          return -1;
        }
        return 0;
      });
      this.dataCheckStock.errorList = [];
      this.dataCheckStock.errorCount = 0;
      let countrow = 0;
      this.tableDataInitial.map((x, i) => {
        if (x.ERR_FLAG == "Y") {
          countrow += 1;
          this.dataCheckStock.errorList.push({
            record : x.SEQ,
            message : x.ERR_MSG
          });
        }
      });
      this.dataCheckStock.errorCount = countrow;
      this.dialogUpload.Close();
    }
  }

  public OpenDialogError(data){
    this.error_list = data;
    this.dialogError.OpenDialog()
  }

  public FilterShelveChange(){
    if (this.paramShelveCheck.SHELVE_FILTER == 'GET_ALL') { 
      this.GetShelveAll(); 
    }
    else if (this.paramShelveCheck.SHELVE_FILTER == 'NOT_MATCH') { 
      this.GetShelveNotMatch(); 
    }
    else if (this.paramShelveCheck.SHELVE_FILTER == 'IS_MATCH') { 
      this.GetShelveIsMatch(); 
    }
    else if (this.paramShelveCheck.SHELVE_FILTER == 'NOT_COUNT') { 
      this.GetShelveNotCount(); 
    }
  }

  public UpdateSelectedItem(data){
    const filter = this.tableDataShelveCheck.filter(x => x.PART_NO === data.PART_NO);
    filter.forEach(row => {
      if (row.IS_ENABLED === 'True') {
        this.selection.toggle(row);
      }
    });
  }
  
  //Tab Confirm Shelve Stock
  private SortShelveCheckTable(){
    this.selection.clear();
    let partNo = "";
    let i = 0;
    this.tableDataShelveCheck.map(row => {
      if(partNo != row.PART_NO){
        partNo = row.PART_NO;
        row.ROWNO = ++i;
        row.IS_SHOW = true;
      }else{
        row.IS_SHOW = false;
      }

      if (this.selection.selected.indexOf(row) === -1 && row.IS_ENABLED === 'True') {
        this.selection.select(row);
      }
    });
  }

  public GetShelveAll(){
    const params = {
      HEADER_ID: this.dataCheckStock.HEADER_ID
    }
    this.http
      .post("WH", "SNWR049_GetShelveAll", params)
      .subscribe((res) => {
        this.tableDataShelveCheck = res.Table;
        this.SortShelveCheckTable();
      },
      (err) => {
        console.log("err", err);
        this.modal.warning(
          "Found an error, please contract support team",
          this.viewref
        );
      });
  }

  public GetShelveNotMatch(){
    const params = {
      HEADER_ID: this.dataCheckStock.HEADER_ID
    }
    this.http
      .post("WH", "SNWR049_GetShelveNotMatch", params)
      .subscribe((res) => {
        this.tableDataShelveCheck = res.Table;
        this.SortShelveCheckTable();
      },
      (err) => {
        console.log("err", err);
        this.modal.warning(
          "Found an error, please contract support team",
          this.viewref
        );
      });
  }

  public GetShelveIsMatch(){
    const params = {
      HEADER_ID: this.dataCheckStock.HEADER_ID
    }
    this.http
      .post("WH", "SNWR049_GetShelveIsMatch", params)
      .subscribe((res) => {
        this.tableDataShelveCheck = res.Table;
        this.SortShelveCheckTable();
      },
      (err) => {
        console.log("err", err);
        this.modal.warning(
          "Found an error, please contract support team",
          this.viewref
        );
      });
  }

  public GetShelveNotCount(){
    const params = {
      HEADER_ID: this.dataCheckStock.HEADER_ID
    }
    this.http
      .post("WH", "SNWR049_GetShelveNotCount", params)
      .subscribe((res) => {
        this.tableDataShelveCheck = res.Table;
        this.SortShelveCheckTable();
      },
      (err) => {
        console.log("err", err);
        this.modal.warning(
          "Found an error, please contract support team",
          this.viewref
        );
      });
  }

  public SaveShelveStock() {
    if (this.selection.selected.length > 0 && this.dataCheckStock.HEADER_ID) {
      this.modal.confirm(
        "Do you want to adjust shelve qty in these location to count qty?",
        this.viewref, () => {
          this.ConfirmShelveStock();
        }
      );
    } else {
      this.modal.warning(
        "Don't have data for save, please try again.",
        this.viewref
      );
    }
  }

  private ConfirmShelveStock(){
    const saveData = this.selection.selected;
    if (saveData.length > 0) {
      const params = {
        HEADER_ID: this.dataCheckStock.HEADER_ID,
        CONFIRM_SHELVE_LIST: this.selection.selected
      }
      this.http
        .post("WH", "SNWR049_SaveShelveStock", params)
        .subscribe(
          (res) => {
            if (res === "Done") {
              this.GetDataByID();
              this.FilterShelveChange();
              this.modal.info(
                "Transaction complete: applied and saved.",
                this.viewref,
                () => {}
              );
            }
          },
          (err) => {
            console.log("err", err);
            this.modal.warning(
              "Found an error, please contract support team",
              this.viewref
            );
          }
        );
    } else {
      this.modal.warning(`No change to save.`, this.viewref);
    }
  }

  /**Checkbox section */
  public isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.tableDataShelveCheck.filter(x => x.IS_ENABLED === 'True').length;
    return numSelected === numRows;
  }

  public Toggle() {
    if (this.isAllSelected()) {
      this.selection.clear();
    } else {
      this.tableDataShelveCheck.forEach(row => {
        if (this.selection.selected.indexOf(row) === -1 && row.IS_ENABLED === 'True') {
          this.selection.select(row);
        }
      });
    }
  }

  public IsStockChecked(data) {
    //  if (data.CHECKED == "True") {
    //    return 1; //Checked
    //  } else if (data.CHECKED == "False") {
    //    return 2; //Indeterminate
    //  } else {
    //    return 0; //Unchecked
    //  }
    return 0;
  }

  focusInput(rowIdx: number) {
    let inputEls = this.Inputs.toArray();
    inputEls[rowIdx].nativeElement.focus();

  }

  shiftFocusDown(rowIdx:number) {
    rowIdx = Math.min(rowIdx + 1, this.tableDataStockTaking.length - 1);
    let inputEls = this.Inputs.toArray();
    if(inputEls[rowIdx].nativeElement.disabled == true){
      this.shiftFocusDown(rowIdx)
    }else{
      this.focusInput(rowIdx);
    }
    
  }

  shiftFocusUp(rowIdx:number) {
    rowIdx = Math.max(0, rowIdx - 1);
    let inputEls = this.Inputs.toArray();
    if(inputEls[rowIdx].nativeElement.disabled == true){
      this.shiftFocusUp(rowIdx)
    }else{
      this.focusInput(rowIdx);
    }
    
  }

}
