import {
  Component,
  EventEmitter,
  OnInit,
  Output,
  ViewChild,
  ViewContainerRef,
} from "@angular/core";
import { DialogTemplateComponent } from "src/app/components/shared/dialog-template/dialog-template.component";
import { Globals } from "src/app/core/global";
import { HttpService } from "src/app/core/http.service";
import { ModalService } from "src/app/core/modal.service";

@Component({
  selector: "SNWR050-list",
  templateUrl: "SNWR050-list.component.html",
  styleUrls: ["../SNWR050.component.css"],
})
export class SNWR050ListComponent implements OnInit {
  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewRef: ViewContainerRef,
    private global: Globals
  ) {}

  public filter: any = {};
  public pickingList: any[] = [];
  public pickingListFrom: string;
  public pickingListTo: string;
  public instructionNo: string;
  public configFlag : string = "";
  @Output() onAddPickingList: EventEmitter<any> = new EventEmitter();
  @ViewChild("printDialog") printDialog: DialogTemplateComponent;

  ngOnInit() {
    this.filter.type = "KITS";
    this.GetConfigFlag();
  }

  private GetConfigFlag(){
    this.http.get("wPMS", "GetConfigFlag", "SNWR050_PICKING_LIST")
    .subscribe(res =>{
      this.configFlag = res.Table[0].CONFIG_VALUE
    })
  }

  public lookupPickListNoConfig: any = {
    ColName: "PICKING_LIST_NO",
    PlaceholderText: "Select Picking List No.",
    SourceController: "WH",
    SourceMethodName: "SNWR050_GetPickListNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.filter,
    },
    UpperCase: true,
  };

  public SetSelectedPickListNo(values: any) {
    this.filter.PICKING_LIST_NO = values.PICKING_LIST_NO;
  }

  public Search() {
    
    if(!this.filter.PICKING_LIST_NO){
      this.modal.warning("Please input Picking List No.", this.viewRef);
      return
    }

    this.pickingList = [];
    this.http.post("WH", "SNWR050_GetPickingList", this.filter).subscribe(
      (res) => {
        this.pickingList = res.Table;
      },
      (err) => {
        console.log("err", err);
        this.modal.error(
          "Found an error, please contact support team",
          this.viewRef
        );
      }
    );
  }

  public PrintPickingList() {
    this.printDialog.OpenDialog();
  }

  public Generate() {
    this.modal.confirm(
      "Are you sure to generate picking list.",
      this.viewRef,
      () => {
        const params = {
          indentType: this.filter.type,
          zone: this.filter.zone,
          kitFlag: this.filter.type == 'KITS'? 'Y' :'N'
        }
        this.http
          .post("WH", "SNWR050_GeneratePicking", params)
          .subscribe(
            (res) => {
              if (res.result === "DONE") {
                if (
                  res.pickingListFrom !== "null" &&
                  res.pickingListTo !== "null"
                ) {
                  this.pickingListFrom = res.pickingListFrom;
                  this.pickingListTo = res.pickingListTo;
                  this.modal.info(
                    `Generate picking list successfully.<br/><br/>Picking list no.<br/>${this.pickingListFrom} - ${this.pickingListTo}`,
                    this.viewRef,
                    () => {
                      setTimeout(() => this.PrintPickingList(), 500);
                    },
                    {
                      height: "20rem",
                    }
                  );
                } else {
                  this.modal.info(`No Picking list generated.`, this.viewRef);
                }
              }
            },
            (err) => {
              console.log("err", err);
              this.modal.error(
                "Found an error, please contact support team",
                this.viewRef
              );
            }
          );
      },
      () => {}
    );
  }

  public Add() {
    this.onAddPickingList.emit();
  }

  public Print() {

    if (this.filter.showQR) {

      this.global.GoToReport("PMS_RPT_WMS_SNWR050_PICKING_WithQR", {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_PICKING_LIST_FROM: this.pickingListFrom,
        P_PICKING_LIST_TO: this.pickingListTo,
        P_INSTRUCTION_NO: this.instructionNo || "",
      });
    } else {

      console.log(this.pickingListFrom, "pickingListFrom")
      console.log(this.pickingListTo, "pickingListTo")
      this.global.GoToReport("PMS_RPT_WMS_SNWR050_PICKING", {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_PICKING_LIST_FROM: this.pickingListFrom,
        P_PICKING_LIST_TO: this.pickingListTo,
        P_INSTRUCTION_NO: this.instructionNo || "",
      });
    }
    
    setTimeout(() => {
      this.printDialog.Close();
    }, 5000);
  
  }

  public PrintSingle(row: any) {

    if (this.filter.showQR) {
      this.global.GoToReport("PMS_RPT_WMS_SNWR050_PICKING_WithQR", {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_PICKING_LIST_FROM: row.PICKING_LIST_NO,
        P_PICKING_LIST_TO: row.PICKING_LIST_NO,
        P_INSTRUCTION_NO: "",
      });
    } else {
      this.global.GoToReport("PMS_RPT_WMS_SNWR050_PICKING", {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_PICKING_LIST_FROM: row.PICKING_LIST_NO,
        P_PICKING_LIST_TO: row.PICKING_LIST_NO,
        P_INSTRUCTION_NO: "",
      });
    }
   
  }
}
