import { Component, OnInit, ViewChild, ViewContainerRef, ElementRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from 'src/app/core/global';
import { AutoCompleteQueryComponent } from 'src/app/components/shared/auto-complete-query/auto-complete-query.component';
import * as moment from 'moment';
import { SelectionModel } from '@angular/cdk/collections';

@Component({
  selector: 'SNWR050',
  templateUrl: './SNWR050.component.html',
  styleUrls: ['../warehouse.component.css', 'SNWR050.component.css']
})

export class SNWR050Component implements OnInit {
  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewRef: ViewContainerRef,
    private global: Globals
  ) { }

  @ViewChild("dialog", { static: true }) dialog: any;
  @ViewChild("autoCompleteVendor", { static: true }) autoCompleteVendor: AutoCompleteQueryComponent;

  public dataIsSelected: any = [];

  public params: any = {};
  public ShowList: boolean = true;
  public dataList: any[] = [];
  public tempData: any = {};
  public iSCancel: boolean = false;

  public rowSave: any = [];
  public partNumber: string;

  public tblFooter: any = [
    {
      fieldName: "ACCEPT_PART_NO",
      value: "Total",
      show: true
    },
    {
      fieldName: "ORDER_QTY",
      show: true
    },
    {
      fieldName: "QTY",

      show: true
    },
    {
      fieldName: "AMOUNT",

      show: true
    }]

  public selection = new SelectionModel<any>(true, []);


  public CustomerSearchConfig: any = {
    ColName: "LOOKUP_CUST",
    PlaceholderText: "Select Customer",
    SourceController: "WH",
    SourceMethodName: "SNWR005_GetSearchCust",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  };



  public BranchLookupConfig: any = {
    ColName: "LOOKUP_BRANCH_NAME",
    PlaceholderText: "Select Branch",
    SourceController: "WH",
    SourceMethodName: "SNWR005_GetBranchCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  };



  ngOnInit() {
    this.params.DOCUMENT_DATE_FROM = moment();
    this.params.DOCUMENT_DATE_TO = moment();

    this.params.ORDER_TYPE = 'EO';
  }

  public OrderTypeChange(selection) {
    this.CustomerSearchConfig.SourceParams.DATA.ORDER_TYPE = selection.value;
  }

  public SetCustCode(value: any) {
    this.params.CUSTOMER_CODE = value.CUSTOMER_CODE;
    this.params.CUSTOMER_NAME = value.CUSTOMER_NAME;
    this.params.BRANCH_CODE = value.BRANCH_CODE;
    this.params.BRANCH_NAME = value.BRANCH_NAME;
  }


  public SetBranchLookup(branch) {
    this.params.BRANCH_CODE = branch.BRANCH_CODE;
    this.params.BRANCH_NAME = branch.BRANCH_NAME_TH;

  }

  public Search() {
    this.dataIsSelected = [];
    this.selection.clear();

    this.http.post("WH", "SNWR050_GetPicking", this.params)
      .subscribe(result => {
        this.dataList = result.Table;
      }, (err) => {
        console.log(err, 'err')
        this.modal.warning("Found an error, please contact support team", this.viewRef);
      });
  }


  QuantityChange(data) {
    if (data.QTY > data.ACCEPT_QTY) {
      data.QTY = data.ACCEPT_QTY
    }
  }

  SetNewPartNo(part: any, data: any) {
    this.tempData.Part = part;
    data.ACCEPT_PART_NO = part.PART_NO;
  }


  public TotalQty() {
    return this.dataList.reduce((a, b) => a + (b.QTY || 0), 0);
  }

  public TotalAmount() {
    return this.dataList.reduce((a, b) => a + ((b.QTY || 0) * (b.UNIT_PRICE_B || 0)), 0);
  }

  public TotalItem() {
    return this.dataList.reduce(
      (a, b) => a + (((b.QTY || 0) / b.RECEIVE_PACKAGE) || 0),
      0
    );
  }

  public AddPickingList() {
    this.params = {};
    this.ShowList = false;
    this.dataList = [];
    this.tempData = {};
    this.iSCancel = false;
    this.rowSave = [];
    this.partNumber;
  }

  public BackToGrid() {
    this.Search();
    this.iSCancel = false;
    this.ShowList = true;
  }

  public isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.dataList.length;
    return numSelected === numRows;
  }

  public Toggle() {
    if (this.isAllSelected()) {
      this.selection.clear()
      this.dataList.map(x => {
        this.dataIsSelected = [];
      })
    } else {
      this.dataList.forEach(row => this.selection.select(row));
      this.dataIsSelected = [];
      this.dataList.map(x => {
        this.dataIsSelected.push(x);
      })
    }

  }

  public CheckboxChange(event, data) {
    if (event.checked) {

      this.dataIsSelected.push(data);
    }
    else {
      this.dataIsSelected.splice(this.dataIsSelected.indexOf(data), 1);
    }
  }

  public ProcessPickingNo() {
    if (this.dataIsSelected.length > 12) {

      this.modal.warning("Cannot process picking more than 12 items", this.viewRef);

    } else if (this.dataIsSelected.length > 0) {

      this.modal.confirm("Are you sure to process picking list?", this.viewRef
        , () => {

          var lSeqList = '0';
          this.dataIsSelected.forEach((row) => {
            lSeqList = lSeqList + ',' + row.SEQ;
          });
          this.http.post('WH', 'SNWR005_PrintPicking', this.dataIsSelected)
            .subscribe(res => {
              if (res.STATUS == 'DONE') {
                this.modal.info('Transaction complete: applied and saved. Picking list no. ' + res.MESSAGE, this.viewRef);

                let pickingList = res.MESSAGE;
                this.global.GoToReport("PMS_RPT_WMS_SNWR005_PICKING",
                  {
                    P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
                    P_PICKING_LIST_FROM: pickingList,
                    P_PICKING_LIST_TO: pickingList,
                  }
                );
                this.Search();
              }
              else {
                this.modal.warning('No change to save. Something went wrong.', this.viewRef);
              }
            }, (err => {
              console.log(err)
              this.modal.error('Found an error, please contact support team', this.viewRef);
            }))

        }, () => { })
    } else {
      this.modal.warning("Please select data", this.viewRef);
    }
  }

}

