import {
  Component,
  OnInit,
  ViewChild,
  ViewContainerRef,
  ElementRef,
} from "@angular/core";
import { HttpService } from "src/app/core/http.service";
import { ModalService } from "src/app/core/modal.service";
import { Globals } from "src/app/core/global";
import { SelectionModel } from "@angular/cdk/collections";
import { Subject } from "rxjs";
import { debounceTime, map, take } from "rxjs/operators";

@Component({
  selector: "SNWR051",
  templateUrl: "./SNWR051.component.html",
  styleUrls: ["../warehouse.component.css"],
})
export class SNWR051Component implements OnInit {
  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewRef: ViewContainerRef,
    private el: ElementRef,
    private global: Globals
  ) {}

  @ViewChild("dialog", { static: true }) dialog: any;
  @ViewChild("pickReportDialog") pickReportDialog: any;

  public params: any = {};
  public paramsDetail: any = {};
  public dataHeader: any = [];
  public dataDetail: any = [];
  public selection = new SelectionModel<any>(true, []);
  public ShowList: any = true;
  public PickQtyChangeSubject: Subject<any> = new Subject<any>();
  public ReportQtyChangeSubject: Subject<any> = new Subject<any>();
  public reportPickData: any = {};
  public isConfirmable: boolean = false;

  ngOnInit() {
    this.isConfirmable = false;

    this.PickQtyChangeSubject.pipe(
      debounceTime(300),
      map((v) => v)
    ).subscribe((data) => {
      this.CheckPickAvailability(data);
    });

    this.ReportQtyChangeSubject.pipe(
      debounceTime(300),
      map((v) => v)
    ).subscribe((data) => {
      this.CheckReportAvailability(data);
    });
  }

  public VendorSearchConfig: any = {
    ColName: "LOOKUP_VENDOR_CODE",
    PlaceholderText: "Select Vendor Code",
    SourceController: "WH",
    SourceMethodName: "SNWR051_GetVendorCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params,
    },
    UpperCase: true,
  };

  public SetVendorCode(value: any) {
    this.params.VENDOR_CODE = value.VENDOR_CODE;
    this.params.VENDOR_NAME = value.VENDOR_NAME;
  }

  public lookupPickListNoConfig: any = {
    ColName: "PICKING_LIST_NO",
    PlaceholderText: "Select Picking List No.",
    SourceController: "WH",
    SourceMethodName: "SNWR051_GetPickListNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params,
    },
    UpperCase: true,
  };

  public SetSelectedPickListNo(values: any) {
    this.params.PICKING_LIST_NO = values.PICKING_LIST_NO;
  }

  public Search() {
    this.dataHeader = [];
    this.http.post("WH", "SNWR051_GetPickingHeader", this.params).subscribe(
      (result) => {
        this.dataHeader = result.Table;
      },
      (err) => {
        console.log("err", err);
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewRef
        );
      }
    );
  }

  public ViewDetail(pData) {
    this.dataHeader = [];
    this.dataDetail = [];
    this.selection.clear();
    this.ShowList = false;
    this.http.post("WH", "SNWR051_GetPickingDetail", pData).subscribe(
      (res) => {
        this.dataHeader = res.Table[0];
        this.dataDetail = res.Table1;
        this.paramsDetail.PICKING_LIST_NO = this.dataDetail[0].PICKING_LIST_NO;
        this.paramsDetail.VENDOR_CODE = this.dataDetail[0].VENDOR_CODE;
        this.paramsDetail.VENDOR_NAME = this.dataDetail[0].VENDOR_NAME;
      },
      (err) => {
        console.log("err", err);
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewRef
        );
      }
    );
  }

  public BackToGrid() {
    this.ShowList = true;
    this.selection.clear();
    this.Search();
  }

  public isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.dataDetail.length;
    return numSelected === numRows;
  }

  public ConfirmSave() {
    const pickItems = this.dataDetail.filter((item) => (item.QTY || 0) > 0);
    if (pickItems.length > 0) {
      this.modal.confirm(
        "Are you sure to confirm pick? " + "[Selected : " + pickItems.length + " Items]",
        this.viewRef,
        () => {
          this.http.post("WH", "SNWR051_Save", pickItems).subscribe(
            (res) => {
              if (res.Result == "Done") {
                this.modal.info(
                  "The data has been confirmed to pick",
                  this.viewRef
                );
                this.ViewDetail(this.paramsDetail);
              } else {
                this.modal.error(res.Message, this.viewRef);
              }
            },
            (err) => {
              console.log("err", err);
              this.modal.error(err.message, this.viewRef);
            }
          );
        },
        () => {}
      );
    } else {
      this.modal.error("No data to process.", this.viewRef);
    }
  }

  public CheckPickAvailability(data: any) {
    const pickedQty = data.PICK_QTY + data.PICK_QTY_BAL;
    if (data.ACCEPT_QTY < pickedQty + data.QTY) {
      this.modal.warning("Pick over Qty.", this.viewRef);
      data.QTY = 0;
    }
    this.isConfirmable = !!this.dataDetail.find((item) => (item.QTY || 0) > 0);
  }

  public OpenReportPickProblemDialog(data: any) {
    this.reportPickData = data;
    this.reportPickData.MISSING_QTY = this.reportPickData.PICK_QTY_BAL || 0;
    this.pickReportDialog.OpenDialog();
  }

  public CheckReportAvailability(data: any) {
    const pickedQty = data.PICK_QTY + (data.QTY || 0);
    const remainQty = data.ACCEPT_QTY - pickedQty;
    if (data.MISSING_QTY > remainQty) {
      this.modal.warning("Report over available Qty", this.viewRef);
      data.MISSING_QTY = 0;
    }
  }

  public SaveReportProblem(data: any) {
    this.modal.confirm(
      "Are you sure you want to report problem for this item?",
      this.viewRef,
      () => {
        this.http.post("WH", "SNWR051_SaveReportProblemPart", data).subscribe(
          (res) => {
            if (res.Result == "Done") {
              this.modal.info("Report problem parts completed.", this.viewRef);
              data.PICK_QTY_BAL = data.MISSING_QTY;
              data.AVAILABLE_PICK_QTY = data.AVAILABLE_PICK_QTY - data.MISSING_QTY;
              this.ViewDetail(this.paramsDetail);
              this.pickReportDialog.Close();
            } else {
              this.modal.error(res.Message, this.viewRef);
            }
          },
          (err) => {
            console.log(err, "err");
            this.modal.error(
              "Found an error, please contact support team",
              this.viewRef
            );
          }
        );
      },
      () => {}
    );
  }
}
