import {
  Component,
  OnInit,
  ViewChild,
  ViewContainerRef,
  ElementRef,
} from "@angular/core";
import { HttpService } from "src/app/core/http.service";
import { ModalService } from "src/app/core/modal.service";
import { Globals } from "src/app/core/global";
import * as moment from "moment";
import { SelectionModel } from "@angular/cdk/collections";
import { Subject } from "rxjs";
import { debounceTime, map, take } from "rxjs/operators";

@Component({
  selector: "SNWR059",
  templateUrl: "./SNWR059.component.html",
  styleUrls: ["../warehouse.component.css"],
})
export class SNWR059Component implements OnInit {
  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewRef: ViewContainerRef,
    private el: ElementRef,
    private global: Globals
  ) {}

  @ViewChild("dialog", { static: true }) dialog: any;

  public ShowList: any = true;
  public params: any = {};
  public paramsDetail: any = {};
  public dataHeader: any = [];
  public dataDetail: any = [];
  
  public lookupPONoConfig: any = {
    ColName: "LOOKUP_PO_NO",
    PlaceholderText: "Select PO No.",
    SourceController: "WH",
    SourceMethodName: "SNWR059_GetPONo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params,
    },
    UpperCase: true,
  };

  public SetSelectedPONo(values: any) {
    if(values){
      this.params.PO_NO = values.PO_NO;
      this.params.PO_DATE = values.PO_DATE;
      this.Search();
    } else {
      this.params.PO_NO = null;
      this.params.PO_DATE = null;
      this.Search();
    }
  }

  public lookupVendorCodeConfig: any = {
    ColName: "LOOKUP_VENDOR_CODE",
    PlaceholderText: "Select Vendor Code",
    SourceController: "WH",
    SourceMethodName: "SNWR059_GetVendorCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params,
    },
    UpperCase: true,
  };

  public SetVendorCode(value: any) {
    if(value){
      this.params.VENDOR_CODE = value.VENDOR_CODE;
      this.params.VENDOR_NAME = value.VENDOR_NAME;
      this.Search();
    } else {
      this.params.VENDOR_CODE = null;
      this.params.VENDOR_NAME = null;
      this.Search();
    }
  }
  
  public lookupTFDocNoConfig: any = {
    ColName: "LOOKUP_TF_DOC_NO",
    PlaceholderText: "Select TF Document No.",
    SourceController: "WH",
    SourceMethodName: "SNWR059_GetTFDocNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.paramsDetail,
    },
    UpperCase: true,
  };

  public SetSelectedTFDocNo(data, values: any) {
    if(values){
      if(values.ACCEPT_PART_NO){
      const findTF = this.dataDetail.find((x) => x.NEW_TF_DOCUMENT_NO
                                              && x.NEW_TF_DOCUMENT_NO == values.TF_DOCUMENT_NO 
                                              && x.NEW_TF_DOCUMENT_NO != data.NEW_TF_DOCUMENT_NO);
      if (findTF){
        this.modal.warning("New TF is already in used.", this.viewRef, ()=>{}, {width:"36.5rem"});
        return;
      }
      else if(values.ACCEPT_PART_NO != data.ACCEPT_PART_NO){
        this.modal.warning("New TF Part no is not match with Current TF Part no.", this.viewRef, ()=>{}, {width:"36.5rem"});
        return;
      } else if (values.TF_QTY > data.ITEM_QTY) {
        this.modal.warning("New TF qty less than Current TF qty", this.viewRef, ()=>{}, {width:"36.5rem"});
        return;
      } else {
        data.NEW_TF_DOCUMENT_NO = values.TF_DOCUMENT_NO;
        data.NEW_TF_DOCUMENT_DATE = values.TF_DOCUMENT_DATE;
        this.paramsDetail.FLAG_SAVE = this.dataDetail.some((x) => x.NEW_TF_DOCUMENT_NO);
      }
      }else{
        data.NEW_TF_DOCUMENT_NO = values.TF_DOCUMENT_NO;
        data.NEW_TF_DOCUMENT_DATE = values.TF_DOCUMENT_DATE;
        this.paramsDetail.FLAG_SAVE = this.dataDetail.some((x) => x.NEW_TF_DOCUMENT_NO);
      }
    } else {
      data.NEW_TF_DOCUMENT_NO = null;
      data.NEW_TF_DOCUMENT_DATE = null;
      this.paramsDetail.FLAG_SAVE = this.dataDetail.some((x) => x.NEW_TF_DOCUMENT_NO);
    }
  }

  ngOnInit() {
    this.params.TYPE_DATE = 'LAST2MONTH'
    this.http.post('WH', 'GetDateByFormat', this.params)
      .subscribe(res => {
        this.params.START_DATE = res.Table[0].TARGETMONTH;
        this.params.END_DATE = moment();
        this.Search();
      });
  }

  public Search() {
    if(!this.params.START_DATE || !this.params.END_DATE){
      this.modal.warning("กรุณาใส่วันที่เพื่อกำหนดช่วงข้อมูล", this.viewRef);
      return;
    }

    this.http.post("WH", "SNWR059_GetPONoHeader", this.params).subscribe(
      (result) => {
        this.dataHeader = result.Table;
      },
      (err) => {
        console.log(err, "err");
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewRef
        );
      }
    );
  }

  public ViewDetail(pData) {
    this.dataDetail = [];
    this.ShowList = false;
    this.http.post("WH", "SNWR059_GetPONoDetail", pData).subscribe(
      (res) => {
        this.dataDetail = res.Table;
        this.paramsDetail.PO_NO = pData.PO_NO;
        this.paramsDetail.PO_DATE = pData.PO_DATE;
        this.paramsDetail.VENDOR = pData.VENDOR;
      },
      (err) => {
        console.log(err, "err");
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewRef
        );
      }
    );
  }

  public BackToGrid() {
    this.ShowList = true;
    this.Search();
  }

  public ConfirmSave() {
    const newTFDocNo = this.dataDetail.filter((item) => item.NEW_TF_DOCUMENT_NO);
    if (newTFDocNo.length > 0) {
      this.modal.confirm("Are you sure to confirm new TF?<br>" + "[New TF Selected : " + newTFDocNo.length + " Items]",
        this.viewRef,
        () => {
          const params = {
            DETAIL : newTFDocNo
          }
          this.http.post("WH", "SNWR059_ConfirmNewTF", params).subscribe(
            (res) => {
              if (res.STATUS == "DONE") {
                this.modal.info(
                  "The data has been confirmed.",
                  this.viewRef
                );
                this.ViewDetail(this.paramsDetail);
              } else {
                this.modal.error(res.MESSAGE, this.viewRef);
              }
            },
            (err) => {
              console.log(err, 'err');
              this.modal.error(err.MESSEGE, this.viewRef);
            }
          );
        },
        () => {},
        {width: "36.5rem"}
      );
    } else {
      this.modal.error("No New TF Doc No to process.", this.viewRef);
    }
  }

  public ReportTFDocNoHeader() {
    this.global.GoToExport("PMS_RPT_WMS_SNWR059_GET_TF_HEADER", {
      P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      P_PO_NO: this.params.PO_NO,
      P_VENDOR_CODE: this.params.VENDOR_CODE,
      P_START_DATE: moment(this.params.START_DATE).format("DD-MMM-YYYY"),
      P_END_DATE: moment(this.params.END_DATE).format("DD-MMM-YYYY"),
    }, true, "EXCELOPENXML"
    );
  }

  public ReportTFDocNoDetail() {
    this.global.GoToExport("PMS_RPT_WMS_SNWR059_GET_TF_DETAIL", {
      P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      P_PO_NO: this.params.PO_NO,
    }, true, "EXCELOPENXML"
    );
  }
  
}
