import {
    Component,
    OnInit,
    ViewChild,
    ViewContainerRef,
    ElementRef,
  } from "@angular/core";
  import { HttpService } from "src/app/core/http.service";
  import { ModalService } from "src/app/core/modal.service";
  import { Globals } from "src/app/core/global";
  import * as moment from "moment";
import { SelectionModel } from "@angular/cdk/collections";
@Component({
    selector: "SNWR060",
    templateUrl: "./SNWR060.component.html",
    styleUrls: ["./SNWR060.component.css"]
})
export class SNWR060Component implements OnInit {
  constructor(
      private http: HttpService,
      private modal: ModalService,
      private viewRef: ViewContainerRef,
      private el: ElementRef,
      private global: Globals
    )
    { }

  @ViewChild("reportReverseTFDialog") reportReverseTFDialog: any;

  public dataTFList: any = [];
  public dataSPList: any = [];
  public dataTFListDetail: any = [];
  public params: any = {};
  public IsSaved : boolean = false;
  public reportReverseTFData: any = {};

  public lookupTFDocNoConfig: any = {
    ColName: "TF_DOCUMENT_NO",
    PlaceholderText: "Select TF Doc No.",
    SourceController: "WH",
    SourceMethodName: "SNWR060_GetTFDocNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params,
    },
    UpperCase: true,
  };

  public lookupSPDocNoConfig: any = {
    ColName: "SP_DOCUMENT_NO",
    PlaceholderText: "Select SP Doc No.",
    SourceController: "WH",
    SourceMethodName: "SNWR060_GetSPDocNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params,
    },
    UpperCase: true,
  };

  public ConfigReason: any = {
    ColName: "LOOKUP_REASON",
    PlaceholderText: "Select Reason Code",
    SourceController: "WH",
    SourceMethodName: "SNWR060_GetReason",
    NoOfShowRecords: 30,
    MinLengthSearch: 0,
    UpperCase: false
  }

  public lookupPartNoConfig: any = {
    ColName: "LOOKUP_PART_NO",
    PlaceholderText: "Select Part No.",
    SourceController: "WH",
    SourceMethodName: "SNWR060_GetPartNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params,
    },
    UpperCase: true,
  };

  public ConfigInstruction: any = {
    ColName: "INSTRUCTION_NO",
    PlaceholderText: "Select Instruction No",
    SourceController: "WH",
    SourceMethodName: "SNWR060_GetInstruction",
    NoOfShowRecords: 30,
    MinLengthSearch: 0,
    UpperCase: false
  }

  public ConfigInstructionTF: any = {
    ColName: "INSTRUCTION_NO",
    PlaceholderText: "Select Instruction No",
    SourceController: "WH",
    SourceMethodName: "SNWR060_GetInstructionTF",
    NoOfShowRecords: 30,
    MinLengthSearch: 0,
    UpperCase: false
  }
  
  public selectionTF = new SelectionModel<any>(true, []);

  public isAllSelectedTF() {
    const numSelected = this.selectionTF.selected.length;
    const numRows = this.dataTFList.length;
    return numSelected === numRows;
  }

  public ToggleTF() {
    this.isAllSelectedTF() ?
      this.selectionTF.clear() :
      this.dataTFList.forEach(row => this.selectionTF.select(row));
  }
  ngOnInit() { 
      // this.params.TYPE_DATE = 'LAST1MONTH'
      // this.http.post('WH', 'GetDateByFormat', this.params)
      //   .subscribe(res => {
      //     this.params.START_DATE = res.Table[0].LAST1MONTH;
      //     this.params.END_DATE = moment();
      //     this.Search();
      //   });
      
  }

  public SetSelectedPartNo(value: any) {
    if(value){
      this.params.PART_NO = value.PART_NO;
      this.params.PART_NAME = value.PART_NAME;
      //this.Search();
    } else {
      this.params.PART_NO = null;
      this.params.PART_NAME = null;
      //this.Search();
    }
  }

  public SetSelectedTFDocNo(values: any) {
    if(values){
      this.params.TF_DOCUMENT_NO = values.TF_DOCUMENT_NO;
    } else {
      this.params.TF_DOCUMENT_NO = null;
    }
  }

  public TabChange(event){
    this.params = {}
    this.dataTFList = []
    this.dataSPList = []
    this.IsSaved = false
  }

  public Search() {
    if(!this.params.PART_NO && !this.params.TF_DOCUMENT_NO && !this.params.INSTRUCTION_NO){
      this.modal.warning("Please select one criteria.", this.viewRef);
      return;
    }
    this.http.post("WH", "SNWR060_GetTFList", this.params).subscribe(
      (result) => {
        this.selectionTF.clear();
        this.dataTFList = result.Table;
        this.params.RT_NO = ''
        this.params.REASON_CODE = ''
        this.IsSaved = false
      },
      (err) => {
        console.log(err, "err");
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewRef
        );
      }
    );
  }

  public CheckQty(data: any) {
    if(data.REVERSE_QTY > data.TF_QTY){
      data.REVERSE_QTY = data.TF_QTY;
      return;
    }
  }

  public Save(){
    // if(!this.params.REASON_CODE){
    //   this.modal.warning("Please select Reason Code.", this.viewRef);
    //   return;
    // }
    const data = this.selectionTF.selected.filter(x => x.REVERSE_QTY > 0)

    if(data.length <= 0){
      this.modal.warning("No data to save.", this.viewRef);
      return;
    }
    this.modal.confirm("Are you sure you want to save?",this.viewRef,() => confirm());

    let confirm = () => {
      const params = {
        DETAIL : data,
        REASON_CODE :this.params.REASON_CODE
      }
      this.http.post("WH", "SNWR060_Save", params).subscribe(
        (res) => {
          if (res.status == "Done") {
            this.modal.info("Save completed.", this.viewRef);
            this.IsSaved = true
            this.params.RT_NO = res.docNO
          } else {
            this.modal.error("Found an error, please contact support team", this.viewRef);
          }
        },
        (err) => {
          console.log(err, "err");
          this.modal.error(
            "Found an error, please contact support team",
            this.viewRef
          );
        }
      );
    }
  }

  public OpenReportReverseTFDialog(data: any) {
    if(data.REVERSE_QTY > data.TF_QTY){
      this.modal.warning("Reverse qty over TF doc qty.", this.viewRef);
      data.REVERSE_QTY = 0;
      return;
    }
    this.reportReverseTFData = data;
    this.reportReverseTFData.REVERSE_QTY_TARGET = data.REVERSE_QTY;
    this.reportReverseTFData.REVERSE_QTY_CURRENT = 0;
    this.reportReverseTFDialog.title = "Report Reverse TF : " + data.TF_DOC_NO;
    this.reportReverseTFDialog.width = "75vw";
    this.reportReverseTFDialog.height = "60vh";
    this.reportReverseTFDialog.OpenDialog();
    this.http.post("WH", "SNWR060_GetTFListDetail", data).subscribe(
      (result) => {
        this.dataTFListDetail = result.Table;
        data.REVERSE_QTY = 0;
      },
      (err) => {
        console.log(err, "err");
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewRef
        );
      }
    );
  }

  public ReportReverseTFQtyChanged(data: any){
    let currentQty = 0;
    this.dataTFListDetail.map((x) => {
      currentQty = currentQty + x.REVERSE_QTY;
    });
    this.reportReverseTFData.REVERSE_QTY_CURRENT = currentQty;

    if(this.reportReverseTFData.REVERSE_QTY_CURRENT > this.reportReverseTFData.REVERSE_QTY_TARGET){
      this.modal.warning("Selected reverse qty over Target reverse qty.", this.viewRef);
      data.REVERSE_QTY = 0;
      return;
    }
  }

  public SaveReportProblem() {
    this.modal.confirm(
      "Are you sure you want to report reverse TF for selected item?",
      this.viewRef,
      () => {
        const params = {
          HEADER: this.reportReverseTFData,
          DETAIL: this.dataTFListDetail,
        }
        this.http.post("WH", "SNWR060_SaveReportReverseTF", params).subscribe(
          (res) => {
            if (res.Result == "Done") {
              this.modal.info("Report Reverse TF completed.", this.viewRef);
              this.Search();
              this.reportReverseTFDialog.Close();
            } else {
              this.modal.error(res.Message, this.viewRef);
            }
          },
          (err) => {
            console.log(err, "err");
            this.modal.error(
              "Found an error, please contact support team",
              this.viewRef
            );
          }
        );
      },
      () => {}
    );
  }

  GetReason(Rea) {
    this.params.REASON_CODE = Rea.REASON_CODE;
  }

  public DeleteRow(data: any) {
    this.dataTFList.splice(this.dataTFList.indexOf(data), 1);
    this.dataTFList = this.dataTFList.slice();
  }  

  ////////////////////////////// SP ///////////////////////////////////////////////////
  public selectionSP = new SelectionModel<any>(true, []);

  public isAllSelectedSP() {
    const numSelected = this.selectionSP.selected.length;
    const numRows = this.dataSPList.length;
    return numSelected === numRows;
  }

  public Toggle() {
    this.isAllSelectedSP() ?
      this.selectionSP.clear() :
      this.dataSPList.forEach(row => this.selectionSP.select(row));
  }

  public SetSelectedSPDocNo(values: any) {
    if(values){
      this.params.SP_DOCUMENT_NO = values.SP_DOCUMENT_NO;
      //this.SearchSP();
    } else {
      this.params.SP_DOCUMENT_NO = null;
      //this.SearchSP();
    }
  }
  
  public SetSelectedInstruction(value: any) {
    if(value){
      this.params.INSTRUCTION_NO = value.INSTRUCTION_NO;
    } else {
      this.params.INSTRUCTION_NO = null;

    }
  }

  public SearchSP() {
    if(!this.params.PART_NO && !this.params.SP_DOCUMENT_NO && !this.params.INSTRUCTION_NO){
      this.modal.warning("Please select one criteria.", this.viewRef);
      return;
    }
    this.http.post("WH", "SNWR060_GetSPList", this.params).subscribe(
      (result) => {
        this.selectionSP.clear();
        this.dataSPList = result.Table;
        this.params.RS_NO = ''
        this.params.REASON_CODE = ''
        this.IsSaved = false
      },
      (err) => {
        console.log(err, "err");
        this.modal.warning(
          "Found an error, please contact support team",
          this.viewRef
        );
      }
    );
  }

  public CheckQtySP(data: any) {
    if(data.REVERSE_QTY > data.SP_QTY){
      data.REVERSE_QTY = data.SP_QTY;
      return;
    }
  }

  public SaveSP(){
    // if(!this.params.REASON_CODE){
    //   this.modal.warning("Please select Reason Code.", this.viewRef);
    //   return;
    // }
    if(this.selectionSP.selected.length <= 0){
      this.modal.warning("No data to save.", this.viewRef);
      return;
    }
    this.modal.confirm("Are you sure you want to save?",this.viewRef,() => confirm());

    let confirm = () => {
      const params = {
        DETAIL : this.selectionSP.selected,
        REASON_CODE :this.params.REASON_CODE
      }
      this.http.post("WH", "SNWR060_SaveSP", params).subscribe(
        (res) => {
          if (res.status == "Done") {
            this.modal.info("Save completed.", this.viewRef);
            this.IsSaved = true
            this.params.RS_NO = res.docNO
          } else {
            this.modal.error("Found an error, please contact support team", this.viewRef);
          }
        },
        (err) => {
          console.log(err, "err");
          this.modal.error(
            "Found an error, please contact support team",
            this.viewRef
          );
        }
      );
    }
  }

}